Documentation
¶
Index ¶
- func DataGoogleCloudAssetResourcesSearchAll_IsConstruct(x interface{}) *bool
- func DataGoogleCloudAssetResourcesSearchAll_IsTerraformDataSource(x interface{}) *bool
- func DataGoogleCloudAssetResourcesSearchAll_IsTerraformElement(x interface{}) *bool
- func DataGoogleCloudAssetResourcesSearchAll_TfResourceType() *string
- func NewDataGoogleCloudAssetResourcesSearchAllResultsList_Override(d DataGoogleCloudAssetResourcesSearchAllResultsList, ...)
- func NewDataGoogleCloudAssetResourcesSearchAllResultsOutputReference_Override(d DataGoogleCloudAssetResourcesSearchAllResultsOutputReference, ...)
- func NewDataGoogleCloudAssetResourcesSearchAll_Override(d DataGoogleCloudAssetResourcesSearchAll, scope constructs.Construct, ...)
- type DataGoogleCloudAssetResourcesSearchAll
- type DataGoogleCloudAssetResourcesSearchAllConfig
- type DataGoogleCloudAssetResourcesSearchAllResults
- type DataGoogleCloudAssetResourcesSearchAllResultsList
- type DataGoogleCloudAssetResourcesSearchAllResultsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataGoogleCloudAssetResourcesSearchAll_IsConstruct ¶
func DataGoogleCloudAssetResourcesSearchAll_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataGoogleCloudAssetResourcesSearchAll_IsTerraformDataSource ¶
func DataGoogleCloudAssetResourcesSearchAll_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataGoogleCloudAssetResourcesSearchAll_IsTerraformElement ¶
func DataGoogleCloudAssetResourcesSearchAll_IsTerraformElement(x interface{}) *bool
Experimental.
func DataGoogleCloudAssetResourcesSearchAll_TfResourceType ¶
func DataGoogleCloudAssetResourcesSearchAll_TfResourceType() *string
func NewDataGoogleCloudAssetResourcesSearchAllResultsList_Override ¶
func NewDataGoogleCloudAssetResourcesSearchAllResultsList_Override(d DataGoogleCloudAssetResourcesSearchAllResultsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataGoogleCloudAssetResourcesSearchAllResultsOutputReference_Override ¶
func NewDataGoogleCloudAssetResourcesSearchAllResultsOutputReference_Override(d DataGoogleCloudAssetResourcesSearchAllResultsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataGoogleCloudAssetResourcesSearchAll_Override ¶
func NewDataGoogleCloudAssetResourcesSearchAll_Override(d DataGoogleCloudAssetResourcesSearchAll, scope constructs.Construct, id *string, config *DataGoogleCloudAssetResourcesSearchAllConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/data-sources/google_cloud_asset_resources_search_all google_cloud_asset_resources_search_all} Data Source.
Types ¶
type DataGoogleCloudAssetResourcesSearchAll ¶
type DataGoogleCloudAssetResourcesSearchAll interface {
cdktf.TerraformDataSource
AssetTypes() *[]*string
SetAssetTypes(val *[]*string)
AssetTypesInput() *[]*string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
Query() *string
SetQuery(val *string)
QueryInput() *string
// Experimental.
RawOverrides() interface{}
Results() DataGoogleCloudAssetResourcesSearchAllResultsList
Scope() *string
SetScope(val *string)
ScopeInput() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetAssetTypes()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetQuery()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/data-sources/google_cloud_asset_resources_search_all google_cloud_asset_resources_search_all}.
func NewDataGoogleCloudAssetResourcesSearchAll ¶
func NewDataGoogleCloudAssetResourcesSearchAll(scope constructs.Construct, id *string, config *DataGoogleCloudAssetResourcesSearchAllConfig) DataGoogleCloudAssetResourcesSearchAll
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/data-sources/google_cloud_asset_resources_search_all google_cloud_asset_resources_search_all} Data Source.
type DataGoogleCloudAssetResourcesSearchAllConfig ¶
type DataGoogleCloudAssetResourcesSearchAllConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/data-sources/google_cloud_asset_resources_search_all#scope DataGoogleCloudAssetResourcesSearchAll#scope}.
Scope *string `field:"required" json:"scope" yaml:"scope"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/data-sources/google_cloud_asset_resources_search_all#asset_types DataGoogleCloudAssetResourcesSearchAll#asset_types}.
AssetTypes *[]*string `field:"optional" json:"assetTypes" yaml:"assetTypes"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/data-sources/google_cloud_asset_resources_search_all#id DataGoogleCloudAssetResourcesSearchAll#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/data-sources/google_cloud_asset_resources_search_all#query DataGoogleCloudAssetResourcesSearchAll#query}.
Query *string `field:"optional" json:"query" yaml:"query"`
}
type DataGoogleCloudAssetResourcesSearchAllResults ¶
type DataGoogleCloudAssetResourcesSearchAllResults struct {
}
type DataGoogleCloudAssetResourcesSearchAllResultsList ¶
type DataGoogleCloudAssetResourcesSearchAllResultsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataGoogleCloudAssetResourcesSearchAllResultsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleCloudAssetResourcesSearchAllResultsList ¶
func NewDataGoogleCloudAssetResourcesSearchAllResultsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataGoogleCloudAssetResourcesSearchAllResultsList
type DataGoogleCloudAssetResourcesSearchAllResultsOutputReference ¶
type DataGoogleCloudAssetResourcesSearchAllResultsOutputReference interface {
cdktf.ComplexObject
AdditionalAttributes() *[]*string
AssetType() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Description() *string
DisplayName() *string
// Experimental.
Fqn() *string
InternalValue() *DataGoogleCloudAssetResourcesSearchAllResults
SetInternalValue(val *DataGoogleCloudAssetResourcesSearchAllResults)
Labels() cdktf.StringMap
Location() *string
Name() *string
NetworkTags() *[]*string
Project() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleCloudAssetResourcesSearchAllResultsOutputReference ¶
func NewDataGoogleCloudAssetResourcesSearchAllResultsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataGoogleCloudAssetResourcesSearchAllResultsOutputReference
Source Files
¶
- DataGoogleCloudAssetResourcesSearchAll.go
- DataGoogleCloudAssetResourcesSearchAllConfig.go
- DataGoogleCloudAssetResourcesSearchAllResults.go
- DataGoogleCloudAssetResourcesSearchAllResultsList.go
- DataGoogleCloudAssetResourcesSearchAllResultsList__checks.go
- DataGoogleCloudAssetResourcesSearchAllResultsOutputReference.go
- DataGoogleCloudAssetResourcesSearchAllResultsOutputReference__checks.go
- DataGoogleCloudAssetResourcesSearchAll__checks.go
- main.go