Documentation
¶
Index ¶
- func DataGoogleDnsKeys_IsConstruct(x interface{}) *bool
- func DataGoogleDnsKeys_IsTerraformDataSource(x interface{}) *bool
- func DataGoogleDnsKeys_IsTerraformElement(x interface{}) *bool
- func DataGoogleDnsKeys_TfResourceType() *string
- func NewDataGoogleDnsKeysKeySigningKeysDigestsList_Override(d DataGoogleDnsKeysKeySigningKeysDigestsList, ...)
- func NewDataGoogleDnsKeysKeySigningKeysDigestsOutputReference_Override(d DataGoogleDnsKeysKeySigningKeysDigestsOutputReference, ...)
- func NewDataGoogleDnsKeysKeySigningKeysList_Override(d DataGoogleDnsKeysKeySigningKeysList, ...)
- func NewDataGoogleDnsKeysKeySigningKeysOutputReference_Override(d DataGoogleDnsKeysKeySigningKeysOutputReference, ...)
- func NewDataGoogleDnsKeysZoneSigningKeysDigestsList_Override(d DataGoogleDnsKeysZoneSigningKeysDigestsList, ...)
- func NewDataGoogleDnsKeysZoneSigningKeysDigestsOutputReference_Override(d DataGoogleDnsKeysZoneSigningKeysDigestsOutputReference, ...)
- func NewDataGoogleDnsKeysZoneSigningKeysList_Override(d DataGoogleDnsKeysZoneSigningKeysList, ...)
- func NewDataGoogleDnsKeysZoneSigningKeysOutputReference_Override(d DataGoogleDnsKeysZoneSigningKeysOutputReference, ...)
- func NewDataGoogleDnsKeys_Override(d DataGoogleDnsKeys, scope constructs.Construct, id *string, ...)
- type DataGoogleDnsKeys
- type DataGoogleDnsKeysConfig
- type DataGoogleDnsKeysKeySigningKeys
- type DataGoogleDnsKeysKeySigningKeysDigests
- type DataGoogleDnsKeysKeySigningKeysDigestsList
- type DataGoogleDnsKeysKeySigningKeysDigestsOutputReference
- type DataGoogleDnsKeysKeySigningKeysList
- type DataGoogleDnsKeysKeySigningKeysOutputReference
- type DataGoogleDnsKeysZoneSigningKeys
- type DataGoogleDnsKeysZoneSigningKeysDigests
- type DataGoogleDnsKeysZoneSigningKeysDigestsList
- type DataGoogleDnsKeysZoneSigningKeysDigestsOutputReference
- type DataGoogleDnsKeysZoneSigningKeysList
- type DataGoogleDnsKeysZoneSigningKeysOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataGoogleDnsKeys_IsConstruct ¶
func DataGoogleDnsKeys_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataGoogleDnsKeys_IsTerraformDataSource ¶
func DataGoogleDnsKeys_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataGoogleDnsKeys_IsTerraformElement ¶
func DataGoogleDnsKeys_IsTerraformElement(x interface{}) *bool
Experimental.
func DataGoogleDnsKeys_TfResourceType ¶
func DataGoogleDnsKeys_TfResourceType() *string
func NewDataGoogleDnsKeysKeySigningKeysDigestsList_Override ¶
func NewDataGoogleDnsKeysKeySigningKeysDigestsList_Override(d DataGoogleDnsKeysKeySigningKeysDigestsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataGoogleDnsKeysKeySigningKeysDigestsOutputReference_Override ¶
func NewDataGoogleDnsKeysKeySigningKeysDigestsOutputReference_Override(d DataGoogleDnsKeysKeySigningKeysDigestsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataGoogleDnsKeysKeySigningKeysList_Override ¶
func NewDataGoogleDnsKeysKeySigningKeysList_Override(d DataGoogleDnsKeysKeySigningKeysList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataGoogleDnsKeysKeySigningKeysOutputReference_Override ¶
func NewDataGoogleDnsKeysKeySigningKeysOutputReference_Override(d DataGoogleDnsKeysKeySigningKeysOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataGoogleDnsKeysZoneSigningKeysDigestsList_Override ¶
func NewDataGoogleDnsKeysZoneSigningKeysDigestsList_Override(d DataGoogleDnsKeysZoneSigningKeysDigestsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataGoogleDnsKeysZoneSigningKeysDigestsOutputReference_Override ¶
func NewDataGoogleDnsKeysZoneSigningKeysDigestsOutputReference_Override(d DataGoogleDnsKeysZoneSigningKeysDigestsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataGoogleDnsKeysZoneSigningKeysList_Override ¶
func NewDataGoogleDnsKeysZoneSigningKeysList_Override(d DataGoogleDnsKeysZoneSigningKeysList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataGoogleDnsKeysZoneSigningKeysOutputReference_Override ¶
func NewDataGoogleDnsKeysZoneSigningKeysOutputReference_Override(d DataGoogleDnsKeysZoneSigningKeysOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataGoogleDnsKeys_Override ¶
func NewDataGoogleDnsKeys_Override(d DataGoogleDnsKeys, scope constructs.Construct, id *string, config *DataGoogleDnsKeysConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/data-sources/google_dns_keys google_dns_keys} Data Source.
Types ¶
type DataGoogleDnsKeys ¶
type DataGoogleDnsKeys interface {
cdktf.TerraformDataSource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
KeySigningKeys() DataGoogleDnsKeysKeySigningKeysList
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
ManagedZone() *string
SetManagedZone(val *string)
ManagedZoneInput() *string
// The tree node.
Node() constructs.Node
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
ZoneSigningKeys() DataGoogleDnsKeysZoneSigningKeysList
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/data-sources/google_dns_keys google_dns_keys}.
func NewDataGoogleDnsKeys ¶
func NewDataGoogleDnsKeys(scope constructs.Construct, id *string, config *DataGoogleDnsKeysConfig) DataGoogleDnsKeys
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/data-sources/google_dns_keys google_dns_keys} Data Source.
type DataGoogleDnsKeysConfig ¶
type DataGoogleDnsKeysConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// The Name of the zone.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/data-sources/google_dns_keys#managed_zone DataGoogleDnsKeys#managed_zone}
ManagedZone *string `field:"required" json:"managedZone" yaml:"managedZone"`
// The ID of the project for the Google Cloud.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/data-sources/google_dns_keys#project DataGoogleDnsKeys#project}
Project *string `field:"optional" json:"project" yaml:"project"`
}
type DataGoogleDnsKeysKeySigningKeys ¶
type DataGoogleDnsKeysKeySigningKeys struct {
}
type DataGoogleDnsKeysKeySigningKeysDigests ¶
type DataGoogleDnsKeysKeySigningKeysDigests struct {
}
type DataGoogleDnsKeysKeySigningKeysDigestsList ¶
type DataGoogleDnsKeysKeySigningKeysDigestsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataGoogleDnsKeysKeySigningKeysDigestsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleDnsKeysKeySigningKeysDigestsList ¶
func NewDataGoogleDnsKeysKeySigningKeysDigestsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataGoogleDnsKeysKeySigningKeysDigestsList
type DataGoogleDnsKeysKeySigningKeysDigestsOutputReference ¶
type DataGoogleDnsKeysKeySigningKeysDigestsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Digest() *string
// Experimental.
Fqn() *string
InternalValue() *DataGoogleDnsKeysKeySigningKeysDigests
SetInternalValue(val *DataGoogleDnsKeysKeySigningKeysDigests)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleDnsKeysKeySigningKeysDigestsOutputReference ¶
func NewDataGoogleDnsKeysKeySigningKeysDigestsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataGoogleDnsKeysKeySigningKeysDigestsOutputReference
type DataGoogleDnsKeysKeySigningKeysList ¶
type DataGoogleDnsKeysKeySigningKeysList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataGoogleDnsKeysKeySigningKeysOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleDnsKeysKeySigningKeysList ¶
func NewDataGoogleDnsKeysKeySigningKeysList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataGoogleDnsKeysKeySigningKeysList
type DataGoogleDnsKeysKeySigningKeysOutputReference ¶
type DataGoogleDnsKeysKeySigningKeysOutputReference interface {
cdktf.ComplexObject
Algorithm() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
CreationTime() *string
Description() *string
Digests() DataGoogleDnsKeysKeySigningKeysDigestsList
DsRecord() *string
// Experimental.
Fqn() *string
Id() *string
InternalValue() *DataGoogleDnsKeysKeySigningKeys
SetInternalValue(val *DataGoogleDnsKeysKeySigningKeys)
IsActive() cdktf.IResolvable
KeyLength() *float64
KeyTag() *float64
PublicKey() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleDnsKeysKeySigningKeysOutputReference ¶
func NewDataGoogleDnsKeysKeySigningKeysOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataGoogleDnsKeysKeySigningKeysOutputReference
type DataGoogleDnsKeysZoneSigningKeys ¶
type DataGoogleDnsKeysZoneSigningKeys struct {
}
type DataGoogleDnsKeysZoneSigningKeysDigests ¶
type DataGoogleDnsKeysZoneSigningKeysDigests struct {
}
type DataGoogleDnsKeysZoneSigningKeysDigestsList ¶
type DataGoogleDnsKeysZoneSigningKeysDigestsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataGoogleDnsKeysZoneSigningKeysDigestsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleDnsKeysZoneSigningKeysDigestsList ¶
func NewDataGoogleDnsKeysZoneSigningKeysDigestsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataGoogleDnsKeysZoneSigningKeysDigestsList
type DataGoogleDnsKeysZoneSigningKeysDigestsOutputReference ¶
type DataGoogleDnsKeysZoneSigningKeysDigestsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Digest() *string
// Experimental.
Fqn() *string
InternalValue() *DataGoogleDnsKeysZoneSigningKeysDigests
SetInternalValue(val *DataGoogleDnsKeysZoneSigningKeysDigests)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleDnsKeysZoneSigningKeysDigestsOutputReference ¶
func NewDataGoogleDnsKeysZoneSigningKeysDigestsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataGoogleDnsKeysZoneSigningKeysDigestsOutputReference
type DataGoogleDnsKeysZoneSigningKeysList ¶
type DataGoogleDnsKeysZoneSigningKeysList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataGoogleDnsKeysZoneSigningKeysOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleDnsKeysZoneSigningKeysList ¶
func NewDataGoogleDnsKeysZoneSigningKeysList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataGoogleDnsKeysZoneSigningKeysList
type DataGoogleDnsKeysZoneSigningKeysOutputReference ¶
type DataGoogleDnsKeysZoneSigningKeysOutputReference interface {
cdktf.ComplexObject
Algorithm() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
CreationTime() *string
Description() *string
Digests() DataGoogleDnsKeysZoneSigningKeysDigestsList
// Experimental.
Fqn() *string
Id() *string
InternalValue() *DataGoogleDnsKeysZoneSigningKeys
SetInternalValue(val *DataGoogleDnsKeysZoneSigningKeys)
IsActive() cdktf.IResolvable
KeyLength() *float64
KeyTag() *float64
PublicKey() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleDnsKeysZoneSigningKeysOutputReference ¶
func NewDataGoogleDnsKeysZoneSigningKeysOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataGoogleDnsKeysZoneSigningKeysOutputReference
Source Files
¶
- DataGoogleDnsKeys.go
- DataGoogleDnsKeysConfig.go
- DataGoogleDnsKeysKeySigningKeys.go
- DataGoogleDnsKeysKeySigningKeysDigests.go
- DataGoogleDnsKeysKeySigningKeysDigestsList.go
- DataGoogleDnsKeysKeySigningKeysDigestsList__checks.go
- DataGoogleDnsKeysKeySigningKeysDigestsOutputReference.go
- DataGoogleDnsKeysKeySigningKeysDigestsOutputReference__checks.go
- DataGoogleDnsKeysKeySigningKeysList.go
- DataGoogleDnsKeysKeySigningKeysList__checks.go
- DataGoogleDnsKeysKeySigningKeysOutputReference.go
- DataGoogleDnsKeysKeySigningKeysOutputReference__checks.go
- DataGoogleDnsKeysZoneSigningKeys.go
- DataGoogleDnsKeysZoneSigningKeysDigests.go
- DataGoogleDnsKeysZoneSigningKeysDigestsList.go
- DataGoogleDnsKeysZoneSigningKeysDigestsList__checks.go
- DataGoogleDnsKeysZoneSigningKeysDigestsOutputReference.go
- DataGoogleDnsKeysZoneSigningKeysDigestsOutputReference__checks.go
- DataGoogleDnsKeysZoneSigningKeysList.go
- DataGoogleDnsKeysZoneSigningKeysList__checks.go
- DataGoogleDnsKeysZoneSigningKeysOutputReference.go
- DataGoogleDnsKeysZoneSigningKeysOutputReference__checks.go
- DataGoogleDnsKeys__checks.go
- main.go