Documentation
¶
Index ¶
- func DataGoogleMonitoringMeshIstioService_IsConstruct(x interface{}) *bool
- func DataGoogleMonitoringMeshIstioService_IsTerraformDataSource(x interface{}) *bool
- func DataGoogleMonitoringMeshIstioService_IsTerraformElement(x interface{}) *bool
- func DataGoogleMonitoringMeshIstioService_TfResourceType() *string
- func NewDataGoogleMonitoringMeshIstioServiceTelemetryList_Override(d DataGoogleMonitoringMeshIstioServiceTelemetryList, ...)
- func NewDataGoogleMonitoringMeshIstioServiceTelemetryOutputReference_Override(d DataGoogleMonitoringMeshIstioServiceTelemetryOutputReference, ...)
- func NewDataGoogleMonitoringMeshIstioService_Override(d DataGoogleMonitoringMeshIstioService, scope constructs.Construct, id *string, ...)
- type DataGoogleMonitoringMeshIstioService
- type DataGoogleMonitoringMeshIstioServiceConfig
- type DataGoogleMonitoringMeshIstioServiceTelemetry
- type DataGoogleMonitoringMeshIstioServiceTelemetryList
- type DataGoogleMonitoringMeshIstioServiceTelemetryOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataGoogleMonitoringMeshIstioService_IsConstruct ¶
func DataGoogleMonitoringMeshIstioService_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataGoogleMonitoringMeshIstioService_IsTerraformDataSource ¶
func DataGoogleMonitoringMeshIstioService_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataGoogleMonitoringMeshIstioService_IsTerraformElement ¶
func DataGoogleMonitoringMeshIstioService_IsTerraformElement(x interface{}) *bool
Experimental.
func DataGoogleMonitoringMeshIstioService_TfResourceType ¶
func DataGoogleMonitoringMeshIstioService_TfResourceType() *string
func NewDataGoogleMonitoringMeshIstioServiceTelemetryList_Override ¶
func NewDataGoogleMonitoringMeshIstioServiceTelemetryList_Override(d DataGoogleMonitoringMeshIstioServiceTelemetryList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataGoogleMonitoringMeshIstioServiceTelemetryOutputReference_Override ¶
func NewDataGoogleMonitoringMeshIstioServiceTelemetryOutputReference_Override(d DataGoogleMonitoringMeshIstioServiceTelemetryOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataGoogleMonitoringMeshIstioService_Override ¶
func NewDataGoogleMonitoringMeshIstioService_Override(d DataGoogleMonitoringMeshIstioService, scope constructs.Construct, id *string, config *DataGoogleMonitoringMeshIstioServiceConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/data-sources/google_monitoring_mesh_istio_service google_monitoring_mesh_istio_service} Data Source.
Types ¶
type DataGoogleMonitoringMeshIstioService ¶
type DataGoogleMonitoringMeshIstioService interface {
cdktf.TerraformDataSource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DisplayName() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
MeshUid() *string
SetMeshUid(val *string)
MeshUidInput() *string
Name() *string
// The tree node.
Node() constructs.Node
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
ServiceId() *string
ServiceName() *string
SetServiceName(val *string)
ServiceNameInput() *string
ServiceNamespace() *string
SetServiceNamespace(val *string)
ServiceNamespaceInput() *string
Telemetry() DataGoogleMonitoringMeshIstioServiceTelemetryList
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
UserLabels() cdktf.StringMap
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/data-sources/google_monitoring_mesh_istio_service google_monitoring_mesh_istio_service}.
func NewDataGoogleMonitoringMeshIstioService ¶
func NewDataGoogleMonitoringMeshIstioService(scope constructs.Construct, id *string, config *DataGoogleMonitoringMeshIstioServiceConfig) DataGoogleMonitoringMeshIstioService
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/data-sources/google_monitoring_mesh_istio_service google_monitoring_mesh_istio_service} Data Source.
type DataGoogleMonitoringMeshIstioServiceConfig ¶
type DataGoogleMonitoringMeshIstioServiceConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Identifier for the mesh in which this Istio service is defined.
//
// Corresponds to the meshUid metric label in Istio metrics.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/data-sources/google_monitoring_mesh_istio_service#mesh_uid DataGoogleMonitoringMeshIstioService#mesh_uid}
MeshUid *string `field:"required" json:"meshUid" yaml:"meshUid"`
// The name of the Istio service underlying this service.
//
// Corresponds to the destination_service_name metric label in Istio metrics.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/data-sources/google_monitoring_mesh_istio_service#service_name DataGoogleMonitoringMeshIstioService#service_name}
ServiceName *string `field:"required" json:"serviceName" yaml:"serviceName"`
// The namespace of the Istio service underlying this service.
//
// Corresponds to the destination_service_namespace metric label in Istio metrics.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/data-sources/google_monitoring_mesh_istio_service#service_namespace DataGoogleMonitoringMeshIstioService#service_namespace}
ServiceNamespace *string `field:"required" json:"serviceNamespace" yaml:"serviceNamespace"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/data-sources/google_monitoring_mesh_istio_service#id DataGoogleMonitoringMeshIstioService#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/data-sources/google_monitoring_mesh_istio_service#project DataGoogleMonitoringMeshIstioService#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
}
type DataGoogleMonitoringMeshIstioServiceTelemetry ¶
type DataGoogleMonitoringMeshIstioServiceTelemetry struct {
}
type DataGoogleMonitoringMeshIstioServiceTelemetryList ¶
type DataGoogleMonitoringMeshIstioServiceTelemetryList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataGoogleMonitoringMeshIstioServiceTelemetryOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleMonitoringMeshIstioServiceTelemetryList ¶
func NewDataGoogleMonitoringMeshIstioServiceTelemetryList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataGoogleMonitoringMeshIstioServiceTelemetryList
type DataGoogleMonitoringMeshIstioServiceTelemetryOutputReference ¶
type DataGoogleMonitoringMeshIstioServiceTelemetryOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataGoogleMonitoringMeshIstioServiceTelemetry
SetInternalValue(val *DataGoogleMonitoringMeshIstioServiceTelemetry)
ResourceName() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleMonitoringMeshIstioServiceTelemetryOutputReference ¶
func NewDataGoogleMonitoringMeshIstioServiceTelemetryOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataGoogleMonitoringMeshIstioServiceTelemetryOutputReference
Source Files
¶
- DataGoogleMonitoringMeshIstioService.go
- DataGoogleMonitoringMeshIstioServiceConfig.go
- DataGoogleMonitoringMeshIstioServiceTelemetry.go
- DataGoogleMonitoringMeshIstioServiceTelemetryList.go
- DataGoogleMonitoringMeshIstioServiceTelemetryList__checks.go
- DataGoogleMonitoringMeshIstioServiceTelemetryOutputReference.go
- DataGoogleMonitoringMeshIstioServiceTelemetryOutputReference__checks.go
- DataGoogleMonitoringMeshIstioService__checks.go
- main.go