Documentation
¶
Index ¶
- func GoogleActiveDirectoryDomainTrust_IsConstruct(x interface{}) *bool
- func GoogleActiveDirectoryDomainTrust_IsTerraformElement(x interface{}) *bool
- func GoogleActiveDirectoryDomainTrust_IsTerraformResource(x interface{}) *bool
- func GoogleActiveDirectoryDomainTrust_TfResourceType() *string
- func NewGoogleActiveDirectoryDomainTrustTimeoutsOutputReference_Override(g GoogleActiveDirectoryDomainTrustTimeoutsOutputReference, ...)
- func NewGoogleActiveDirectoryDomainTrust_Override(g GoogleActiveDirectoryDomainTrust, scope constructs.Construct, id *string, ...)
- type GoogleActiveDirectoryDomainTrust
- type GoogleActiveDirectoryDomainTrustConfig
- type GoogleActiveDirectoryDomainTrustTimeouts
- type GoogleActiveDirectoryDomainTrustTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleActiveDirectoryDomainTrust_IsConstruct ¶
func GoogleActiveDirectoryDomainTrust_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleActiveDirectoryDomainTrust_IsTerraformElement ¶
func GoogleActiveDirectoryDomainTrust_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleActiveDirectoryDomainTrust_IsTerraformResource ¶
func GoogleActiveDirectoryDomainTrust_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleActiveDirectoryDomainTrust_TfResourceType ¶
func GoogleActiveDirectoryDomainTrust_TfResourceType() *string
func NewGoogleActiveDirectoryDomainTrustTimeoutsOutputReference_Override ¶
func NewGoogleActiveDirectoryDomainTrustTimeoutsOutputReference_Override(g GoogleActiveDirectoryDomainTrustTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleActiveDirectoryDomainTrust_Override ¶
func NewGoogleActiveDirectoryDomainTrust_Override(g GoogleActiveDirectoryDomainTrust, scope constructs.Construct, id *string, config *GoogleActiveDirectoryDomainTrustConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_active_directory_domain_trust google_active_directory_domain_trust} Resource.
Types ¶
type GoogleActiveDirectoryDomainTrust ¶
type GoogleActiveDirectoryDomainTrust interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Domain() *string
SetDomain(val *string)
DomainInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
SelectiveAuthentication() interface{}
SetSelectiveAuthentication(val interface{})
SelectiveAuthenticationInput() interface{}
TargetDnsIpAddresses() *[]*string
SetTargetDnsIpAddresses(val *[]*string)
TargetDnsIpAddressesInput() *[]*string
TargetDomainName() *string
SetTargetDomainName(val *string)
TargetDomainNameInput() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GoogleActiveDirectoryDomainTrustTimeoutsOutputReference
TimeoutsInput() interface{}
TrustDirection() *string
SetTrustDirection(val *string)
TrustDirectionInput() *string
TrustHandshakeSecret() *string
SetTrustHandshakeSecret(val *string)
TrustHandshakeSecretInput() *string
TrustType() *string
SetTrustType(val *string)
TrustTypeInput() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutTimeouts(value *GoogleActiveDirectoryDomainTrustTimeouts)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
ResetSelectiveAuthentication()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_active_directory_domain_trust google_active_directory_domain_trust}.
func NewGoogleActiveDirectoryDomainTrust ¶
func NewGoogleActiveDirectoryDomainTrust(scope constructs.Construct, id *string, config *GoogleActiveDirectoryDomainTrustConfig) GoogleActiveDirectoryDomainTrust
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_active_directory_domain_trust google_active_directory_domain_trust} Resource.
type GoogleActiveDirectoryDomainTrustConfig ¶
type GoogleActiveDirectoryDomainTrustConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// The fully qualified domain name. e.g. mydomain.myorganization.com, with the restrictions, https://cloud.google.com/managed-microsoft-ad/reference/rest/v1/projects.locations.global.domains.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_active_directory_domain_trust#domain GoogleActiveDirectoryDomainTrust#domain}
Domain *string `field:"required" json:"domain" yaml:"domain"`
// The target DNS server IP addresses which can resolve the remote domain involved in the trust.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_active_directory_domain_trust#target_dns_ip_addresses GoogleActiveDirectoryDomainTrust#target_dns_ip_addresses}
TargetDnsIpAddresses *[]*string `field:"required" json:"targetDnsIpAddresses" yaml:"targetDnsIpAddresses"`
// The fully qualified target domain name which will be in trust with the current domain.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_active_directory_domain_trust#target_domain_name GoogleActiveDirectoryDomainTrust#target_domain_name}
TargetDomainName *string `field:"required" json:"targetDomainName" yaml:"targetDomainName"`
// The trust direction, which decides if the current domain is trusted, trusting, or both. Possible values: ["INBOUND", "OUTBOUND", "BIDIRECTIONAL"].
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_active_directory_domain_trust#trust_direction GoogleActiveDirectoryDomainTrust#trust_direction}
TrustDirection *string `field:"required" json:"trustDirection" yaml:"trustDirection"`
// The trust secret used for the handshake with the target domain. This will not be stored.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_active_directory_domain_trust#trust_handshake_secret GoogleActiveDirectoryDomainTrust#trust_handshake_secret}
TrustHandshakeSecret *string `field:"required" json:"trustHandshakeSecret" yaml:"trustHandshakeSecret"`
// The type of trust represented by the trust resource. Possible values: ["FOREST", "EXTERNAL"].
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_active_directory_domain_trust#trust_type GoogleActiveDirectoryDomainTrust#trust_type}
TrustType *string `field:"required" json:"trustType" yaml:"trustType"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_active_directory_domain_trust#id GoogleActiveDirectoryDomainTrust#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_active_directory_domain_trust#project GoogleActiveDirectoryDomainTrust#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// Whether the trusted side has forest/domain wide access or selective access to an approved set of resources.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_active_directory_domain_trust#selective_authentication GoogleActiveDirectoryDomainTrust#selective_authentication}
SelectiveAuthentication interface{} `field:"optional" json:"selectiveAuthentication" yaml:"selectiveAuthentication"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_active_directory_domain_trust#timeouts GoogleActiveDirectoryDomainTrust#timeouts}
Timeouts *GoogleActiveDirectoryDomainTrustTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type GoogleActiveDirectoryDomainTrustTimeouts ¶
type GoogleActiveDirectoryDomainTrustTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_active_directory_domain_trust#create GoogleActiveDirectoryDomainTrust#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_active_directory_domain_trust#delete GoogleActiveDirectoryDomainTrust#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_active_directory_domain_trust#update GoogleActiveDirectoryDomainTrust#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type GoogleActiveDirectoryDomainTrustTimeoutsOutputReference ¶
type GoogleActiveDirectoryDomainTrustTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleActiveDirectoryDomainTrustTimeoutsOutputReference ¶
func NewGoogleActiveDirectoryDomainTrustTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleActiveDirectoryDomainTrustTimeoutsOutputReference