Documentation
¶
Index ¶
- func GoogleApigeeOrganization_IsConstruct(x interface{}) *bool
- func GoogleApigeeOrganization_IsTerraformElement(x interface{}) *bool
- func GoogleApigeeOrganization_IsTerraformResource(x interface{}) *bool
- func GoogleApigeeOrganization_TfResourceType() *string
- func NewGoogleApigeeOrganizationPropertiesOutputReference_Override(g GoogleApigeeOrganizationPropertiesOutputReference, ...)
- func NewGoogleApigeeOrganizationPropertiesPropertyList_Override(g GoogleApigeeOrganizationPropertiesPropertyList, ...)
- func NewGoogleApigeeOrganizationPropertiesPropertyOutputReference_Override(g GoogleApigeeOrganizationPropertiesPropertyOutputReference, ...)
- func NewGoogleApigeeOrganizationTimeoutsOutputReference_Override(g GoogleApigeeOrganizationTimeoutsOutputReference, ...)
- func NewGoogleApigeeOrganization_Override(g GoogleApigeeOrganization, scope constructs.Construct, id *string, ...)
- type GoogleApigeeOrganization
- type GoogleApigeeOrganizationConfig
- type GoogleApigeeOrganizationProperties
- type GoogleApigeeOrganizationPropertiesOutputReference
- type GoogleApigeeOrganizationPropertiesProperty
- type GoogleApigeeOrganizationPropertiesPropertyList
- type GoogleApigeeOrganizationPropertiesPropertyOutputReference
- type GoogleApigeeOrganizationTimeouts
- type GoogleApigeeOrganizationTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleApigeeOrganization_IsConstruct ¶
func GoogleApigeeOrganization_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleApigeeOrganization_IsTerraformElement ¶
func GoogleApigeeOrganization_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleApigeeOrganization_IsTerraformResource ¶
func GoogleApigeeOrganization_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleApigeeOrganization_TfResourceType ¶
func GoogleApigeeOrganization_TfResourceType() *string
func NewGoogleApigeeOrganizationPropertiesOutputReference_Override ¶
func NewGoogleApigeeOrganizationPropertiesOutputReference_Override(g GoogleApigeeOrganizationPropertiesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleApigeeOrganizationPropertiesPropertyList_Override ¶
func NewGoogleApigeeOrganizationPropertiesPropertyList_Override(g GoogleApigeeOrganizationPropertiesPropertyList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGoogleApigeeOrganizationPropertiesPropertyOutputReference_Override ¶
func NewGoogleApigeeOrganizationPropertiesPropertyOutputReference_Override(g GoogleApigeeOrganizationPropertiesPropertyOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGoogleApigeeOrganizationTimeoutsOutputReference_Override ¶
func NewGoogleApigeeOrganizationTimeoutsOutputReference_Override(g GoogleApigeeOrganizationTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleApigeeOrganization_Override ¶
func NewGoogleApigeeOrganization_Override(g GoogleApigeeOrganization, scope constructs.Construct, id *string, config *GoogleApigeeOrganizationConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_apigee_organization google_apigee_organization} Resource.
Types ¶
type GoogleApigeeOrganization ¶
type GoogleApigeeOrganization interface {
cdktf.TerraformResource
AnalyticsRegion() *string
SetAnalyticsRegion(val *string)
AnalyticsRegionInput() *string
ApigeeProjectId() *string
AuthorizedNetwork() *string
SetAuthorizedNetwork(val *string)
AuthorizedNetworkInput() *string
BillingType() *string
SetBillingType(val *string)
BillingTypeInput() *string
CaCertificate() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
DisableVpcPeering() interface{}
SetDisableVpcPeering(val interface{})
DisableVpcPeeringInput() interface{}
DisplayName() *string
SetDisplayName(val *string)
DisplayNameInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
// The tree node.
Node() constructs.Node
ProjectId() *string
SetProjectId(val *string)
ProjectIdInput() *string
Properties() GoogleApigeeOrganizationPropertiesOutputReference
PropertiesInput() *GoogleApigeeOrganizationProperties
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Retention() *string
SetRetention(val *string)
RetentionInput() *string
RuntimeDatabaseEncryptionKeyName() *string
SetRuntimeDatabaseEncryptionKeyName(val *string)
RuntimeDatabaseEncryptionKeyNameInput() *string
RuntimeType() *string
SetRuntimeType(val *string)
RuntimeTypeInput() *string
SubscriptionType() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GoogleApigeeOrganizationTimeoutsOutputReference
TimeoutsInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutProperties(value *GoogleApigeeOrganizationProperties)
PutTimeouts(value *GoogleApigeeOrganizationTimeouts)
ResetAnalyticsRegion()
ResetAuthorizedNetwork()
ResetBillingType()
ResetDescription()
ResetDisableVpcPeering()
ResetDisplayName()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProperties()
ResetRetention()
ResetRuntimeDatabaseEncryptionKeyName()
ResetRuntimeType()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_apigee_organization google_apigee_organization}.
func NewGoogleApigeeOrganization ¶
func NewGoogleApigeeOrganization(scope constructs.Construct, id *string, config *GoogleApigeeOrganizationConfig) GoogleApigeeOrganization
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_apigee_organization google_apigee_organization} Resource.
type GoogleApigeeOrganizationConfig ¶
type GoogleApigeeOrganizationConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// The project ID associated with the Apigee organization.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_apigee_organization#project_id GoogleApigeeOrganization#project_id}
ProjectId *string `field:"required" json:"projectId" yaml:"projectId"`
// Primary GCP region for analytics data storage. For valid values, see [Create an Apigee organization](https://cloud.google.com/apigee/docs/api-platform/get-started/create-org).
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_apigee_organization#analytics_region GoogleApigeeOrganization#analytics_region}
AnalyticsRegion *string `field:"optional" json:"analyticsRegion" yaml:"analyticsRegion"`
// Compute Engine network used for Service Networking to be peered with Apigee runtime instances.
//
// See [Getting started with the Service Networking API](https://cloud.google.com/service-infrastructure/docs/service-networking/getting-started).
// Valid only when 'RuntimeType' is set to CLOUD. The value can be updated only when there are no runtime instances. For example: "default".
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_apigee_organization#authorized_network GoogleApigeeOrganization#authorized_network}
AuthorizedNetwork *string `field:"optional" json:"authorizedNetwork" yaml:"authorizedNetwork"`
// Billing type of the Apigee organization. See [Apigee pricing](https://cloud.google.com/apigee/pricing).
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_apigee_organization#billing_type GoogleApigeeOrganization#billing_type}
BillingType *string `field:"optional" json:"billingType" yaml:"billingType"`
// Description of the Apigee organization.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_apigee_organization#description GoogleApigeeOrganization#description}
Description *string `field:"optional" json:"description" yaml:"description"`
// Flag that specifies whether the VPC Peering through Private Google Access should be disabled between the consumer network and Apigee.
//
// Required if an 'authorizedNetwork'
// on the consumer project is not provided, in which case the flag should be set to 'true'.
// Valid only when 'RuntimeType' is set to CLOUD. The value must be set before the creation
// of any Apigee runtime instance and can be updated only when there are no runtime instances.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_apigee_organization#disable_vpc_peering GoogleApigeeOrganization#disable_vpc_peering}
DisableVpcPeering interface{} `field:"optional" json:"disableVpcPeering" yaml:"disableVpcPeering"`
// The display name of the Apigee organization.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_apigee_organization#display_name GoogleApigeeOrganization#display_name}
DisplayName *string `field:"optional" json:"displayName" yaml:"displayName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_apigee_organization#id GoogleApigeeOrganization#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// properties block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_apigee_organization#properties GoogleApigeeOrganization#properties}
Properties *GoogleApigeeOrganizationProperties `field:"optional" json:"properties" yaml:"properties"`
// Optional.
//
// This setting is applicable only for organizations that are soft-deleted (i.e., BillingType
// is not EVALUATION). It controls how long Organization data will be retained after the initial delete
// operation completes. During this period, the Organization may be restored to its last known state.
// After this period, the Organization will no longer be able to be restored. Default value: "DELETION_RETENTION_UNSPECIFIED" Possible values: ["DELETION_RETENTION_UNSPECIFIED", "MINIMUM"]
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_apigee_organization#retention GoogleApigeeOrganization#retention}
Retention *string `field:"optional" json:"retention" yaml:"retention"`
// Cloud KMS key name used for encrypting the data that is stored and replicated across runtime instances.
//
// Update is not allowed after the organization is created.
// If not specified, a Google-Managed encryption key will be used.
// Valid only when 'RuntimeType' is CLOUD. For example: 'projects/foo/locations/us/keyRings/bar/cryptoKeys/baz'.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_apigee_organization#runtime_database_encryption_key_name GoogleApigeeOrganization#runtime_database_encryption_key_name}
RuntimeDatabaseEncryptionKeyName *string `field:"optional" json:"runtimeDatabaseEncryptionKeyName" yaml:"runtimeDatabaseEncryptionKeyName"`
// Runtime type of the Apigee organization based on the Apigee subscription purchased. Default value: "CLOUD" Possible values: ["CLOUD", "HYBRID"].
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_apigee_organization#runtime_type GoogleApigeeOrganization#runtime_type}
RuntimeType *string `field:"optional" json:"runtimeType" yaml:"runtimeType"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_apigee_organization#timeouts GoogleApigeeOrganization#timeouts}
Timeouts *GoogleApigeeOrganizationTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type GoogleApigeeOrganizationProperties ¶
type GoogleApigeeOrganizationProperties struct {
// property block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_apigee_organization#property GoogleApigeeOrganization#property}
Property interface{} `field:"optional" json:"property" yaml:"property"`
}
type GoogleApigeeOrganizationPropertiesOutputReference ¶
type GoogleApigeeOrganizationPropertiesOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleApigeeOrganizationProperties
SetInternalValue(val *GoogleApigeeOrganizationProperties)
Property() GoogleApigeeOrganizationPropertiesPropertyList
PropertyInput() interface{}
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutProperty(value interface{})
ResetProperty()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleApigeeOrganizationPropertiesOutputReference ¶
func NewGoogleApigeeOrganizationPropertiesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleApigeeOrganizationPropertiesOutputReference
type GoogleApigeeOrganizationPropertiesProperty ¶
type GoogleApigeeOrganizationPropertiesProperty struct {
// Name of the property.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_apigee_organization#name GoogleApigeeOrganization#name}
Name *string `field:"optional" json:"name" yaml:"name"`
// Value of the property.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_apigee_organization#value GoogleApigeeOrganization#value}
Value *string `field:"optional" json:"value" yaml:"value"`
}
type GoogleApigeeOrganizationPropertiesPropertyList ¶
type GoogleApigeeOrganizationPropertiesPropertyList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) GoogleApigeeOrganizationPropertiesPropertyOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleApigeeOrganizationPropertiesPropertyList ¶
func NewGoogleApigeeOrganizationPropertiesPropertyList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GoogleApigeeOrganizationPropertiesPropertyList
type GoogleApigeeOrganizationPropertiesPropertyOutputReference ¶
type GoogleApigeeOrganizationPropertiesPropertyOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Name() *string
SetName(val *string)
NameInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Value() *string
SetValue(val *string)
ValueInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetName()
ResetValue()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleApigeeOrganizationPropertiesPropertyOutputReference ¶
func NewGoogleApigeeOrganizationPropertiesPropertyOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GoogleApigeeOrganizationPropertiesPropertyOutputReference
type GoogleApigeeOrganizationTimeouts ¶
type GoogleApigeeOrganizationTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_apigee_organization#create GoogleApigeeOrganization#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_apigee_organization#delete GoogleApigeeOrganization#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_apigee_organization#update GoogleApigeeOrganization#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type GoogleApigeeOrganizationTimeoutsOutputReference ¶
type GoogleApigeeOrganizationTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleApigeeOrganizationTimeoutsOutputReference ¶
func NewGoogleApigeeOrganizationTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleApigeeOrganizationTimeoutsOutputReference
Source Files
¶
- GoogleApigeeOrganization.go
- GoogleApigeeOrganizationConfig.go
- GoogleApigeeOrganizationProperties.go
- GoogleApigeeOrganizationPropertiesOutputReference.go
- GoogleApigeeOrganizationPropertiesOutputReference__checks.go
- GoogleApigeeOrganizationPropertiesProperty.go
- GoogleApigeeOrganizationPropertiesPropertyList.go
- GoogleApigeeOrganizationPropertiesPropertyList__checks.go
- GoogleApigeeOrganizationPropertiesPropertyOutputReference.go
- GoogleApigeeOrganizationPropertiesPropertyOutputReference__checks.go
- GoogleApigeeOrganizationTimeouts.go
- GoogleApigeeOrganizationTimeoutsOutputReference.go
- GoogleApigeeOrganizationTimeoutsOutputReference__checks.go
- GoogleApigeeOrganization__checks.go
- main.go