Documentation
¶
Index ¶
- func GoogleApigeeSharedflowDeployment_IsConstruct(x interface{}) *bool
- func GoogleApigeeSharedflowDeployment_IsTerraformElement(x interface{}) *bool
- func GoogleApigeeSharedflowDeployment_IsTerraformResource(x interface{}) *bool
- func GoogleApigeeSharedflowDeployment_TfResourceType() *string
- func NewGoogleApigeeSharedflowDeploymentTimeoutsOutputReference_Override(g GoogleApigeeSharedflowDeploymentTimeoutsOutputReference, ...)
- func NewGoogleApigeeSharedflowDeployment_Override(g GoogleApigeeSharedflowDeployment, scope constructs.Construct, id *string, ...)
- type GoogleApigeeSharedflowDeployment
- type GoogleApigeeSharedflowDeploymentConfig
- type GoogleApigeeSharedflowDeploymentTimeouts
- type GoogleApigeeSharedflowDeploymentTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleApigeeSharedflowDeployment_IsConstruct ¶
func GoogleApigeeSharedflowDeployment_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleApigeeSharedflowDeployment_IsTerraformElement ¶
func GoogleApigeeSharedflowDeployment_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleApigeeSharedflowDeployment_IsTerraformResource ¶
func GoogleApigeeSharedflowDeployment_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleApigeeSharedflowDeployment_TfResourceType ¶
func GoogleApigeeSharedflowDeployment_TfResourceType() *string
func NewGoogleApigeeSharedflowDeploymentTimeoutsOutputReference_Override ¶
func NewGoogleApigeeSharedflowDeploymentTimeoutsOutputReference_Override(g GoogleApigeeSharedflowDeploymentTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleApigeeSharedflowDeployment_Override ¶
func NewGoogleApigeeSharedflowDeployment_Override(g GoogleApigeeSharedflowDeployment, scope constructs.Construct, id *string, config *GoogleApigeeSharedflowDeploymentConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_apigee_sharedflow_deployment google_apigee_sharedflow_deployment} Resource.
Types ¶
type GoogleApigeeSharedflowDeployment ¶
type GoogleApigeeSharedflowDeployment interface {
cdktf.TerraformResource
CdktfStack() cdktf.TerraformStack
Connection() interface{}
SetConnection(val interface{})
ConstructNodeMetadata() *map[string]interface{}
Count() interface{}
SetCount(val interface{})
DependsOn() *[]*string
// Experimental.
ForEach() cdktf.ITerraformIterator
SetForEach(val cdktf.ITerraformIterator)
Fqn() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Provider() cdktf.TerraformProvider
SetProvider(val cdktf.TerraformProvider)
Provisioners() *[]interface{}
SetProvisioners(val *[]interface{})
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
TerraformMetaArguments() *map[string]interface{}
// Experimental.
AddOverride(path *string, value interface{})
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
GetListAttribute(terraformAttribute *string) *[]*string
GetNumberAttribute(terraformAttribute *string) *float64
GetNumberListAttribute(terraformAttribute *string) *[]*float64
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
GetStringAttribute(terraformAttribute *string) *string
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ToMetadata() interface{}
ToString() *string
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_apigee_sharedflow_deployment google_apigee_sharedflow_deployment}.
func NewGoogleApigeeSharedflowDeployment ¶
func NewGoogleApigeeSharedflowDeployment(scope constructs.Construct, id *string, config *GoogleApigeeSharedflowDeploymentConfig) GoogleApigeeSharedflowDeployment
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_apigee_sharedflow_deployment google_apigee_sharedflow_deployment} Resource.
type GoogleApigeeSharedflowDeploymentConfig ¶
type GoogleApigeeSharedflowDeploymentConfig struct {
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
Count interface{} `field:"optional" json:"count" yaml:"count"`
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_apigee_sharedflow_deployment#environment GoogleApigeeSharedflowDeployment#environment}
Environment *string `field:"required" json:"environment" yaml:"environment"`
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_apigee_sharedflow_deployment#org_id GoogleApigeeSharedflowDeployment#org_id}
OrgId *string `field:"required" json:"orgId" yaml:"orgId"`
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_apigee_sharedflow_deployment#revision GoogleApigeeSharedflowDeployment#revision}
Revision *string `field:"required" json:"revision" yaml:"revision"`
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_apigee_sharedflow_deployment#sharedflow_id GoogleApigeeSharedflowDeployment#sharedflow_id}
SharedflowId *string `field:"required" json:"sharedflowId" yaml:"sharedflowId"`
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
//
// The format must be {ACCOUNT_ID}@{PROJECT}.iam.gserviceaccount.com.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_apigee_sharedflow_deployment#service_account GoogleApigeeSharedflowDeployment#service_account}
ServiceAccount *string `field:"optional" json:"serviceAccount" yaml:"serviceAccount"`
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_apigee_sharedflow_deployment#timeouts GoogleApigeeSharedflowDeployment#timeouts}
Timeouts *GoogleApigeeSharedflowDeploymentTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type GoogleApigeeSharedflowDeploymentTimeoutsOutputReference ¶
type GoogleApigeeSharedflowDeploymentTimeoutsOutputReference interface {
cdktf.ComplexObject
// Experimental.
ComplexObjectIndex() interface{}
SetComplexObjectIndex(val interface{})
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
// Experimental.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
ComputeFqn() *string
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
GetListAttribute(terraformAttribute *string) *[]*string
GetNumberAttribute(terraformAttribute *string) *float64
GetNumberListAttribute(terraformAttribute *string) *[]*float64
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
GetStringAttribute(terraformAttribute *string) *string
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
InterpolationAsList() cdktf.IResolvable
// Experimental.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleApigeeSharedflowDeploymentTimeoutsOutputReference ¶
func NewGoogleApigeeSharedflowDeploymentTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleApigeeSharedflowDeploymentTimeoutsOutputReference