Documentation
¶
Index ¶
- func GoogleBeyondcorpAppConnection_IsConstruct(x interface{}) *bool
- func GoogleBeyondcorpAppConnection_IsTerraformElement(x interface{}) *bool
- func GoogleBeyondcorpAppConnection_IsTerraformResource(x interface{}) *bool
- func GoogleBeyondcorpAppConnection_TfResourceType() *string
- func NewGoogleBeyondcorpAppConnectionApplicationEndpointOutputReference_Override(g GoogleBeyondcorpAppConnectionApplicationEndpointOutputReference, ...)
- func NewGoogleBeyondcorpAppConnectionGatewayOutputReference_Override(g GoogleBeyondcorpAppConnectionGatewayOutputReference, ...)
- func NewGoogleBeyondcorpAppConnectionTimeoutsOutputReference_Override(g GoogleBeyondcorpAppConnectionTimeoutsOutputReference, ...)
- func NewGoogleBeyondcorpAppConnection_Override(g GoogleBeyondcorpAppConnection, scope constructs.Construct, id *string, ...)
- type GoogleBeyondcorpAppConnection
- type GoogleBeyondcorpAppConnectionApplicationEndpoint
- type GoogleBeyondcorpAppConnectionApplicationEndpointOutputReference
- type GoogleBeyondcorpAppConnectionConfig
- type GoogleBeyondcorpAppConnectionGateway
- type GoogleBeyondcorpAppConnectionGatewayOutputReference
- type GoogleBeyondcorpAppConnectionTimeouts
- type GoogleBeyondcorpAppConnectionTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleBeyondcorpAppConnection_IsConstruct ¶
func GoogleBeyondcorpAppConnection_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleBeyondcorpAppConnection_IsTerraformElement ¶
func GoogleBeyondcorpAppConnection_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleBeyondcorpAppConnection_IsTerraformResource ¶
func GoogleBeyondcorpAppConnection_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleBeyondcorpAppConnection_TfResourceType ¶
func GoogleBeyondcorpAppConnection_TfResourceType() *string
func NewGoogleBeyondcorpAppConnectionApplicationEndpointOutputReference_Override ¶
func NewGoogleBeyondcorpAppConnectionApplicationEndpointOutputReference_Override(g GoogleBeyondcorpAppConnectionApplicationEndpointOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleBeyondcorpAppConnectionGatewayOutputReference_Override ¶
func NewGoogleBeyondcorpAppConnectionGatewayOutputReference_Override(g GoogleBeyondcorpAppConnectionGatewayOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleBeyondcorpAppConnectionTimeoutsOutputReference_Override ¶
func NewGoogleBeyondcorpAppConnectionTimeoutsOutputReference_Override(g GoogleBeyondcorpAppConnectionTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleBeyondcorpAppConnection_Override ¶
func NewGoogleBeyondcorpAppConnection_Override(g GoogleBeyondcorpAppConnection, scope constructs.Construct, id *string, config *GoogleBeyondcorpAppConnectionConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_beyondcorp_app_connection google_beyondcorp_app_connection} Resource.
Types ¶
type GoogleBeyondcorpAppConnection ¶
type GoogleBeyondcorpAppConnection interface {
cdktf.TerraformResource
ApplicationEndpoint() GoogleBeyondcorpAppConnectionApplicationEndpointOutputReference
ApplicationEndpointInput() *GoogleBeyondcorpAppConnectionApplicationEndpoint
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
Connectors() *[]*string
SetConnectors(val *[]*string)
ConnectorsInput() *[]*string
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DisplayName() *string
SetDisplayName(val *string)
DisplayNameInput() *string
EffectiveLabels() cdktf.StringMap
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Gateway() GoogleBeyondcorpAppConnectionGatewayOutputReference
GatewayInput() *GoogleBeyondcorpAppConnectionGateway
Id() *string
SetId(val *string)
IdInput() *string
Labels() *map[string]*string
SetLabels(val *map[string]*string)
LabelsInput() *map[string]*string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Region() *string
SetRegion(val *string)
RegionInput() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
TerraformLabels() cdktf.StringMap
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GoogleBeyondcorpAppConnectionTimeoutsOutputReference
TimeoutsInput() interface{}
Type() *string
SetType(val *string)
TypeInput() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutApplicationEndpoint(value *GoogleBeyondcorpAppConnectionApplicationEndpoint)
PutGateway(value *GoogleBeyondcorpAppConnectionGateway)
PutTimeouts(value *GoogleBeyondcorpAppConnectionTimeouts)
ResetConnectors()
ResetDisplayName()
ResetGateway()
ResetId()
ResetLabels()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
ResetRegion()
ResetTimeouts()
ResetType()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_beyondcorp_app_connection google_beyondcorp_app_connection}.
func NewGoogleBeyondcorpAppConnection ¶
func NewGoogleBeyondcorpAppConnection(scope constructs.Construct, id *string, config *GoogleBeyondcorpAppConnectionConfig) GoogleBeyondcorpAppConnection
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_beyondcorp_app_connection google_beyondcorp_app_connection} Resource.
type GoogleBeyondcorpAppConnectionApplicationEndpoint ¶
type GoogleBeyondcorpAppConnectionApplicationEndpoint struct {
// Hostname or IP address of the remote application endpoint.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_beyondcorp_app_connection#host GoogleBeyondcorpAppConnection#host}
Host *string `field:"required" json:"host" yaml:"host"`
// Port of the remote application endpoint.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_beyondcorp_app_connection#port GoogleBeyondcorpAppConnection#port}
Port *float64 `field:"required" json:"port" yaml:"port"`
}
type GoogleBeyondcorpAppConnectionApplicationEndpointOutputReference ¶
type GoogleBeyondcorpAppConnectionApplicationEndpointOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Host() *string
SetHost(val *string)
HostInput() *string
InternalValue() *GoogleBeyondcorpAppConnectionApplicationEndpoint
SetInternalValue(val *GoogleBeyondcorpAppConnectionApplicationEndpoint)
Port() *float64
SetPort(val *float64)
PortInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleBeyondcorpAppConnectionApplicationEndpointOutputReference ¶
func NewGoogleBeyondcorpAppConnectionApplicationEndpointOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleBeyondcorpAppConnectionApplicationEndpointOutputReference
type GoogleBeyondcorpAppConnectionConfig ¶
type GoogleBeyondcorpAppConnectionConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// application_endpoint block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_beyondcorp_app_connection#application_endpoint GoogleBeyondcorpAppConnection#application_endpoint}
ApplicationEndpoint *GoogleBeyondcorpAppConnectionApplicationEndpoint `field:"required" json:"applicationEndpoint" yaml:"applicationEndpoint"`
// ID of the AppConnection.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_beyondcorp_app_connection#name GoogleBeyondcorpAppConnection#name}
Name *string `field:"required" json:"name" yaml:"name"`
// List of AppConnectors that are authorised to be associated with this AppConnection.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_beyondcorp_app_connection#connectors GoogleBeyondcorpAppConnection#connectors}
Connectors *[]*string `field:"optional" json:"connectors" yaml:"connectors"`
// An arbitrary user-provided name for the AppConnection.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_beyondcorp_app_connection#display_name GoogleBeyondcorpAppConnection#display_name}
DisplayName *string `field:"optional" json:"displayName" yaml:"displayName"`
// gateway block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_beyondcorp_app_connection#gateway GoogleBeyondcorpAppConnection#gateway}
Gateway *GoogleBeyondcorpAppConnectionGateway `field:"optional" json:"gateway" yaml:"gateway"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_beyondcorp_app_connection#id GoogleBeyondcorpAppConnection#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Resource labels to represent user provided metadata.
//
// **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
// Please refer to the field 'effective_labels' for all of the labels present on the resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_beyondcorp_app_connection#labels GoogleBeyondcorpAppConnection#labels}
Labels *map[string]*string `field:"optional" json:"labels" yaml:"labels"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_beyondcorp_app_connection#project GoogleBeyondcorpAppConnection#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// The region of the AppConnection.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_beyondcorp_app_connection#region GoogleBeyondcorpAppConnection#region}
Region *string `field:"optional" json:"region" yaml:"region"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_beyondcorp_app_connection#timeouts GoogleBeyondcorpAppConnection#timeouts}
Timeouts *GoogleBeyondcorpAppConnectionTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
// The type of network connectivity used by the AppConnection. Refer to https://cloud.google.com/beyondcorp/docs/reference/rest/v1/projects.locations.appConnections#type for a list of possible values.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_beyondcorp_app_connection#type GoogleBeyondcorpAppConnection#type}
Type *string `field:"optional" json:"type" yaml:"type"`
}
type GoogleBeyondcorpAppConnectionGateway ¶
type GoogleBeyondcorpAppConnectionGateway struct {
// AppGateway name in following format: projects/{project_id}/locations/{locationId}/appgateways/{gateway_id}.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_beyondcorp_app_connection#app_gateway GoogleBeyondcorpAppConnection#app_gateway}
AppGateway *string `field:"required" json:"appGateway" yaml:"appGateway"`
// The type of hosting used by the gateway. Refer to https://cloud.google.com/beyondcorp/docs/reference/rest/v1/projects.locations.appConnections#Type_1 for a list of possible values.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_beyondcorp_app_connection#type GoogleBeyondcorpAppConnection#type}
Type *string `field:"optional" json:"type" yaml:"type"`
}
type GoogleBeyondcorpAppConnectionGatewayOutputReference ¶
type GoogleBeyondcorpAppConnectionGatewayOutputReference interface {
cdktf.ComplexObject
AppGateway() *string
SetAppGateway(val *string)
AppGatewayInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
IngressPort() *float64
InternalValue() *GoogleBeyondcorpAppConnectionGateway
SetInternalValue(val *GoogleBeyondcorpAppConnectionGateway)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
SetType(val *string)
TypeInput() *string
Uri() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetType()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleBeyondcorpAppConnectionGatewayOutputReference ¶
func NewGoogleBeyondcorpAppConnectionGatewayOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleBeyondcorpAppConnectionGatewayOutputReference
type GoogleBeyondcorpAppConnectionTimeouts ¶
type GoogleBeyondcorpAppConnectionTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_beyondcorp_app_connection#create GoogleBeyondcorpAppConnection#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_beyondcorp_app_connection#delete GoogleBeyondcorpAppConnection#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_beyondcorp_app_connection#update GoogleBeyondcorpAppConnection#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type GoogleBeyondcorpAppConnectionTimeoutsOutputReference ¶
type GoogleBeyondcorpAppConnectionTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleBeyondcorpAppConnectionTimeoutsOutputReference ¶
func NewGoogleBeyondcorpAppConnectionTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleBeyondcorpAppConnectionTimeoutsOutputReference
Source Files
¶
- GoogleBeyondcorpAppConnection.go
- GoogleBeyondcorpAppConnectionApplicationEndpoint.go
- GoogleBeyondcorpAppConnectionApplicationEndpointOutputReference.go
- GoogleBeyondcorpAppConnectionApplicationEndpointOutputReference__checks.go
- GoogleBeyondcorpAppConnectionConfig.go
- GoogleBeyondcorpAppConnectionGateway.go
- GoogleBeyondcorpAppConnectionGatewayOutputReference.go
- GoogleBeyondcorpAppConnectionGatewayOutputReference__checks.go
- GoogleBeyondcorpAppConnectionTimeouts.go
- GoogleBeyondcorpAppConnectionTimeoutsOutputReference.go
- GoogleBeyondcorpAppConnectionTimeoutsOutputReference__checks.go
- GoogleBeyondcorpAppConnection__checks.go
- main.go