Documentation
¶
Index ¶
- func GoogleBiglakeDatabase_IsConstruct(x interface{}) *bool
- func GoogleBiglakeDatabase_IsTerraformElement(x interface{}) *bool
- func GoogleBiglakeDatabase_IsTerraformResource(x interface{}) *bool
- func GoogleBiglakeDatabase_TfResourceType() *string
- func NewGoogleBiglakeDatabaseHiveOptionsOutputReference_Override(g GoogleBiglakeDatabaseHiveOptionsOutputReference, ...)
- func NewGoogleBiglakeDatabaseTimeoutsOutputReference_Override(g GoogleBiglakeDatabaseTimeoutsOutputReference, ...)
- func NewGoogleBiglakeDatabase_Override(g GoogleBiglakeDatabase, scope constructs.Construct, id *string, ...)
- type GoogleBiglakeDatabase
- type GoogleBiglakeDatabaseConfig
- type GoogleBiglakeDatabaseHiveOptions
- type GoogleBiglakeDatabaseHiveOptionsOutputReference
- type GoogleBiglakeDatabaseTimeouts
- type GoogleBiglakeDatabaseTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleBiglakeDatabase_IsConstruct ¶
func GoogleBiglakeDatabase_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleBiglakeDatabase_IsTerraformElement ¶
func GoogleBiglakeDatabase_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleBiglakeDatabase_IsTerraformResource ¶
func GoogleBiglakeDatabase_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleBiglakeDatabase_TfResourceType ¶
func GoogleBiglakeDatabase_TfResourceType() *string
func NewGoogleBiglakeDatabaseHiveOptionsOutputReference_Override ¶
func NewGoogleBiglakeDatabaseHiveOptionsOutputReference_Override(g GoogleBiglakeDatabaseHiveOptionsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleBiglakeDatabaseTimeoutsOutputReference_Override ¶
func NewGoogleBiglakeDatabaseTimeoutsOutputReference_Override(g GoogleBiglakeDatabaseTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleBiglakeDatabase_Override ¶
func NewGoogleBiglakeDatabase_Override(g GoogleBiglakeDatabase, scope constructs.Construct, id *string, config *GoogleBiglakeDatabaseConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_biglake_database google_biglake_database} Resource.
Types ¶
type GoogleBiglakeDatabase ¶
type GoogleBiglakeDatabase interface {
cdktf.TerraformResource
Catalog() *string
SetCatalog(val *string)
CatalogInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
CreateTime() *string
DeleteTime() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
ExpireTime() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
HiveOptions() GoogleBiglakeDatabaseHiveOptionsOutputReference
HiveOptionsInput() *GoogleBiglakeDatabaseHiveOptions
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GoogleBiglakeDatabaseTimeoutsOutputReference
TimeoutsInput() interface{}
Type() *string
SetType(val *string)
TypeInput() *string
UpdateTime() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutHiveOptions(value *GoogleBiglakeDatabaseHiveOptions)
PutTimeouts(value *GoogleBiglakeDatabaseTimeouts)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_biglake_database google_biglake_database}.
func NewGoogleBiglakeDatabase ¶
func NewGoogleBiglakeDatabase(scope constructs.Construct, id *string, config *GoogleBiglakeDatabaseConfig) GoogleBiglakeDatabase
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_biglake_database google_biglake_database} Resource.
type GoogleBiglakeDatabaseConfig ¶
type GoogleBiglakeDatabaseConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// The parent catalog.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_biglake_database#catalog GoogleBiglakeDatabase#catalog}
Catalog *string `field:"required" json:"catalog" yaml:"catalog"`
// hive_options block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_biglake_database#hive_options GoogleBiglakeDatabase#hive_options}
HiveOptions *GoogleBiglakeDatabaseHiveOptions `field:"required" json:"hiveOptions" yaml:"hiveOptions"`
// The name of the database.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_biglake_database#name GoogleBiglakeDatabase#name}
Name *string `field:"required" json:"name" yaml:"name"`
// The database type.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_biglake_database#type GoogleBiglakeDatabase#type}
Type *string `field:"required" json:"type" yaml:"type"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_biglake_database#id GoogleBiglakeDatabase#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_biglake_database#timeouts GoogleBiglakeDatabase#timeouts}
Timeouts *GoogleBiglakeDatabaseTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type GoogleBiglakeDatabaseHiveOptions ¶
type GoogleBiglakeDatabaseHiveOptions struct {
// Cloud Storage folder URI where the database data is stored, starting with "gs://".
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_biglake_database#location_uri GoogleBiglakeDatabase#location_uri}
LocationUri *string `field:"optional" json:"locationUri" yaml:"locationUri"`
// Stores user supplied Hive database parameters.
//
// An object containing a
// list of"key": value pairs.
// Example: { "name": "wrench", "mass": "1.3kg", "count": "3" }.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_biglake_database#parameters GoogleBiglakeDatabase#parameters}
Parameters *map[string]*string `field:"optional" json:"parameters" yaml:"parameters"`
}
type GoogleBiglakeDatabaseHiveOptionsOutputReference ¶
type GoogleBiglakeDatabaseHiveOptionsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleBiglakeDatabaseHiveOptions
SetInternalValue(val *GoogleBiglakeDatabaseHiveOptions)
LocationUri() *string
SetLocationUri(val *string)
LocationUriInput() *string
Parameters() *map[string]*string
SetParameters(val *map[string]*string)
ParametersInput() *map[string]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetLocationUri()
ResetParameters()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleBiglakeDatabaseHiveOptionsOutputReference ¶
func NewGoogleBiglakeDatabaseHiveOptionsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleBiglakeDatabaseHiveOptionsOutputReference
type GoogleBiglakeDatabaseTimeouts ¶
type GoogleBiglakeDatabaseTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_biglake_database#create GoogleBiglakeDatabase#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_biglake_database#delete GoogleBiglakeDatabase#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_biglake_database#update GoogleBiglakeDatabase#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type GoogleBiglakeDatabaseTimeoutsOutputReference ¶
type GoogleBiglakeDatabaseTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleBiglakeDatabaseTimeoutsOutputReference ¶
func NewGoogleBiglakeDatabaseTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleBiglakeDatabaseTimeoutsOutputReference
Source Files
¶
- GoogleBiglakeDatabase.go
- GoogleBiglakeDatabaseConfig.go
- GoogleBiglakeDatabaseHiveOptions.go
- GoogleBiglakeDatabaseHiveOptionsOutputReference.go
- GoogleBiglakeDatabaseHiveOptionsOutputReference__checks.go
- GoogleBiglakeDatabaseTimeouts.go
- GoogleBiglakeDatabaseTimeoutsOutputReference.go
- GoogleBiglakeDatabaseTimeoutsOutputReference__checks.go
- GoogleBiglakeDatabase__checks.go
- main.go