Documentation
¶
Index ¶
- func GoogleCertificateManagerCertificate_IsConstruct(x interface{}) *bool
- func GoogleCertificateManagerCertificate_IsTerraformElement(x interface{}) *bool
- func GoogleCertificateManagerCertificate_IsTerraformResource(x interface{}) *bool
- func GoogleCertificateManagerCertificate_TfResourceType() *string
- func NewGoogleCertificateManagerCertificateManagedAuthorizationAttemptInfoList_Override(g GoogleCertificateManagerCertificateManagedAuthorizationAttemptInfoList, ...)
- func NewGoogleCertificateManagerCertificateManagedAuthorizationAttemptInfoOutputReference_Override(...)
- func NewGoogleCertificateManagerCertificateManagedOutputReference_Override(g GoogleCertificateManagerCertificateManagedOutputReference, ...)
- func NewGoogleCertificateManagerCertificateManagedProvisioningIssueList_Override(g GoogleCertificateManagerCertificateManagedProvisioningIssueList, ...)
- func NewGoogleCertificateManagerCertificateManagedProvisioningIssueOutputReference_Override(g GoogleCertificateManagerCertificateManagedProvisioningIssueOutputReference, ...)
- func NewGoogleCertificateManagerCertificateSelfManagedOutputReference_Override(g GoogleCertificateManagerCertificateSelfManagedOutputReference, ...)
- func NewGoogleCertificateManagerCertificateTimeoutsOutputReference_Override(g GoogleCertificateManagerCertificateTimeoutsOutputReference, ...)
- func NewGoogleCertificateManagerCertificate_Override(g GoogleCertificateManagerCertificate, scope constructs.Construct, id *string, ...)
- type GoogleCertificateManagerCertificate
- type GoogleCertificateManagerCertificateConfig
- type GoogleCertificateManagerCertificateManaged
- type GoogleCertificateManagerCertificateManagedAuthorizationAttemptInfo
- type GoogleCertificateManagerCertificateManagedAuthorizationAttemptInfoList
- type GoogleCertificateManagerCertificateManagedAuthorizationAttemptInfoOutputReference
- type GoogleCertificateManagerCertificateManagedOutputReference
- type GoogleCertificateManagerCertificateManagedProvisioningIssue
- type GoogleCertificateManagerCertificateManagedProvisioningIssueList
- type GoogleCertificateManagerCertificateManagedProvisioningIssueOutputReference
- type GoogleCertificateManagerCertificateSelfManaged
- type GoogleCertificateManagerCertificateSelfManagedOutputReference
- type GoogleCertificateManagerCertificateTimeouts
- type GoogleCertificateManagerCertificateTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleCertificateManagerCertificate_IsConstruct ¶
func GoogleCertificateManagerCertificate_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleCertificateManagerCertificate_IsTerraformElement ¶
func GoogleCertificateManagerCertificate_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleCertificateManagerCertificate_IsTerraformResource ¶
func GoogleCertificateManagerCertificate_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleCertificateManagerCertificate_TfResourceType ¶
func GoogleCertificateManagerCertificate_TfResourceType() *string
func NewGoogleCertificateManagerCertificateManagedAuthorizationAttemptInfoList_Override ¶
func NewGoogleCertificateManagerCertificateManagedAuthorizationAttemptInfoList_Override(g GoogleCertificateManagerCertificateManagedAuthorizationAttemptInfoList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGoogleCertificateManagerCertificateManagedAuthorizationAttemptInfoOutputReference_Override ¶
func NewGoogleCertificateManagerCertificateManagedAuthorizationAttemptInfoOutputReference_Override(g GoogleCertificateManagerCertificateManagedAuthorizationAttemptInfoOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGoogleCertificateManagerCertificateManagedOutputReference_Override ¶
func NewGoogleCertificateManagerCertificateManagedOutputReference_Override(g GoogleCertificateManagerCertificateManagedOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleCertificateManagerCertificateManagedProvisioningIssueList_Override ¶
func NewGoogleCertificateManagerCertificateManagedProvisioningIssueList_Override(g GoogleCertificateManagerCertificateManagedProvisioningIssueList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGoogleCertificateManagerCertificateManagedProvisioningIssueOutputReference_Override ¶
func NewGoogleCertificateManagerCertificateManagedProvisioningIssueOutputReference_Override(g GoogleCertificateManagerCertificateManagedProvisioningIssueOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGoogleCertificateManagerCertificateSelfManagedOutputReference_Override ¶
func NewGoogleCertificateManagerCertificateSelfManagedOutputReference_Override(g GoogleCertificateManagerCertificateSelfManagedOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleCertificateManagerCertificateTimeoutsOutputReference_Override ¶
func NewGoogleCertificateManagerCertificateTimeoutsOutputReference_Override(g GoogleCertificateManagerCertificateTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleCertificateManagerCertificate_Override ¶
func NewGoogleCertificateManagerCertificate_Override(g GoogleCertificateManagerCertificate, scope constructs.Construct, id *string, config *GoogleCertificateManagerCertificateConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_certificate_manager_certificate google_certificate_manager_certificate} Resource.
Types ¶
type GoogleCertificateManagerCertificate ¶
type GoogleCertificateManagerCertificate interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
EffectiveLabels() cdktf.StringMap
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
Labels() *map[string]*string
SetLabels(val *map[string]*string)
LabelsInput() *map[string]*string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Location() *string
SetLocation(val *string)
LocationInput() *string
Managed() GoogleCertificateManagerCertificateManagedOutputReference
ManagedInput() *GoogleCertificateManagerCertificateManaged
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Scope() *string
SetScope(val *string)
ScopeInput() *string
SelfManaged() GoogleCertificateManagerCertificateSelfManagedOutputReference
SelfManagedInput() *GoogleCertificateManagerCertificateSelfManaged
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
TerraformLabels() cdktf.StringMap
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GoogleCertificateManagerCertificateTimeoutsOutputReference
TimeoutsInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutManaged(value *GoogleCertificateManagerCertificateManaged)
PutSelfManaged(value *GoogleCertificateManagerCertificateSelfManaged)
PutTimeouts(value *GoogleCertificateManagerCertificateTimeouts)
ResetDescription()
ResetId()
ResetLabels()
ResetLocation()
ResetManaged()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
ResetScope()
ResetSelfManaged()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_certificate_manager_certificate google_certificate_manager_certificate}.
func NewGoogleCertificateManagerCertificate ¶
func NewGoogleCertificateManagerCertificate(scope constructs.Construct, id *string, config *GoogleCertificateManagerCertificateConfig) GoogleCertificateManagerCertificate
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_certificate_manager_certificate google_certificate_manager_certificate} Resource.
type GoogleCertificateManagerCertificateConfig ¶
type GoogleCertificateManagerCertificateConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// A user-defined name of the certificate.
//
// Certificate names must be unique
// The name must be 1-64 characters long, and match the regular expression [a-zA-Z][a-zA-Z0-9_-]* which means the first character must be a letter,
// and all following characters must be a dash, underscore, letter or digit.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_certificate_manager_certificate#name GoogleCertificateManagerCertificate#name}
Name *string `field:"required" json:"name" yaml:"name"`
// A human-readable description of the resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_certificate_manager_certificate#description GoogleCertificateManagerCertificate#description}
Description *string `field:"optional" json:"description" yaml:"description"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_certificate_manager_certificate#id GoogleCertificateManagerCertificate#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Set of label tags associated with the Certificate resource.
//
// **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
// Please refer to the field 'effective_labels' for all of the labels present on the resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_certificate_manager_certificate#labels GoogleCertificateManagerCertificate#labels}
Labels *map[string]*string `field:"optional" json:"labels" yaml:"labels"`
// The Certificate Manager location. If not specified, "global" is used.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_certificate_manager_certificate#location GoogleCertificateManagerCertificate#location}
Location *string `field:"optional" json:"location" yaml:"location"`
// managed block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_certificate_manager_certificate#managed GoogleCertificateManagerCertificate#managed}
Managed *GoogleCertificateManagerCertificateManaged `field:"optional" json:"managed" yaml:"managed"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_certificate_manager_certificate#project GoogleCertificateManagerCertificate#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// The scope of the certificate.
//
// DEFAULT: Certificates with default scope are served from core Google data centers.
// If unsure, choose this option.
//
// EDGE_CACHE: Certificates with scope EDGE_CACHE are special-purposed certificates, served from Edge Points of Presence.
// See https://cloud.google.com/vpc/docs/edge-locations.
//
// ALL_REGIONS: Certificates with ALL_REGIONS scope are served from all GCP regions (You can only use ALL_REGIONS with global certs).
// See https://cloud.google.com/compute/docs/regions-zones
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_certificate_manager_certificate#scope GoogleCertificateManagerCertificate#scope}
Scope *string `field:"optional" json:"scope" yaml:"scope"`
// self_managed block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_certificate_manager_certificate#self_managed GoogleCertificateManagerCertificate#self_managed}
SelfManaged *GoogleCertificateManagerCertificateSelfManaged `field:"optional" json:"selfManaged" yaml:"selfManaged"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_certificate_manager_certificate#timeouts GoogleCertificateManagerCertificate#timeouts}
Timeouts *GoogleCertificateManagerCertificateTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type GoogleCertificateManagerCertificateManaged ¶
type GoogleCertificateManagerCertificateManaged struct {
// Authorizations that will be used for performing domain authorization. Either issuanceConfig or dnsAuthorizations should be specificed, but not both.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_certificate_manager_certificate#dns_authorizations GoogleCertificateManagerCertificate#dns_authorizations}
DnsAuthorizations *[]*string `field:"optional" json:"dnsAuthorizations" yaml:"dnsAuthorizations"`
// The domains for which a managed SSL certificate will be generated. Wildcard domains are only supported with DNS challenge resolution.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_certificate_manager_certificate#domains GoogleCertificateManagerCertificate#domains}
Domains *[]*string `field:"optional" json:"domains" yaml:"domains"`
// The resource name for a CertificateIssuanceConfig used to configure private PKI certificates in the format projects/* /locations/* /certificateIssuanceConfigs/*.
//
// If this field is not set, the certificates will instead be publicly signed as documented at https://cloud.google.com/load-balancing/docs/ssl-certificates/google-managed-certs#caa.
// Either issuanceConfig or dnsAuthorizations should be specificed, but not both.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_certificate_manager_certificate#issuance_config GoogleCertificateManagerCertificate#issuance_config}
//
// Note: The above comment contained a comment block ending sequence (* followed by /). We have introduced a space between to prevent syntax errors. Please ignore the space.
IssuanceConfig *string `field:"optional" json:"issuanceConfig" yaml:"issuanceConfig"`
}
type GoogleCertificateManagerCertificateManagedAuthorizationAttemptInfo ¶
type GoogleCertificateManagerCertificateManagedAuthorizationAttemptInfo struct {
}
type GoogleCertificateManagerCertificateManagedAuthorizationAttemptInfoList ¶
type GoogleCertificateManagerCertificateManagedAuthorizationAttemptInfoList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) GoogleCertificateManagerCertificateManagedAuthorizationAttemptInfoOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleCertificateManagerCertificateManagedAuthorizationAttemptInfoList ¶
func NewGoogleCertificateManagerCertificateManagedAuthorizationAttemptInfoList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GoogleCertificateManagerCertificateManagedAuthorizationAttemptInfoList
type GoogleCertificateManagerCertificateManagedAuthorizationAttemptInfoOutputReference ¶
type GoogleCertificateManagerCertificateManagedAuthorizationAttemptInfoOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Details() *string
Domain() *string
FailureReason() *string
// Experimental.
Fqn() *string
InternalValue() *GoogleCertificateManagerCertificateManagedAuthorizationAttemptInfo
SetInternalValue(val *GoogleCertificateManagerCertificateManagedAuthorizationAttemptInfo)
State() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleCertificateManagerCertificateManagedAuthorizationAttemptInfoOutputReference ¶
func NewGoogleCertificateManagerCertificateManagedAuthorizationAttemptInfoOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GoogleCertificateManagerCertificateManagedAuthorizationAttemptInfoOutputReference
type GoogleCertificateManagerCertificateManagedOutputReference ¶
type GoogleCertificateManagerCertificateManagedOutputReference interface {
cdktf.ComplexObject
AuthorizationAttemptInfo() GoogleCertificateManagerCertificateManagedAuthorizationAttemptInfoList
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DnsAuthorizations() *[]*string
SetDnsAuthorizations(val *[]*string)
DnsAuthorizationsInput() *[]*string
Domains() *[]*string
SetDomains(val *[]*string)
DomainsInput() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleCertificateManagerCertificateManaged
SetInternalValue(val *GoogleCertificateManagerCertificateManaged)
IssuanceConfig() *string
SetIssuanceConfig(val *string)
IssuanceConfigInput() *string
ProvisioningIssue() GoogleCertificateManagerCertificateManagedProvisioningIssueList
State() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetDnsAuthorizations()
ResetDomains()
ResetIssuanceConfig()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleCertificateManagerCertificateManagedOutputReference ¶
func NewGoogleCertificateManagerCertificateManagedOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleCertificateManagerCertificateManagedOutputReference
type GoogleCertificateManagerCertificateManagedProvisioningIssue ¶
type GoogleCertificateManagerCertificateManagedProvisioningIssue struct {
}
type GoogleCertificateManagerCertificateManagedProvisioningIssueList ¶
type GoogleCertificateManagerCertificateManagedProvisioningIssueList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) GoogleCertificateManagerCertificateManagedProvisioningIssueOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleCertificateManagerCertificateManagedProvisioningIssueList ¶
func NewGoogleCertificateManagerCertificateManagedProvisioningIssueList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GoogleCertificateManagerCertificateManagedProvisioningIssueList
type GoogleCertificateManagerCertificateManagedProvisioningIssueOutputReference ¶
type GoogleCertificateManagerCertificateManagedProvisioningIssueOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Details() *string
// Experimental.
Fqn() *string
InternalValue() *GoogleCertificateManagerCertificateManagedProvisioningIssue
SetInternalValue(val *GoogleCertificateManagerCertificateManagedProvisioningIssue)
Reason() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleCertificateManagerCertificateManagedProvisioningIssueOutputReference ¶
func NewGoogleCertificateManagerCertificateManagedProvisioningIssueOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GoogleCertificateManagerCertificateManagedProvisioningIssueOutputReference
type GoogleCertificateManagerCertificateSelfManaged ¶
type GoogleCertificateManagerCertificateSelfManaged struct {
// The certificate chain in PEM-encoded form.
//
// Leaf certificate comes first, followed by intermediate ones if any.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_certificate_manager_certificate#certificate_pem GoogleCertificateManagerCertificate#certificate_pem}
CertificatePem *string `field:"optional" json:"certificatePem" yaml:"certificatePem"`
// The certificate chain in PEM-encoded form.
//
// Leaf certificate comes first, followed by intermediate ones if any.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_certificate_manager_certificate#pem_certificate GoogleCertificateManagerCertificate#pem_certificate}
PemCertificate *string `field:"optional" json:"pemCertificate" yaml:"pemCertificate"`
// The private key of the leaf certificate in PEM-encoded form.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_certificate_manager_certificate#pem_private_key GoogleCertificateManagerCertificate#pem_private_key}
PemPrivateKey *string `field:"optional" json:"pemPrivateKey" yaml:"pemPrivateKey"`
// The private key of the leaf certificate in PEM-encoded form.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_certificate_manager_certificate#private_key_pem GoogleCertificateManagerCertificate#private_key_pem}
PrivateKeyPem *string `field:"optional" json:"privateKeyPem" yaml:"privateKeyPem"`
}
type GoogleCertificateManagerCertificateSelfManagedOutputReference ¶
type GoogleCertificateManagerCertificateSelfManagedOutputReference interface {
cdktf.ComplexObject
CertificatePem() *string
SetCertificatePem(val *string)
CertificatePemInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleCertificateManagerCertificateSelfManaged
SetInternalValue(val *GoogleCertificateManagerCertificateSelfManaged)
PemCertificate() *string
SetPemCertificate(val *string)
PemCertificateInput() *string
PemPrivateKey() *string
SetPemPrivateKey(val *string)
PemPrivateKeyInput() *string
PrivateKeyPem() *string
SetPrivateKeyPem(val *string)
PrivateKeyPemInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCertificatePem()
ResetPemCertificate()
ResetPemPrivateKey()
ResetPrivateKeyPem()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleCertificateManagerCertificateSelfManagedOutputReference ¶
func NewGoogleCertificateManagerCertificateSelfManagedOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleCertificateManagerCertificateSelfManagedOutputReference
type GoogleCertificateManagerCertificateTimeouts ¶
type GoogleCertificateManagerCertificateTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_certificate_manager_certificate#create GoogleCertificateManagerCertificate#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_certificate_manager_certificate#delete GoogleCertificateManagerCertificate#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_certificate_manager_certificate#update GoogleCertificateManagerCertificate#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type GoogleCertificateManagerCertificateTimeoutsOutputReference ¶
type GoogleCertificateManagerCertificateTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleCertificateManagerCertificateTimeoutsOutputReference ¶
func NewGoogleCertificateManagerCertificateTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleCertificateManagerCertificateTimeoutsOutputReference
Source Files
¶
- GoogleCertificateManagerCertificate.go
- GoogleCertificateManagerCertificateConfig.go
- GoogleCertificateManagerCertificateManaged.go
- GoogleCertificateManagerCertificateManagedAuthorizationAttemptInfo.go
- GoogleCertificateManagerCertificateManagedAuthorizationAttemptInfoList.go
- GoogleCertificateManagerCertificateManagedAuthorizationAttemptInfoList__checks.go
- GoogleCertificateManagerCertificateManagedAuthorizationAttemptInfoOutputReference.go
- GoogleCertificateManagerCertificateManagedAuthorizationAttemptInfoOutputReference__checks.go
- GoogleCertificateManagerCertificateManagedOutputReference.go
- GoogleCertificateManagerCertificateManagedOutputReference__checks.go
- GoogleCertificateManagerCertificateManagedProvisioningIssue.go
- GoogleCertificateManagerCertificateManagedProvisioningIssueList.go
- GoogleCertificateManagerCertificateManagedProvisioningIssueList__checks.go
- GoogleCertificateManagerCertificateManagedProvisioningIssueOutputReference.go
- GoogleCertificateManagerCertificateManagedProvisioningIssueOutputReference__checks.go
- GoogleCertificateManagerCertificateSelfManaged.go
- GoogleCertificateManagerCertificateSelfManagedOutputReference.go
- GoogleCertificateManagerCertificateSelfManagedOutputReference__checks.go
- GoogleCertificateManagerCertificateTimeouts.go
- GoogleCertificateManagerCertificateTimeoutsOutputReference.go
- GoogleCertificateManagerCertificateTimeoutsOutputReference__checks.go
- GoogleCertificateManagerCertificate__checks.go
- main.go