Documentation
¶
Index ¶
- func GoogleComputeNetworkEndpoints_IsConstruct(x interface{}) *bool
- func GoogleComputeNetworkEndpoints_IsTerraformElement(x interface{}) *bool
- func GoogleComputeNetworkEndpoints_IsTerraformResource(x interface{}) *bool
- func GoogleComputeNetworkEndpoints_TfResourceType() *string
- func NewGoogleComputeNetworkEndpointsNetworkEndpointsList_Override(g GoogleComputeNetworkEndpointsNetworkEndpointsList, ...)
- func NewGoogleComputeNetworkEndpointsNetworkEndpointsOutputReference_Override(g GoogleComputeNetworkEndpointsNetworkEndpointsOutputReference, ...)
- func NewGoogleComputeNetworkEndpointsTimeoutsOutputReference_Override(g GoogleComputeNetworkEndpointsTimeoutsOutputReference, ...)
- func NewGoogleComputeNetworkEndpoints_Override(g GoogleComputeNetworkEndpoints, scope constructs.Construct, id *string, ...)
- type GoogleComputeNetworkEndpoints
- type GoogleComputeNetworkEndpointsConfig
- type GoogleComputeNetworkEndpointsNetworkEndpoints
- type GoogleComputeNetworkEndpointsNetworkEndpointsList
- type GoogleComputeNetworkEndpointsNetworkEndpointsOutputReference
- type GoogleComputeNetworkEndpointsTimeouts
- type GoogleComputeNetworkEndpointsTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleComputeNetworkEndpoints_IsConstruct ¶
func GoogleComputeNetworkEndpoints_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleComputeNetworkEndpoints_IsTerraformElement ¶
func GoogleComputeNetworkEndpoints_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleComputeNetworkEndpoints_IsTerraformResource ¶
func GoogleComputeNetworkEndpoints_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleComputeNetworkEndpoints_TfResourceType ¶
func GoogleComputeNetworkEndpoints_TfResourceType() *string
func NewGoogleComputeNetworkEndpointsNetworkEndpointsList_Override ¶
func NewGoogleComputeNetworkEndpointsNetworkEndpointsList_Override(g GoogleComputeNetworkEndpointsNetworkEndpointsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGoogleComputeNetworkEndpointsNetworkEndpointsOutputReference_Override ¶
func NewGoogleComputeNetworkEndpointsNetworkEndpointsOutputReference_Override(g GoogleComputeNetworkEndpointsNetworkEndpointsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGoogleComputeNetworkEndpointsTimeoutsOutputReference_Override ¶
func NewGoogleComputeNetworkEndpointsTimeoutsOutputReference_Override(g GoogleComputeNetworkEndpointsTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleComputeNetworkEndpoints_Override ¶
func NewGoogleComputeNetworkEndpoints_Override(g GoogleComputeNetworkEndpoints, scope constructs.Construct, id *string, config *GoogleComputeNetworkEndpointsConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_compute_network_endpoints google_compute_network_endpoints} Resource.
Types ¶
type GoogleComputeNetworkEndpoints ¶
type GoogleComputeNetworkEndpoints interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
NetworkEndpointGroup() *string
SetNetworkEndpointGroup(val *string)
NetworkEndpointGroupInput() *string
NetworkEndpoints() GoogleComputeNetworkEndpointsNetworkEndpointsList
NetworkEndpointsInput() interface{}
// The tree node.
Node() constructs.Node
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GoogleComputeNetworkEndpointsTimeoutsOutputReference
TimeoutsInput() interface{}
Zone() *string
SetZone(val *string)
ZoneInput() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutNetworkEndpoints(value interface{})
PutTimeouts(value *GoogleComputeNetworkEndpointsTimeouts)
ResetId()
ResetNetworkEndpoints()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
ResetTimeouts()
ResetZone()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_compute_network_endpoints google_compute_network_endpoints}.
func NewGoogleComputeNetworkEndpoints ¶
func NewGoogleComputeNetworkEndpoints(scope constructs.Construct, id *string, config *GoogleComputeNetworkEndpointsConfig) GoogleComputeNetworkEndpoints
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_compute_network_endpoints google_compute_network_endpoints} Resource.
type GoogleComputeNetworkEndpointsConfig ¶
type GoogleComputeNetworkEndpointsConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// The network endpoint group these endpoints are part of.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_compute_network_endpoints#network_endpoint_group GoogleComputeNetworkEndpoints#network_endpoint_group}
NetworkEndpointGroup *string `field:"required" json:"networkEndpointGroup" yaml:"networkEndpointGroup"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_compute_network_endpoints#id GoogleComputeNetworkEndpoints#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// network_endpoints block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_compute_network_endpoints#network_endpoints GoogleComputeNetworkEndpoints#network_endpoints}
NetworkEndpoints interface{} `field:"optional" json:"networkEndpoints" yaml:"networkEndpoints"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_compute_network_endpoints#project GoogleComputeNetworkEndpoints#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_compute_network_endpoints#timeouts GoogleComputeNetworkEndpoints#timeouts}
Timeouts *GoogleComputeNetworkEndpointsTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
// Zone where the containing network endpoint group is located.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_compute_network_endpoints#zone GoogleComputeNetworkEndpoints#zone}
Zone *string `field:"optional" json:"zone" yaml:"zone"`
}
type GoogleComputeNetworkEndpointsNetworkEndpoints ¶
type GoogleComputeNetworkEndpointsNetworkEndpoints struct {
// IPv4 address of network endpoint.
//
// The IP address must belong
// to a VM in GCE (either the primary IP or as part of an aliased IP
// range).
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_compute_network_endpoints#ip_address GoogleComputeNetworkEndpoints#ip_address}
IpAddress *string `field:"required" json:"ipAddress" yaml:"ipAddress"`
// The name for a specific VM instance that the IP address belongs to.
//
// This is required for network endpoints of type GCE_VM_IP_PORT.
// The instance must be in the same zone as the network endpoint group.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_compute_network_endpoints#instance GoogleComputeNetworkEndpoints#instance}
Instance *string `field:"optional" json:"instance" yaml:"instance"`
// Port number of network endpoint. **Note** 'port' is required unless the Network Endpoint Group is created with the type of 'GCE_VM_IP'.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_compute_network_endpoints#port GoogleComputeNetworkEndpoints#port}
Port *float64 `field:"optional" json:"port" yaml:"port"`
}
type GoogleComputeNetworkEndpointsNetworkEndpointsList ¶
type GoogleComputeNetworkEndpointsNetworkEndpointsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) GoogleComputeNetworkEndpointsNetworkEndpointsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleComputeNetworkEndpointsNetworkEndpointsList ¶
func NewGoogleComputeNetworkEndpointsNetworkEndpointsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GoogleComputeNetworkEndpointsNetworkEndpointsList
type GoogleComputeNetworkEndpointsNetworkEndpointsOutputReference ¶
type GoogleComputeNetworkEndpointsNetworkEndpointsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Instance() *string
SetInstance(val *string)
InstanceInput() *string
InternalValue() interface{}
SetInternalValue(val interface{})
IpAddress() *string
SetIpAddress(val *string)
IpAddressInput() *string
Port() *float64
SetPort(val *float64)
PortInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetInstance()
ResetPort()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleComputeNetworkEndpointsNetworkEndpointsOutputReference ¶
func NewGoogleComputeNetworkEndpointsNetworkEndpointsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GoogleComputeNetworkEndpointsNetworkEndpointsOutputReference
type GoogleComputeNetworkEndpointsTimeouts ¶
type GoogleComputeNetworkEndpointsTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_compute_network_endpoints#create GoogleComputeNetworkEndpoints#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_compute_network_endpoints#delete GoogleComputeNetworkEndpoints#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_compute_network_endpoints#update GoogleComputeNetworkEndpoints#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type GoogleComputeNetworkEndpointsTimeoutsOutputReference ¶
type GoogleComputeNetworkEndpointsTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleComputeNetworkEndpointsTimeoutsOutputReference ¶
func NewGoogleComputeNetworkEndpointsTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleComputeNetworkEndpointsTimeoutsOutputReference
Source Files
¶
- GoogleComputeNetworkEndpoints.go
- GoogleComputeNetworkEndpointsConfig.go
- GoogleComputeNetworkEndpointsNetworkEndpoints.go
- GoogleComputeNetworkEndpointsNetworkEndpointsList.go
- GoogleComputeNetworkEndpointsNetworkEndpointsList__checks.go
- GoogleComputeNetworkEndpointsNetworkEndpointsOutputReference.go
- GoogleComputeNetworkEndpointsNetworkEndpointsOutputReference__checks.go
- GoogleComputeNetworkEndpointsTimeouts.go
- GoogleComputeNetworkEndpointsTimeoutsOutputReference.go
- GoogleComputeNetworkEndpointsTimeoutsOutputReference__checks.go
- GoogleComputeNetworkEndpoints__checks.go
- main.go