Documentation
¶
Index ¶
- func GoogleDataCatalogEntryGroupIamBinding_IsConstruct(x interface{}) *bool
- func GoogleDataCatalogEntryGroupIamBinding_IsTerraformElement(x interface{}) *bool
- func GoogleDataCatalogEntryGroupIamBinding_IsTerraformResource(x interface{}) *bool
- func GoogleDataCatalogEntryGroupIamBinding_TfResourceType() *string
- func NewGoogleDataCatalogEntryGroupIamBindingConditionOutputReference_Override(g GoogleDataCatalogEntryGroupIamBindingConditionOutputReference, ...)
- func NewGoogleDataCatalogEntryGroupIamBinding_Override(g GoogleDataCatalogEntryGroupIamBinding, scope constructs.Construct, ...)
- type GoogleDataCatalogEntryGroupIamBinding
- type GoogleDataCatalogEntryGroupIamBindingCondition
- type GoogleDataCatalogEntryGroupIamBindingConditionOutputReference
- type GoogleDataCatalogEntryGroupIamBindingConfig
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleDataCatalogEntryGroupIamBinding_IsConstruct ¶
func GoogleDataCatalogEntryGroupIamBinding_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleDataCatalogEntryGroupIamBinding_IsTerraformElement ¶
func GoogleDataCatalogEntryGroupIamBinding_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleDataCatalogEntryGroupIamBinding_IsTerraformResource ¶
func GoogleDataCatalogEntryGroupIamBinding_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleDataCatalogEntryGroupIamBinding_TfResourceType ¶
func GoogleDataCatalogEntryGroupIamBinding_TfResourceType() *string
func NewGoogleDataCatalogEntryGroupIamBindingConditionOutputReference_Override ¶
func NewGoogleDataCatalogEntryGroupIamBindingConditionOutputReference_Override(g GoogleDataCatalogEntryGroupIamBindingConditionOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleDataCatalogEntryGroupIamBinding_Override ¶
func NewGoogleDataCatalogEntryGroupIamBinding_Override(g GoogleDataCatalogEntryGroupIamBinding, scope constructs.Construct, id *string, config *GoogleDataCatalogEntryGroupIamBindingConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_data_catalog_entry_group_iam_binding google_data_catalog_entry_group_iam_binding} Resource.
Types ¶
type GoogleDataCatalogEntryGroupIamBinding ¶
type GoogleDataCatalogEntryGroupIamBinding interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
Condition() GoogleDataCatalogEntryGroupIamBindingConditionOutputReference
ConditionInput() *GoogleDataCatalogEntryGroupIamBindingCondition
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
EntryGroup() *string
SetEntryGroup(val *string)
EntryGroupInput() *string
Etag() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Members() *[]*string
SetMembers(val *[]*string)
MembersInput() *[]*string
// The tree node.
Node() constructs.Node
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Region() *string
SetRegion(val *string)
RegionInput() *string
Role() *string
SetRole(val *string)
RoleInput() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutCondition(value *GoogleDataCatalogEntryGroupIamBindingCondition)
ResetCondition()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
ResetRegion()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_data_catalog_entry_group_iam_binding google_data_catalog_entry_group_iam_binding}.
func NewGoogleDataCatalogEntryGroupIamBinding ¶
func NewGoogleDataCatalogEntryGroupIamBinding(scope constructs.Construct, id *string, config *GoogleDataCatalogEntryGroupIamBindingConfig) GoogleDataCatalogEntryGroupIamBinding
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_data_catalog_entry_group_iam_binding google_data_catalog_entry_group_iam_binding} Resource.
type GoogleDataCatalogEntryGroupIamBindingCondition ¶
type GoogleDataCatalogEntryGroupIamBindingCondition struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_data_catalog_entry_group_iam_binding#expression GoogleDataCatalogEntryGroupIamBinding#expression}.
Expression *string `field:"required" json:"expression" yaml:"expression"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_data_catalog_entry_group_iam_binding#title GoogleDataCatalogEntryGroupIamBinding#title}.
Title *string `field:"required" json:"title" yaml:"title"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_data_catalog_entry_group_iam_binding#description GoogleDataCatalogEntryGroupIamBinding#description}.
Description *string `field:"optional" json:"description" yaml:"description"`
}
type GoogleDataCatalogEntryGroupIamBindingConditionOutputReference ¶
type GoogleDataCatalogEntryGroupIamBindingConditionOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Description() *string
SetDescription(val *string)
DescriptionInput() *string
Expression() *string
SetExpression(val *string)
ExpressionInput() *string
// Experimental.
Fqn() *string
InternalValue() *GoogleDataCatalogEntryGroupIamBindingCondition
SetInternalValue(val *GoogleDataCatalogEntryGroupIamBindingCondition)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Title() *string
SetTitle(val *string)
TitleInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetDescription()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleDataCatalogEntryGroupIamBindingConditionOutputReference ¶
func NewGoogleDataCatalogEntryGroupIamBindingConditionOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleDataCatalogEntryGroupIamBindingConditionOutputReference
type GoogleDataCatalogEntryGroupIamBindingConfig ¶
type GoogleDataCatalogEntryGroupIamBindingConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_data_catalog_entry_group_iam_binding#entry_group GoogleDataCatalogEntryGroupIamBinding#entry_group}.
EntryGroup *string `field:"required" json:"entryGroup" yaml:"entryGroup"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_data_catalog_entry_group_iam_binding#members GoogleDataCatalogEntryGroupIamBinding#members}.
Members *[]*string `field:"required" json:"members" yaml:"members"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_data_catalog_entry_group_iam_binding#role GoogleDataCatalogEntryGroupIamBinding#role}.
Role *string `field:"required" json:"role" yaml:"role"`
// condition block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_data_catalog_entry_group_iam_binding#condition GoogleDataCatalogEntryGroupIamBinding#condition}
Condition *GoogleDataCatalogEntryGroupIamBindingCondition `field:"optional" json:"condition" yaml:"condition"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_data_catalog_entry_group_iam_binding#id GoogleDataCatalogEntryGroupIamBinding#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_data_catalog_entry_group_iam_binding#project GoogleDataCatalogEntryGroupIamBinding#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_data_catalog_entry_group_iam_binding#region GoogleDataCatalogEntryGroupIamBinding#region}.
Region *string `field:"optional" json:"region" yaml:"region"`
}
Source Files
¶
- GoogleDataCatalogEntryGroupIamBinding.go
- GoogleDataCatalogEntryGroupIamBindingCondition.go
- GoogleDataCatalogEntryGroupIamBindingConditionOutputReference.go
- GoogleDataCatalogEntryGroupIamBindingConditionOutputReference__checks.go
- GoogleDataCatalogEntryGroupIamBindingConfig.go
- GoogleDataCatalogEntryGroupIamBinding__checks.go
- main.go