Documentation
¶
Index ¶
- func GoogleDataprocAutoscalingPolicy_IsConstruct(x interface{}) *bool
- func GoogleDataprocAutoscalingPolicy_IsTerraformElement(x interface{}) *bool
- func GoogleDataprocAutoscalingPolicy_IsTerraformResource(x interface{}) *bool
- func GoogleDataprocAutoscalingPolicy_TfResourceType() *string
- func NewGoogleDataprocAutoscalingPolicyBasicAlgorithmOutputReference_Override(g GoogleDataprocAutoscalingPolicyBasicAlgorithmOutputReference, ...)
- func NewGoogleDataprocAutoscalingPolicyBasicAlgorithmYarnConfigOutputReference_Override(g GoogleDataprocAutoscalingPolicyBasicAlgorithmYarnConfigOutputReference, ...)
- func NewGoogleDataprocAutoscalingPolicySecondaryWorkerConfigOutputReference_Override(g GoogleDataprocAutoscalingPolicySecondaryWorkerConfigOutputReference, ...)
- func NewGoogleDataprocAutoscalingPolicyTimeoutsOutputReference_Override(g GoogleDataprocAutoscalingPolicyTimeoutsOutputReference, ...)
- func NewGoogleDataprocAutoscalingPolicyWorkerConfigOutputReference_Override(g GoogleDataprocAutoscalingPolicyWorkerConfigOutputReference, ...)
- func NewGoogleDataprocAutoscalingPolicy_Override(g GoogleDataprocAutoscalingPolicy, scope constructs.Construct, id *string, ...)
- type GoogleDataprocAutoscalingPolicy
- type GoogleDataprocAutoscalingPolicyBasicAlgorithm
- type GoogleDataprocAutoscalingPolicyBasicAlgorithmOutputReference
- type GoogleDataprocAutoscalingPolicyBasicAlgorithmYarnConfig
- type GoogleDataprocAutoscalingPolicyBasicAlgorithmYarnConfigOutputReference
- type GoogleDataprocAutoscalingPolicyConfig
- type GoogleDataprocAutoscalingPolicySecondaryWorkerConfig
- type GoogleDataprocAutoscalingPolicySecondaryWorkerConfigOutputReference
- type GoogleDataprocAutoscalingPolicyTimeouts
- type GoogleDataprocAutoscalingPolicyTimeoutsOutputReference
- type GoogleDataprocAutoscalingPolicyWorkerConfig
- type GoogleDataprocAutoscalingPolicyWorkerConfigOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleDataprocAutoscalingPolicy_IsConstruct ¶
func GoogleDataprocAutoscalingPolicy_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleDataprocAutoscalingPolicy_IsTerraformElement ¶
func GoogleDataprocAutoscalingPolicy_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleDataprocAutoscalingPolicy_IsTerraformResource ¶
func GoogleDataprocAutoscalingPolicy_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleDataprocAutoscalingPolicy_TfResourceType ¶
func GoogleDataprocAutoscalingPolicy_TfResourceType() *string
func NewGoogleDataprocAutoscalingPolicyBasicAlgorithmOutputReference_Override ¶
func NewGoogleDataprocAutoscalingPolicyBasicAlgorithmOutputReference_Override(g GoogleDataprocAutoscalingPolicyBasicAlgorithmOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleDataprocAutoscalingPolicyBasicAlgorithmYarnConfigOutputReference_Override ¶
func NewGoogleDataprocAutoscalingPolicyBasicAlgorithmYarnConfigOutputReference_Override(g GoogleDataprocAutoscalingPolicyBasicAlgorithmYarnConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleDataprocAutoscalingPolicySecondaryWorkerConfigOutputReference_Override ¶
func NewGoogleDataprocAutoscalingPolicySecondaryWorkerConfigOutputReference_Override(g GoogleDataprocAutoscalingPolicySecondaryWorkerConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleDataprocAutoscalingPolicyTimeoutsOutputReference_Override ¶
func NewGoogleDataprocAutoscalingPolicyTimeoutsOutputReference_Override(g GoogleDataprocAutoscalingPolicyTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleDataprocAutoscalingPolicyWorkerConfigOutputReference_Override ¶
func NewGoogleDataprocAutoscalingPolicyWorkerConfigOutputReference_Override(g GoogleDataprocAutoscalingPolicyWorkerConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleDataprocAutoscalingPolicy_Override ¶
func NewGoogleDataprocAutoscalingPolicy_Override(g GoogleDataprocAutoscalingPolicy, scope constructs.Construct, id *string, config *GoogleDataprocAutoscalingPolicyConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_dataproc_autoscaling_policy google_dataproc_autoscaling_policy} Resource.
Types ¶
type GoogleDataprocAutoscalingPolicy ¶
type GoogleDataprocAutoscalingPolicy interface {
cdktf.TerraformResource
BasicAlgorithm() GoogleDataprocAutoscalingPolicyBasicAlgorithmOutputReference
BasicAlgorithmInput() *GoogleDataprocAutoscalingPolicyBasicAlgorithm
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Location() *string
SetLocation(val *string)
LocationInput() *string
Name() *string
// The tree node.
Node() constructs.Node
PolicyId() *string
SetPolicyId(val *string)
PolicyIdInput() *string
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
SecondaryWorkerConfig() GoogleDataprocAutoscalingPolicySecondaryWorkerConfigOutputReference
SecondaryWorkerConfigInput() *GoogleDataprocAutoscalingPolicySecondaryWorkerConfig
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GoogleDataprocAutoscalingPolicyTimeoutsOutputReference
TimeoutsInput() interface{}
WorkerConfig() GoogleDataprocAutoscalingPolicyWorkerConfigOutputReference
WorkerConfigInput() *GoogleDataprocAutoscalingPolicyWorkerConfig
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutBasicAlgorithm(value *GoogleDataprocAutoscalingPolicyBasicAlgorithm)
PutSecondaryWorkerConfig(value *GoogleDataprocAutoscalingPolicySecondaryWorkerConfig)
PutTimeouts(value *GoogleDataprocAutoscalingPolicyTimeouts)
PutWorkerConfig(value *GoogleDataprocAutoscalingPolicyWorkerConfig)
ResetBasicAlgorithm()
ResetId()
ResetLocation()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
ResetSecondaryWorkerConfig()
ResetTimeouts()
ResetWorkerConfig()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_dataproc_autoscaling_policy google_dataproc_autoscaling_policy}.
func NewGoogleDataprocAutoscalingPolicy ¶
func NewGoogleDataprocAutoscalingPolicy(scope constructs.Construct, id *string, config *GoogleDataprocAutoscalingPolicyConfig) GoogleDataprocAutoscalingPolicy
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_dataproc_autoscaling_policy google_dataproc_autoscaling_policy} Resource.
type GoogleDataprocAutoscalingPolicyBasicAlgorithm ¶
type GoogleDataprocAutoscalingPolicyBasicAlgorithm struct {
// yarn_config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_dataproc_autoscaling_policy#yarn_config GoogleDataprocAutoscalingPolicy#yarn_config}
YarnConfig *GoogleDataprocAutoscalingPolicyBasicAlgorithmYarnConfig `field:"required" json:"yarnConfig" yaml:"yarnConfig"`
// Duration between scaling events. A scaling period starts after the update operation from the previous event has completed.
//
// Bounds: [2m, 1d]. Default: 2m.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_dataproc_autoscaling_policy#cooldown_period GoogleDataprocAutoscalingPolicy#cooldown_period}
CooldownPeriod *string `field:"optional" json:"cooldownPeriod" yaml:"cooldownPeriod"`
}
type GoogleDataprocAutoscalingPolicyBasicAlgorithmOutputReference ¶
type GoogleDataprocAutoscalingPolicyBasicAlgorithmOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
CooldownPeriod() *string
SetCooldownPeriod(val *string)
CooldownPeriodInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleDataprocAutoscalingPolicyBasicAlgorithm
SetInternalValue(val *GoogleDataprocAutoscalingPolicyBasicAlgorithm)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
YarnConfig() GoogleDataprocAutoscalingPolicyBasicAlgorithmYarnConfigOutputReference
YarnConfigInput() *GoogleDataprocAutoscalingPolicyBasicAlgorithmYarnConfig
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutYarnConfig(value *GoogleDataprocAutoscalingPolicyBasicAlgorithmYarnConfig)
ResetCooldownPeriod()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleDataprocAutoscalingPolicyBasicAlgorithmOutputReference ¶
func NewGoogleDataprocAutoscalingPolicyBasicAlgorithmOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleDataprocAutoscalingPolicyBasicAlgorithmOutputReference
type GoogleDataprocAutoscalingPolicyBasicAlgorithmYarnConfig ¶
type GoogleDataprocAutoscalingPolicyBasicAlgorithmYarnConfig struct {
// Timeout for YARN graceful decommissioning of Node Managers.
//
// Specifies the
// duration to wait for jobs to complete before forcefully removing workers
// (and potentially interrupting jobs). Only applicable to downscaling operations.
//
// Bounds: [0s, 1d].
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_dataproc_autoscaling_policy#graceful_decommission_timeout GoogleDataprocAutoscalingPolicy#graceful_decommission_timeout}
GracefulDecommissionTimeout *string `field:"required" json:"gracefulDecommissionTimeout" yaml:"gracefulDecommissionTimeout"`
// Fraction of average pending memory in the last cooldown period for which to remove workers.
//
// A scale-down factor of 1 will result in scaling down so that there
// is no available memory remaining after the update (more aggressive scaling).
// A scale-down factor of 0 disables removing workers, which can be beneficial for
// autoscaling a single job.
//
// Bounds: [0.0, 1.0].
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_dataproc_autoscaling_policy#scale_down_factor GoogleDataprocAutoscalingPolicy#scale_down_factor}
ScaleDownFactor *float64 `field:"required" json:"scaleDownFactor" yaml:"scaleDownFactor"`
// Fraction of average pending memory in the last cooldown period for which to add workers.
//
// A scale-up factor of 1.0 will result in scaling up so that there
// is no pending memory remaining after the update (more aggressive scaling).
// A scale-up factor closer to 0 will result in a smaller magnitude of scaling up
// (less aggressive scaling).
//
// Bounds: [0.0, 1.0].
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_dataproc_autoscaling_policy#scale_up_factor GoogleDataprocAutoscalingPolicy#scale_up_factor}
ScaleUpFactor *float64 `field:"required" json:"scaleUpFactor" yaml:"scaleUpFactor"`
// Minimum scale-down threshold as a fraction of total cluster size before scaling occurs.
//
// For example, in a 20-worker cluster, a threshold of 0.1 means the autoscaler must
// recommend at least a 2 worker scale-down for the cluster to scale. A threshold of 0
// means the autoscaler will scale down on any recommended change.
//
// Bounds: [0.0, 1.0]. Default: 0.0.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_dataproc_autoscaling_policy#scale_down_min_worker_fraction GoogleDataprocAutoscalingPolicy#scale_down_min_worker_fraction}
ScaleDownMinWorkerFraction *float64 `field:"optional" json:"scaleDownMinWorkerFraction" yaml:"scaleDownMinWorkerFraction"`
// Minimum scale-up threshold as a fraction of total cluster size before scaling occurs.
//
// For example, in a 20-worker cluster, a threshold of 0.1 means the autoscaler
// must recommend at least a 2-worker scale-up for the cluster to scale. A threshold of
// 0 means the autoscaler will scale up on any recommended change.
//
// Bounds: [0.0, 1.0]. Default: 0.0.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_dataproc_autoscaling_policy#scale_up_min_worker_fraction GoogleDataprocAutoscalingPolicy#scale_up_min_worker_fraction}
ScaleUpMinWorkerFraction *float64 `field:"optional" json:"scaleUpMinWorkerFraction" yaml:"scaleUpMinWorkerFraction"`
}
type GoogleDataprocAutoscalingPolicyBasicAlgorithmYarnConfigOutputReference ¶
type GoogleDataprocAutoscalingPolicyBasicAlgorithmYarnConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
GracefulDecommissionTimeout() *string
SetGracefulDecommissionTimeout(val *string)
GracefulDecommissionTimeoutInput() *string
InternalValue() *GoogleDataprocAutoscalingPolicyBasicAlgorithmYarnConfig
SetInternalValue(val *GoogleDataprocAutoscalingPolicyBasicAlgorithmYarnConfig)
ScaleDownFactor() *float64
SetScaleDownFactor(val *float64)
ScaleDownFactorInput() *float64
ScaleDownMinWorkerFraction() *float64
SetScaleDownMinWorkerFraction(val *float64)
ScaleDownMinWorkerFractionInput() *float64
ScaleUpFactor() *float64
SetScaleUpFactor(val *float64)
ScaleUpFactorInput() *float64
ScaleUpMinWorkerFraction() *float64
SetScaleUpMinWorkerFraction(val *float64)
ScaleUpMinWorkerFractionInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetScaleDownMinWorkerFraction()
ResetScaleUpMinWorkerFraction()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleDataprocAutoscalingPolicyBasicAlgorithmYarnConfigOutputReference ¶
func NewGoogleDataprocAutoscalingPolicyBasicAlgorithmYarnConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleDataprocAutoscalingPolicyBasicAlgorithmYarnConfigOutputReference
type GoogleDataprocAutoscalingPolicyConfig ¶
type GoogleDataprocAutoscalingPolicyConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// The policy id.
//
// The id must contain only letters (a-z, A-Z), numbers (0-9), underscores (_),
// and hyphens (-). Cannot begin or end with underscore or hyphen. Must consist of between
// 3 and 50 characters.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_dataproc_autoscaling_policy#policy_id GoogleDataprocAutoscalingPolicy#policy_id}
PolicyId *string `field:"required" json:"policyId" yaml:"policyId"`
// basic_algorithm block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_dataproc_autoscaling_policy#basic_algorithm GoogleDataprocAutoscalingPolicy#basic_algorithm}
BasicAlgorithm *GoogleDataprocAutoscalingPolicyBasicAlgorithm `field:"optional" json:"basicAlgorithm" yaml:"basicAlgorithm"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_dataproc_autoscaling_policy#id GoogleDataprocAutoscalingPolicy#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// The location where the autoscaling policy should reside. The default value is 'global'.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_dataproc_autoscaling_policy#location GoogleDataprocAutoscalingPolicy#location}
Location *string `field:"optional" json:"location" yaml:"location"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_dataproc_autoscaling_policy#project GoogleDataprocAutoscalingPolicy#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// secondary_worker_config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_dataproc_autoscaling_policy#secondary_worker_config GoogleDataprocAutoscalingPolicy#secondary_worker_config}
SecondaryWorkerConfig *GoogleDataprocAutoscalingPolicySecondaryWorkerConfig `field:"optional" json:"secondaryWorkerConfig" yaml:"secondaryWorkerConfig"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_dataproc_autoscaling_policy#timeouts GoogleDataprocAutoscalingPolicy#timeouts}
Timeouts *GoogleDataprocAutoscalingPolicyTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
// worker_config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_dataproc_autoscaling_policy#worker_config GoogleDataprocAutoscalingPolicy#worker_config}
WorkerConfig *GoogleDataprocAutoscalingPolicyWorkerConfig `field:"optional" json:"workerConfig" yaml:"workerConfig"`
}
type GoogleDataprocAutoscalingPolicySecondaryWorkerConfig ¶
type GoogleDataprocAutoscalingPolicySecondaryWorkerConfig struct {
// Maximum number of instances for this group.
//
// Note that by default, clusters will not use
// secondary workers. Required for secondary workers if the minimum secondary instances is set.
// Bounds: [minInstances, ). Defaults to 0.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_dataproc_autoscaling_policy#max_instances GoogleDataprocAutoscalingPolicy#max_instances}
MaxInstances *float64 `field:"optional" json:"maxInstances" yaml:"maxInstances"`
// Minimum number of instances for this group. Bounds: [0, maxInstances]. Defaults to 0.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_dataproc_autoscaling_policy#min_instances GoogleDataprocAutoscalingPolicy#min_instances}
MinInstances *float64 `field:"optional" json:"minInstances" yaml:"minInstances"`
// Weight for the instance group, which is used to determine the fraction of total workers in the cluster from this instance group.
//
// For example, if primary workers have weight 2,
// and secondary workers have weight 1, the cluster will have approximately 2 primary workers
// for each secondary worker.
//
// The cluster may not reach the specified balance if constrained by min/max bounds or other
// autoscaling settings. For example, if maxInstances for secondary workers is 0, then only
// primary workers will be added. The cluster can also be out of balance when created.
//
// If weight is not set on any instance group, the cluster will default to equal weight for
// all groups: the cluster will attempt to maintain an equal number of workers in each group
// within the configured size bounds for each group. If weight is set for one group only,
// the cluster will default to zero weight on the unset group. For example if weight is set
// only on primary workers, the cluster will use primary workers only and no secondary workers.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_dataproc_autoscaling_policy#weight GoogleDataprocAutoscalingPolicy#weight}
Weight *float64 `field:"optional" json:"weight" yaml:"weight"`
}
type GoogleDataprocAutoscalingPolicySecondaryWorkerConfigOutputReference ¶
type GoogleDataprocAutoscalingPolicySecondaryWorkerConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleDataprocAutoscalingPolicySecondaryWorkerConfig
SetInternalValue(val *GoogleDataprocAutoscalingPolicySecondaryWorkerConfig)
MaxInstances() *float64
SetMaxInstances(val *float64)
MaxInstancesInput() *float64
MinInstances() *float64
SetMinInstances(val *float64)
MinInstancesInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Weight() *float64
SetWeight(val *float64)
WeightInput() *float64
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetMaxInstances()
ResetMinInstances()
ResetWeight()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleDataprocAutoscalingPolicySecondaryWorkerConfigOutputReference ¶
func NewGoogleDataprocAutoscalingPolicySecondaryWorkerConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleDataprocAutoscalingPolicySecondaryWorkerConfigOutputReference
type GoogleDataprocAutoscalingPolicyTimeouts ¶
type GoogleDataprocAutoscalingPolicyTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_dataproc_autoscaling_policy#create GoogleDataprocAutoscalingPolicy#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_dataproc_autoscaling_policy#delete GoogleDataprocAutoscalingPolicy#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_dataproc_autoscaling_policy#update GoogleDataprocAutoscalingPolicy#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type GoogleDataprocAutoscalingPolicyTimeoutsOutputReference ¶
type GoogleDataprocAutoscalingPolicyTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleDataprocAutoscalingPolicyTimeoutsOutputReference ¶
func NewGoogleDataprocAutoscalingPolicyTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleDataprocAutoscalingPolicyTimeoutsOutputReference
type GoogleDataprocAutoscalingPolicyWorkerConfig ¶
type GoogleDataprocAutoscalingPolicyWorkerConfig struct {
// Maximum number of instances for this group.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_dataproc_autoscaling_policy#max_instances GoogleDataprocAutoscalingPolicy#max_instances}
MaxInstances *float64 `field:"required" json:"maxInstances" yaml:"maxInstances"`
// Minimum number of instances for this group. Bounds: [2, maxInstances]. Defaults to 2.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_dataproc_autoscaling_policy#min_instances GoogleDataprocAutoscalingPolicy#min_instances}
MinInstances *float64 `field:"optional" json:"minInstances" yaml:"minInstances"`
// Weight for the instance group, which is used to determine the fraction of total workers in the cluster from this instance group.
//
// For example, if primary workers have weight 2,
// and secondary workers have weight 1, the cluster will have approximately 2 primary workers
// for each secondary worker.
//
// The cluster may not reach the specified balance if constrained by min/max bounds or other
// autoscaling settings. For example, if maxInstances for secondary workers is 0, then only
// primary workers will be added. The cluster can also be out of balance when created.
//
// If weight is not set on any instance group, the cluster will default to equal weight for
// all groups: the cluster will attempt to maintain an equal number of workers in each group
// within the configured size bounds for each group. If weight is set for one group only,
// the cluster will default to zero weight on the unset group. For example if weight is set
// only on primary workers, the cluster will use primary workers only and no secondary workers.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_dataproc_autoscaling_policy#weight GoogleDataprocAutoscalingPolicy#weight}
Weight *float64 `field:"optional" json:"weight" yaml:"weight"`
}
type GoogleDataprocAutoscalingPolicyWorkerConfigOutputReference ¶
type GoogleDataprocAutoscalingPolicyWorkerConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleDataprocAutoscalingPolicyWorkerConfig
SetInternalValue(val *GoogleDataprocAutoscalingPolicyWorkerConfig)
MaxInstances() *float64
SetMaxInstances(val *float64)
MaxInstancesInput() *float64
MinInstances() *float64
SetMinInstances(val *float64)
MinInstancesInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Weight() *float64
SetWeight(val *float64)
WeightInput() *float64
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetMinInstances()
ResetWeight()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleDataprocAutoscalingPolicyWorkerConfigOutputReference ¶
func NewGoogleDataprocAutoscalingPolicyWorkerConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleDataprocAutoscalingPolicyWorkerConfigOutputReference
Source Files
¶
- GoogleDataprocAutoscalingPolicy.go
- GoogleDataprocAutoscalingPolicyBasicAlgorithm.go
- GoogleDataprocAutoscalingPolicyBasicAlgorithmOutputReference.go
- GoogleDataprocAutoscalingPolicyBasicAlgorithmOutputReference__checks.go
- GoogleDataprocAutoscalingPolicyBasicAlgorithmYarnConfig.go
- GoogleDataprocAutoscalingPolicyBasicAlgorithmYarnConfigOutputReference.go
- GoogleDataprocAutoscalingPolicyBasicAlgorithmYarnConfigOutputReference__checks.go
- GoogleDataprocAutoscalingPolicyConfig.go
- GoogleDataprocAutoscalingPolicySecondaryWorkerConfig.go
- GoogleDataprocAutoscalingPolicySecondaryWorkerConfigOutputReference.go
- GoogleDataprocAutoscalingPolicySecondaryWorkerConfigOutputReference__checks.go
- GoogleDataprocAutoscalingPolicyTimeouts.go
- GoogleDataprocAutoscalingPolicyTimeoutsOutputReference.go
- GoogleDataprocAutoscalingPolicyTimeoutsOutputReference__checks.go
- GoogleDataprocAutoscalingPolicyWorkerConfig.go
- GoogleDataprocAutoscalingPolicyWorkerConfigOutputReference.go
- GoogleDataprocAutoscalingPolicyWorkerConfigOutputReference__checks.go
- GoogleDataprocAutoscalingPolicy__checks.go
- main.go