Documentation
¶
Index ¶
- func GoogleDatastreamPrivateConnection_IsConstruct(x interface{}) *bool
- func GoogleDatastreamPrivateConnection_IsTerraformElement(x interface{}) *bool
- func GoogleDatastreamPrivateConnection_IsTerraformResource(x interface{}) *bool
- func GoogleDatastreamPrivateConnection_TfResourceType() *string
- func NewGoogleDatastreamPrivateConnectionErrorList_Override(g GoogleDatastreamPrivateConnectionErrorList, ...)
- func NewGoogleDatastreamPrivateConnectionErrorOutputReference_Override(g GoogleDatastreamPrivateConnectionErrorOutputReference, ...)
- func NewGoogleDatastreamPrivateConnectionTimeoutsOutputReference_Override(g GoogleDatastreamPrivateConnectionTimeoutsOutputReference, ...)
- func NewGoogleDatastreamPrivateConnectionVpcPeeringConfigOutputReference_Override(g GoogleDatastreamPrivateConnectionVpcPeeringConfigOutputReference, ...)
- func NewGoogleDatastreamPrivateConnection_Override(g GoogleDatastreamPrivateConnection, scope constructs.Construct, id *string, ...)
- type GoogleDatastreamPrivateConnection
- type GoogleDatastreamPrivateConnectionConfig
- type GoogleDatastreamPrivateConnectionError
- type GoogleDatastreamPrivateConnectionErrorList
- type GoogleDatastreamPrivateConnectionErrorOutputReference
- type GoogleDatastreamPrivateConnectionTimeouts
- type GoogleDatastreamPrivateConnectionTimeoutsOutputReference
- type GoogleDatastreamPrivateConnectionVpcPeeringConfig
- type GoogleDatastreamPrivateConnectionVpcPeeringConfigOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleDatastreamPrivateConnection_IsConstruct ¶
func GoogleDatastreamPrivateConnection_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleDatastreamPrivateConnection_IsTerraformElement ¶
func GoogleDatastreamPrivateConnection_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleDatastreamPrivateConnection_IsTerraformResource ¶
func GoogleDatastreamPrivateConnection_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleDatastreamPrivateConnection_TfResourceType ¶
func GoogleDatastreamPrivateConnection_TfResourceType() *string
func NewGoogleDatastreamPrivateConnectionErrorList_Override ¶
func NewGoogleDatastreamPrivateConnectionErrorList_Override(g GoogleDatastreamPrivateConnectionErrorList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGoogleDatastreamPrivateConnectionErrorOutputReference_Override ¶
func NewGoogleDatastreamPrivateConnectionErrorOutputReference_Override(g GoogleDatastreamPrivateConnectionErrorOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGoogleDatastreamPrivateConnectionTimeoutsOutputReference_Override ¶
func NewGoogleDatastreamPrivateConnectionTimeoutsOutputReference_Override(g GoogleDatastreamPrivateConnectionTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleDatastreamPrivateConnectionVpcPeeringConfigOutputReference_Override ¶
func NewGoogleDatastreamPrivateConnectionVpcPeeringConfigOutputReference_Override(g GoogleDatastreamPrivateConnectionVpcPeeringConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleDatastreamPrivateConnection_Override ¶
func NewGoogleDatastreamPrivateConnection_Override(g GoogleDatastreamPrivateConnection, scope constructs.Construct, id *string, config *GoogleDatastreamPrivateConnectionConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_datastream_private_connection google_datastream_private_connection} Resource.
Types ¶
type GoogleDatastreamPrivateConnection ¶
type GoogleDatastreamPrivateConnection interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DisplayName() *string
SetDisplayName(val *string)
DisplayNameInput() *string
EffectiveLabels() cdktf.StringMap
Error() GoogleDatastreamPrivateConnectionErrorList
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
Labels() *map[string]*string
SetLabels(val *map[string]*string)
LabelsInput() *map[string]*string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Location() *string
SetLocation(val *string)
LocationInput() *string
Name() *string
// The tree node.
Node() constructs.Node
PrivateConnectionId() *string
SetPrivateConnectionId(val *string)
PrivateConnectionIdInput() *string
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
State() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
TerraformLabels() cdktf.StringMap
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GoogleDatastreamPrivateConnectionTimeoutsOutputReference
TimeoutsInput() interface{}
VpcPeeringConfig() GoogleDatastreamPrivateConnectionVpcPeeringConfigOutputReference
VpcPeeringConfigInput() *GoogleDatastreamPrivateConnectionVpcPeeringConfig
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutTimeouts(value *GoogleDatastreamPrivateConnectionTimeouts)
PutVpcPeeringConfig(value *GoogleDatastreamPrivateConnectionVpcPeeringConfig)
ResetId()
ResetLabels()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_datastream_private_connection google_datastream_private_connection}.
func NewGoogleDatastreamPrivateConnection ¶
func NewGoogleDatastreamPrivateConnection(scope constructs.Construct, id *string, config *GoogleDatastreamPrivateConnectionConfig) GoogleDatastreamPrivateConnection
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_datastream_private_connection google_datastream_private_connection} Resource.
type GoogleDatastreamPrivateConnectionConfig ¶
type GoogleDatastreamPrivateConnectionConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Display name.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_datastream_private_connection#display_name GoogleDatastreamPrivateConnection#display_name}
DisplayName *string `field:"required" json:"displayName" yaml:"displayName"`
// The name of the location this private connection is located in.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_datastream_private_connection#location GoogleDatastreamPrivateConnection#location}
Location *string `field:"required" json:"location" yaml:"location"`
// The private connectivity identifier.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_datastream_private_connection#private_connection_id GoogleDatastreamPrivateConnection#private_connection_id}
PrivateConnectionId *string `field:"required" json:"privateConnectionId" yaml:"privateConnectionId"`
// vpc_peering_config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_datastream_private_connection#vpc_peering_config GoogleDatastreamPrivateConnection#vpc_peering_config}
VpcPeeringConfig *GoogleDatastreamPrivateConnectionVpcPeeringConfig `field:"required" json:"vpcPeeringConfig" yaml:"vpcPeeringConfig"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_datastream_private_connection#id GoogleDatastreamPrivateConnection#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Labels.
//
// **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
// Please refer to the field 'effective_labels' for all of the labels present on the resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_datastream_private_connection#labels GoogleDatastreamPrivateConnection#labels}
Labels *map[string]*string `field:"optional" json:"labels" yaml:"labels"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_datastream_private_connection#project GoogleDatastreamPrivateConnection#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_datastream_private_connection#timeouts GoogleDatastreamPrivateConnection#timeouts}
Timeouts *GoogleDatastreamPrivateConnectionTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type GoogleDatastreamPrivateConnectionError ¶
type GoogleDatastreamPrivateConnectionError struct {
}
type GoogleDatastreamPrivateConnectionErrorList ¶
type GoogleDatastreamPrivateConnectionErrorList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) GoogleDatastreamPrivateConnectionErrorOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleDatastreamPrivateConnectionErrorList ¶
func NewGoogleDatastreamPrivateConnectionErrorList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GoogleDatastreamPrivateConnectionErrorList
type GoogleDatastreamPrivateConnectionErrorOutputReference ¶
type GoogleDatastreamPrivateConnectionErrorOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Details() cdktf.StringMap
// Experimental.
Fqn() *string
InternalValue() *GoogleDatastreamPrivateConnectionError
SetInternalValue(val *GoogleDatastreamPrivateConnectionError)
Message() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleDatastreamPrivateConnectionErrorOutputReference ¶
func NewGoogleDatastreamPrivateConnectionErrorOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GoogleDatastreamPrivateConnectionErrorOutputReference
type GoogleDatastreamPrivateConnectionTimeouts ¶
type GoogleDatastreamPrivateConnectionTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_datastream_private_connection#create GoogleDatastreamPrivateConnection#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_datastream_private_connection#delete GoogleDatastreamPrivateConnection#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
}
type GoogleDatastreamPrivateConnectionTimeoutsOutputReference ¶
type GoogleDatastreamPrivateConnectionTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleDatastreamPrivateConnectionTimeoutsOutputReference ¶
func NewGoogleDatastreamPrivateConnectionTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleDatastreamPrivateConnectionTimeoutsOutputReference
type GoogleDatastreamPrivateConnectionVpcPeeringConfig ¶
type GoogleDatastreamPrivateConnectionVpcPeeringConfig struct {
// A free subnet for peering. (CIDR of /29).
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_datastream_private_connection#subnet GoogleDatastreamPrivateConnection#subnet}
Subnet *string `field:"required" json:"subnet" yaml:"subnet"`
// Fully qualified name of the VPC that Datastream will peer to. Format: projects/{project}/global/{networks}/{name}.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_datastream_private_connection#vpc GoogleDatastreamPrivateConnection#vpc}
Vpc *string `field:"required" json:"vpc" yaml:"vpc"`
}
type GoogleDatastreamPrivateConnectionVpcPeeringConfigOutputReference ¶
type GoogleDatastreamPrivateConnectionVpcPeeringConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleDatastreamPrivateConnectionVpcPeeringConfig
SetInternalValue(val *GoogleDatastreamPrivateConnectionVpcPeeringConfig)
Subnet() *string
SetSubnet(val *string)
SubnetInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Vpc() *string
SetVpc(val *string)
VpcInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleDatastreamPrivateConnectionVpcPeeringConfigOutputReference ¶
func NewGoogleDatastreamPrivateConnectionVpcPeeringConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleDatastreamPrivateConnectionVpcPeeringConfigOutputReference
Source Files
¶
- GoogleDatastreamPrivateConnection.go
- GoogleDatastreamPrivateConnectionConfig.go
- GoogleDatastreamPrivateConnectionError.go
- GoogleDatastreamPrivateConnectionErrorList.go
- GoogleDatastreamPrivateConnectionErrorList__checks.go
- GoogleDatastreamPrivateConnectionErrorOutputReference.go
- GoogleDatastreamPrivateConnectionErrorOutputReference__checks.go
- GoogleDatastreamPrivateConnectionTimeouts.go
- GoogleDatastreamPrivateConnectionTimeoutsOutputReference.go
- GoogleDatastreamPrivateConnectionTimeoutsOutputReference__checks.go
- GoogleDatastreamPrivateConnectionVpcPeeringConfig.go
- GoogleDatastreamPrivateConnectionVpcPeeringConfigOutputReference.go
- GoogleDatastreamPrivateConnectionVpcPeeringConfigOutputReference__checks.go
- GoogleDatastreamPrivateConnection__checks.go
- main.go