Documentation
¶
Index ¶
- func GoogleDialogflowCxAgent_IsConstruct(x interface{}) *bool
- func GoogleDialogflowCxAgent_IsTerraformElement(x interface{}) *bool
- func GoogleDialogflowCxAgent_IsTerraformResource(x interface{}) *bool
- func GoogleDialogflowCxAgent_TfResourceType() *string
- func NewGoogleDialogflowCxAgentSpeechToTextSettingsOutputReference_Override(g GoogleDialogflowCxAgentSpeechToTextSettingsOutputReference, ...)
- func NewGoogleDialogflowCxAgentTimeoutsOutputReference_Override(g GoogleDialogflowCxAgentTimeoutsOutputReference, ...)
- func NewGoogleDialogflowCxAgent_Override(g GoogleDialogflowCxAgent, scope constructs.Construct, id *string, ...)
- type GoogleDialogflowCxAgent
- type GoogleDialogflowCxAgentConfig
- type GoogleDialogflowCxAgentSpeechToTextSettings
- type GoogleDialogflowCxAgentSpeechToTextSettingsOutputReference
- type GoogleDialogflowCxAgentTimeouts
- type GoogleDialogflowCxAgentTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleDialogflowCxAgent_IsConstruct ¶
func GoogleDialogflowCxAgent_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleDialogflowCxAgent_IsTerraformElement ¶
func GoogleDialogflowCxAgent_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleDialogflowCxAgent_IsTerraformResource ¶
func GoogleDialogflowCxAgent_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleDialogflowCxAgent_TfResourceType ¶
func GoogleDialogflowCxAgent_TfResourceType() *string
func NewGoogleDialogflowCxAgentSpeechToTextSettingsOutputReference_Override ¶
func NewGoogleDialogflowCxAgentSpeechToTextSettingsOutputReference_Override(g GoogleDialogflowCxAgentSpeechToTextSettingsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleDialogflowCxAgentTimeoutsOutputReference_Override ¶
func NewGoogleDialogflowCxAgentTimeoutsOutputReference_Override(g GoogleDialogflowCxAgentTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleDialogflowCxAgent_Override ¶
func NewGoogleDialogflowCxAgent_Override(g GoogleDialogflowCxAgent, scope constructs.Construct, id *string, config *GoogleDialogflowCxAgentConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_dialogflow_cx_agent google_dialogflow_cx_agent} Resource.
Types ¶
type GoogleDialogflowCxAgent ¶
type GoogleDialogflowCxAgent interface {
cdktf.TerraformResource
AvatarUri() *string
SetAvatarUri(val *string)
AvatarUriInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
DefaultLanguageCode() *string
SetDefaultLanguageCode(val *string)
DefaultLanguageCodeInput() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
DisplayName() *string
SetDisplayName(val *string)
DisplayNameInput() *string
EnableSpellCorrection() interface{}
SetEnableSpellCorrection(val interface{})
EnableSpellCorrectionInput() interface{}
EnableStackdriverLogging() interface{}
SetEnableStackdriverLogging(val interface{})
EnableStackdriverLoggingInput() interface{}
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Location() *string
SetLocation(val *string)
LocationInput() *string
Name() *string
// The tree node.
Node() constructs.Node
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
SecuritySettings() *string
SetSecuritySettings(val *string)
SecuritySettingsInput() *string
SpeechToTextSettings() GoogleDialogflowCxAgentSpeechToTextSettingsOutputReference
SpeechToTextSettingsInput() *GoogleDialogflowCxAgentSpeechToTextSettings
StartFlow() *string
SupportedLanguageCodes() *[]*string
SetSupportedLanguageCodes(val *[]*string)
SupportedLanguageCodesInput() *[]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GoogleDialogflowCxAgentTimeoutsOutputReference
TimeoutsInput() interface{}
TimeZone() *string
SetTimeZone(val *string)
TimeZoneInput() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutSpeechToTextSettings(value *GoogleDialogflowCxAgentSpeechToTextSettings)
PutTimeouts(value *GoogleDialogflowCxAgentTimeouts)
ResetAvatarUri()
ResetDescription()
ResetEnableSpellCorrection()
ResetEnableStackdriverLogging()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
ResetSecuritySettings()
ResetSpeechToTextSettings()
ResetSupportedLanguageCodes()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_dialogflow_cx_agent google_dialogflow_cx_agent}.
func NewGoogleDialogflowCxAgent ¶
func NewGoogleDialogflowCxAgent(scope constructs.Construct, id *string, config *GoogleDialogflowCxAgentConfig) GoogleDialogflowCxAgent
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_dialogflow_cx_agent google_dialogflow_cx_agent} Resource.
type GoogleDialogflowCxAgentConfig ¶
type GoogleDialogflowCxAgentConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// The default language of the agent as a language tag.
//
// [See Language Support](https://cloud.google.com/dialogflow/cx/docs/reference/language)
// for a list of the currently supported language codes. This field cannot be updated after creation.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_dialogflow_cx_agent#default_language_code GoogleDialogflowCxAgent#default_language_code}
DefaultLanguageCode *string `field:"required" json:"defaultLanguageCode" yaml:"defaultLanguageCode"`
// The human-readable name of the agent, unique within the location.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_dialogflow_cx_agent#display_name GoogleDialogflowCxAgent#display_name}
DisplayName *string `field:"required" json:"displayName" yaml:"displayName"`
// The name of the location this agent is located in.
//
// ~> **Note:** The first time you are deploying an Agent in your project you must configure location settings.
// This is a one time step but at the moment you can only [configure location settings](https://cloud.google.com/dialogflow/cx/docs/concept/region#location-settings) via the Dialogflow CX console.
// Another options is to use global location so you don't need to manually configure location settings.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_dialogflow_cx_agent#location GoogleDialogflowCxAgent#location}
Location *string `field:"required" json:"location" yaml:"location"`
// The time zone of this agent from the [time zone database](https://www.iana.org/time-zones), e.g., America/New_York, Europe/Paris.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_dialogflow_cx_agent#time_zone GoogleDialogflowCxAgent#time_zone}
TimeZone *string `field:"required" json:"timeZone" yaml:"timeZone"`
// The URI of the agent's avatar.
//
// Avatars are used throughout the Dialogflow console and in the self-hosted Web Demo integration.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_dialogflow_cx_agent#avatar_uri GoogleDialogflowCxAgent#avatar_uri}
AvatarUri *string `field:"optional" json:"avatarUri" yaml:"avatarUri"`
// The description of this agent. The maximum length is 500 characters. If exceeded, the request is rejected.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_dialogflow_cx_agent#description GoogleDialogflowCxAgent#description}
Description *string `field:"optional" json:"description" yaml:"description"`
// Indicates if automatic spell correction is enabled in detect intent requests.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_dialogflow_cx_agent#enable_spell_correction GoogleDialogflowCxAgent#enable_spell_correction}
EnableSpellCorrection interface{} `field:"optional" json:"enableSpellCorrection" yaml:"enableSpellCorrection"`
// Determines whether this agent should log conversation queries.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_dialogflow_cx_agent#enable_stackdriver_logging GoogleDialogflowCxAgent#enable_stackdriver_logging}
EnableStackdriverLogging interface{} `field:"optional" json:"enableStackdriverLogging" yaml:"enableStackdriverLogging"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_dialogflow_cx_agent#id GoogleDialogflowCxAgent#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_dialogflow_cx_agent#project GoogleDialogflowCxAgent#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// Name of the SecuritySettings reference for the agent. Format: projects/<Project ID>/locations/<Location ID>/securitySettings/<Security Settings ID>.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_dialogflow_cx_agent#security_settings GoogleDialogflowCxAgent#security_settings}
SecuritySettings *string `field:"optional" json:"securitySettings" yaml:"securitySettings"`
// speech_to_text_settings block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_dialogflow_cx_agent#speech_to_text_settings GoogleDialogflowCxAgent#speech_to_text_settings}
SpeechToTextSettings *GoogleDialogflowCxAgentSpeechToTextSettings `field:"optional" json:"speechToTextSettings" yaml:"speechToTextSettings"`
// The list of all languages supported by this agent (except for the default_language_code).
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_dialogflow_cx_agent#supported_language_codes GoogleDialogflowCxAgent#supported_language_codes}
SupportedLanguageCodes *[]*string `field:"optional" json:"supportedLanguageCodes" yaml:"supportedLanguageCodes"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_dialogflow_cx_agent#timeouts GoogleDialogflowCxAgent#timeouts}
Timeouts *GoogleDialogflowCxAgentTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type GoogleDialogflowCxAgentSpeechToTextSettings ¶
type GoogleDialogflowCxAgentSpeechToTextSettings struct {
// Whether to use speech adaptation for speech recognition.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_dialogflow_cx_agent#enable_speech_adaptation GoogleDialogflowCxAgent#enable_speech_adaptation}
EnableSpeechAdaptation interface{} `field:"optional" json:"enableSpeechAdaptation" yaml:"enableSpeechAdaptation"`
}
type GoogleDialogflowCxAgentSpeechToTextSettingsOutputReference ¶
type GoogleDialogflowCxAgentSpeechToTextSettingsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
EnableSpeechAdaptation() interface{}
SetEnableSpeechAdaptation(val interface{})
EnableSpeechAdaptationInput() interface{}
// Experimental.
Fqn() *string
InternalValue() *GoogleDialogflowCxAgentSpeechToTextSettings
SetInternalValue(val *GoogleDialogflowCxAgentSpeechToTextSettings)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetEnableSpeechAdaptation()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleDialogflowCxAgentSpeechToTextSettingsOutputReference ¶
func NewGoogleDialogflowCxAgentSpeechToTextSettingsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleDialogflowCxAgentSpeechToTextSettingsOutputReference
type GoogleDialogflowCxAgentTimeouts ¶
type GoogleDialogflowCxAgentTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_dialogflow_cx_agent#create GoogleDialogflowCxAgent#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_dialogflow_cx_agent#delete GoogleDialogflowCxAgent#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_dialogflow_cx_agent#update GoogleDialogflowCxAgent#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type GoogleDialogflowCxAgentTimeoutsOutputReference ¶
type GoogleDialogflowCxAgentTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleDialogflowCxAgentTimeoutsOutputReference ¶
func NewGoogleDialogflowCxAgentTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleDialogflowCxAgentTimeoutsOutputReference
Source Files
¶
- GoogleDialogflowCxAgent.go
- GoogleDialogflowCxAgentConfig.go
- GoogleDialogflowCxAgentSpeechToTextSettings.go
- GoogleDialogflowCxAgentSpeechToTextSettingsOutputReference.go
- GoogleDialogflowCxAgentSpeechToTextSettingsOutputReference__checks.go
- GoogleDialogflowCxAgentTimeouts.go
- GoogleDialogflowCxAgentTimeoutsOutputReference.go
- GoogleDialogflowCxAgentTimeoutsOutputReference__checks.go
- GoogleDialogflowCxAgent__checks.go
- main.go