Documentation
¶
Index ¶
- func GoogleEventarcTrigger_IsConstruct(x interface{}) *bool
- func GoogleEventarcTrigger_IsTerraformElement(x interface{}) *bool
- func GoogleEventarcTrigger_IsTerraformResource(x interface{}) *bool
- func GoogleEventarcTrigger_TfResourceType() *string
- func NewGoogleEventarcTriggerDestinationCloudRunServiceOutputReference_Override(g GoogleEventarcTriggerDestinationCloudRunServiceOutputReference, ...)
- func NewGoogleEventarcTriggerDestinationGkeOutputReference_Override(g GoogleEventarcTriggerDestinationGkeOutputReference, ...)
- func NewGoogleEventarcTriggerDestinationOutputReference_Override(g GoogleEventarcTriggerDestinationOutputReference, ...)
- func NewGoogleEventarcTriggerMatchingCriteriaList_Override(g GoogleEventarcTriggerMatchingCriteriaList, ...)
- func NewGoogleEventarcTriggerMatchingCriteriaOutputReference_Override(g GoogleEventarcTriggerMatchingCriteriaOutputReference, ...)
- func NewGoogleEventarcTriggerTimeoutsOutputReference_Override(g GoogleEventarcTriggerTimeoutsOutputReference, ...)
- func NewGoogleEventarcTriggerTransportOutputReference_Override(g GoogleEventarcTriggerTransportOutputReference, ...)
- func NewGoogleEventarcTriggerTransportPubsubOutputReference_Override(g GoogleEventarcTriggerTransportPubsubOutputReference, ...)
- func NewGoogleEventarcTrigger_Override(g GoogleEventarcTrigger, scope constructs.Construct, id *string, ...)
- type GoogleEventarcTrigger
- type GoogleEventarcTriggerConfig
- type GoogleEventarcTriggerDestination
- type GoogleEventarcTriggerDestinationCloudRunService
- type GoogleEventarcTriggerDestinationCloudRunServiceOutputReference
- type GoogleEventarcTriggerDestinationGke
- type GoogleEventarcTriggerDestinationGkeOutputReference
- type GoogleEventarcTriggerDestinationOutputReference
- type GoogleEventarcTriggerMatchingCriteria
- type GoogleEventarcTriggerMatchingCriteriaList
- type GoogleEventarcTriggerMatchingCriteriaOutputReference
- type GoogleEventarcTriggerTimeouts
- type GoogleEventarcTriggerTimeoutsOutputReference
- type GoogleEventarcTriggerTransport
- type GoogleEventarcTriggerTransportOutputReference
- type GoogleEventarcTriggerTransportPubsub
- type GoogleEventarcTriggerTransportPubsubOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleEventarcTrigger_IsConstruct ¶
func GoogleEventarcTrigger_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleEventarcTrigger_IsTerraformElement ¶
func GoogleEventarcTrigger_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleEventarcTrigger_IsTerraformResource ¶
func GoogleEventarcTrigger_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleEventarcTrigger_TfResourceType ¶
func GoogleEventarcTrigger_TfResourceType() *string
func NewGoogleEventarcTriggerDestinationCloudRunServiceOutputReference_Override ¶
func NewGoogleEventarcTriggerDestinationCloudRunServiceOutputReference_Override(g GoogleEventarcTriggerDestinationCloudRunServiceOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleEventarcTriggerDestinationGkeOutputReference_Override ¶
func NewGoogleEventarcTriggerDestinationGkeOutputReference_Override(g GoogleEventarcTriggerDestinationGkeOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleEventarcTriggerDestinationOutputReference_Override ¶
func NewGoogleEventarcTriggerDestinationOutputReference_Override(g GoogleEventarcTriggerDestinationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleEventarcTriggerMatchingCriteriaList_Override ¶
func NewGoogleEventarcTriggerMatchingCriteriaList_Override(g GoogleEventarcTriggerMatchingCriteriaList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGoogleEventarcTriggerMatchingCriteriaOutputReference_Override ¶
func NewGoogleEventarcTriggerMatchingCriteriaOutputReference_Override(g GoogleEventarcTriggerMatchingCriteriaOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGoogleEventarcTriggerTimeoutsOutputReference_Override ¶
func NewGoogleEventarcTriggerTimeoutsOutputReference_Override(g GoogleEventarcTriggerTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleEventarcTriggerTransportOutputReference_Override ¶
func NewGoogleEventarcTriggerTransportOutputReference_Override(g GoogleEventarcTriggerTransportOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleEventarcTriggerTransportPubsubOutputReference_Override ¶
func NewGoogleEventarcTriggerTransportPubsubOutputReference_Override(g GoogleEventarcTriggerTransportPubsubOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleEventarcTrigger_Override ¶
func NewGoogleEventarcTrigger_Override(g GoogleEventarcTrigger, scope constructs.Construct, id *string, config *GoogleEventarcTriggerConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_eventarc_trigger google_eventarc_trigger} Resource.
Types ¶
type GoogleEventarcTrigger ¶
type GoogleEventarcTrigger interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
Channel() *string
SetChannel(val *string)
ChannelInput() *string
Conditions() cdktf.StringMap
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
CreateTime() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Destination() GoogleEventarcTriggerDestinationOutputReference
DestinationInput() *GoogleEventarcTriggerDestination
EffectiveLabels() cdktf.StringMap
Etag() *string
EventDataContentType() *string
SetEventDataContentType(val *string)
EventDataContentTypeInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
Labels() *map[string]*string
SetLabels(val *map[string]*string)
LabelsInput() *map[string]*string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Location() *string
SetLocation(val *string)
LocationInput() *string
MatchingCriteria() GoogleEventarcTriggerMatchingCriteriaList
MatchingCriteriaInput() interface{}
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
ServiceAccount() *string
SetServiceAccount(val *string)
ServiceAccountInput() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
TerraformLabels() cdktf.StringMap
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GoogleEventarcTriggerTimeoutsOutputReference
TimeoutsInput() interface{}
Transport() GoogleEventarcTriggerTransportOutputReference
TransportInput() *GoogleEventarcTriggerTransport
Uid() *string
UpdateTime() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutDestination(value *GoogleEventarcTriggerDestination)
PutMatchingCriteria(value interface{})
PutTimeouts(value *GoogleEventarcTriggerTimeouts)
PutTransport(value *GoogleEventarcTriggerTransport)
ResetChannel()
ResetEventDataContentType()
ResetId()
ResetLabels()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
ResetServiceAccount()
ResetTimeouts()
ResetTransport()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_eventarc_trigger google_eventarc_trigger}.
func NewGoogleEventarcTrigger ¶
func NewGoogleEventarcTrigger(scope constructs.Construct, id *string, config *GoogleEventarcTriggerConfig) GoogleEventarcTrigger
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_eventarc_trigger google_eventarc_trigger} Resource.
type GoogleEventarcTriggerConfig ¶
type GoogleEventarcTriggerConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// destination block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_eventarc_trigger#destination GoogleEventarcTrigger#destination}
Destination *GoogleEventarcTriggerDestination `field:"required" json:"destination" yaml:"destination"`
// The location for the resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_eventarc_trigger#location GoogleEventarcTrigger#location}
Location *string `field:"required" json:"location" yaml:"location"`
// matching_criteria block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_eventarc_trigger#matching_criteria GoogleEventarcTrigger#matching_criteria}
MatchingCriteria interface{} `field:"required" json:"matchingCriteria" yaml:"matchingCriteria"`
// Required. The resource name of the trigger. Must be unique within the location on the project.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_eventarc_trigger#name GoogleEventarcTrigger#name}
Name *string `field:"required" json:"name" yaml:"name"`
// Optional.
//
// The name of the channel associated with the trigger in `projects/{project}/locations/{location}/channels/{channel}` format. You must provide a channel to receive events from Eventarc SaaS partners.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_eventarc_trigger#channel GoogleEventarcTrigger#channel}
Channel *string `field:"optional" json:"channel" yaml:"channel"`
// Optional.
//
// EventDataContentType specifies the type of payload in MIME format that is expected from the CloudEvent data field. This is set to `application/json` if the value is not defined.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_eventarc_trigger#event_data_content_type GoogleEventarcTrigger#event_data_content_type}
EventDataContentType *string `field:"optional" json:"eventDataContentType" yaml:"eventDataContentType"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_eventarc_trigger#id GoogleEventarcTrigger#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Optional. User labels attached to the triggers that can be used to group resources.
//
// **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
// Please refer to the field `effective_labels` for all of the labels present on the resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_eventarc_trigger#labels GoogleEventarcTrigger#labels}
Labels *map[string]*string `field:"optional" json:"labels" yaml:"labels"`
// The project for the resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_eventarc_trigger#project GoogleEventarcTrigger#project}
Project *string `field:"optional" json:"project" yaml:"project"`
// Optional.
//
// The IAM service account email associated with the trigger. The service account represents the identity of the trigger. The principal who calls this API must have `iam.serviceAccounts.actAs` permission in the service account. See https://cloud.google.com/iam/docs/understanding-service-accounts#sa_common for more information. For Cloud Run destinations, this service account is used to generate identity tokens when invoking the service. See https://cloud.google.com/run/docs/triggering/pubsub-push#create-service-account for information on how to invoke authenticated Cloud Run services. In order to create Audit Log triggers, the service account should also have `roles/eventarc.eventReceiver` IAM role.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_eventarc_trigger#service_account GoogleEventarcTrigger#service_account}
ServiceAccount *string `field:"optional" json:"serviceAccount" yaml:"serviceAccount"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_eventarc_trigger#timeouts GoogleEventarcTrigger#timeouts}
Timeouts *GoogleEventarcTriggerTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
// transport block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_eventarc_trigger#transport GoogleEventarcTrigger#transport}
Transport *GoogleEventarcTriggerTransport `field:"optional" json:"transport" yaml:"transport"`
}
type GoogleEventarcTriggerDestination ¶
type GoogleEventarcTriggerDestination struct {
// [WARNING] Configuring a Cloud Function in Trigger is not supported as of today.
//
// The Cloud Function resource name. Format: projects/{project}/locations/{location}/functions/{function}
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_eventarc_trigger#cloud_function GoogleEventarcTrigger#cloud_function}
CloudFunction *string `field:"optional" json:"cloudFunction" yaml:"cloudFunction"`
// cloud_run_service block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_eventarc_trigger#cloud_run_service GoogleEventarcTrigger#cloud_run_service}
CloudRunService *GoogleEventarcTriggerDestinationCloudRunService `field:"optional" json:"cloudRunService" yaml:"cloudRunService"`
// gke block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_eventarc_trigger#gke GoogleEventarcTrigger#gke}
Gke *GoogleEventarcTriggerDestinationGke `field:"optional" json:"gke" yaml:"gke"`
// The resource name of the Workflow whose Executions are triggered by the events.
//
// The Workflow resource should be deployed in the same project as the trigger. Format: `projects/{project}/locations/{location}/workflows/{workflow}`
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_eventarc_trigger#workflow GoogleEventarcTrigger#workflow}
Workflow *string `field:"optional" json:"workflow" yaml:"workflow"`
}
type GoogleEventarcTriggerDestinationCloudRunService ¶
type GoogleEventarcTriggerDestinationCloudRunService struct {
// Required.
//
// The name of the Cloud Run service being addressed. See https://cloud.google.com/run/docs/reference/rest/v1/namespaces.services. Only services located in the same project of the trigger object can be addressed.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_eventarc_trigger#service GoogleEventarcTrigger#service}
Service *string `field:"required" json:"service" yaml:"service"`
// Optional.
//
// The relative path on the Cloud Run service the events should be sent to. The value must conform to the definition of URI path segment (section 3.3 of RFC2396). Examples: "/route", "route", "route/subroute".
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_eventarc_trigger#path GoogleEventarcTrigger#path}
Path *string `field:"optional" json:"path" yaml:"path"`
// Required. The region the Cloud Run service is deployed in.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_eventarc_trigger#region GoogleEventarcTrigger#region}
Region *string `field:"optional" json:"region" yaml:"region"`
}
type GoogleEventarcTriggerDestinationCloudRunServiceOutputReference ¶
type GoogleEventarcTriggerDestinationCloudRunServiceOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleEventarcTriggerDestinationCloudRunService
SetInternalValue(val *GoogleEventarcTriggerDestinationCloudRunService)
Path() *string
SetPath(val *string)
PathInput() *string
Region() *string
SetRegion(val *string)
RegionInput() *string
Service() *string
SetService(val *string)
ServiceInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetPath()
ResetRegion()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleEventarcTriggerDestinationCloudRunServiceOutputReference ¶
func NewGoogleEventarcTriggerDestinationCloudRunServiceOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleEventarcTriggerDestinationCloudRunServiceOutputReference
type GoogleEventarcTriggerDestinationGke ¶
type GoogleEventarcTriggerDestinationGke struct {
// Required.
//
// The name of the cluster the GKE service is running in. The cluster must be running in the same project as the trigger being created.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_eventarc_trigger#cluster GoogleEventarcTrigger#cluster}
Cluster *string `field:"required" json:"cluster" yaml:"cluster"`
// Required.
//
// The name of the Google Compute Engine in which the cluster resides, which can either be compute zone (for example, us-central1-a) for the zonal clusters or region (for example, us-central1) for regional clusters.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_eventarc_trigger#location GoogleEventarcTrigger#location}
Location *string `field:"required" json:"location" yaml:"location"`
// Required. The namespace the GKE service is running in.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_eventarc_trigger#namespace GoogleEventarcTrigger#namespace}
Namespace *string `field:"required" json:"namespace" yaml:"namespace"`
// Required. Name of the GKE service.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_eventarc_trigger#service GoogleEventarcTrigger#service}
Service *string `field:"required" json:"service" yaml:"service"`
// Optional.
//
// The relative path on the GKE service the events should be sent to. The value must conform to the definition of a URI path segment (section 3.3 of RFC2396). Examples: "/route", "route", "route/subroute".
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_eventarc_trigger#path GoogleEventarcTrigger#path}
Path *string `field:"optional" json:"path" yaml:"path"`
}
type GoogleEventarcTriggerDestinationGkeOutputReference ¶
type GoogleEventarcTriggerDestinationGkeOutputReference interface {
cdktf.ComplexObject
Cluster() *string
SetCluster(val *string)
ClusterInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleEventarcTriggerDestinationGke
SetInternalValue(val *GoogleEventarcTriggerDestinationGke)
Location() *string
SetLocation(val *string)
LocationInput() *string
Namespace() *string
SetNamespace(val *string)
NamespaceInput() *string
Path() *string
SetPath(val *string)
PathInput() *string
Service() *string
SetService(val *string)
ServiceInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetPath()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleEventarcTriggerDestinationGkeOutputReference ¶
func NewGoogleEventarcTriggerDestinationGkeOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleEventarcTriggerDestinationGkeOutputReference
type GoogleEventarcTriggerDestinationOutputReference ¶
type GoogleEventarcTriggerDestinationOutputReference interface {
cdktf.ComplexObject
CloudFunction() *string
SetCloudFunction(val *string)
CloudFunctionInput() *string
CloudRunService() GoogleEventarcTriggerDestinationCloudRunServiceOutputReference
CloudRunServiceInput() *GoogleEventarcTriggerDestinationCloudRunService
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Gke() GoogleEventarcTriggerDestinationGkeOutputReference
GkeInput() *GoogleEventarcTriggerDestinationGke
InternalValue() *GoogleEventarcTriggerDestination
SetInternalValue(val *GoogleEventarcTriggerDestination)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Workflow() *string
SetWorkflow(val *string)
WorkflowInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutCloudRunService(value *GoogleEventarcTriggerDestinationCloudRunService)
PutGke(value *GoogleEventarcTriggerDestinationGke)
ResetCloudFunction()
ResetCloudRunService()
ResetGke()
ResetWorkflow()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleEventarcTriggerDestinationOutputReference ¶
func NewGoogleEventarcTriggerDestinationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleEventarcTriggerDestinationOutputReference
type GoogleEventarcTriggerMatchingCriteria ¶
type GoogleEventarcTriggerMatchingCriteria struct {
// Required.
//
// The name of a CloudEvents attribute. Currently, only a subset of attributes are supported for filtering. All triggers MUST provide a filter for the 'type' attribute.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_eventarc_trigger#attribute GoogleEventarcTrigger#attribute}
Attribute *string `field:"required" json:"attribute" yaml:"attribute"`
// Required. The value for the attribute. See https://cloud.google.com/eventarc/docs/creating-triggers#trigger-gcloud for available values.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_eventarc_trigger#value GoogleEventarcTrigger#value}
Value *string `field:"required" json:"value" yaml:"value"`
// Optional.
//
// The operator used for matching the events with the value of the filter. If not specified, only events that have an exact key-value pair specified in the filter are matched. The only allowed value is `match-path-pattern`.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_eventarc_trigger#operator GoogleEventarcTrigger#operator}
Operator *string `field:"optional" json:"operator" yaml:"operator"`
}
type GoogleEventarcTriggerMatchingCriteriaList ¶
type GoogleEventarcTriggerMatchingCriteriaList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) GoogleEventarcTriggerMatchingCriteriaOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleEventarcTriggerMatchingCriteriaList ¶
func NewGoogleEventarcTriggerMatchingCriteriaList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GoogleEventarcTriggerMatchingCriteriaList
type GoogleEventarcTriggerMatchingCriteriaOutputReference ¶
type GoogleEventarcTriggerMatchingCriteriaOutputReference interface {
cdktf.ComplexObject
Attribute() *string
SetAttribute(val *string)
AttributeInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Operator() *string
SetOperator(val *string)
OperatorInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Value() *string
SetValue(val *string)
ValueInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetOperator()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleEventarcTriggerMatchingCriteriaOutputReference ¶
func NewGoogleEventarcTriggerMatchingCriteriaOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GoogleEventarcTriggerMatchingCriteriaOutputReference
type GoogleEventarcTriggerTimeouts ¶
type GoogleEventarcTriggerTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_eventarc_trigger#create GoogleEventarcTrigger#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_eventarc_trigger#delete GoogleEventarcTrigger#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_eventarc_trigger#update GoogleEventarcTrigger#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type GoogleEventarcTriggerTimeoutsOutputReference ¶
type GoogleEventarcTriggerTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleEventarcTriggerTimeoutsOutputReference ¶
func NewGoogleEventarcTriggerTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleEventarcTriggerTimeoutsOutputReference
type GoogleEventarcTriggerTransport ¶
type GoogleEventarcTriggerTransport struct {
// pubsub block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_eventarc_trigger#pubsub GoogleEventarcTrigger#pubsub}
Pubsub *GoogleEventarcTriggerTransportPubsub `field:"optional" json:"pubsub" yaml:"pubsub"`
}
type GoogleEventarcTriggerTransportOutputReference ¶
type GoogleEventarcTriggerTransportOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleEventarcTriggerTransport
SetInternalValue(val *GoogleEventarcTriggerTransport)
Pubsub() GoogleEventarcTriggerTransportPubsubOutputReference
PubsubInput() *GoogleEventarcTriggerTransportPubsub
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutPubsub(value *GoogleEventarcTriggerTransportPubsub)
ResetPubsub()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleEventarcTriggerTransportOutputReference ¶
func NewGoogleEventarcTriggerTransportOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleEventarcTriggerTransportOutputReference
type GoogleEventarcTriggerTransportPubsub ¶
type GoogleEventarcTriggerTransportPubsub struct {
// Optional.
//
// The name of the Pub/Sub topic created and managed by Eventarc system as a transport for the event delivery. Format: `projects/{PROJECT_ID}/topics/{TOPIC_NAME}. You may set an existing topic for triggers of the type google.cloud.pubsub.topic.v1.messagePublished` only. The topic you provide here will not be deleted by Eventarc at trigger deletion.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_eventarc_trigger#topic GoogleEventarcTrigger#topic}
Topic *string `field:"optional" json:"topic" yaml:"topic"`
}
type GoogleEventarcTriggerTransportPubsubOutputReference ¶
type GoogleEventarcTriggerTransportPubsubOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleEventarcTriggerTransportPubsub
SetInternalValue(val *GoogleEventarcTriggerTransportPubsub)
Subscription() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Topic() *string
SetTopic(val *string)
TopicInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetTopic()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleEventarcTriggerTransportPubsubOutputReference ¶
func NewGoogleEventarcTriggerTransportPubsubOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleEventarcTriggerTransportPubsubOutputReference
Source Files
¶
- GoogleEventarcTrigger.go
- GoogleEventarcTriggerConfig.go
- GoogleEventarcTriggerDestination.go
- GoogleEventarcTriggerDestinationCloudRunService.go
- GoogleEventarcTriggerDestinationCloudRunServiceOutputReference.go
- GoogleEventarcTriggerDestinationCloudRunServiceOutputReference__checks.go
- GoogleEventarcTriggerDestinationGke.go
- GoogleEventarcTriggerDestinationGkeOutputReference.go
- GoogleEventarcTriggerDestinationGkeOutputReference__checks.go
- GoogleEventarcTriggerDestinationOutputReference.go
- GoogleEventarcTriggerDestinationOutputReference__checks.go
- GoogleEventarcTriggerMatchingCriteria.go
- GoogleEventarcTriggerMatchingCriteriaList.go
- GoogleEventarcTriggerMatchingCriteriaList__checks.go
- GoogleEventarcTriggerMatchingCriteriaOutputReference.go
- GoogleEventarcTriggerMatchingCriteriaOutputReference__checks.go
- GoogleEventarcTriggerTimeouts.go
- GoogleEventarcTriggerTimeoutsOutputReference.go
- GoogleEventarcTriggerTimeoutsOutputReference__checks.go
- GoogleEventarcTriggerTransport.go
- GoogleEventarcTriggerTransportOutputReference.go
- GoogleEventarcTriggerTransportOutputReference__checks.go
- GoogleEventarcTriggerTransportPubsub.go
- GoogleEventarcTriggerTransportPubsubOutputReference.go
- GoogleEventarcTriggerTransportPubsubOutputReference__checks.go
- GoogleEventarcTrigger__checks.go
- main.go