Documentation
¶
Index ¶
- func GoogleFolderIamAuditConfig_IsConstruct(x interface{}) *bool
- func GoogleFolderIamAuditConfig_IsTerraformElement(x interface{}) *bool
- func GoogleFolderIamAuditConfig_IsTerraformResource(x interface{}) *bool
- func GoogleFolderIamAuditConfig_TfResourceType() *string
- func NewGoogleFolderIamAuditConfigAuditLogConfigList_Override(g GoogleFolderIamAuditConfigAuditLogConfigList, ...)
- func NewGoogleFolderIamAuditConfigAuditLogConfigOutputReference_Override(g GoogleFolderIamAuditConfigAuditLogConfigOutputReference, ...)
- func NewGoogleFolderIamAuditConfig_Override(g GoogleFolderIamAuditConfig, scope constructs.Construct, id *string, ...)
- type GoogleFolderIamAuditConfig
- type GoogleFolderIamAuditConfigAuditLogConfig
- type GoogleFolderIamAuditConfigAuditLogConfigList
- type GoogleFolderIamAuditConfigAuditLogConfigOutputReference
- type GoogleFolderIamAuditConfigConfig
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleFolderIamAuditConfig_IsConstruct ¶
func GoogleFolderIamAuditConfig_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleFolderIamAuditConfig_IsTerraformElement ¶
func GoogleFolderIamAuditConfig_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleFolderIamAuditConfig_IsTerraformResource ¶
func GoogleFolderIamAuditConfig_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleFolderIamAuditConfig_TfResourceType ¶
func GoogleFolderIamAuditConfig_TfResourceType() *string
func NewGoogleFolderIamAuditConfigAuditLogConfigList_Override ¶
func NewGoogleFolderIamAuditConfigAuditLogConfigList_Override(g GoogleFolderIamAuditConfigAuditLogConfigList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGoogleFolderIamAuditConfigAuditLogConfigOutputReference_Override ¶
func NewGoogleFolderIamAuditConfigAuditLogConfigOutputReference_Override(g GoogleFolderIamAuditConfigAuditLogConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGoogleFolderIamAuditConfig_Override ¶
func NewGoogleFolderIamAuditConfig_Override(g GoogleFolderIamAuditConfig, scope constructs.Construct, id *string, config *GoogleFolderIamAuditConfigConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_folder_iam_audit_config google_folder_iam_audit_config} Resource.
Types ¶
type GoogleFolderIamAuditConfig ¶
type GoogleFolderIamAuditConfig interface {
cdktf.TerraformResource
AuditLogConfig() GoogleFolderIamAuditConfigAuditLogConfigList
AuditLogConfigInput() interface{}
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Etag() *string
Folder() *string
SetFolder(val *string)
FolderInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Service() *string
SetService(val *string)
ServiceInput() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutAuditLogConfig(value interface{})
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_folder_iam_audit_config google_folder_iam_audit_config}.
func NewGoogleFolderIamAuditConfig ¶
func NewGoogleFolderIamAuditConfig(scope constructs.Construct, id *string, config *GoogleFolderIamAuditConfigConfig) GoogleFolderIamAuditConfig
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_folder_iam_audit_config google_folder_iam_audit_config} Resource.
type GoogleFolderIamAuditConfigAuditLogConfig ¶
type GoogleFolderIamAuditConfigAuditLogConfig struct {
// Permission type for which logging is to be configured. Must be one of DATA_READ, DATA_WRITE, or ADMIN_READ.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_folder_iam_audit_config#log_type GoogleFolderIamAuditConfig#log_type}
LogType *string `field:"required" json:"logType" yaml:"logType"`
// Identities that do not cause logging for this type of permission.
//
// Each entry can have one of the following values:user:{emailid}: An email address that represents a specific Google account. For example, alice@gmail.com or joe@example.com. serviceAccount:{emailid}: An email address that represents a service account. For example, my-other-app@appspot.gserviceaccount.com. group:{emailid}: An email address that represents a Google group. For example, admins@example.com. domain:{domain}: A G Suite domain (primary, instead of alias) name that represents all the users of that domain. For example, google.com or example.com.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_folder_iam_audit_config#exempted_members GoogleFolderIamAuditConfig#exempted_members}
ExemptedMembers *[]*string `field:"optional" json:"exemptedMembers" yaml:"exemptedMembers"`
}
type GoogleFolderIamAuditConfigAuditLogConfigList ¶
type GoogleFolderIamAuditConfigAuditLogConfigList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) GoogleFolderIamAuditConfigAuditLogConfigOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleFolderIamAuditConfigAuditLogConfigList ¶
func NewGoogleFolderIamAuditConfigAuditLogConfigList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GoogleFolderIamAuditConfigAuditLogConfigList
type GoogleFolderIamAuditConfigAuditLogConfigOutputReference ¶
type GoogleFolderIamAuditConfigAuditLogConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
ExemptedMembers() *[]*string
SetExemptedMembers(val *[]*string)
ExemptedMembersInput() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
LogType() *string
SetLogType(val *string)
LogTypeInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetExemptedMembers()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleFolderIamAuditConfigAuditLogConfigOutputReference ¶
func NewGoogleFolderIamAuditConfigAuditLogConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GoogleFolderIamAuditConfigAuditLogConfigOutputReference
type GoogleFolderIamAuditConfigConfig ¶
type GoogleFolderIamAuditConfigConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// audit_log_config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_folder_iam_audit_config#audit_log_config GoogleFolderIamAuditConfig#audit_log_config}
AuditLogConfig interface{} `field:"required" json:"auditLogConfig" yaml:"auditLogConfig"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_folder_iam_audit_config#folder GoogleFolderIamAuditConfig#folder}.
Folder *string `field:"required" json:"folder" yaml:"folder"`
// Service which will be enabled for audit logging. The special value allServices covers all services.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_folder_iam_audit_config#service GoogleFolderIamAuditConfig#service}
Service *string `field:"required" json:"service" yaml:"service"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_folder_iam_audit_config#id GoogleFolderIamAuditConfig#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
}
Source Files
¶
- GoogleFolderIamAuditConfig.go
- GoogleFolderIamAuditConfigAuditLogConfig.go
- GoogleFolderIamAuditConfigAuditLogConfigList.go
- GoogleFolderIamAuditConfigAuditLogConfigList__checks.go
- GoogleFolderIamAuditConfigAuditLogConfigOutputReference.go
- GoogleFolderIamAuditConfigAuditLogConfigOutputReference__checks.go
- GoogleFolderIamAuditConfigConfig.go
- GoogleFolderIamAuditConfig__checks.go
- main.go