Documentation
¶
Index ¶
- func GoogleMlEngineModel_IsConstruct(x interface{}) *bool
- func GoogleMlEngineModel_IsTerraformElement(x interface{}) *bool
- func GoogleMlEngineModel_IsTerraformResource(x interface{}) *bool
- func GoogleMlEngineModel_TfResourceType() *string
- func NewGoogleMlEngineModelDefaultVersionOutputReference_Override(g GoogleMlEngineModelDefaultVersionOutputReference, ...)
- func NewGoogleMlEngineModelTimeoutsOutputReference_Override(g GoogleMlEngineModelTimeoutsOutputReference, ...)
- func NewGoogleMlEngineModel_Override(g GoogleMlEngineModel, scope constructs.Construct, id *string, ...)
- type GoogleMlEngineModel
- type GoogleMlEngineModelConfig
- type GoogleMlEngineModelDefaultVersion
- type GoogleMlEngineModelDefaultVersionOutputReference
- type GoogleMlEngineModelTimeouts
- type GoogleMlEngineModelTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleMlEngineModel_IsConstruct ¶
func GoogleMlEngineModel_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleMlEngineModel_IsTerraformElement ¶
func GoogleMlEngineModel_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleMlEngineModel_IsTerraformResource ¶
func GoogleMlEngineModel_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleMlEngineModel_TfResourceType ¶
func GoogleMlEngineModel_TfResourceType() *string
func NewGoogleMlEngineModelDefaultVersionOutputReference_Override ¶
func NewGoogleMlEngineModelDefaultVersionOutputReference_Override(g GoogleMlEngineModelDefaultVersionOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleMlEngineModelTimeoutsOutputReference_Override ¶
func NewGoogleMlEngineModelTimeoutsOutputReference_Override(g GoogleMlEngineModelTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleMlEngineModel_Override ¶
func NewGoogleMlEngineModel_Override(g GoogleMlEngineModel, scope constructs.Construct, id *string, config *GoogleMlEngineModelConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_ml_engine_model google_ml_engine_model} Resource.
Types ¶
type GoogleMlEngineModel ¶
type GoogleMlEngineModel interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
DefaultVersion() GoogleMlEngineModelDefaultVersionOutputReference
DefaultVersionInput() *GoogleMlEngineModelDefaultVersion
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
EffectiveLabels() cdktf.StringMap
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
Labels() *map[string]*string
SetLabels(val *map[string]*string)
LabelsInput() *map[string]*string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
OnlinePredictionConsoleLogging() interface{}
SetOnlinePredictionConsoleLogging(val interface{})
OnlinePredictionConsoleLoggingInput() interface{}
OnlinePredictionLogging() interface{}
SetOnlinePredictionLogging(val interface{})
OnlinePredictionLoggingInput() interface{}
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Regions() *[]*string
SetRegions(val *[]*string)
RegionsInput() *[]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
TerraformLabels() cdktf.StringMap
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GoogleMlEngineModelTimeoutsOutputReference
TimeoutsInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutDefaultVersion(value *GoogleMlEngineModelDefaultVersion)
PutTimeouts(value *GoogleMlEngineModelTimeouts)
ResetDefaultVersion()
ResetDescription()
ResetId()
ResetLabels()
ResetOnlinePredictionConsoleLogging()
ResetOnlinePredictionLogging()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
ResetRegions()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_ml_engine_model google_ml_engine_model}.
func NewGoogleMlEngineModel ¶
func NewGoogleMlEngineModel(scope constructs.Construct, id *string, config *GoogleMlEngineModelConfig) GoogleMlEngineModel
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_ml_engine_model google_ml_engine_model} Resource.
type GoogleMlEngineModelConfig ¶
type GoogleMlEngineModelConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// The name specified for the model.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_ml_engine_model#name GoogleMlEngineModel#name}
Name *string `field:"required" json:"name" yaml:"name"`
// default_version block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_ml_engine_model#default_version GoogleMlEngineModel#default_version}
DefaultVersion *GoogleMlEngineModelDefaultVersion `field:"optional" json:"defaultVersion" yaml:"defaultVersion"`
// The description specified for the model when it was created.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_ml_engine_model#description GoogleMlEngineModel#description}
Description *string `field:"optional" json:"description" yaml:"description"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_ml_engine_model#id GoogleMlEngineModel#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// One or more labels that you can add, to organize your models.
//
// **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
// Please refer to the field 'effective_labels' for all of the labels present on the resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_ml_engine_model#labels GoogleMlEngineModel#labels}
Labels *map[string]*string `field:"optional" json:"labels" yaml:"labels"`
// If true, online prediction nodes send stderr and stdout streams to Stackdriver Logging.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_ml_engine_model#online_prediction_console_logging GoogleMlEngineModel#online_prediction_console_logging}
OnlinePredictionConsoleLogging interface{} `field:"optional" json:"onlinePredictionConsoleLogging" yaml:"onlinePredictionConsoleLogging"`
// If true, online prediction access logs are sent to StackDriver Logging.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_ml_engine_model#online_prediction_logging GoogleMlEngineModel#online_prediction_logging}
OnlinePredictionLogging interface{} `field:"optional" json:"onlinePredictionLogging" yaml:"onlinePredictionLogging"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_ml_engine_model#project GoogleMlEngineModel#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// The list of regions where the model is going to be deployed. Currently only one region per model is supported.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_ml_engine_model#regions GoogleMlEngineModel#regions}
Regions *[]*string `field:"optional" json:"regions" yaml:"regions"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_ml_engine_model#timeouts GoogleMlEngineModel#timeouts}
Timeouts *GoogleMlEngineModelTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type GoogleMlEngineModelDefaultVersion ¶
type GoogleMlEngineModelDefaultVersion struct {
// The name specified for the version when it was created.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_ml_engine_model#name GoogleMlEngineModel#name}
Name *string `field:"required" json:"name" yaml:"name"`
}
type GoogleMlEngineModelDefaultVersionOutputReference ¶
type GoogleMlEngineModelDefaultVersionOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleMlEngineModelDefaultVersion
SetInternalValue(val *GoogleMlEngineModelDefaultVersion)
Name() *string
SetName(val *string)
NameInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleMlEngineModelDefaultVersionOutputReference ¶
func NewGoogleMlEngineModelDefaultVersionOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleMlEngineModelDefaultVersionOutputReference
type GoogleMlEngineModelTimeouts ¶
type GoogleMlEngineModelTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_ml_engine_model#create GoogleMlEngineModel#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_ml_engine_model#delete GoogleMlEngineModel#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
}
type GoogleMlEngineModelTimeoutsOutputReference ¶
type GoogleMlEngineModelTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleMlEngineModelTimeoutsOutputReference ¶
func NewGoogleMlEngineModelTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleMlEngineModelTimeoutsOutputReference
Source Files
¶
- GoogleMlEngineModel.go
- GoogleMlEngineModelConfig.go
- GoogleMlEngineModelDefaultVersion.go
- GoogleMlEngineModelDefaultVersionOutputReference.go
- GoogleMlEngineModelDefaultVersionOutputReference__checks.go
- GoogleMlEngineModelTimeouts.go
- GoogleMlEngineModelTimeoutsOutputReference.go
- GoogleMlEngineModelTimeoutsOutputReference__checks.go
- GoogleMlEngineModel__checks.go
- main.go