Documentation
¶
Index ¶
- func GoogleMonitoringService_IsConstruct(x interface{}) *bool
- func GoogleMonitoringService_IsTerraformElement(x interface{}) *bool
- func GoogleMonitoringService_IsTerraformResource(x interface{}) *bool
- func GoogleMonitoringService_TfResourceType() *string
- func NewGoogleMonitoringServiceBasicServiceOutputReference_Override(g GoogleMonitoringServiceBasicServiceOutputReference, ...)
- func NewGoogleMonitoringServiceTelemetryList_Override(g GoogleMonitoringServiceTelemetryList, ...)
- func NewGoogleMonitoringServiceTelemetryOutputReference_Override(g GoogleMonitoringServiceTelemetryOutputReference, ...)
- func NewGoogleMonitoringServiceTimeoutsOutputReference_Override(g GoogleMonitoringServiceTimeoutsOutputReference, ...)
- func NewGoogleMonitoringService_Override(g GoogleMonitoringService, scope constructs.Construct, id *string, ...)
- type GoogleMonitoringService
- type GoogleMonitoringServiceBasicService
- type GoogleMonitoringServiceBasicServiceOutputReference
- type GoogleMonitoringServiceConfig
- type GoogleMonitoringServiceTelemetry
- type GoogleMonitoringServiceTelemetryList
- type GoogleMonitoringServiceTelemetryOutputReference
- type GoogleMonitoringServiceTimeouts
- type GoogleMonitoringServiceTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleMonitoringService_IsConstruct ¶
func GoogleMonitoringService_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleMonitoringService_IsTerraformElement ¶
func GoogleMonitoringService_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleMonitoringService_IsTerraformResource ¶
func GoogleMonitoringService_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleMonitoringService_TfResourceType ¶
func GoogleMonitoringService_TfResourceType() *string
func NewGoogleMonitoringServiceBasicServiceOutputReference_Override ¶
func NewGoogleMonitoringServiceBasicServiceOutputReference_Override(g GoogleMonitoringServiceBasicServiceOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleMonitoringServiceTelemetryList_Override ¶
func NewGoogleMonitoringServiceTelemetryList_Override(g GoogleMonitoringServiceTelemetryList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGoogleMonitoringServiceTelemetryOutputReference_Override ¶
func NewGoogleMonitoringServiceTelemetryOutputReference_Override(g GoogleMonitoringServiceTelemetryOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGoogleMonitoringServiceTimeoutsOutputReference_Override ¶
func NewGoogleMonitoringServiceTimeoutsOutputReference_Override(g GoogleMonitoringServiceTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleMonitoringService_Override ¶
func NewGoogleMonitoringService_Override(g GoogleMonitoringService, scope constructs.Construct, id *string, config *GoogleMonitoringServiceConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_monitoring_service google_monitoring_service} Resource.
Types ¶
type GoogleMonitoringService ¶
type GoogleMonitoringService interface {
cdktf.TerraformResource
BasicService() GoogleMonitoringServiceBasicServiceOutputReference
BasicServiceInput() *GoogleMonitoringServiceBasicService
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DisplayName() *string
SetDisplayName(val *string)
DisplayNameInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
// The tree node.
Node() constructs.Node
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
ServiceId() *string
SetServiceId(val *string)
ServiceIdInput() *string
Telemetry() GoogleMonitoringServiceTelemetryList
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GoogleMonitoringServiceTimeoutsOutputReference
TimeoutsInput() interface{}
UserLabels() *map[string]*string
SetUserLabels(val *map[string]*string)
UserLabelsInput() *map[string]*string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutBasicService(value *GoogleMonitoringServiceBasicService)
PutTimeouts(value *GoogleMonitoringServiceTimeouts)
ResetBasicService()
ResetDisplayName()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
ResetTimeouts()
ResetUserLabels()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_monitoring_service google_monitoring_service}.
func NewGoogleMonitoringService ¶
func NewGoogleMonitoringService(scope constructs.Construct, id *string, config *GoogleMonitoringServiceConfig) GoogleMonitoringService
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_monitoring_service google_monitoring_service} Resource.
type GoogleMonitoringServiceBasicService ¶
type GoogleMonitoringServiceBasicService struct {
// Labels that specify the resource that emits the monitoring data which is used for SLO reporting of this 'Service'.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_monitoring_service#service_labels GoogleMonitoringService#service_labels}
ServiceLabels *map[string]*string `field:"optional" json:"serviceLabels" yaml:"serviceLabels"`
// The type of service that this basic service defines, e.g. APP_ENGINE service type.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_monitoring_service#service_type GoogleMonitoringService#service_type}
ServiceType *string `field:"optional" json:"serviceType" yaml:"serviceType"`
}
type GoogleMonitoringServiceBasicServiceOutputReference ¶
type GoogleMonitoringServiceBasicServiceOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleMonitoringServiceBasicService
SetInternalValue(val *GoogleMonitoringServiceBasicService)
ServiceLabels() *map[string]*string
SetServiceLabels(val *map[string]*string)
ServiceLabelsInput() *map[string]*string
ServiceType() *string
SetServiceType(val *string)
ServiceTypeInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetServiceLabels()
ResetServiceType()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleMonitoringServiceBasicServiceOutputReference ¶
func NewGoogleMonitoringServiceBasicServiceOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleMonitoringServiceBasicServiceOutputReference
type GoogleMonitoringServiceConfig ¶
type GoogleMonitoringServiceConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// An optional service ID to use. If not given, the server will generate a service ID.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_monitoring_service#service_id GoogleMonitoringService#service_id}
ServiceId *string `field:"required" json:"serviceId" yaml:"serviceId"`
// basic_service block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_monitoring_service#basic_service GoogleMonitoringService#basic_service}
BasicService *GoogleMonitoringServiceBasicService `field:"optional" json:"basicService" yaml:"basicService"`
// Name used for UI elements listing this Service.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_monitoring_service#display_name GoogleMonitoringService#display_name}
DisplayName *string `field:"optional" json:"displayName" yaml:"displayName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_monitoring_service#id GoogleMonitoringService#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_monitoring_service#project GoogleMonitoringService#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_monitoring_service#timeouts GoogleMonitoringService#timeouts}
Timeouts *GoogleMonitoringServiceTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
// Labels which have been used to annotate the service.
//
// Label keys must start
// with a letter. Label keys and values may contain lowercase letters,
// numbers, underscores, and dashes. Label keys and values have a maximum
// length of 63 characters, and must be less than 128 bytes in size. Up to 64
// label entries may be stored. For labels which do not have a semantic value,
// the empty string may be supplied for the label value.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_monitoring_service#user_labels GoogleMonitoringService#user_labels}
UserLabels *map[string]*string `field:"optional" json:"userLabels" yaml:"userLabels"`
}
type GoogleMonitoringServiceTelemetry ¶
type GoogleMonitoringServiceTelemetry struct {
}
type GoogleMonitoringServiceTelemetryList ¶
type GoogleMonitoringServiceTelemetryList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) GoogleMonitoringServiceTelemetryOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleMonitoringServiceTelemetryList ¶
func NewGoogleMonitoringServiceTelemetryList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GoogleMonitoringServiceTelemetryList
type GoogleMonitoringServiceTelemetryOutputReference ¶
type GoogleMonitoringServiceTelemetryOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleMonitoringServiceTelemetry
SetInternalValue(val *GoogleMonitoringServiceTelemetry)
ResourceName() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleMonitoringServiceTelemetryOutputReference ¶
func NewGoogleMonitoringServiceTelemetryOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GoogleMonitoringServiceTelemetryOutputReference
type GoogleMonitoringServiceTimeouts ¶
type GoogleMonitoringServiceTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_monitoring_service#create GoogleMonitoringService#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_monitoring_service#delete GoogleMonitoringService#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_monitoring_service#update GoogleMonitoringService#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type GoogleMonitoringServiceTimeoutsOutputReference ¶
type GoogleMonitoringServiceTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleMonitoringServiceTimeoutsOutputReference ¶
func NewGoogleMonitoringServiceTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleMonitoringServiceTimeoutsOutputReference
Source Files
¶
- GoogleMonitoringService.go
- GoogleMonitoringServiceBasicService.go
- GoogleMonitoringServiceBasicServiceOutputReference.go
- GoogleMonitoringServiceBasicServiceOutputReference__checks.go
- GoogleMonitoringServiceConfig.go
- GoogleMonitoringServiceTelemetry.go
- GoogleMonitoringServiceTelemetryList.go
- GoogleMonitoringServiceTelemetryList__checks.go
- GoogleMonitoringServiceTelemetryOutputReference.go
- GoogleMonitoringServiceTelemetryOutputReference__checks.go
- GoogleMonitoringServiceTimeouts.go
- GoogleMonitoringServiceTimeoutsOutputReference.go
- GoogleMonitoringServiceTimeoutsOutputReference__checks.go
- GoogleMonitoringService__checks.go
- main.go