Documentation
¶
Index ¶
- func GoogleNetworkServicesEndpointPolicy_IsConstruct(x interface{}) *bool
- func GoogleNetworkServicesEndpointPolicy_IsTerraformElement(x interface{}) *bool
- func GoogleNetworkServicesEndpointPolicy_IsTerraformResource(x interface{}) *bool
- func GoogleNetworkServicesEndpointPolicy_TfResourceType() *string
- func NewGoogleNetworkServicesEndpointPolicyEndpointMatcherMetadataLabelMatcherMetadataLabelsList_Override(...)
- func NewGoogleNetworkServicesEndpointPolicyEndpointMatcherMetadataLabelMatcherMetadataLabelsOutputReference_Override(...)
- func NewGoogleNetworkServicesEndpointPolicyEndpointMatcherMetadataLabelMatcherOutputReference_Override(...)
- func NewGoogleNetworkServicesEndpointPolicyEndpointMatcherOutputReference_Override(g GoogleNetworkServicesEndpointPolicyEndpointMatcherOutputReference, ...)
- func NewGoogleNetworkServicesEndpointPolicyTimeoutsOutputReference_Override(g GoogleNetworkServicesEndpointPolicyTimeoutsOutputReference, ...)
- func NewGoogleNetworkServicesEndpointPolicyTrafficPortSelectorOutputReference_Override(g GoogleNetworkServicesEndpointPolicyTrafficPortSelectorOutputReference, ...)
- func NewGoogleNetworkServicesEndpointPolicy_Override(g GoogleNetworkServicesEndpointPolicy, scope constructs.Construct, id *string, ...)
- type GoogleNetworkServicesEndpointPolicy
- type GoogleNetworkServicesEndpointPolicyConfig
- type GoogleNetworkServicesEndpointPolicyEndpointMatcher
- type GoogleNetworkServicesEndpointPolicyEndpointMatcherMetadataLabelMatcher
- type GoogleNetworkServicesEndpointPolicyEndpointMatcherMetadataLabelMatcherMetadataLabels
- type GoogleNetworkServicesEndpointPolicyEndpointMatcherMetadataLabelMatcherMetadataLabelsList
- type GoogleNetworkServicesEndpointPolicyEndpointMatcherMetadataLabelMatcherMetadataLabelsOutputReference
- type GoogleNetworkServicesEndpointPolicyEndpointMatcherMetadataLabelMatcherOutputReference
- type GoogleNetworkServicesEndpointPolicyEndpointMatcherOutputReference
- type GoogleNetworkServicesEndpointPolicyTimeouts
- type GoogleNetworkServicesEndpointPolicyTimeoutsOutputReference
- type GoogleNetworkServicesEndpointPolicyTrafficPortSelector
- type GoogleNetworkServicesEndpointPolicyTrafficPortSelectorOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleNetworkServicesEndpointPolicy_IsConstruct ¶
func GoogleNetworkServicesEndpointPolicy_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleNetworkServicesEndpointPolicy_IsTerraformElement ¶
func GoogleNetworkServicesEndpointPolicy_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleNetworkServicesEndpointPolicy_IsTerraformResource ¶
func GoogleNetworkServicesEndpointPolicy_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleNetworkServicesEndpointPolicy_TfResourceType ¶
func GoogleNetworkServicesEndpointPolicy_TfResourceType() *string
func NewGoogleNetworkServicesEndpointPolicyEndpointMatcherMetadataLabelMatcherMetadataLabelsList_Override ¶
func NewGoogleNetworkServicesEndpointPolicyEndpointMatcherMetadataLabelMatcherMetadataLabelsList_Override(g GoogleNetworkServicesEndpointPolicyEndpointMatcherMetadataLabelMatcherMetadataLabelsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGoogleNetworkServicesEndpointPolicyEndpointMatcherMetadataLabelMatcherMetadataLabelsOutputReference_Override ¶
func NewGoogleNetworkServicesEndpointPolicyEndpointMatcherMetadataLabelMatcherMetadataLabelsOutputReference_Override(g GoogleNetworkServicesEndpointPolicyEndpointMatcherMetadataLabelMatcherMetadataLabelsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGoogleNetworkServicesEndpointPolicyEndpointMatcherMetadataLabelMatcherOutputReference_Override ¶
func NewGoogleNetworkServicesEndpointPolicyEndpointMatcherMetadataLabelMatcherOutputReference_Override(g GoogleNetworkServicesEndpointPolicyEndpointMatcherMetadataLabelMatcherOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleNetworkServicesEndpointPolicyEndpointMatcherOutputReference_Override ¶
func NewGoogleNetworkServicesEndpointPolicyEndpointMatcherOutputReference_Override(g GoogleNetworkServicesEndpointPolicyEndpointMatcherOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleNetworkServicesEndpointPolicyTimeoutsOutputReference_Override ¶
func NewGoogleNetworkServicesEndpointPolicyTimeoutsOutputReference_Override(g GoogleNetworkServicesEndpointPolicyTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleNetworkServicesEndpointPolicyTrafficPortSelectorOutputReference_Override ¶
func NewGoogleNetworkServicesEndpointPolicyTrafficPortSelectorOutputReference_Override(g GoogleNetworkServicesEndpointPolicyTrafficPortSelectorOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleNetworkServicesEndpointPolicy_Override ¶
func NewGoogleNetworkServicesEndpointPolicy_Override(g GoogleNetworkServicesEndpointPolicy, scope constructs.Construct, id *string, config *GoogleNetworkServicesEndpointPolicyConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_network_services_endpoint_policy google_network_services_endpoint_policy} Resource.
Types ¶
type GoogleNetworkServicesEndpointPolicy ¶
type GoogleNetworkServicesEndpointPolicy interface {
cdktf.TerraformResource
AuthorizationPolicy() *string
SetAuthorizationPolicy(val *string)
AuthorizationPolicyInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
ClientTlsPolicy() *string
SetClientTlsPolicy(val *string)
ClientTlsPolicyInput() *string
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
CreateTime() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
EffectiveLabels() cdktf.StringMap
EndpointMatcher() GoogleNetworkServicesEndpointPolicyEndpointMatcherOutputReference
EndpointMatcherInput() *GoogleNetworkServicesEndpointPolicyEndpointMatcher
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
Labels() *map[string]*string
SetLabels(val *map[string]*string)
LabelsInput() *map[string]*string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
ServerTlsPolicy() *string
SetServerTlsPolicy(val *string)
ServerTlsPolicyInput() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
TerraformLabels() cdktf.StringMap
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GoogleNetworkServicesEndpointPolicyTimeoutsOutputReference
TimeoutsInput() interface{}
TrafficPortSelector() GoogleNetworkServicesEndpointPolicyTrafficPortSelectorOutputReference
TrafficPortSelectorInput() *GoogleNetworkServicesEndpointPolicyTrafficPortSelector
Type() *string
SetType(val *string)
TypeInput() *string
UpdateTime() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutEndpointMatcher(value *GoogleNetworkServicesEndpointPolicyEndpointMatcher)
PutTimeouts(value *GoogleNetworkServicesEndpointPolicyTimeouts)
PutTrafficPortSelector(value *GoogleNetworkServicesEndpointPolicyTrafficPortSelector)
ResetAuthorizationPolicy()
ResetClientTlsPolicy()
ResetDescription()
ResetId()
ResetLabels()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
ResetServerTlsPolicy()
ResetTimeouts()
ResetTrafficPortSelector()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_network_services_endpoint_policy google_network_services_endpoint_policy}.
func NewGoogleNetworkServicesEndpointPolicy ¶
func NewGoogleNetworkServicesEndpointPolicy(scope constructs.Construct, id *string, config *GoogleNetworkServicesEndpointPolicyConfig) GoogleNetworkServicesEndpointPolicy
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_network_services_endpoint_policy google_network_services_endpoint_policy} Resource.
type GoogleNetworkServicesEndpointPolicyConfig ¶
type GoogleNetworkServicesEndpointPolicyConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// endpoint_matcher block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_network_services_endpoint_policy#endpoint_matcher GoogleNetworkServicesEndpointPolicy#endpoint_matcher}
EndpointMatcher *GoogleNetworkServicesEndpointPolicyEndpointMatcher `field:"required" json:"endpointMatcher" yaml:"endpointMatcher"`
// Name of the EndpointPolicy resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_network_services_endpoint_policy#name GoogleNetworkServicesEndpointPolicy#name}
Name *string `field:"required" json:"name" yaml:"name"`
// The type of endpoint policy. This is primarily used to validate the configuration. Possible values: ["SIDECAR_PROXY", "GRPC_SERVER"].
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_network_services_endpoint_policy#type GoogleNetworkServicesEndpointPolicy#type}
Type *string `field:"required" json:"type" yaml:"type"`
// This field specifies the URL of AuthorizationPolicy resource that applies authorization policies to the inbound traffic at the matched endpoints.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_network_services_endpoint_policy#authorization_policy GoogleNetworkServicesEndpointPolicy#authorization_policy}
AuthorizationPolicy *string `field:"optional" json:"authorizationPolicy" yaml:"authorizationPolicy"`
// A URL referring to a ClientTlsPolicy resource.
//
// ClientTlsPolicy can be set to specify the authentication for traffic from the proxy to the actual endpoints.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_network_services_endpoint_policy#client_tls_policy GoogleNetworkServicesEndpointPolicy#client_tls_policy}
ClientTlsPolicy *string `field:"optional" json:"clientTlsPolicy" yaml:"clientTlsPolicy"`
// A free-text description of the resource. Max length 1024 characters.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_network_services_endpoint_policy#description GoogleNetworkServicesEndpointPolicy#description}
Description *string `field:"optional" json:"description" yaml:"description"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_network_services_endpoint_policy#id GoogleNetworkServicesEndpointPolicy#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Set of label tags associated with the TcpRoute resource.
//
// **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
// Please refer to the field 'effective_labels' for all of the labels present on the resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_network_services_endpoint_policy#labels GoogleNetworkServicesEndpointPolicy#labels}
Labels *map[string]*string `field:"optional" json:"labels" yaml:"labels"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_network_services_endpoint_policy#project GoogleNetworkServicesEndpointPolicy#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// A URL referring to ServerTlsPolicy resource.
//
// ServerTlsPolicy is used to determine the authentication policy to be applied to terminate the inbound traffic at the identified backends.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_network_services_endpoint_policy#server_tls_policy GoogleNetworkServicesEndpointPolicy#server_tls_policy}
ServerTlsPolicy *string `field:"optional" json:"serverTlsPolicy" yaml:"serverTlsPolicy"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_network_services_endpoint_policy#timeouts GoogleNetworkServicesEndpointPolicy#timeouts}
Timeouts *GoogleNetworkServicesEndpointPolicyTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
// traffic_port_selector block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_network_services_endpoint_policy#traffic_port_selector GoogleNetworkServicesEndpointPolicy#traffic_port_selector}
TrafficPortSelector *GoogleNetworkServicesEndpointPolicyTrafficPortSelector `field:"optional" json:"trafficPortSelector" yaml:"trafficPortSelector"`
}
type GoogleNetworkServicesEndpointPolicyEndpointMatcher ¶
type GoogleNetworkServicesEndpointPolicyEndpointMatcher struct {
// metadata_label_matcher block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_network_services_endpoint_policy#metadata_label_matcher GoogleNetworkServicesEndpointPolicy#metadata_label_matcher}
MetadataLabelMatcher *GoogleNetworkServicesEndpointPolicyEndpointMatcherMetadataLabelMatcher `field:"required" json:"metadataLabelMatcher" yaml:"metadataLabelMatcher"`
}
type GoogleNetworkServicesEndpointPolicyEndpointMatcherMetadataLabelMatcher ¶
type GoogleNetworkServicesEndpointPolicyEndpointMatcherMetadataLabelMatcher struct {
// Specifies how matching should be done. Possible values: ["MATCH_ANY", "MATCH_ALL"].
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_network_services_endpoint_policy#metadata_label_match_criteria GoogleNetworkServicesEndpointPolicy#metadata_label_match_criteria}
MetadataLabelMatchCriteria *string `field:"required" json:"metadataLabelMatchCriteria" yaml:"metadataLabelMatchCriteria"`
// metadata_labels block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_network_services_endpoint_policy#metadata_labels GoogleNetworkServicesEndpointPolicy#metadata_labels}
MetadataLabels interface{} `field:"optional" json:"metadataLabels" yaml:"metadataLabels"`
}
type GoogleNetworkServicesEndpointPolicyEndpointMatcherMetadataLabelMatcherMetadataLabels ¶
type GoogleNetworkServicesEndpointPolicyEndpointMatcherMetadataLabelMatcherMetadataLabels struct {
// Required. Label name presented as key in xDS Node Metadata.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_network_services_endpoint_policy#label_name GoogleNetworkServicesEndpointPolicy#label_name}
LabelName *string `field:"required" json:"labelName" yaml:"labelName"`
// Required. Label value presented as value corresponding to the above key, in xDS Node Metadata.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_network_services_endpoint_policy#label_value GoogleNetworkServicesEndpointPolicy#label_value}
LabelValue *string `field:"required" json:"labelValue" yaml:"labelValue"`
}
type GoogleNetworkServicesEndpointPolicyEndpointMatcherMetadataLabelMatcherMetadataLabelsList ¶
type GoogleNetworkServicesEndpointPolicyEndpointMatcherMetadataLabelMatcherMetadataLabelsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) GoogleNetworkServicesEndpointPolicyEndpointMatcherMetadataLabelMatcherMetadataLabelsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleNetworkServicesEndpointPolicyEndpointMatcherMetadataLabelMatcherMetadataLabelsList ¶
func NewGoogleNetworkServicesEndpointPolicyEndpointMatcherMetadataLabelMatcherMetadataLabelsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GoogleNetworkServicesEndpointPolicyEndpointMatcherMetadataLabelMatcherMetadataLabelsList
type GoogleNetworkServicesEndpointPolicyEndpointMatcherMetadataLabelMatcherMetadataLabelsOutputReference ¶
type GoogleNetworkServicesEndpointPolicyEndpointMatcherMetadataLabelMatcherMetadataLabelsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
LabelName() *string
SetLabelName(val *string)
LabelNameInput() *string
LabelValue() *string
SetLabelValue(val *string)
LabelValueInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleNetworkServicesEndpointPolicyEndpointMatcherMetadataLabelMatcherMetadataLabelsOutputReference ¶
func NewGoogleNetworkServicesEndpointPolicyEndpointMatcherMetadataLabelMatcherMetadataLabelsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GoogleNetworkServicesEndpointPolicyEndpointMatcherMetadataLabelMatcherMetadataLabelsOutputReference
type GoogleNetworkServicesEndpointPolicyEndpointMatcherMetadataLabelMatcherOutputReference ¶
type GoogleNetworkServicesEndpointPolicyEndpointMatcherMetadataLabelMatcherOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleNetworkServicesEndpointPolicyEndpointMatcherMetadataLabelMatcher
SetInternalValue(val *GoogleNetworkServicesEndpointPolicyEndpointMatcherMetadataLabelMatcher)
MetadataLabelMatchCriteria() *string
SetMetadataLabelMatchCriteria(val *string)
MetadataLabelMatchCriteriaInput() *string
MetadataLabels() GoogleNetworkServicesEndpointPolicyEndpointMatcherMetadataLabelMatcherMetadataLabelsList
MetadataLabelsInput() interface{}
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutMetadataLabels(value interface{})
ResetMetadataLabels()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleNetworkServicesEndpointPolicyEndpointMatcherMetadataLabelMatcherOutputReference ¶
func NewGoogleNetworkServicesEndpointPolicyEndpointMatcherMetadataLabelMatcherOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleNetworkServicesEndpointPolicyEndpointMatcherMetadataLabelMatcherOutputReference
type GoogleNetworkServicesEndpointPolicyEndpointMatcherOutputReference ¶
type GoogleNetworkServicesEndpointPolicyEndpointMatcherOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleNetworkServicesEndpointPolicyEndpointMatcher
SetInternalValue(val *GoogleNetworkServicesEndpointPolicyEndpointMatcher)
MetadataLabelMatcher() GoogleNetworkServicesEndpointPolicyEndpointMatcherMetadataLabelMatcherOutputReference
MetadataLabelMatcherInput() *GoogleNetworkServicesEndpointPolicyEndpointMatcherMetadataLabelMatcher
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutMetadataLabelMatcher(value *GoogleNetworkServicesEndpointPolicyEndpointMatcherMetadataLabelMatcher)
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleNetworkServicesEndpointPolicyEndpointMatcherOutputReference ¶
func NewGoogleNetworkServicesEndpointPolicyEndpointMatcherOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleNetworkServicesEndpointPolicyEndpointMatcherOutputReference
type GoogleNetworkServicesEndpointPolicyTimeouts ¶
type GoogleNetworkServicesEndpointPolicyTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_network_services_endpoint_policy#create GoogleNetworkServicesEndpointPolicy#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_network_services_endpoint_policy#delete GoogleNetworkServicesEndpointPolicy#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_network_services_endpoint_policy#update GoogleNetworkServicesEndpointPolicy#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type GoogleNetworkServicesEndpointPolicyTimeoutsOutputReference ¶
type GoogleNetworkServicesEndpointPolicyTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleNetworkServicesEndpointPolicyTimeoutsOutputReference ¶
func NewGoogleNetworkServicesEndpointPolicyTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleNetworkServicesEndpointPolicyTimeoutsOutputReference
type GoogleNetworkServicesEndpointPolicyTrafficPortSelector ¶
type GoogleNetworkServicesEndpointPolicyTrafficPortSelector struct {
// List of ports.
//
// Can be port numbers or port range (example, [80-90] specifies all ports from 80 to 90, including 80 and 90) or named ports or * to specify all ports. If the list is empty, all ports are selected.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_network_services_endpoint_policy#ports GoogleNetworkServicesEndpointPolicy#ports}
Ports *[]*string `field:"required" json:"ports" yaml:"ports"`
}
type GoogleNetworkServicesEndpointPolicyTrafficPortSelectorOutputReference ¶
type GoogleNetworkServicesEndpointPolicyTrafficPortSelectorOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleNetworkServicesEndpointPolicyTrafficPortSelector
SetInternalValue(val *GoogleNetworkServicesEndpointPolicyTrafficPortSelector)
Ports() *[]*string
SetPorts(val *[]*string)
PortsInput() *[]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleNetworkServicesEndpointPolicyTrafficPortSelectorOutputReference ¶
func NewGoogleNetworkServicesEndpointPolicyTrafficPortSelectorOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleNetworkServicesEndpointPolicyTrafficPortSelectorOutputReference
Source Files
¶
- GoogleNetworkServicesEndpointPolicy.go
- GoogleNetworkServicesEndpointPolicyConfig.go
- GoogleNetworkServicesEndpointPolicyEndpointMatcher.go
- GoogleNetworkServicesEndpointPolicyEndpointMatcherMetadataLabelMatcher.go
- GoogleNetworkServicesEndpointPolicyEndpointMatcherMetadataLabelMatcherMetadataLabels.go
- GoogleNetworkServicesEndpointPolicyEndpointMatcherMetadataLabelMatcherMetadataLabelsList.go
- GoogleNetworkServicesEndpointPolicyEndpointMatcherMetadataLabelMatcherMetadataLabelsList__checks.go
- GoogleNetworkServicesEndpointPolicyEndpointMatcherMetadataLabelMatcherMetadataLabelsOutputReference.go
- GoogleNetworkServicesEndpointPolicyEndpointMatcherMetadataLabelMatcherMetadataLabelsOutputReference__checks.go
- GoogleNetworkServicesEndpointPolicyEndpointMatcherMetadataLabelMatcherOutputReference.go
- GoogleNetworkServicesEndpointPolicyEndpointMatcherMetadataLabelMatcherOutputReference__checks.go
- GoogleNetworkServicesEndpointPolicyEndpointMatcherOutputReference.go
- GoogleNetworkServicesEndpointPolicyEndpointMatcherOutputReference__checks.go
- GoogleNetworkServicesEndpointPolicyTimeouts.go
- GoogleNetworkServicesEndpointPolicyTimeoutsOutputReference.go
- GoogleNetworkServicesEndpointPolicyTimeoutsOutputReference__checks.go
- GoogleNetworkServicesEndpointPolicyTrafficPortSelector.go
- GoogleNetworkServicesEndpointPolicyTrafficPortSelectorOutputReference.go
- GoogleNetworkServicesEndpointPolicyTrafficPortSelectorOutputReference__checks.go
- GoogleNetworkServicesEndpointPolicy__checks.go
- main.go