Documentation
¶
Index ¶
- func GoogleVpcAccessConnector_IsConstruct(x interface{}) *bool
- func GoogleVpcAccessConnector_IsTerraformElement(x interface{}) *bool
- func GoogleVpcAccessConnector_IsTerraformResource(x interface{}) *bool
- func GoogleVpcAccessConnector_TfResourceType() *string
- func NewGoogleVpcAccessConnectorSubnetOutputReference_Override(g GoogleVpcAccessConnectorSubnetOutputReference, ...)
- func NewGoogleVpcAccessConnectorTimeoutsOutputReference_Override(g GoogleVpcAccessConnectorTimeoutsOutputReference, ...)
- func NewGoogleVpcAccessConnector_Override(g GoogleVpcAccessConnector, scope constructs.Construct, id *string, ...)
- type GoogleVpcAccessConnector
- type GoogleVpcAccessConnectorConfig
- type GoogleVpcAccessConnectorSubnet
- type GoogleVpcAccessConnectorSubnetOutputReference
- type GoogleVpcAccessConnectorTimeouts
- type GoogleVpcAccessConnectorTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleVpcAccessConnector_IsConstruct ¶
func GoogleVpcAccessConnector_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleVpcAccessConnector_IsTerraformElement ¶
func GoogleVpcAccessConnector_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleVpcAccessConnector_IsTerraformResource ¶
func GoogleVpcAccessConnector_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleVpcAccessConnector_TfResourceType ¶
func GoogleVpcAccessConnector_TfResourceType() *string
func NewGoogleVpcAccessConnectorSubnetOutputReference_Override ¶
func NewGoogleVpcAccessConnectorSubnetOutputReference_Override(g GoogleVpcAccessConnectorSubnetOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleVpcAccessConnectorTimeoutsOutputReference_Override ¶
func NewGoogleVpcAccessConnectorTimeoutsOutputReference_Override(g GoogleVpcAccessConnectorTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleVpcAccessConnector_Override ¶
func NewGoogleVpcAccessConnector_Override(g GoogleVpcAccessConnector, scope constructs.Construct, id *string, config *GoogleVpcAccessConnectorConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_vpc_access_connector google_vpc_access_connector} Resource.
Types ¶
type GoogleVpcAccessConnector ¶
type GoogleVpcAccessConnector interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
ConnectedProjects() *[]*string
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
IpCidrRange() *string
SetIpCidrRange(val *string)
IpCidrRangeInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
MachineType() *string
SetMachineType(val *string)
MachineTypeInput() *string
MaxInstances() *float64
SetMaxInstances(val *float64)
MaxInstancesInput() *float64
MaxThroughput() *float64
SetMaxThroughput(val *float64)
MaxThroughputInput() *float64
MinInstances() *float64
SetMinInstances(val *float64)
MinInstancesInput() *float64
MinThroughput() *float64
SetMinThroughput(val *float64)
MinThroughputInput() *float64
Name() *string
SetName(val *string)
NameInput() *string
Network() *string
SetNetwork(val *string)
NetworkInput() *string
// The tree node.
Node() constructs.Node
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Region() *string
SetRegion(val *string)
RegionInput() *string
SelfLink() *string
State() *string
Subnet() GoogleVpcAccessConnectorSubnetOutputReference
SubnetInput() *GoogleVpcAccessConnectorSubnet
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GoogleVpcAccessConnectorTimeoutsOutputReference
TimeoutsInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutSubnet(value *GoogleVpcAccessConnectorSubnet)
PutTimeouts(value *GoogleVpcAccessConnectorTimeouts)
ResetId()
ResetIpCidrRange()
ResetMachineType()
ResetMaxInstances()
ResetMaxThroughput()
ResetMinInstances()
ResetMinThroughput()
ResetNetwork()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
ResetRegion()
ResetSubnet()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_vpc_access_connector google_vpc_access_connector}.
func NewGoogleVpcAccessConnector ¶
func NewGoogleVpcAccessConnector(scope constructs.Construct, id *string, config *GoogleVpcAccessConnectorConfig) GoogleVpcAccessConnector
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_vpc_access_connector google_vpc_access_connector} Resource.
type GoogleVpcAccessConnectorConfig ¶
type GoogleVpcAccessConnectorConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// The name of the resource (Max 25 characters).
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_vpc_access_connector#name GoogleVpcAccessConnector#name}
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_vpc_access_connector#id GoogleVpcAccessConnector#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// The range of internal addresses that follows RFC 4632 notation. Example: '10.132.0.0/28'.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_vpc_access_connector#ip_cidr_range GoogleVpcAccessConnector#ip_cidr_range}
IpCidrRange *string `field:"optional" json:"ipCidrRange" yaml:"ipCidrRange"`
// Machine type of VM Instance underlying connector. Default is e2-micro.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_vpc_access_connector#machine_type GoogleVpcAccessConnector#machine_type}
MachineType *string `field:"optional" json:"machineType" yaml:"machineType"`
// Maximum value of instances in autoscaling group underlying the connector.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_vpc_access_connector#max_instances GoogleVpcAccessConnector#max_instances}
MaxInstances *float64 `field:"optional" json:"maxInstances" yaml:"maxInstances"`
// Maximum throughput of the connector in Mbps, must be greater than 'min_throughput'. Default is 300.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_vpc_access_connector#max_throughput GoogleVpcAccessConnector#max_throughput}
MaxThroughput *float64 `field:"optional" json:"maxThroughput" yaml:"maxThroughput"`
// Minimum value of instances in autoscaling group underlying the connector.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_vpc_access_connector#min_instances GoogleVpcAccessConnector#min_instances}
MinInstances *float64 `field:"optional" json:"minInstances" yaml:"minInstances"`
// Minimum throughput of the connector in Mbps. Default and min is 200.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_vpc_access_connector#min_throughput GoogleVpcAccessConnector#min_throughput}
MinThroughput *float64 `field:"optional" json:"minThroughput" yaml:"minThroughput"`
// Name or self_link of the VPC network. Required if 'ip_cidr_range' is set.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_vpc_access_connector#network GoogleVpcAccessConnector#network}
Network *string `field:"optional" json:"network" yaml:"network"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_vpc_access_connector#project GoogleVpcAccessConnector#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// Region where the VPC Access connector resides. If it is not provided, the provider region is used.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_vpc_access_connector#region GoogleVpcAccessConnector#region}
Region *string `field:"optional" json:"region" yaml:"region"`
// subnet block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_vpc_access_connector#subnet GoogleVpcAccessConnector#subnet}
Subnet *GoogleVpcAccessConnectorSubnet `field:"optional" json:"subnet" yaml:"subnet"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_vpc_access_connector#timeouts GoogleVpcAccessConnector#timeouts}
Timeouts *GoogleVpcAccessConnectorTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type GoogleVpcAccessConnectorSubnet ¶
type GoogleVpcAccessConnectorSubnet struct {
// Subnet name (relative, not fully qualified).
//
// E.g. if the full subnet selfLink is
// https://compute.googleapis.com/compute/v1/projects/{project}/regions/{region}/subnetworks/{subnetName} the correct input for this field would be {subnetName}"
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_vpc_access_connector#name GoogleVpcAccessConnector#name}
Name *string `field:"optional" json:"name" yaml:"name"`
// Project in which the subnet exists.
//
// If not set, this project is assumed to be the project for which the connector create request was issued.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_vpc_access_connector#project_id GoogleVpcAccessConnector#project_id}
ProjectId *string `field:"optional" json:"projectId" yaml:"projectId"`
}
type GoogleVpcAccessConnectorSubnetOutputReference ¶
type GoogleVpcAccessConnectorSubnetOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleVpcAccessConnectorSubnet
SetInternalValue(val *GoogleVpcAccessConnectorSubnet)
Name() *string
SetName(val *string)
NameInput() *string
ProjectId() *string
SetProjectId(val *string)
ProjectIdInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetName()
ResetProjectId()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleVpcAccessConnectorSubnetOutputReference ¶
func NewGoogleVpcAccessConnectorSubnetOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleVpcAccessConnectorSubnetOutputReference
type GoogleVpcAccessConnectorTimeouts ¶
type GoogleVpcAccessConnectorTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_vpc_access_connector#create GoogleVpcAccessConnector#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_vpc_access_connector#delete GoogleVpcAccessConnector#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
}
type GoogleVpcAccessConnectorTimeoutsOutputReference ¶
type GoogleVpcAccessConnectorTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleVpcAccessConnectorTimeoutsOutputReference ¶
func NewGoogleVpcAccessConnectorTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleVpcAccessConnectorTimeoutsOutputReference
Source Files
¶
- GoogleVpcAccessConnector.go
- GoogleVpcAccessConnectorConfig.go
- GoogleVpcAccessConnectorSubnet.go
- GoogleVpcAccessConnectorSubnetOutputReference.go
- GoogleVpcAccessConnectorSubnetOutputReference__checks.go
- GoogleVpcAccessConnectorTimeouts.go
- GoogleVpcAccessConnectorTimeoutsOutputReference.go
- GoogleVpcAccessConnectorTimeoutsOutputReference__checks.go
- GoogleVpcAccessConnector__checks.go
- main.go