Documentation
¶
Index ¶
- func GoogleWorkstationsWorkstationIamMember_IsConstruct(x interface{}) *bool
- func GoogleWorkstationsWorkstationIamMember_IsTerraformElement(x interface{}) *bool
- func GoogleWorkstationsWorkstationIamMember_IsTerraformResource(x interface{}) *bool
- func GoogleWorkstationsWorkstationIamMember_TfResourceType() *string
- func NewGoogleWorkstationsWorkstationIamMemberConditionOutputReference_Override(g GoogleWorkstationsWorkstationIamMemberConditionOutputReference, ...)
- func NewGoogleWorkstationsWorkstationIamMember_Override(g GoogleWorkstationsWorkstationIamMember, scope constructs.Construct, ...)
- type GoogleWorkstationsWorkstationIamMember
- type GoogleWorkstationsWorkstationIamMemberCondition
- type GoogleWorkstationsWorkstationIamMemberConditionOutputReference
- type GoogleWorkstationsWorkstationIamMemberConfig
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleWorkstationsWorkstationIamMember_IsConstruct ¶
func GoogleWorkstationsWorkstationIamMember_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleWorkstationsWorkstationIamMember_IsTerraformElement ¶
func GoogleWorkstationsWorkstationIamMember_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleWorkstationsWorkstationIamMember_IsTerraformResource ¶
func GoogleWorkstationsWorkstationIamMember_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleWorkstationsWorkstationIamMember_TfResourceType ¶
func GoogleWorkstationsWorkstationIamMember_TfResourceType() *string
func NewGoogleWorkstationsWorkstationIamMemberConditionOutputReference_Override ¶
func NewGoogleWorkstationsWorkstationIamMemberConditionOutputReference_Override(g GoogleWorkstationsWorkstationIamMemberConditionOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleWorkstationsWorkstationIamMember_Override ¶
func NewGoogleWorkstationsWorkstationIamMember_Override(g GoogleWorkstationsWorkstationIamMember, scope constructs.Construct, id *string, config *GoogleWorkstationsWorkstationIamMemberConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_workstations_workstation_iam_member google_workstations_workstation_iam_member} Resource.
Types ¶
type GoogleWorkstationsWorkstationIamMember ¶
type GoogleWorkstationsWorkstationIamMember interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
Condition() GoogleWorkstationsWorkstationIamMemberConditionOutputReference
ConditionInput() *GoogleWorkstationsWorkstationIamMemberCondition
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Etag() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Location() *string
SetLocation(val *string)
LocationInput() *string
Member() *string
SetMember(val *string)
MemberInput() *string
// The tree node.
Node() constructs.Node
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Role() *string
SetRole(val *string)
RoleInput() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
WorkstationClusterId() *string
SetWorkstationClusterId(val *string)
WorkstationClusterIdInput() *string
WorkstationConfigId() *string
SetWorkstationConfigId(val *string)
WorkstationConfigIdInput() *string
WorkstationId() *string
SetWorkstationId(val *string)
WorkstationIdInput() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutCondition(value *GoogleWorkstationsWorkstationIamMemberCondition)
ResetCondition()
ResetId()
ResetLocation()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_workstations_workstation_iam_member google_workstations_workstation_iam_member}.
func NewGoogleWorkstationsWorkstationIamMember ¶
func NewGoogleWorkstationsWorkstationIamMember(scope constructs.Construct, id *string, config *GoogleWorkstationsWorkstationIamMemberConfig) GoogleWorkstationsWorkstationIamMember
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_workstations_workstation_iam_member google_workstations_workstation_iam_member} Resource.
type GoogleWorkstationsWorkstationIamMemberCondition ¶
type GoogleWorkstationsWorkstationIamMemberCondition struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_workstations_workstation_iam_member#expression GoogleWorkstationsWorkstationIamMember#expression}.
Expression *string `field:"required" json:"expression" yaml:"expression"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_workstations_workstation_iam_member#title GoogleWorkstationsWorkstationIamMember#title}.
Title *string `field:"required" json:"title" yaml:"title"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_workstations_workstation_iam_member#description GoogleWorkstationsWorkstationIamMember#description}.
Description *string `field:"optional" json:"description" yaml:"description"`
}
type GoogleWorkstationsWorkstationIamMemberConditionOutputReference ¶
type GoogleWorkstationsWorkstationIamMemberConditionOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Description() *string
SetDescription(val *string)
DescriptionInput() *string
Expression() *string
SetExpression(val *string)
ExpressionInput() *string
// Experimental.
Fqn() *string
InternalValue() *GoogleWorkstationsWorkstationIamMemberCondition
SetInternalValue(val *GoogleWorkstationsWorkstationIamMemberCondition)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Title() *string
SetTitle(val *string)
TitleInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetDescription()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleWorkstationsWorkstationIamMemberConditionOutputReference ¶
func NewGoogleWorkstationsWorkstationIamMemberConditionOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleWorkstationsWorkstationIamMemberConditionOutputReference
type GoogleWorkstationsWorkstationIamMemberConfig ¶
type GoogleWorkstationsWorkstationIamMemberConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_workstations_workstation_iam_member#member GoogleWorkstationsWorkstationIamMember#member}.
Member *string `field:"required" json:"member" yaml:"member"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_workstations_workstation_iam_member#role GoogleWorkstationsWorkstationIamMember#role}.
Role *string `field:"required" json:"role" yaml:"role"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_workstations_workstation_iam_member#workstation_cluster_id GoogleWorkstationsWorkstationIamMember#workstation_cluster_id}.
WorkstationClusterId *string `field:"required" json:"workstationClusterId" yaml:"workstationClusterId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_workstations_workstation_iam_member#workstation_config_id GoogleWorkstationsWorkstationIamMember#workstation_config_id}.
WorkstationConfigId *string `field:"required" json:"workstationConfigId" yaml:"workstationConfigId"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_workstations_workstation_iam_member#workstation_id GoogleWorkstationsWorkstationIamMember#workstation_id}.
WorkstationId *string `field:"required" json:"workstationId" yaml:"workstationId"`
// condition block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_workstations_workstation_iam_member#condition GoogleWorkstationsWorkstationIamMember#condition}
Condition *GoogleWorkstationsWorkstationIamMemberCondition `field:"optional" json:"condition" yaml:"condition"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_workstations_workstation_iam_member#id GoogleWorkstationsWorkstationIamMember#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_workstations_workstation_iam_member#location GoogleWorkstationsWorkstationIamMember#location}.
Location *string `field:"optional" json:"location" yaml:"location"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.1.0/docs/resources/google_workstations_workstation_iam_member#project GoogleWorkstationsWorkstationIamMember#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
}
Source Files
¶
- GoogleWorkstationsWorkstationIamMember.go
- GoogleWorkstationsWorkstationIamMemberCondition.go
- GoogleWorkstationsWorkstationIamMemberConditionOutputReference.go
- GoogleWorkstationsWorkstationIamMemberConditionOutputReference__checks.go
- GoogleWorkstationsWorkstationIamMemberConfig.go
- GoogleWorkstationsWorkstationIamMember__checks.go
- main.go