Documentation
¶
Index ¶
- func DataGoogleBeyondcorpAppConnector_IsConstruct(x interface{}) *bool
- func DataGoogleBeyondcorpAppConnector_IsTerraformDataSource(x interface{}) *bool
- func DataGoogleBeyondcorpAppConnector_IsTerraformElement(x interface{}) *bool
- func DataGoogleBeyondcorpAppConnector_TfResourceType() *string
- func NewDataGoogleBeyondcorpAppConnectorPrincipalInfoList_Override(d DataGoogleBeyondcorpAppConnectorPrincipalInfoList, ...)
- func NewDataGoogleBeyondcorpAppConnectorPrincipalInfoOutputReference_Override(d DataGoogleBeyondcorpAppConnectorPrincipalInfoOutputReference, ...)
- func NewDataGoogleBeyondcorpAppConnectorPrincipalInfoServiceAccountList_Override(d DataGoogleBeyondcorpAppConnectorPrincipalInfoServiceAccountList, ...)
- func NewDataGoogleBeyondcorpAppConnectorPrincipalInfoServiceAccountOutputReference_Override(d DataGoogleBeyondcorpAppConnectorPrincipalInfoServiceAccountOutputReference, ...)
- func NewDataGoogleBeyondcorpAppConnector_Override(d DataGoogleBeyondcorpAppConnector, scope constructs.Construct, id *string, ...)
- type DataGoogleBeyondcorpAppConnector
- type DataGoogleBeyondcorpAppConnectorConfig
- type DataGoogleBeyondcorpAppConnectorPrincipalInfo
- type DataGoogleBeyondcorpAppConnectorPrincipalInfoList
- type DataGoogleBeyondcorpAppConnectorPrincipalInfoOutputReference
- type DataGoogleBeyondcorpAppConnectorPrincipalInfoServiceAccount
- type DataGoogleBeyondcorpAppConnectorPrincipalInfoServiceAccountList
- type DataGoogleBeyondcorpAppConnectorPrincipalInfoServiceAccountOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataGoogleBeyondcorpAppConnector_IsConstruct ¶
func DataGoogleBeyondcorpAppConnector_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataGoogleBeyondcorpAppConnector_IsTerraformDataSource ¶
func DataGoogleBeyondcorpAppConnector_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataGoogleBeyondcorpAppConnector_IsTerraformElement ¶
func DataGoogleBeyondcorpAppConnector_IsTerraformElement(x interface{}) *bool
Experimental.
func DataGoogleBeyondcorpAppConnector_TfResourceType ¶
func DataGoogleBeyondcorpAppConnector_TfResourceType() *string
func NewDataGoogleBeyondcorpAppConnectorPrincipalInfoList_Override ¶
func NewDataGoogleBeyondcorpAppConnectorPrincipalInfoList_Override(d DataGoogleBeyondcorpAppConnectorPrincipalInfoList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataGoogleBeyondcorpAppConnectorPrincipalInfoOutputReference_Override ¶
func NewDataGoogleBeyondcorpAppConnectorPrincipalInfoOutputReference_Override(d DataGoogleBeyondcorpAppConnectorPrincipalInfoOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataGoogleBeyondcorpAppConnectorPrincipalInfoServiceAccountList_Override ¶
func NewDataGoogleBeyondcorpAppConnectorPrincipalInfoServiceAccountList_Override(d DataGoogleBeyondcorpAppConnectorPrincipalInfoServiceAccountList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataGoogleBeyondcorpAppConnectorPrincipalInfoServiceAccountOutputReference_Override ¶
func NewDataGoogleBeyondcorpAppConnectorPrincipalInfoServiceAccountOutputReference_Override(d DataGoogleBeyondcorpAppConnectorPrincipalInfoServiceAccountOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataGoogleBeyondcorpAppConnector_Override ¶
func NewDataGoogleBeyondcorpAppConnector_Override(d DataGoogleBeyondcorpAppConnector, scope constructs.Construct, id *string, config *DataGoogleBeyondcorpAppConnectorConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/data-sources/google_beyondcorp_app_connector google_beyondcorp_app_connector} Data Source.
Types ¶
type DataGoogleBeyondcorpAppConnector ¶
type DataGoogleBeyondcorpAppConnector interface {
cdktf.TerraformDataSource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DisplayName() *string
EffectiveLabels() cdktf.StringMap
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
Labels() cdktf.StringMap
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
PrincipalInfo() DataGoogleBeyondcorpAppConnectorPrincipalInfoList
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
Region() *string
SetRegion(val *string)
RegionInput() *string
State() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
TerraformLabels() cdktf.StringMap
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
ResetRegion()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/data-sources/google_beyondcorp_app_connector google_beyondcorp_app_connector}.
func NewDataGoogleBeyondcorpAppConnector ¶
func NewDataGoogleBeyondcorpAppConnector(scope constructs.Construct, id *string, config *DataGoogleBeyondcorpAppConnectorConfig) DataGoogleBeyondcorpAppConnector
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/data-sources/google_beyondcorp_app_connector google_beyondcorp_app_connector} Data Source.
type DataGoogleBeyondcorpAppConnectorConfig ¶
type DataGoogleBeyondcorpAppConnectorConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// ID of the AppConnector.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/data-sources/google_beyondcorp_app_connector#name DataGoogleBeyondcorpAppConnector#name}
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/data-sources/google_beyondcorp_app_connector#id DataGoogleBeyondcorpAppConnector#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/data-sources/google_beyondcorp_app_connector#project DataGoogleBeyondcorpAppConnector#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// The region of the AppConnector.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/data-sources/google_beyondcorp_app_connector#region DataGoogleBeyondcorpAppConnector#region}
Region *string `field:"optional" json:"region" yaml:"region"`
}
type DataGoogleBeyondcorpAppConnectorPrincipalInfo ¶
type DataGoogleBeyondcorpAppConnectorPrincipalInfo struct {
}
type DataGoogleBeyondcorpAppConnectorPrincipalInfoList ¶
type DataGoogleBeyondcorpAppConnectorPrincipalInfoList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataGoogleBeyondcorpAppConnectorPrincipalInfoOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleBeyondcorpAppConnectorPrincipalInfoList ¶
func NewDataGoogleBeyondcorpAppConnectorPrincipalInfoList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataGoogleBeyondcorpAppConnectorPrincipalInfoList
type DataGoogleBeyondcorpAppConnectorPrincipalInfoOutputReference ¶
type DataGoogleBeyondcorpAppConnectorPrincipalInfoOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataGoogleBeyondcorpAppConnectorPrincipalInfo
SetInternalValue(val *DataGoogleBeyondcorpAppConnectorPrincipalInfo)
ServiceAccount() DataGoogleBeyondcorpAppConnectorPrincipalInfoServiceAccountList
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleBeyondcorpAppConnectorPrincipalInfoOutputReference ¶
func NewDataGoogleBeyondcorpAppConnectorPrincipalInfoOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataGoogleBeyondcorpAppConnectorPrincipalInfoOutputReference
type DataGoogleBeyondcorpAppConnectorPrincipalInfoServiceAccount ¶
type DataGoogleBeyondcorpAppConnectorPrincipalInfoServiceAccount struct {
}
type DataGoogleBeyondcorpAppConnectorPrincipalInfoServiceAccountList ¶
type DataGoogleBeyondcorpAppConnectorPrincipalInfoServiceAccountList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) DataGoogleBeyondcorpAppConnectorPrincipalInfoServiceAccountOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleBeyondcorpAppConnectorPrincipalInfoServiceAccountList ¶
func NewDataGoogleBeyondcorpAppConnectorPrincipalInfoServiceAccountList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataGoogleBeyondcorpAppConnectorPrincipalInfoServiceAccountList
type DataGoogleBeyondcorpAppConnectorPrincipalInfoServiceAccountOutputReference ¶
type DataGoogleBeyondcorpAppConnectorPrincipalInfoServiceAccountOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Email() *string
// Experimental.
Fqn() *string
InternalValue() *DataGoogleBeyondcorpAppConnectorPrincipalInfoServiceAccount
SetInternalValue(val *DataGoogleBeyondcorpAppConnectorPrincipalInfoServiceAccount)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleBeyondcorpAppConnectorPrincipalInfoServiceAccountOutputReference ¶
func NewDataGoogleBeyondcorpAppConnectorPrincipalInfoServiceAccountOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataGoogleBeyondcorpAppConnectorPrincipalInfoServiceAccountOutputReference
Source Files
¶
- DataGoogleBeyondcorpAppConnector.go
- DataGoogleBeyondcorpAppConnectorConfig.go
- DataGoogleBeyondcorpAppConnectorPrincipalInfo.go
- DataGoogleBeyondcorpAppConnectorPrincipalInfoList.go
- DataGoogleBeyondcorpAppConnectorPrincipalInfoList__checks.go
- DataGoogleBeyondcorpAppConnectorPrincipalInfoOutputReference.go
- DataGoogleBeyondcorpAppConnectorPrincipalInfoOutputReference__checks.go
- DataGoogleBeyondcorpAppConnectorPrincipalInfoServiceAccount.go
- DataGoogleBeyondcorpAppConnectorPrincipalInfoServiceAccountList.go
- DataGoogleBeyondcorpAppConnectorPrincipalInfoServiceAccountList__checks.go
- DataGoogleBeyondcorpAppConnectorPrincipalInfoServiceAccountOutputReference.go
- DataGoogleBeyondcorpAppConnectorPrincipalInfoServiceAccountOutputReference__checks.go
- DataGoogleBeyondcorpAppConnector__checks.go
- main.go