Documentation
¶
Index ¶
- func GoogleAlloydbInstance_IsConstruct(x interface{}) *bool
- func GoogleAlloydbInstance_IsTerraformElement(x interface{}) *bool
- func GoogleAlloydbInstance_IsTerraformResource(x interface{}) *bool
- func GoogleAlloydbInstance_TfResourceType() *string
- func NewGoogleAlloydbInstanceMachineConfigOutputReference_Override(g GoogleAlloydbInstanceMachineConfigOutputReference, ...)
- func NewGoogleAlloydbInstanceQueryInsightsConfigOutputReference_Override(g GoogleAlloydbInstanceQueryInsightsConfigOutputReference, ...)
- func NewGoogleAlloydbInstanceReadPoolConfigOutputReference_Override(g GoogleAlloydbInstanceReadPoolConfigOutputReference, ...)
- func NewGoogleAlloydbInstanceTimeoutsOutputReference_Override(g GoogleAlloydbInstanceTimeoutsOutputReference, ...)
- func NewGoogleAlloydbInstance_Override(g GoogleAlloydbInstance, scope constructs.Construct, id *string, ...)
- type GoogleAlloydbInstance
- type GoogleAlloydbInstanceConfig
- type GoogleAlloydbInstanceMachineConfig
- type GoogleAlloydbInstanceMachineConfigOutputReference
- type GoogleAlloydbInstanceQueryInsightsConfig
- type GoogleAlloydbInstanceQueryInsightsConfigOutputReference
- type GoogleAlloydbInstanceReadPoolConfig
- type GoogleAlloydbInstanceReadPoolConfigOutputReference
- type GoogleAlloydbInstanceTimeouts
- type GoogleAlloydbInstanceTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleAlloydbInstance_IsConstruct ¶
func GoogleAlloydbInstance_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleAlloydbInstance_IsTerraformElement ¶
func GoogleAlloydbInstance_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleAlloydbInstance_IsTerraformResource ¶
func GoogleAlloydbInstance_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleAlloydbInstance_TfResourceType ¶
func GoogleAlloydbInstance_TfResourceType() *string
func NewGoogleAlloydbInstanceMachineConfigOutputReference_Override ¶
func NewGoogleAlloydbInstanceMachineConfigOutputReference_Override(g GoogleAlloydbInstanceMachineConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleAlloydbInstanceQueryInsightsConfigOutputReference_Override ¶
func NewGoogleAlloydbInstanceQueryInsightsConfigOutputReference_Override(g GoogleAlloydbInstanceQueryInsightsConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleAlloydbInstanceReadPoolConfigOutputReference_Override ¶
func NewGoogleAlloydbInstanceReadPoolConfigOutputReference_Override(g GoogleAlloydbInstanceReadPoolConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleAlloydbInstanceTimeoutsOutputReference_Override ¶
func NewGoogleAlloydbInstanceTimeoutsOutputReference_Override(g GoogleAlloydbInstanceTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleAlloydbInstance_Override ¶
func NewGoogleAlloydbInstance_Override(g GoogleAlloydbInstance, scope constructs.Construct, id *string, config *GoogleAlloydbInstanceConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_alloydb_instance google_alloydb_instance} Resource.
Types ¶
type GoogleAlloydbInstance ¶
type GoogleAlloydbInstance interface {
cdktf.TerraformResource
Annotations() *map[string]*string
SetAnnotations(val *map[string]*string)
AnnotationsInput() *map[string]*string
AvailabilityType() *string
SetAvailabilityType(val *string)
AvailabilityTypeInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
Cluster() *string
SetCluster(val *string)
ClusterInput() *string
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
CreateTime() *string
DatabaseFlags() *map[string]*string
SetDatabaseFlags(val *map[string]*string)
DatabaseFlagsInput() *map[string]*string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DisplayName() *string
SetDisplayName(val *string)
DisplayNameInput() *string
EffectiveAnnotations() cdktf.StringMap
EffectiveLabels() cdktf.StringMap
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
GceZone() *string
SetGceZone(val *string)
GceZoneInput() *string
Id() *string
SetId(val *string)
IdInput() *string
InstanceId() *string
SetInstanceId(val *string)
InstanceIdInput() *string
InstanceType() *string
SetInstanceType(val *string)
InstanceTypeInput() *string
IpAddress() *string
Labels() *map[string]*string
SetLabels(val *map[string]*string)
LabelsInput() *map[string]*string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
MachineConfig() GoogleAlloydbInstanceMachineConfigOutputReference
MachineConfigInput() *GoogleAlloydbInstanceMachineConfig
Name() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
QueryInsightsConfig() GoogleAlloydbInstanceQueryInsightsConfigOutputReference
QueryInsightsConfigInput() *GoogleAlloydbInstanceQueryInsightsConfig
// Experimental.
RawOverrides() interface{}
ReadPoolConfig() GoogleAlloydbInstanceReadPoolConfigOutputReference
ReadPoolConfigInput() *GoogleAlloydbInstanceReadPoolConfig
Reconciling() cdktf.IResolvable
State() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
TerraformLabels() cdktf.StringMap
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GoogleAlloydbInstanceTimeoutsOutputReference
TimeoutsInput() interface{}
Uid() *string
UpdateTime() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutMachineConfig(value *GoogleAlloydbInstanceMachineConfig)
PutQueryInsightsConfig(value *GoogleAlloydbInstanceQueryInsightsConfig)
PutReadPoolConfig(value *GoogleAlloydbInstanceReadPoolConfig)
PutTimeouts(value *GoogleAlloydbInstanceTimeouts)
ResetAnnotations()
ResetAvailabilityType()
ResetDatabaseFlags()
ResetDisplayName()
ResetGceZone()
ResetId()
ResetLabels()
ResetMachineConfig()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetQueryInsightsConfig()
ResetReadPoolConfig()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_alloydb_instance google_alloydb_instance}.
func NewGoogleAlloydbInstance ¶
func NewGoogleAlloydbInstance(scope constructs.Construct, id *string, config *GoogleAlloydbInstanceConfig) GoogleAlloydbInstance
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_alloydb_instance google_alloydb_instance} Resource.
type GoogleAlloydbInstanceConfig ¶
type GoogleAlloydbInstanceConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Identifies the alloydb cluster. Must be in the format 'projects/{project}/locations/{location}/clusters/{cluster_id}'.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_alloydb_instance#cluster GoogleAlloydbInstance#cluster}
Cluster *string `field:"required" json:"cluster" yaml:"cluster"`
// The ID of the alloydb instance.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_alloydb_instance#instance_id GoogleAlloydbInstance#instance_id}
InstanceId *string `field:"required" json:"instanceId" yaml:"instanceId"`
// The type of the instance.
//
// If the instance type is READ_POOL, provide the associated PRIMARY instance in the 'depends_on' meta-data attribute. Possible values: ["PRIMARY", "READ_POOL"]
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_alloydb_instance#instance_type GoogleAlloydbInstance#instance_type}
InstanceType *string `field:"required" json:"instanceType" yaml:"instanceType"`
// Annotations to allow client tools to store small amount of arbitrary data. This is distinct from labels.
//
// **Note**: This field is non-authoritative, and will only manage the annotations present in your configuration.
// Please refer to the field 'effective_annotations' for all of the annotations present on the resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_alloydb_instance#annotations GoogleAlloydbInstance#annotations}
Annotations *map[string]*string `field:"optional" json:"annotations" yaml:"annotations"`
// 'Availability type of an Instance.
//
// Defaults to REGIONAL for both primary and read instances.
// Note that primary and read instances can have different availability types.
// Only READ_POOL instance supports ZONAL type. Users can't specify the zone for READ_POOL instance.
// Zone is automatically chosen from the list of zones in the region specified.
// Read pool of size 1 can only have zonal availability. Read pools with node count of 2 or more
// can have regional availability (nodes are present in 2 or more zones in a region).' Possible values: ["AVAILABILITY_TYPE_UNSPECIFIED", "ZONAL", "REGIONAL"]
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_alloydb_instance#availability_type GoogleAlloydbInstance#availability_type}
AvailabilityType *string `field:"optional" json:"availabilityType" yaml:"availabilityType"`
// Database flags.
//
// Set at instance level. * They are copied from primary instance on read instance creation. * Read instances can set new or override existing flags that are relevant for reads, e.g. for enabling columnar cache on a read instance. Flags set on read instance may or may not be present on primary.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_alloydb_instance#database_flags GoogleAlloydbInstance#database_flags}
DatabaseFlags *map[string]*string `field:"optional" json:"databaseFlags" yaml:"databaseFlags"`
// User-settable and human-readable display name for the Instance.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_alloydb_instance#display_name GoogleAlloydbInstance#display_name}
DisplayName *string `field:"optional" json:"displayName" yaml:"displayName"`
// The Compute Engine zone that the instance should serve from, per https://cloud.google.com/compute/docs/regions-zones This can ONLY be specified for ZONAL instances. If present for a REGIONAL instance, an error will be thrown. If this is absent for a ZONAL instance, instance is created in a random zone with available capacity.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_alloydb_instance#gce_zone GoogleAlloydbInstance#gce_zone}
GceZone *string `field:"optional" json:"gceZone" yaml:"gceZone"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_alloydb_instance#id GoogleAlloydbInstance#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// User-defined labels for the alloydb instance.
//
// **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
// Please refer to the field 'effective_labels' for all of the labels present on the resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_alloydb_instance#labels GoogleAlloydbInstance#labels}
Labels *map[string]*string `field:"optional" json:"labels" yaml:"labels"`
// machine_config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_alloydb_instance#machine_config GoogleAlloydbInstance#machine_config}
MachineConfig *GoogleAlloydbInstanceMachineConfig `field:"optional" json:"machineConfig" yaml:"machineConfig"`
// query_insights_config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_alloydb_instance#query_insights_config GoogleAlloydbInstance#query_insights_config}
QueryInsightsConfig *GoogleAlloydbInstanceQueryInsightsConfig `field:"optional" json:"queryInsightsConfig" yaml:"queryInsightsConfig"`
// read_pool_config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_alloydb_instance#read_pool_config GoogleAlloydbInstance#read_pool_config}
ReadPoolConfig *GoogleAlloydbInstanceReadPoolConfig `field:"optional" json:"readPoolConfig" yaml:"readPoolConfig"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_alloydb_instance#timeouts GoogleAlloydbInstance#timeouts}
Timeouts *GoogleAlloydbInstanceTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type GoogleAlloydbInstanceMachineConfig ¶
type GoogleAlloydbInstanceMachineConfig struct {
// The number of CPU's in the VM instance.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_alloydb_instance#cpu_count GoogleAlloydbInstance#cpu_count}
CpuCount *float64 `field:"optional" json:"cpuCount" yaml:"cpuCount"`
}
type GoogleAlloydbInstanceMachineConfigOutputReference ¶
type GoogleAlloydbInstanceMachineConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
CpuCount() *float64
SetCpuCount(val *float64)
CpuCountInput() *float64
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleAlloydbInstanceMachineConfig
SetInternalValue(val *GoogleAlloydbInstanceMachineConfig)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCpuCount()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleAlloydbInstanceMachineConfigOutputReference ¶
func NewGoogleAlloydbInstanceMachineConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleAlloydbInstanceMachineConfigOutputReference
type GoogleAlloydbInstanceQueryInsightsConfig ¶
type GoogleAlloydbInstanceQueryInsightsConfig struct {
// Number of query execution plans captured by Insights per minute for all queries combined.
//
// The default value is 5. Any integer between 0 and 20 is considered valid.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_alloydb_instance#query_plans_per_minute GoogleAlloydbInstance#query_plans_per_minute}
QueryPlansPerMinute *float64 `field:"optional" json:"queryPlansPerMinute" yaml:"queryPlansPerMinute"`
// Query string length. The default value is 1024. Any integer between 256 and 4500 is considered valid.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_alloydb_instance#query_string_length GoogleAlloydbInstance#query_string_length}
QueryStringLength *float64 `field:"optional" json:"queryStringLength" yaml:"queryStringLength"`
// Record application tags for an instance. This flag is turned "on" by default.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_alloydb_instance#record_application_tags GoogleAlloydbInstance#record_application_tags}
RecordApplicationTags interface{} `field:"optional" json:"recordApplicationTags" yaml:"recordApplicationTags"`
// Record client address for an instance. Client address is PII information. This flag is turned "on" by default.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_alloydb_instance#record_client_address GoogleAlloydbInstance#record_client_address}
RecordClientAddress interface{} `field:"optional" json:"recordClientAddress" yaml:"recordClientAddress"`
}
type GoogleAlloydbInstanceQueryInsightsConfigOutputReference ¶
type GoogleAlloydbInstanceQueryInsightsConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleAlloydbInstanceQueryInsightsConfig
SetInternalValue(val *GoogleAlloydbInstanceQueryInsightsConfig)
QueryPlansPerMinute() *float64
SetQueryPlansPerMinute(val *float64)
QueryPlansPerMinuteInput() *float64
QueryStringLength() *float64
SetQueryStringLength(val *float64)
QueryStringLengthInput() *float64
RecordApplicationTags() interface{}
SetRecordApplicationTags(val interface{})
RecordApplicationTagsInput() interface{}
RecordClientAddress() interface{}
SetRecordClientAddress(val interface{})
RecordClientAddressInput() interface{}
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetQueryPlansPerMinute()
ResetQueryStringLength()
ResetRecordApplicationTags()
ResetRecordClientAddress()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleAlloydbInstanceQueryInsightsConfigOutputReference ¶
func NewGoogleAlloydbInstanceQueryInsightsConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleAlloydbInstanceQueryInsightsConfigOutputReference
type GoogleAlloydbInstanceReadPoolConfig ¶
type GoogleAlloydbInstanceReadPoolConfig struct {
// Read capacity, i.e. number of nodes in a read pool instance.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_alloydb_instance#node_count GoogleAlloydbInstance#node_count}
NodeCount *float64 `field:"optional" json:"nodeCount" yaml:"nodeCount"`
}
type GoogleAlloydbInstanceReadPoolConfigOutputReference ¶
type GoogleAlloydbInstanceReadPoolConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleAlloydbInstanceReadPoolConfig
SetInternalValue(val *GoogleAlloydbInstanceReadPoolConfig)
NodeCount() *float64
SetNodeCount(val *float64)
NodeCountInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetNodeCount()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleAlloydbInstanceReadPoolConfigOutputReference ¶
func NewGoogleAlloydbInstanceReadPoolConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleAlloydbInstanceReadPoolConfigOutputReference
type GoogleAlloydbInstanceTimeouts ¶
type GoogleAlloydbInstanceTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_alloydb_instance#create GoogleAlloydbInstance#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_alloydb_instance#delete GoogleAlloydbInstance#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_alloydb_instance#update GoogleAlloydbInstance#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type GoogleAlloydbInstanceTimeoutsOutputReference ¶
type GoogleAlloydbInstanceTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleAlloydbInstanceTimeoutsOutputReference ¶
func NewGoogleAlloydbInstanceTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleAlloydbInstanceTimeoutsOutputReference
Source Files
¶
- GoogleAlloydbInstance.go
- GoogleAlloydbInstanceConfig.go
- GoogleAlloydbInstanceMachineConfig.go
- GoogleAlloydbInstanceMachineConfigOutputReference.go
- GoogleAlloydbInstanceMachineConfigOutputReference__checks.go
- GoogleAlloydbInstanceQueryInsightsConfig.go
- GoogleAlloydbInstanceQueryInsightsConfigOutputReference.go
- GoogleAlloydbInstanceQueryInsightsConfigOutputReference__checks.go
- GoogleAlloydbInstanceReadPoolConfig.go
- GoogleAlloydbInstanceReadPoolConfigOutputReference.go
- GoogleAlloydbInstanceReadPoolConfigOutputReference__checks.go
- GoogleAlloydbInstanceTimeouts.go
- GoogleAlloydbInstanceTimeoutsOutputReference.go
- GoogleAlloydbInstanceTimeoutsOutputReference__checks.go
- GoogleAlloydbInstance__checks.go
- main.go