Documentation
¶
Index ¶
- func GoogleApiGatewayApiConfigA_IsConstruct(x interface{}) *bool
- func GoogleApiGatewayApiConfigA_IsTerraformElement(x interface{}) *bool
- func GoogleApiGatewayApiConfigA_IsTerraformResource(x interface{}) *bool
- func GoogleApiGatewayApiConfigA_TfResourceType() *string
- func NewGoogleApiGatewayApiConfigA_Override(g GoogleApiGatewayApiConfigA, scope constructs.Construct, id *string, ...)
- func NewGoogleApiGatewayApiConfigGatewayConfigBackendConfigOutputReference_Override(g GoogleApiGatewayApiConfigGatewayConfigBackendConfigOutputReference, ...)
- func NewGoogleApiGatewayApiConfigGatewayConfigOutputReference_Override(g GoogleApiGatewayApiConfigGatewayConfigOutputReference, ...)
- func NewGoogleApiGatewayApiConfigGrpcServicesFileDescriptorSetOutputReference_Override(g GoogleApiGatewayApiConfigGrpcServicesFileDescriptorSetOutputReference, ...)
- func NewGoogleApiGatewayApiConfigGrpcServicesList_Override(g GoogleApiGatewayApiConfigGrpcServicesList, ...)
- func NewGoogleApiGatewayApiConfigGrpcServicesOutputReference_Override(g GoogleApiGatewayApiConfigGrpcServicesOutputReference, ...)
- func NewGoogleApiGatewayApiConfigGrpcServicesSourceList_Override(g GoogleApiGatewayApiConfigGrpcServicesSourceList, ...)
- func NewGoogleApiGatewayApiConfigGrpcServicesSourceOutputReference_Override(g GoogleApiGatewayApiConfigGrpcServicesSourceOutputReference, ...)
- func NewGoogleApiGatewayApiConfigManagedServiceConfigsList_Override(g GoogleApiGatewayApiConfigManagedServiceConfigsList, ...)
- func NewGoogleApiGatewayApiConfigManagedServiceConfigsOutputReference_Override(g GoogleApiGatewayApiConfigManagedServiceConfigsOutputReference, ...)
- func NewGoogleApiGatewayApiConfigOpenapiDocumentsDocumentOutputReference_Override(g GoogleApiGatewayApiConfigOpenapiDocumentsDocumentOutputReference, ...)
- func NewGoogleApiGatewayApiConfigOpenapiDocumentsList_Override(g GoogleApiGatewayApiConfigOpenapiDocumentsList, ...)
- func NewGoogleApiGatewayApiConfigOpenapiDocumentsOutputReference_Override(g GoogleApiGatewayApiConfigOpenapiDocumentsOutputReference, ...)
- func NewGoogleApiGatewayApiConfigTimeoutsOutputReference_Override(g GoogleApiGatewayApiConfigTimeoutsOutputReference, ...)
- type GoogleApiGatewayApiConfigA
- type GoogleApiGatewayApiConfigAConfig
- type GoogleApiGatewayApiConfigGatewayConfig
- type GoogleApiGatewayApiConfigGatewayConfigBackendConfig
- type GoogleApiGatewayApiConfigGatewayConfigBackendConfigOutputReference
- type GoogleApiGatewayApiConfigGatewayConfigOutputReference
- type GoogleApiGatewayApiConfigGrpcServices
- type GoogleApiGatewayApiConfigGrpcServicesFileDescriptorSet
- type GoogleApiGatewayApiConfigGrpcServicesFileDescriptorSetOutputReference
- type GoogleApiGatewayApiConfigGrpcServicesList
- type GoogleApiGatewayApiConfigGrpcServicesOutputReference
- type GoogleApiGatewayApiConfigGrpcServicesSource
- type GoogleApiGatewayApiConfigGrpcServicesSourceList
- type GoogleApiGatewayApiConfigGrpcServicesSourceOutputReference
- type GoogleApiGatewayApiConfigManagedServiceConfigs
- type GoogleApiGatewayApiConfigManagedServiceConfigsList
- type GoogleApiGatewayApiConfigManagedServiceConfigsOutputReference
- type GoogleApiGatewayApiConfigOpenapiDocuments
- type GoogleApiGatewayApiConfigOpenapiDocumentsDocument
- type GoogleApiGatewayApiConfigOpenapiDocumentsDocumentOutputReference
- type GoogleApiGatewayApiConfigOpenapiDocumentsList
- type GoogleApiGatewayApiConfigOpenapiDocumentsOutputReference
- type GoogleApiGatewayApiConfigTimeouts
- type GoogleApiGatewayApiConfigTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleApiGatewayApiConfigA_IsConstruct ¶
func GoogleApiGatewayApiConfigA_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleApiGatewayApiConfigA_IsTerraformElement ¶
func GoogleApiGatewayApiConfigA_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleApiGatewayApiConfigA_IsTerraformResource ¶
func GoogleApiGatewayApiConfigA_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleApiGatewayApiConfigA_TfResourceType ¶
func GoogleApiGatewayApiConfigA_TfResourceType() *string
func NewGoogleApiGatewayApiConfigA_Override ¶
func NewGoogleApiGatewayApiConfigA_Override(g GoogleApiGatewayApiConfigA, scope constructs.Construct, id *string, config *GoogleApiGatewayApiConfigAConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_api_gateway_api_config google_api_gateway_api_config} Resource.
func NewGoogleApiGatewayApiConfigGatewayConfigBackendConfigOutputReference_Override ¶
func NewGoogleApiGatewayApiConfigGatewayConfigBackendConfigOutputReference_Override(g GoogleApiGatewayApiConfigGatewayConfigBackendConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleApiGatewayApiConfigGatewayConfigOutputReference_Override ¶
func NewGoogleApiGatewayApiConfigGatewayConfigOutputReference_Override(g GoogleApiGatewayApiConfigGatewayConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleApiGatewayApiConfigGrpcServicesFileDescriptorSetOutputReference_Override ¶
func NewGoogleApiGatewayApiConfigGrpcServicesFileDescriptorSetOutputReference_Override(g GoogleApiGatewayApiConfigGrpcServicesFileDescriptorSetOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleApiGatewayApiConfigGrpcServicesList_Override ¶
func NewGoogleApiGatewayApiConfigGrpcServicesList_Override(g GoogleApiGatewayApiConfigGrpcServicesList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGoogleApiGatewayApiConfigGrpcServicesOutputReference_Override ¶
func NewGoogleApiGatewayApiConfigGrpcServicesOutputReference_Override(g GoogleApiGatewayApiConfigGrpcServicesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGoogleApiGatewayApiConfigGrpcServicesSourceList_Override ¶
func NewGoogleApiGatewayApiConfigGrpcServicesSourceList_Override(g GoogleApiGatewayApiConfigGrpcServicesSourceList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGoogleApiGatewayApiConfigGrpcServicesSourceOutputReference_Override ¶
func NewGoogleApiGatewayApiConfigGrpcServicesSourceOutputReference_Override(g GoogleApiGatewayApiConfigGrpcServicesSourceOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGoogleApiGatewayApiConfigManagedServiceConfigsList_Override ¶
func NewGoogleApiGatewayApiConfigManagedServiceConfigsList_Override(g GoogleApiGatewayApiConfigManagedServiceConfigsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGoogleApiGatewayApiConfigManagedServiceConfigsOutputReference_Override ¶
func NewGoogleApiGatewayApiConfigManagedServiceConfigsOutputReference_Override(g GoogleApiGatewayApiConfigManagedServiceConfigsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGoogleApiGatewayApiConfigOpenapiDocumentsDocumentOutputReference_Override ¶
func NewGoogleApiGatewayApiConfigOpenapiDocumentsDocumentOutputReference_Override(g GoogleApiGatewayApiConfigOpenapiDocumentsDocumentOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleApiGatewayApiConfigOpenapiDocumentsList_Override ¶
func NewGoogleApiGatewayApiConfigOpenapiDocumentsList_Override(g GoogleApiGatewayApiConfigOpenapiDocumentsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGoogleApiGatewayApiConfigOpenapiDocumentsOutputReference_Override ¶
func NewGoogleApiGatewayApiConfigOpenapiDocumentsOutputReference_Override(g GoogleApiGatewayApiConfigOpenapiDocumentsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGoogleApiGatewayApiConfigTimeoutsOutputReference_Override ¶
func NewGoogleApiGatewayApiConfigTimeoutsOutputReference_Override(g GoogleApiGatewayApiConfigTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
Types ¶
type GoogleApiGatewayApiConfigA ¶
type GoogleApiGatewayApiConfigA interface {
cdktf.TerraformResource
Api() *string
SetApi(val *string)
ApiConfigId() *string
SetApiConfigId(val *string)
ApiConfigIdInput() *string
ApiConfigIdPrefix() *string
SetApiConfigIdPrefix(val *string)
ApiConfigIdPrefixInput() *string
ApiInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DisplayName() *string
SetDisplayName(val *string)
DisplayNameInput() *string
EffectiveLabels() cdktf.StringMap
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
GatewayConfig() GoogleApiGatewayApiConfigGatewayConfigOutputReference
GatewayConfigInput() *GoogleApiGatewayApiConfigGatewayConfig
GrpcServices() GoogleApiGatewayApiConfigGrpcServicesList
GrpcServicesInput() interface{}
Id() *string
SetId(val *string)
IdInput() *string
Labels() *map[string]*string
SetLabels(val *map[string]*string)
LabelsInput() *map[string]*string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
ManagedServiceConfigs() GoogleApiGatewayApiConfigManagedServiceConfigsList
ManagedServiceConfigsInput() interface{}
Name() *string
// The tree node.
Node() constructs.Node
OpenapiDocuments() GoogleApiGatewayApiConfigOpenapiDocumentsList
OpenapiDocumentsInput() interface{}
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
ServiceConfigId() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
TerraformLabels() cdktf.StringMap
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GoogleApiGatewayApiConfigTimeoutsOutputReference
TimeoutsInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutGatewayConfig(value *GoogleApiGatewayApiConfigGatewayConfig)
PutGrpcServices(value interface{})
PutManagedServiceConfigs(value interface{})
PutOpenapiDocuments(value interface{})
PutTimeouts(value *GoogleApiGatewayApiConfigTimeouts)
ResetApiConfigId()
ResetApiConfigIdPrefix()
ResetDisplayName()
ResetGatewayConfig()
ResetGrpcServices()
ResetId()
ResetLabels()
ResetManagedServiceConfigs()
ResetOpenapiDocuments()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_api_gateway_api_config google_api_gateway_api_config}.
func NewGoogleApiGatewayApiConfigA ¶
func NewGoogleApiGatewayApiConfigA(scope constructs.Construct, id *string, config *GoogleApiGatewayApiConfigAConfig) GoogleApiGatewayApiConfigA
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_api_gateway_api_config google_api_gateway_api_config} Resource.
type GoogleApiGatewayApiConfigAConfig ¶
type GoogleApiGatewayApiConfigAConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// The API to attach the config to.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_api_gateway_api_config#api GoogleApiGatewayApiConfigA#api}
Api *string `field:"required" json:"api" yaml:"api"`
// Identifier to assign to the API Config. Must be unique within scope of the parent resource(api).
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_api_gateway_api_config#api_config_id GoogleApiGatewayApiConfigA#api_config_id}
ApiConfigId *string `field:"optional" json:"apiConfigId" yaml:"apiConfigId"`
// Creates a unique name beginning with the specified prefix.
//
// If this and api_config_id are unspecified, a random value is chosen for the name.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_api_gateway_api_config#api_config_id_prefix GoogleApiGatewayApiConfigA#api_config_id_prefix}
ApiConfigIdPrefix *string `field:"optional" json:"apiConfigIdPrefix" yaml:"apiConfigIdPrefix"`
// A user-visible name for the API.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_api_gateway_api_config#display_name GoogleApiGatewayApiConfigA#display_name}
DisplayName *string `field:"optional" json:"displayName" yaml:"displayName"`
// gateway_config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_api_gateway_api_config#gateway_config GoogleApiGatewayApiConfigA#gateway_config}
GatewayConfig *GoogleApiGatewayApiConfigGatewayConfig `field:"optional" json:"gatewayConfig" yaml:"gatewayConfig"`
// grpc_services block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_api_gateway_api_config#grpc_services GoogleApiGatewayApiConfigA#grpc_services}
GrpcServices interface{} `field:"optional" json:"grpcServices" yaml:"grpcServices"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_api_gateway_api_config#id GoogleApiGatewayApiConfigA#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Resource labels to represent user-provided metadata.
//
// **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
// Please refer to the field 'effective_labels' for all of the labels present on the resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_api_gateway_api_config#labels GoogleApiGatewayApiConfigA#labels}
Labels *map[string]*string `field:"optional" json:"labels" yaml:"labels"`
// managed_service_configs block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_api_gateway_api_config#managed_service_configs GoogleApiGatewayApiConfigA#managed_service_configs}
ManagedServiceConfigs interface{} `field:"optional" json:"managedServiceConfigs" yaml:"managedServiceConfigs"`
// openapi_documents block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_api_gateway_api_config#openapi_documents GoogleApiGatewayApiConfigA#openapi_documents}
OpenapiDocuments interface{} `field:"optional" json:"openapiDocuments" yaml:"openapiDocuments"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_api_gateway_api_config#project GoogleApiGatewayApiConfigA#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_api_gateway_api_config#timeouts GoogleApiGatewayApiConfigA#timeouts}
Timeouts *GoogleApiGatewayApiConfigTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type GoogleApiGatewayApiConfigGatewayConfig ¶
type GoogleApiGatewayApiConfigGatewayConfig struct {
// backend_config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_api_gateway_api_config#backend_config GoogleApiGatewayApiConfigA#backend_config}
BackendConfig *GoogleApiGatewayApiConfigGatewayConfigBackendConfig `field:"required" json:"backendConfig" yaml:"backendConfig"`
}
type GoogleApiGatewayApiConfigGatewayConfigBackendConfig ¶
type GoogleApiGatewayApiConfigGatewayConfigBackendConfig struct {
// Google Cloud IAM service account used to sign OIDC tokens for backends that have authentication configured (https://cloud.google.com/service-infrastructure/docs/service-management/reference/rest/v1/services.configs#backend).
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_api_gateway_api_config#google_service_account GoogleApiGatewayApiConfigA#google_service_account}
GoogleServiceAccount *string `field:"required" json:"googleServiceAccount" yaml:"googleServiceAccount"`
}
type GoogleApiGatewayApiConfigGatewayConfigBackendConfigOutputReference ¶
type GoogleApiGatewayApiConfigGatewayConfigBackendConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
GoogleServiceAccount() *string
SetGoogleServiceAccount(val *string)
GoogleServiceAccountInput() *string
InternalValue() *GoogleApiGatewayApiConfigGatewayConfigBackendConfig
SetInternalValue(val *GoogleApiGatewayApiConfigGatewayConfigBackendConfig)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleApiGatewayApiConfigGatewayConfigBackendConfigOutputReference ¶
func NewGoogleApiGatewayApiConfigGatewayConfigBackendConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleApiGatewayApiConfigGatewayConfigBackendConfigOutputReference
type GoogleApiGatewayApiConfigGatewayConfigOutputReference ¶
type GoogleApiGatewayApiConfigGatewayConfigOutputReference interface {
cdktf.ComplexObject
BackendConfig() GoogleApiGatewayApiConfigGatewayConfigBackendConfigOutputReference
BackendConfigInput() *GoogleApiGatewayApiConfigGatewayConfigBackendConfig
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleApiGatewayApiConfigGatewayConfig
SetInternalValue(val *GoogleApiGatewayApiConfigGatewayConfig)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutBackendConfig(value *GoogleApiGatewayApiConfigGatewayConfigBackendConfig)
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleApiGatewayApiConfigGatewayConfigOutputReference ¶
func NewGoogleApiGatewayApiConfigGatewayConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleApiGatewayApiConfigGatewayConfigOutputReference
type GoogleApiGatewayApiConfigGrpcServices ¶
type GoogleApiGatewayApiConfigGrpcServices struct {
// file_descriptor_set block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_api_gateway_api_config#file_descriptor_set GoogleApiGatewayApiConfigA#file_descriptor_set}
FileDescriptorSet *GoogleApiGatewayApiConfigGrpcServicesFileDescriptorSet `field:"required" json:"fileDescriptorSet" yaml:"fileDescriptorSet"`
// source block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_api_gateway_api_config#source GoogleApiGatewayApiConfigA#source}
Source interface{} `field:"optional" json:"source" yaml:"source"`
}
type GoogleApiGatewayApiConfigGrpcServicesFileDescriptorSet ¶
type GoogleApiGatewayApiConfigGrpcServicesFileDescriptorSet struct {
// Base64 encoded content of the file.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_api_gateway_api_config#contents GoogleApiGatewayApiConfigA#contents}
Contents *string `field:"required" json:"contents" yaml:"contents"`
// The file path (full or relative path). This is typically the path of the file when it is uploaded.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_api_gateway_api_config#path GoogleApiGatewayApiConfigA#path}
Path *string `field:"required" json:"path" yaml:"path"`
}
type GoogleApiGatewayApiConfigGrpcServicesFileDescriptorSetOutputReference ¶
type GoogleApiGatewayApiConfigGrpcServicesFileDescriptorSetOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Contents() *string
SetContents(val *string)
ContentsInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleApiGatewayApiConfigGrpcServicesFileDescriptorSet
SetInternalValue(val *GoogleApiGatewayApiConfigGrpcServicesFileDescriptorSet)
Path() *string
SetPath(val *string)
PathInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleApiGatewayApiConfigGrpcServicesFileDescriptorSetOutputReference ¶
func NewGoogleApiGatewayApiConfigGrpcServicesFileDescriptorSetOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleApiGatewayApiConfigGrpcServicesFileDescriptorSetOutputReference
type GoogleApiGatewayApiConfigGrpcServicesList ¶
type GoogleApiGatewayApiConfigGrpcServicesList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) GoogleApiGatewayApiConfigGrpcServicesOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleApiGatewayApiConfigGrpcServicesList ¶
func NewGoogleApiGatewayApiConfigGrpcServicesList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GoogleApiGatewayApiConfigGrpcServicesList
type GoogleApiGatewayApiConfigGrpcServicesOutputReference ¶
type GoogleApiGatewayApiConfigGrpcServicesOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
FileDescriptorSet() GoogleApiGatewayApiConfigGrpcServicesFileDescriptorSetOutputReference
FileDescriptorSetInput() *GoogleApiGatewayApiConfigGrpcServicesFileDescriptorSet
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Source() GoogleApiGatewayApiConfigGrpcServicesSourceList
SourceInput() interface{}
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutFileDescriptorSet(value *GoogleApiGatewayApiConfigGrpcServicesFileDescriptorSet)
PutSource(value interface{})
ResetSource()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleApiGatewayApiConfigGrpcServicesOutputReference ¶
func NewGoogleApiGatewayApiConfigGrpcServicesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GoogleApiGatewayApiConfigGrpcServicesOutputReference
type GoogleApiGatewayApiConfigGrpcServicesSource ¶
type GoogleApiGatewayApiConfigGrpcServicesSource struct {
// Base64 encoded content of the file.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_api_gateway_api_config#contents GoogleApiGatewayApiConfigA#contents}
Contents *string `field:"required" json:"contents" yaml:"contents"`
// The file path (full or relative path). This is typically the path of the file when it is uploaded.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_api_gateway_api_config#path GoogleApiGatewayApiConfigA#path}
Path *string `field:"required" json:"path" yaml:"path"`
}
type GoogleApiGatewayApiConfigGrpcServicesSourceList ¶
type GoogleApiGatewayApiConfigGrpcServicesSourceList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) GoogleApiGatewayApiConfigGrpcServicesSourceOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleApiGatewayApiConfigGrpcServicesSourceList ¶
func NewGoogleApiGatewayApiConfigGrpcServicesSourceList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GoogleApiGatewayApiConfigGrpcServicesSourceList
type GoogleApiGatewayApiConfigGrpcServicesSourceOutputReference ¶
type GoogleApiGatewayApiConfigGrpcServicesSourceOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Contents() *string
SetContents(val *string)
ContentsInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Path() *string
SetPath(val *string)
PathInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleApiGatewayApiConfigGrpcServicesSourceOutputReference ¶
func NewGoogleApiGatewayApiConfigGrpcServicesSourceOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GoogleApiGatewayApiConfigGrpcServicesSourceOutputReference
type GoogleApiGatewayApiConfigManagedServiceConfigs ¶
type GoogleApiGatewayApiConfigManagedServiceConfigs struct {
// Base64 encoded content of the file.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_api_gateway_api_config#contents GoogleApiGatewayApiConfigA#contents}
Contents *string `field:"required" json:"contents" yaml:"contents"`
// The file path (full or relative path). This is typically the path of the file when it is uploaded.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_api_gateway_api_config#path GoogleApiGatewayApiConfigA#path}
Path *string `field:"required" json:"path" yaml:"path"`
}
type GoogleApiGatewayApiConfigManagedServiceConfigsList ¶
type GoogleApiGatewayApiConfigManagedServiceConfigsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) GoogleApiGatewayApiConfigManagedServiceConfigsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleApiGatewayApiConfigManagedServiceConfigsList ¶
func NewGoogleApiGatewayApiConfigManagedServiceConfigsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GoogleApiGatewayApiConfigManagedServiceConfigsList
type GoogleApiGatewayApiConfigManagedServiceConfigsOutputReference ¶
type GoogleApiGatewayApiConfigManagedServiceConfigsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Contents() *string
SetContents(val *string)
ContentsInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Path() *string
SetPath(val *string)
PathInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleApiGatewayApiConfigManagedServiceConfigsOutputReference ¶
func NewGoogleApiGatewayApiConfigManagedServiceConfigsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GoogleApiGatewayApiConfigManagedServiceConfigsOutputReference
type GoogleApiGatewayApiConfigOpenapiDocuments ¶
type GoogleApiGatewayApiConfigOpenapiDocuments struct {
// document block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_api_gateway_api_config#document GoogleApiGatewayApiConfigA#document}
Document *GoogleApiGatewayApiConfigOpenapiDocumentsDocument `field:"required" json:"document" yaml:"document"`
}
type GoogleApiGatewayApiConfigOpenapiDocumentsDocument ¶
type GoogleApiGatewayApiConfigOpenapiDocumentsDocument struct {
// Base64 encoded content of the file.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_api_gateway_api_config#contents GoogleApiGatewayApiConfigA#contents}
Contents *string `field:"required" json:"contents" yaml:"contents"`
// The file path (full or relative path). This is typically the path of the file when it is uploaded.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_api_gateway_api_config#path GoogleApiGatewayApiConfigA#path}
Path *string `field:"required" json:"path" yaml:"path"`
}
type GoogleApiGatewayApiConfigOpenapiDocumentsDocumentOutputReference ¶
type GoogleApiGatewayApiConfigOpenapiDocumentsDocumentOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Contents() *string
SetContents(val *string)
ContentsInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleApiGatewayApiConfigOpenapiDocumentsDocument
SetInternalValue(val *GoogleApiGatewayApiConfigOpenapiDocumentsDocument)
Path() *string
SetPath(val *string)
PathInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleApiGatewayApiConfigOpenapiDocumentsDocumentOutputReference ¶
func NewGoogleApiGatewayApiConfigOpenapiDocumentsDocumentOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleApiGatewayApiConfigOpenapiDocumentsDocumentOutputReference
type GoogleApiGatewayApiConfigOpenapiDocumentsList ¶
type GoogleApiGatewayApiConfigOpenapiDocumentsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) GoogleApiGatewayApiConfigOpenapiDocumentsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleApiGatewayApiConfigOpenapiDocumentsList ¶
func NewGoogleApiGatewayApiConfigOpenapiDocumentsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GoogleApiGatewayApiConfigOpenapiDocumentsList
type GoogleApiGatewayApiConfigOpenapiDocumentsOutputReference ¶
type GoogleApiGatewayApiConfigOpenapiDocumentsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Document() GoogleApiGatewayApiConfigOpenapiDocumentsDocumentOutputReference
DocumentInput() *GoogleApiGatewayApiConfigOpenapiDocumentsDocument
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutDocument(value *GoogleApiGatewayApiConfigOpenapiDocumentsDocument)
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleApiGatewayApiConfigOpenapiDocumentsOutputReference ¶
func NewGoogleApiGatewayApiConfigOpenapiDocumentsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GoogleApiGatewayApiConfigOpenapiDocumentsOutputReference
type GoogleApiGatewayApiConfigTimeouts ¶
type GoogleApiGatewayApiConfigTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_api_gateway_api_config#create GoogleApiGatewayApiConfigA#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_api_gateway_api_config#delete GoogleApiGatewayApiConfigA#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_api_gateway_api_config#update GoogleApiGatewayApiConfigA#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type GoogleApiGatewayApiConfigTimeoutsOutputReference ¶
type GoogleApiGatewayApiConfigTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleApiGatewayApiConfigTimeoutsOutputReference ¶
func NewGoogleApiGatewayApiConfigTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleApiGatewayApiConfigTimeoutsOutputReference
Source Files
¶
- GoogleApiGatewayApiConfigA.go
- GoogleApiGatewayApiConfigAConfig.go
- GoogleApiGatewayApiConfigA__checks.go
- GoogleApiGatewayApiConfigGatewayConfig.go
- GoogleApiGatewayApiConfigGatewayConfigBackendConfig.go
- GoogleApiGatewayApiConfigGatewayConfigBackendConfigOutputReference.go
- GoogleApiGatewayApiConfigGatewayConfigBackendConfigOutputReference__checks.go
- GoogleApiGatewayApiConfigGatewayConfigOutputReference.go
- GoogleApiGatewayApiConfigGatewayConfigOutputReference__checks.go
- GoogleApiGatewayApiConfigGrpcServices.go
- GoogleApiGatewayApiConfigGrpcServicesFileDescriptorSet.go
- GoogleApiGatewayApiConfigGrpcServicesFileDescriptorSetOutputReference.go
- GoogleApiGatewayApiConfigGrpcServicesFileDescriptorSetOutputReference__checks.go
- GoogleApiGatewayApiConfigGrpcServicesList.go
- GoogleApiGatewayApiConfigGrpcServicesList__checks.go
- GoogleApiGatewayApiConfigGrpcServicesOutputReference.go
- GoogleApiGatewayApiConfigGrpcServicesOutputReference__checks.go
- GoogleApiGatewayApiConfigGrpcServicesSource.go
- GoogleApiGatewayApiConfigGrpcServicesSourceList.go
- GoogleApiGatewayApiConfigGrpcServicesSourceList__checks.go
- GoogleApiGatewayApiConfigGrpcServicesSourceOutputReference.go
- GoogleApiGatewayApiConfigGrpcServicesSourceOutputReference__checks.go
- GoogleApiGatewayApiConfigManagedServiceConfigs.go
- GoogleApiGatewayApiConfigManagedServiceConfigsList.go
- GoogleApiGatewayApiConfigManagedServiceConfigsList__checks.go
- GoogleApiGatewayApiConfigManagedServiceConfigsOutputReference.go
- GoogleApiGatewayApiConfigManagedServiceConfigsOutputReference__checks.go
- GoogleApiGatewayApiConfigOpenapiDocuments.go
- GoogleApiGatewayApiConfigOpenapiDocumentsDocument.go
- GoogleApiGatewayApiConfigOpenapiDocumentsDocumentOutputReference.go
- GoogleApiGatewayApiConfigOpenapiDocumentsDocumentOutputReference__checks.go
- GoogleApiGatewayApiConfigOpenapiDocumentsList.go
- GoogleApiGatewayApiConfigOpenapiDocumentsList__checks.go
- GoogleApiGatewayApiConfigOpenapiDocumentsOutputReference.go
- GoogleApiGatewayApiConfigOpenapiDocumentsOutputReference__checks.go
- GoogleApiGatewayApiConfigTimeouts.go
- GoogleApiGatewayApiConfigTimeoutsOutputReference.go
- GoogleApiGatewayApiConfigTimeoutsOutputReference__checks.go
- main.go