Documentation
¶
Index ¶
- func GoogleAppEngineApplication_IsConstruct(x interface{}) *bool
- func GoogleAppEngineApplication_IsTerraformElement(x interface{}) *bool
- func GoogleAppEngineApplication_IsTerraformResource(x interface{}) *bool
- func GoogleAppEngineApplication_TfResourceType() *string
- func NewGoogleAppEngineApplicationFeatureSettingsOutputReference_Override(g GoogleAppEngineApplicationFeatureSettingsOutputReference, ...)
- func NewGoogleAppEngineApplicationIapOutputReference_Override(g GoogleAppEngineApplicationIapOutputReference, ...)
- func NewGoogleAppEngineApplicationTimeoutsOutputReference_Override(g GoogleAppEngineApplicationTimeoutsOutputReference, ...)
- func NewGoogleAppEngineApplicationUrlDispatchRuleList_Override(g GoogleAppEngineApplicationUrlDispatchRuleList, ...)
- func NewGoogleAppEngineApplicationUrlDispatchRuleOutputReference_Override(g GoogleAppEngineApplicationUrlDispatchRuleOutputReference, ...)
- func NewGoogleAppEngineApplication_Override(g GoogleAppEngineApplication, scope constructs.Construct, id *string, ...)
- type GoogleAppEngineApplication
- type GoogleAppEngineApplicationConfig
- type GoogleAppEngineApplicationFeatureSettings
- type GoogleAppEngineApplicationFeatureSettingsOutputReference
- type GoogleAppEngineApplicationIap
- type GoogleAppEngineApplicationIapOutputReference
- type GoogleAppEngineApplicationTimeouts
- type GoogleAppEngineApplicationTimeoutsOutputReference
- type GoogleAppEngineApplicationUrlDispatchRule
- type GoogleAppEngineApplicationUrlDispatchRuleList
- type GoogleAppEngineApplicationUrlDispatchRuleOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleAppEngineApplication_IsConstruct ¶
func GoogleAppEngineApplication_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleAppEngineApplication_IsTerraformElement ¶
func GoogleAppEngineApplication_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleAppEngineApplication_IsTerraformResource ¶
func GoogleAppEngineApplication_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleAppEngineApplication_TfResourceType ¶
func GoogleAppEngineApplication_TfResourceType() *string
func NewGoogleAppEngineApplicationFeatureSettingsOutputReference_Override ¶
func NewGoogleAppEngineApplicationFeatureSettingsOutputReference_Override(g GoogleAppEngineApplicationFeatureSettingsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleAppEngineApplicationIapOutputReference_Override ¶
func NewGoogleAppEngineApplicationIapOutputReference_Override(g GoogleAppEngineApplicationIapOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleAppEngineApplicationTimeoutsOutputReference_Override ¶
func NewGoogleAppEngineApplicationTimeoutsOutputReference_Override(g GoogleAppEngineApplicationTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleAppEngineApplicationUrlDispatchRuleList_Override ¶
func NewGoogleAppEngineApplicationUrlDispatchRuleList_Override(g GoogleAppEngineApplicationUrlDispatchRuleList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGoogleAppEngineApplicationUrlDispatchRuleOutputReference_Override ¶
func NewGoogleAppEngineApplicationUrlDispatchRuleOutputReference_Override(g GoogleAppEngineApplicationUrlDispatchRuleOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGoogleAppEngineApplication_Override ¶
func NewGoogleAppEngineApplication_Override(g GoogleAppEngineApplication, scope constructs.Construct, id *string, config *GoogleAppEngineApplicationConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_app_engine_application google_app_engine_application} Resource.
Types ¶
type GoogleAppEngineApplication ¶
type GoogleAppEngineApplication interface {
cdktf.TerraformResource
AppId() *string
AuthDomain() *string
SetAuthDomain(val *string)
AuthDomainInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
CodeBucket() *string
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
DatabaseType() *string
SetDatabaseType(val *string)
DatabaseTypeInput() *string
DefaultBucket() *string
DefaultHostname() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
FeatureSettings() GoogleAppEngineApplicationFeatureSettingsOutputReference
FeatureSettingsInput() *GoogleAppEngineApplicationFeatureSettings
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
GcrDomain() *string
Iap() GoogleAppEngineApplicationIapOutputReference
IapInput() *GoogleAppEngineApplicationIap
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
LocationId() *string
SetLocationId(val *string)
LocationIdInput() *string
Name() *string
// The tree node.
Node() constructs.Node
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
ServingStatus() *string
SetServingStatus(val *string)
ServingStatusInput() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GoogleAppEngineApplicationTimeoutsOutputReference
TimeoutsInput() interface{}
UrlDispatchRule() GoogleAppEngineApplicationUrlDispatchRuleList
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutFeatureSettings(value *GoogleAppEngineApplicationFeatureSettings)
PutIap(value *GoogleAppEngineApplicationIap)
PutTimeouts(value *GoogleAppEngineApplicationTimeouts)
ResetAuthDomain()
ResetDatabaseType()
ResetFeatureSettings()
ResetIap()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
ResetServingStatus()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_app_engine_application google_app_engine_application}.
func NewGoogleAppEngineApplication ¶
func NewGoogleAppEngineApplication(scope constructs.Construct, id *string, config *GoogleAppEngineApplicationConfig) GoogleAppEngineApplication
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_app_engine_application google_app_engine_application} Resource.
type GoogleAppEngineApplicationConfig ¶
type GoogleAppEngineApplicationConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// The location to serve the app from.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_app_engine_application#location_id GoogleAppEngineApplication#location_id}
LocationId *string `field:"required" json:"locationId" yaml:"locationId"`
// The domain to authenticate users with when using App Engine's User API.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_app_engine_application#auth_domain GoogleAppEngineApplication#auth_domain}
AuthDomain *string `field:"optional" json:"authDomain" yaml:"authDomain"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_app_engine_application#database_type GoogleAppEngineApplication#database_type}.
DatabaseType *string `field:"optional" json:"databaseType" yaml:"databaseType"`
// feature_settings block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_app_engine_application#feature_settings GoogleAppEngineApplication#feature_settings}
FeatureSettings *GoogleAppEngineApplicationFeatureSettings `field:"optional" json:"featureSettings" yaml:"featureSettings"`
// iap block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_app_engine_application#iap GoogleAppEngineApplication#iap}
Iap *GoogleAppEngineApplicationIap `field:"optional" json:"iap" yaml:"iap"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_app_engine_application#id GoogleAppEngineApplication#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// The project ID to create the application under.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_app_engine_application#project GoogleAppEngineApplication#project}
Project *string `field:"optional" json:"project" yaml:"project"`
// The serving status of the app.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_app_engine_application#serving_status GoogleAppEngineApplication#serving_status}
ServingStatus *string `field:"optional" json:"servingStatus" yaml:"servingStatus"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_app_engine_application#timeouts GoogleAppEngineApplication#timeouts}
Timeouts *GoogleAppEngineApplicationTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type GoogleAppEngineApplicationFeatureSettings ¶
type GoogleAppEngineApplicationFeatureSettings struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_app_engine_application#split_health_checks GoogleAppEngineApplication#split_health_checks}.
SplitHealthChecks interface{} `field:"required" json:"splitHealthChecks" yaml:"splitHealthChecks"`
}
type GoogleAppEngineApplicationFeatureSettingsOutputReference ¶
type GoogleAppEngineApplicationFeatureSettingsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleAppEngineApplicationFeatureSettings
SetInternalValue(val *GoogleAppEngineApplicationFeatureSettings)
SplitHealthChecks() interface{}
SetSplitHealthChecks(val interface{})
SplitHealthChecksInput() interface{}
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleAppEngineApplicationFeatureSettingsOutputReference ¶
func NewGoogleAppEngineApplicationFeatureSettingsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleAppEngineApplicationFeatureSettingsOutputReference
type GoogleAppEngineApplicationIap ¶
type GoogleAppEngineApplicationIap struct {
// OAuth2 client ID to use for the authentication flow.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_app_engine_application#oauth2_client_id GoogleAppEngineApplication#oauth2_client_id}
Oauth2ClientId *string `field:"required" json:"oauth2ClientId" yaml:"oauth2ClientId"`
// OAuth2 client secret to use for the authentication flow.
//
// The SHA-256 hash of the value is returned in the oauth2ClientSecretSha256 field.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_app_engine_application#oauth2_client_secret GoogleAppEngineApplication#oauth2_client_secret}
Oauth2ClientSecret *string `field:"required" json:"oauth2ClientSecret" yaml:"oauth2ClientSecret"`
// Adapted for use with the app.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_app_engine_application#enabled GoogleAppEngineApplication#enabled}
Enabled interface{} `field:"optional" json:"enabled" yaml:"enabled"`
}
type GoogleAppEngineApplicationIapOutputReference ¶
type GoogleAppEngineApplicationIapOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Enabled() interface{}
SetEnabled(val interface{})
EnabledInput() interface{}
// Experimental.
Fqn() *string
InternalValue() *GoogleAppEngineApplicationIap
SetInternalValue(val *GoogleAppEngineApplicationIap)
Oauth2ClientId() *string
SetOauth2ClientId(val *string)
Oauth2ClientIdInput() *string
Oauth2ClientSecret() *string
SetOauth2ClientSecret(val *string)
Oauth2ClientSecretInput() *string
Oauth2ClientSecretSha256() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetEnabled()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleAppEngineApplicationIapOutputReference ¶
func NewGoogleAppEngineApplicationIapOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleAppEngineApplicationIapOutputReference
type GoogleAppEngineApplicationTimeouts ¶
type GoogleAppEngineApplicationTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_app_engine_application#create GoogleAppEngineApplication#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_app_engine_application#update GoogleAppEngineApplication#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type GoogleAppEngineApplicationTimeoutsOutputReference ¶
type GoogleAppEngineApplicationTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleAppEngineApplicationTimeoutsOutputReference ¶
func NewGoogleAppEngineApplicationTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleAppEngineApplicationTimeoutsOutputReference
type GoogleAppEngineApplicationUrlDispatchRule ¶
type GoogleAppEngineApplicationUrlDispatchRule struct {
}
type GoogleAppEngineApplicationUrlDispatchRuleList ¶
type GoogleAppEngineApplicationUrlDispatchRuleList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) GoogleAppEngineApplicationUrlDispatchRuleOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleAppEngineApplicationUrlDispatchRuleList ¶
func NewGoogleAppEngineApplicationUrlDispatchRuleList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GoogleAppEngineApplicationUrlDispatchRuleList
type GoogleAppEngineApplicationUrlDispatchRuleOutputReference ¶
type GoogleAppEngineApplicationUrlDispatchRuleOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Domain() *string
// Experimental.
Fqn() *string
InternalValue() *GoogleAppEngineApplicationUrlDispatchRule
SetInternalValue(val *GoogleAppEngineApplicationUrlDispatchRule)
Path() *string
Service() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleAppEngineApplicationUrlDispatchRuleOutputReference ¶
func NewGoogleAppEngineApplicationUrlDispatchRuleOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GoogleAppEngineApplicationUrlDispatchRuleOutputReference
Source Files
¶
- GoogleAppEngineApplication.go
- GoogleAppEngineApplicationConfig.go
- GoogleAppEngineApplicationFeatureSettings.go
- GoogleAppEngineApplicationFeatureSettingsOutputReference.go
- GoogleAppEngineApplicationFeatureSettingsOutputReference__checks.go
- GoogleAppEngineApplicationIap.go
- GoogleAppEngineApplicationIapOutputReference.go
- GoogleAppEngineApplicationIapOutputReference__checks.go
- GoogleAppEngineApplicationTimeouts.go
- GoogleAppEngineApplicationTimeoutsOutputReference.go
- GoogleAppEngineApplicationTimeoutsOutputReference__checks.go
- GoogleAppEngineApplicationUrlDispatchRule.go
- GoogleAppEngineApplicationUrlDispatchRuleList.go
- GoogleAppEngineApplicationUrlDispatchRuleList__checks.go
- GoogleAppEngineApplicationUrlDispatchRuleOutputReference.go
- GoogleAppEngineApplicationUrlDispatchRuleOutputReference__checks.go
- GoogleAppEngineApplication__checks.go
- main.go