Documentation
¶
Index ¶
- func GoogleBigqueryRoutine_IsConstruct(x interface{}) *bool
- func GoogleBigqueryRoutine_IsTerraformElement(x interface{}) *bool
- func GoogleBigqueryRoutine_IsTerraformResource(x interface{}) *bool
- func GoogleBigqueryRoutine_TfResourceType() *string
- func NewGoogleBigqueryRoutineArgumentsList_Override(g GoogleBigqueryRoutineArgumentsList, ...)
- func NewGoogleBigqueryRoutineArgumentsOutputReference_Override(g GoogleBigqueryRoutineArgumentsOutputReference, ...)
- func NewGoogleBigqueryRoutineTimeoutsOutputReference_Override(g GoogleBigqueryRoutineTimeoutsOutputReference, ...)
- func NewGoogleBigqueryRoutine_Override(g GoogleBigqueryRoutine, scope constructs.Construct, id *string, ...)
- type GoogleBigqueryRoutine
- type GoogleBigqueryRoutineArguments
- type GoogleBigqueryRoutineArgumentsList
- type GoogleBigqueryRoutineArgumentsOutputReference
- type GoogleBigqueryRoutineConfig
- type GoogleBigqueryRoutineTimeouts
- type GoogleBigqueryRoutineTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleBigqueryRoutine_IsConstruct ¶
func GoogleBigqueryRoutine_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleBigqueryRoutine_IsTerraformElement ¶
func GoogleBigqueryRoutine_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleBigqueryRoutine_IsTerraformResource ¶
func GoogleBigqueryRoutine_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleBigqueryRoutine_TfResourceType ¶
func GoogleBigqueryRoutine_TfResourceType() *string
func NewGoogleBigqueryRoutineArgumentsList_Override ¶
func NewGoogleBigqueryRoutineArgumentsList_Override(g GoogleBigqueryRoutineArgumentsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGoogleBigqueryRoutineArgumentsOutputReference_Override ¶
func NewGoogleBigqueryRoutineArgumentsOutputReference_Override(g GoogleBigqueryRoutineArgumentsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGoogleBigqueryRoutineTimeoutsOutputReference_Override ¶
func NewGoogleBigqueryRoutineTimeoutsOutputReference_Override(g GoogleBigqueryRoutineTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleBigqueryRoutine_Override ¶
func NewGoogleBigqueryRoutine_Override(g GoogleBigqueryRoutine, scope constructs.Construct, id *string, config *GoogleBigqueryRoutineConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_bigquery_routine google_bigquery_routine} Resource.
Types ¶
type GoogleBigqueryRoutine ¶
type GoogleBigqueryRoutine interface {
cdktf.TerraformResource
Arguments() GoogleBigqueryRoutineArgumentsList
ArgumentsInput() interface{}
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
CreationTime() *float64
DatasetId() *string
SetDatasetId(val *string)
DatasetIdInput() *string
DefinitionBody() *string
SetDefinitionBody(val *string)
DefinitionBodyInput() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
DeterminismLevel() *string
SetDeterminismLevel(val *string)
DeterminismLevelInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
ImportedLibraries() *[]*string
SetImportedLibraries(val *[]*string)
ImportedLibrariesInput() *[]*string
Language() *string
SetLanguage(val *string)
LanguageInput() *string
LastModifiedTime() *float64
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
ReturnTableType() *string
SetReturnTableType(val *string)
ReturnTableTypeInput() *string
ReturnType() *string
SetReturnType(val *string)
ReturnTypeInput() *string
RoutineId() *string
SetRoutineId(val *string)
RoutineIdInput() *string
RoutineType() *string
SetRoutineType(val *string)
RoutineTypeInput() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GoogleBigqueryRoutineTimeoutsOutputReference
TimeoutsInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutArguments(value interface{})
PutTimeouts(value *GoogleBigqueryRoutineTimeouts)
ResetArguments()
ResetDescription()
ResetDeterminismLevel()
ResetId()
ResetImportedLibraries()
ResetLanguage()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
ResetReturnTableType()
ResetReturnType()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_bigquery_routine google_bigquery_routine}.
func NewGoogleBigqueryRoutine ¶
func NewGoogleBigqueryRoutine(scope constructs.Construct, id *string, config *GoogleBigqueryRoutineConfig) GoogleBigqueryRoutine
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_bigquery_routine google_bigquery_routine} Resource.
type GoogleBigqueryRoutineArguments ¶
type GoogleBigqueryRoutineArguments struct {
// Defaults to FIXED_TYPE. Default value: "FIXED_TYPE" Possible values: ["FIXED_TYPE", "ANY_TYPE"].
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_bigquery_routine#argument_kind GoogleBigqueryRoutine#argument_kind}
ArgumentKind *string `field:"optional" json:"argumentKind" yaml:"argumentKind"`
// A JSON schema for the data type.
//
// Required unless argumentKind = ANY_TYPE.
// ~>**NOTE**: Because this field expects a JSON string, any changes to the string
// will create a diff, even if the JSON itself hasn't changed. If the API returns
// a different value for the same schema, e.g. it switched the order of values
// or replaced STRUCT field type with RECORD field type, we currently cannot
// suppress the recurring diff this causes. As a workaround, we recommend using
// the schema as returned by the API.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_bigquery_routine#data_type GoogleBigqueryRoutine#data_type}
DataType *string `field:"optional" json:"dataType" yaml:"dataType"`
// Specifies whether the argument is input or output. Can be set for procedures only. Possible values: ["IN", "OUT", "INOUT"].
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_bigquery_routine#mode GoogleBigqueryRoutine#mode}
Mode *string `field:"optional" json:"mode" yaml:"mode"`
// The name of this argument. Can be absent for function return argument.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_bigquery_routine#name GoogleBigqueryRoutine#name}
Name *string `field:"optional" json:"name" yaml:"name"`
}
type GoogleBigqueryRoutineArgumentsList ¶
type GoogleBigqueryRoutineArgumentsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) GoogleBigqueryRoutineArgumentsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleBigqueryRoutineArgumentsList ¶
func NewGoogleBigqueryRoutineArgumentsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GoogleBigqueryRoutineArgumentsList
type GoogleBigqueryRoutineArgumentsOutputReference ¶
type GoogleBigqueryRoutineArgumentsOutputReference interface {
cdktf.ComplexObject
ArgumentKind() *string
SetArgumentKind(val *string)
ArgumentKindInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DataType() *string
SetDataType(val *string)
DataTypeInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Mode() *string
SetMode(val *string)
ModeInput() *string
Name() *string
SetName(val *string)
NameInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetArgumentKind()
ResetDataType()
ResetMode()
ResetName()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleBigqueryRoutineArgumentsOutputReference ¶
func NewGoogleBigqueryRoutineArgumentsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GoogleBigqueryRoutineArgumentsOutputReference
type GoogleBigqueryRoutineConfig ¶
type GoogleBigqueryRoutineConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// The ID of the dataset containing this routine.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_bigquery_routine#dataset_id GoogleBigqueryRoutine#dataset_id}
DatasetId *string `field:"required" json:"datasetId" yaml:"datasetId"`
// The body of the routine.
//
// For functions, this is the expression in the AS clause.
// If language=SQL, it is the substring inside (but excluding) the parentheses.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_bigquery_routine#definition_body GoogleBigqueryRoutine#definition_body}
DefinitionBody *string `field:"required" json:"definitionBody" yaml:"definitionBody"`
// The ID of the the routine.
//
// The ID must contain only letters (a-z, A-Z), numbers (0-9), or underscores (_). The maximum length is 256 characters.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_bigquery_routine#routine_id GoogleBigqueryRoutine#routine_id}
RoutineId *string `field:"required" json:"routineId" yaml:"routineId"`
// The type of routine. Possible values: ["SCALAR_FUNCTION", "PROCEDURE", "TABLE_VALUED_FUNCTION"].
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_bigquery_routine#routine_type GoogleBigqueryRoutine#routine_type}
RoutineType *string `field:"required" json:"routineType" yaml:"routineType"`
// arguments block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_bigquery_routine#arguments GoogleBigqueryRoutine#arguments}
Arguments interface{} `field:"optional" json:"arguments" yaml:"arguments"`
// The description of the routine if defined.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_bigquery_routine#description GoogleBigqueryRoutine#description}
Description *string `field:"optional" json:"description" yaml:"description"`
// The determinism level of the JavaScript UDF if defined. Possible values: ["DETERMINISM_LEVEL_UNSPECIFIED", "DETERMINISTIC", "NOT_DETERMINISTIC"].
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_bigquery_routine#determinism_level GoogleBigqueryRoutine#determinism_level}
DeterminismLevel *string `field:"optional" json:"determinismLevel" yaml:"determinismLevel"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_bigquery_routine#id GoogleBigqueryRoutine#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Optional. If language = "JAVASCRIPT", this field stores the path of the imported JAVASCRIPT libraries.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_bigquery_routine#imported_libraries GoogleBigqueryRoutine#imported_libraries}
ImportedLibraries *[]*string `field:"optional" json:"importedLibraries" yaml:"importedLibraries"`
// The language of the routine. Possible values: ["SQL", "JAVASCRIPT"].
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_bigquery_routine#language GoogleBigqueryRoutine#language}
Language *string `field:"optional" json:"language" yaml:"language"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_bigquery_routine#project GoogleBigqueryRoutine#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// Optional. Can be set only if routineType = "TABLE_VALUED_FUNCTION".
//
// If absent, the return table type is inferred from definitionBody at query time in each query
// that references this routine. If present, then the columns in the evaluated table result will
// be cast to match the column types specificed in return table type, at query time.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_bigquery_routine#return_table_type GoogleBigqueryRoutine#return_table_type}
ReturnTableType *string `field:"optional" json:"returnTableType" yaml:"returnTableType"`
// A JSON schema for the return type.
//
// Optional if language = "SQL"; required otherwise.
// If absent, the return type is inferred from definitionBody at query time in each query
// that references this routine. If present, then the evaluated result will be cast to
// the specified returned type at query time. ~>**NOTE**: Because this field expects a JSON
// string, any changes to the string will create a diff, even if the JSON itself hasn't
// changed. If the API returns a different value for the same schema, e.g. it switche
// d the order of values or replaced STRUCT field type with RECORD field type, we currently
// cannot suppress the recurring diff this causes. As a workaround, we recommend using
// the schema as returned by the API.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_bigquery_routine#return_type GoogleBigqueryRoutine#return_type}
ReturnType *string `field:"optional" json:"returnType" yaml:"returnType"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_bigquery_routine#timeouts GoogleBigqueryRoutine#timeouts}
Timeouts *GoogleBigqueryRoutineTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type GoogleBigqueryRoutineTimeouts ¶
type GoogleBigqueryRoutineTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_bigquery_routine#create GoogleBigqueryRoutine#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_bigquery_routine#delete GoogleBigqueryRoutine#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_bigquery_routine#update GoogleBigqueryRoutine#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type GoogleBigqueryRoutineTimeoutsOutputReference ¶
type GoogleBigqueryRoutineTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleBigqueryRoutineTimeoutsOutputReference ¶
func NewGoogleBigqueryRoutineTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleBigqueryRoutineTimeoutsOutputReference
Source Files
¶
- GoogleBigqueryRoutine.go
- GoogleBigqueryRoutineArguments.go
- GoogleBigqueryRoutineArgumentsList.go
- GoogleBigqueryRoutineArgumentsList__checks.go
- GoogleBigqueryRoutineArgumentsOutputReference.go
- GoogleBigqueryRoutineArgumentsOutputReference__checks.go
- GoogleBigqueryRoutineConfig.go
- GoogleBigqueryRoutineTimeouts.go
- GoogleBigqueryRoutineTimeoutsOutputReference.go
- GoogleBigqueryRoutineTimeoutsOutputReference__checks.go
- GoogleBigqueryRoutine__checks.go
- main.go