Documentation
¶
Index ¶
- func GoogleCloudAssetProjectFeed_IsConstruct(x interface{}) *bool
- func GoogleCloudAssetProjectFeed_IsTerraformElement(x interface{}) *bool
- func GoogleCloudAssetProjectFeed_IsTerraformResource(x interface{}) *bool
- func GoogleCloudAssetProjectFeed_TfResourceType() *string
- func NewGoogleCloudAssetProjectFeedConditionOutputReference_Override(g GoogleCloudAssetProjectFeedConditionOutputReference, ...)
- func NewGoogleCloudAssetProjectFeedFeedOutputConfigOutputReference_Override(g GoogleCloudAssetProjectFeedFeedOutputConfigOutputReference, ...)
- func NewGoogleCloudAssetProjectFeedFeedOutputConfigPubsubDestinationOutputReference_Override(g GoogleCloudAssetProjectFeedFeedOutputConfigPubsubDestinationOutputReference, ...)
- func NewGoogleCloudAssetProjectFeedTimeoutsOutputReference_Override(g GoogleCloudAssetProjectFeedTimeoutsOutputReference, ...)
- func NewGoogleCloudAssetProjectFeed_Override(g GoogleCloudAssetProjectFeed, scope constructs.Construct, id *string, ...)
- type GoogleCloudAssetProjectFeed
- type GoogleCloudAssetProjectFeedCondition
- type GoogleCloudAssetProjectFeedConditionOutputReference
- type GoogleCloudAssetProjectFeedConfig
- type GoogleCloudAssetProjectFeedFeedOutputConfig
- type GoogleCloudAssetProjectFeedFeedOutputConfigOutputReference
- type GoogleCloudAssetProjectFeedFeedOutputConfigPubsubDestination
- type GoogleCloudAssetProjectFeedFeedOutputConfigPubsubDestinationOutputReference
- type GoogleCloudAssetProjectFeedTimeouts
- type GoogleCloudAssetProjectFeedTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleCloudAssetProjectFeed_IsConstruct ¶
func GoogleCloudAssetProjectFeed_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleCloudAssetProjectFeed_IsTerraformElement ¶
func GoogleCloudAssetProjectFeed_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleCloudAssetProjectFeed_IsTerraformResource ¶
func GoogleCloudAssetProjectFeed_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleCloudAssetProjectFeed_TfResourceType ¶
func GoogleCloudAssetProjectFeed_TfResourceType() *string
func NewGoogleCloudAssetProjectFeedConditionOutputReference_Override ¶
func NewGoogleCloudAssetProjectFeedConditionOutputReference_Override(g GoogleCloudAssetProjectFeedConditionOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleCloudAssetProjectFeedFeedOutputConfigOutputReference_Override ¶
func NewGoogleCloudAssetProjectFeedFeedOutputConfigOutputReference_Override(g GoogleCloudAssetProjectFeedFeedOutputConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleCloudAssetProjectFeedFeedOutputConfigPubsubDestinationOutputReference_Override ¶
func NewGoogleCloudAssetProjectFeedFeedOutputConfigPubsubDestinationOutputReference_Override(g GoogleCloudAssetProjectFeedFeedOutputConfigPubsubDestinationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleCloudAssetProjectFeedTimeoutsOutputReference_Override ¶
func NewGoogleCloudAssetProjectFeedTimeoutsOutputReference_Override(g GoogleCloudAssetProjectFeedTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleCloudAssetProjectFeed_Override ¶
func NewGoogleCloudAssetProjectFeed_Override(g GoogleCloudAssetProjectFeed, scope constructs.Construct, id *string, config *GoogleCloudAssetProjectFeedConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_cloud_asset_project_feed google_cloud_asset_project_feed} Resource.
Types ¶
type GoogleCloudAssetProjectFeed ¶
type GoogleCloudAssetProjectFeed interface {
cdktf.TerraformResource
AssetNames() *[]*string
SetAssetNames(val *[]*string)
AssetNamesInput() *[]*string
AssetTypes() *[]*string
SetAssetTypes(val *[]*string)
AssetTypesInput() *[]*string
BillingProject() *string
SetBillingProject(val *string)
BillingProjectInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
Condition() GoogleCloudAssetProjectFeedConditionOutputReference
ConditionInput() *GoogleCloudAssetProjectFeedCondition
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
ContentType() *string
SetContentType(val *string)
ContentTypeInput() *string
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
FeedId() *string
SetFeedId(val *string)
FeedIdInput() *string
FeedOutputConfig() GoogleCloudAssetProjectFeedFeedOutputConfigOutputReference
FeedOutputConfigInput() *GoogleCloudAssetProjectFeedFeedOutputConfig
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
// The tree node.
Node() constructs.Node
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GoogleCloudAssetProjectFeedTimeoutsOutputReference
TimeoutsInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutCondition(value *GoogleCloudAssetProjectFeedCondition)
PutFeedOutputConfig(value *GoogleCloudAssetProjectFeedFeedOutputConfig)
PutTimeouts(value *GoogleCloudAssetProjectFeedTimeouts)
ResetAssetNames()
ResetAssetTypes()
ResetBillingProject()
ResetCondition()
ResetContentType()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_cloud_asset_project_feed google_cloud_asset_project_feed}.
func NewGoogleCloudAssetProjectFeed ¶
func NewGoogleCloudAssetProjectFeed(scope constructs.Construct, id *string, config *GoogleCloudAssetProjectFeedConfig) GoogleCloudAssetProjectFeed
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_cloud_asset_project_feed google_cloud_asset_project_feed} Resource.
type GoogleCloudAssetProjectFeedCondition ¶
type GoogleCloudAssetProjectFeedCondition struct {
// Textual representation of an expression in Common Expression Language syntax.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_cloud_asset_project_feed#expression GoogleCloudAssetProjectFeed#expression}
Expression *string `field:"required" json:"expression" yaml:"expression"`
// Description of the expression.
//
// This is a longer text which describes the expression,
// e.g. when hovered over it in a UI.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_cloud_asset_project_feed#description GoogleCloudAssetProjectFeed#description}
Description *string `field:"optional" json:"description" yaml:"description"`
// String indicating the location of the expression for error reporting, e.g. a file name and a position in the file.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_cloud_asset_project_feed#location GoogleCloudAssetProjectFeed#location}
Location *string `field:"optional" json:"location" yaml:"location"`
// Title for the expression, i.e. a short string describing its purpose. This can be used e.g. in UIs which allow to enter the expression.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_cloud_asset_project_feed#title GoogleCloudAssetProjectFeed#title}
Title *string `field:"optional" json:"title" yaml:"title"`
}
type GoogleCloudAssetProjectFeedConditionOutputReference ¶
type GoogleCloudAssetProjectFeedConditionOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Description() *string
SetDescription(val *string)
DescriptionInput() *string
Expression() *string
SetExpression(val *string)
ExpressionInput() *string
// Experimental.
Fqn() *string
InternalValue() *GoogleCloudAssetProjectFeedCondition
SetInternalValue(val *GoogleCloudAssetProjectFeedCondition)
Location() *string
SetLocation(val *string)
LocationInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Title() *string
SetTitle(val *string)
TitleInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetDescription()
ResetLocation()
ResetTitle()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleCloudAssetProjectFeedConditionOutputReference ¶
func NewGoogleCloudAssetProjectFeedConditionOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleCloudAssetProjectFeedConditionOutputReference
type GoogleCloudAssetProjectFeedConfig ¶
type GoogleCloudAssetProjectFeedConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// This is the client-assigned asset feed identifier and it needs to be unique under a specific parent.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_cloud_asset_project_feed#feed_id GoogleCloudAssetProjectFeed#feed_id}
FeedId *string `field:"required" json:"feedId" yaml:"feedId"`
// feed_output_config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_cloud_asset_project_feed#feed_output_config GoogleCloudAssetProjectFeed#feed_output_config}
FeedOutputConfig *GoogleCloudAssetProjectFeedFeedOutputConfig `field:"required" json:"feedOutputConfig" yaml:"feedOutputConfig"`
// A list of the full names of the assets to receive updates.
//
// You must specify either or both of
// assetNames and assetTypes. Only asset updates matching specified assetNames and assetTypes are
// exported to the feed. For example: //compute.googleapis.com/projects/my_project_123/zones/zone1/instances/instance1.
// See https://cloud.google.com/apis/design/resourceNames#fullResourceName for more info.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_cloud_asset_project_feed#asset_names GoogleCloudAssetProjectFeed#asset_names}
AssetNames *[]*string `field:"optional" json:"assetNames" yaml:"assetNames"`
// A list of types of the assets to receive updates.
//
// You must specify either or both of assetNames
// and assetTypes. Only asset updates matching specified assetNames and assetTypes are exported to
// the feed. For example: "compute.googleapis.com/Disk"
// See https://cloud.google.com/asset-inventory/docs/supported-asset-types for a list of all
// supported asset types.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_cloud_asset_project_feed#asset_types GoogleCloudAssetProjectFeed#asset_types}
AssetTypes *[]*string `field:"optional" json:"assetTypes" yaml:"assetTypes"`
// The project whose identity will be used when sending messages to the destination pubsub topic.
//
// It also specifies the project for API
// enablement check, quota, and billing. If not specified, the resource's
// project will be used.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_cloud_asset_project_feed#billing_project GoogleCloudAssetProjectFeed#billing_project}
BillingProject *string `field:"optional" json:"billingProject" yaml:"billingProject"`
// condition block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_cloud_asset_project_feed#condition GoogleCloudAssetProjectFeed#condition}
Condition *GoogleCloudAssetProjectFeedCondition `field:"optional" json:"condition" yaml:"condition"`
// Asset content type.
//
// If not specified, no content but the asset name and type will be returned. Possible values: ["CONTENT_TYPE_UNSPECIFIED", "RESOURCE", "IAM_POLICY", "ORG_POLICY", "OS_INVENTORY", "ACCESS_POLICY"]
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_cloud_asset_project_feed#content_type GoogleCloudAssetProjectFeed#content_type}
ContentType *string `field:"optional" json:"contentType" yaml:"contentType"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_cloud_asset_project_feed#id GoogleCloudAssetProjectFeed#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_cloud_asset_project_feed#project GoogleCloudAssetProjectFeed#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_cloud_asset_project_feed#timeouts GoogleCloudAssetProjectFeed#timeouts}
Timeouts *GoogleCloudAssetProjectFeedTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type GoogleCloudAssetProjectFeedFeedOutputConfig ¶
type GoogleCloudAssetProjectFeedFeedOutputConfig struct {
// pubsub_destination block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_cloud_asset_project_feed#pubsub_destination GoogleCloudAssetProjectFeed#pubsub_destination}
PubsubDestination *GoogleCloudAssetProjectFeedFeedOutputConfigPubsubDestination `field:"required" json:"pubsubDestination" yaml:"pubsubDestination"`
}
type GoogleCloudAssetProjectFeedFeedOutputConfigOutputReference ¶
type GoogleCloudAssetProjectFeedFeedOutputConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleCloudAssetProjectFeedFeedOutputConfig
SetInternalValue(val *GoogleCloudAssetProjectFeedFeedOutputConfig)
PubsubDestination() GoogleCloudAssetProjectFeedFeedOutputConfigPubsubDestinationOutputReference
PubsubDestinationInput() *GoogleCloudAssetProjectFeedFeedOutputConfigPubsubDestination
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutPubsubDestination(value *GoogleCloudAssetProjectFeedFeedOutputConfigPubsubDestination)
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleCloudAssetProjectFeedFeedOutputConfigOutputReference ¶
func NewGoogleCloudAssetProjectFeedFeedOutputConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleCloudAssetProjectFeedFeedOutputConfigOutputReference
type GoogleCloudAssetProjectFeedFeedOutputConfigPubsubDestination ¶
type GoogleCloudAssetProjectFeedFeedOutputConfigPubsubDestination struct {
// Destination on Cloud Pubsub topic.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_cloud_asset_project_feed#topic GoogleCloudAssetProjectFeed#topic}
Topic *string `field:"required" json:"topic" yaml:"topic"`
}
type GoogleCloudAssetProjectFeedFeedOutputConfigPubsubDestinationOutputReference ¶
type GoogleCloudAssetProjectFeedFeedOutputConfigPubsubDestinationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleCloudAssetProjectFeedFeedOutputConfigPubsubDestination
SetInternalValue(val *GoogleCloudAssetProjectFeedFeedOutputConfigPubsubDestination)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Topic() *string
SetTopic(val *string)
TopicInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleCloudAssetProjectFeedFeedOutputConfigPubsubDestinationOutputReference ¶
func NewGoogleCloudAssetProjectFeedFeedOutputConfigPubsubDestinationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleCloudAssetProjectFeedFeedOutputConfigPubsubDestinationOutputReference
type GoogleCloudAssetProjectFeedTimeouts ¶
type GoogleCloudAssetProjectFeedTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_cloud_asset_project_feed#create GoogleCloudAssetProjectFeed#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_cloud_asset_project_feed#delete GoogleCloudAssetProjectFeed#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_cloud_asset_project_feed#update GoogleCloudAssetProjectFeed#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type GoogleCloudAssetProjectFeedTimeoutsOutputReference ¶
type GoogleCloudAssetProjectFeedTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleCloudAssetProjectFeedTimeoutsOutputReference ¶
func NewGoogleCloudAssetProjectFeedTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleCloudAssetProjectFeedTimeoutsOutputReference
Source Files
¶
- GoogleCloudAssetProjectFeed.go
- GoogleCloudAssetProjectFeedCondition.go
- GoogleCloudAssetProjectFeedConditionOutputReference.go
- GoogleCloudAssetProjectFeedConditionOutputReference__checks.go
- GoogleCloudAssetProjectFeedConfig.go
- GoogleCloudAssetProjectFeedFeedOutputConfig.go
- GoogleCloudAssetProjectFeedFeedOutputConfigOutputReference.go
- GoogleCloudAssetProjectFeedFeedOutputConfigOutputReference__checks.go
- GoogleCloudAssetProjectFeedFeedOutputConfigPubsubDestination.go
- GoogleCloudAssetProjectFeedFeedOutputConfigPubsubDestinationOutputReference.go
- GoogleCloudAssetProjectFeedFeedOutputConfigPubsubDestinationOutputReference__checks.go
- GoogleCloudAssetProjectFeedTimeouts.go
- GoogleCloudAssetProjectFeedTimeoutsOutputReference.go
- GoogleCloudAssetProjectFeedTimeoutsOutputReference__checks.go
- GoogleCloudAssetProjectFeed__checks.go
- main.go