Documentation
¶
Index ¶
- func GoogleComputeMachineImage_IsConstruct(x interface{}) *bool
- func GoogleComputeMachineImage_IsTerraformElement(x interface{}) *bool
- func GoogleComputeMachineImage_IsTerraformResource(x interface{}) *bool
- func GoogleComputeMachineImage_TfResourceType() *string
- func NewGoogleComputeMachineImageMachineImageEncryptionKeyOutputReference_Override(g GoogleComputeMachineImageMachineImageEncryptionKeyOutputReference, ...)
- func NewGoogleComputeMachineImageTimeoutsOutputReference_Override(g GoogleComputeMachineImageTimeoutsOutputReference, ...)
- func NewGoogleComputeMachineImage_Override(g GoogleComputeMachineImage, scope constructs.Construct, id *string, ...)
- type GoogleComputeMachineImage
- type GoogleComputeMachineImageConfig
- type GoogleComputeMachineImageMachineImageEncryptionKey
- type GoogleComputeMachineImageMachineImageEncryptionKeyOutputReference
- type GoogleComputeMachineImageTimeouts
- type GoogleComputeMachineImageTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleComputeMachineImage_IsConstruct ¶
func GoogleComputeMachineImage_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleComputeMachineImage_IsTerraformElement ¶
func GoogleComputeMachineImage_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleComputeMachineImage_IsTerraformResource ¶
func GoogleComputeMachineImage_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleComputeMachineImage_TfResourceType ¶
func GoogleComputeMachineImage_TfResourceType() *string
func NewGoogleComputeMachineImageMachineImageEncryptionKeyOutputReference_Override ¶
func NewGoogleComputeMachineImageMachineImageEncryptionKeyOutputReference_Override(g GoogleComputeMachineImageMachineImageEncryptionKeyOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleComputeMachineImageTimeoutsOutputReference_Override ¶
func NewGoogleComputeMachineImageTimeoutsOutputReference_Override(g GoogleComputeMachineImageTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleComputeMachineImage_Override ¶
func NewGoogleComputeMachineImage_Override(g GoogleComputeMachineImage, scope constructs.Construct, id *string, config *GoogleComputeMachineImageConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_compute_machine_image google_compute_machine_image} Resource.
Types ¶
type GoogleComputeMachineImage ¶
type GoogleComputeMachineImage interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
GuestFlush() interface{}
SetGuestFlush(val interface{})
GuestFlushInput() interface{}
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
MachineImageEncryptionKey() GoogleComputeMachineImageMachineImageEncryptionKeyOutputReference
MachineImageEncryptionKeyInput() *GoogleComputeMachineImageMachineImageEncryptionKey
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
SelfLink() *string
SourceInstance() *string
SetSourceInstance(val *string)
SourceInstanceInput() *string
StorageLocations() *[]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GoogleComputeMachineImageTimeoutsOutputReference
TimeoutsInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutMachineImageEncryptionKey(value *GoogleComputeMachineImageMachineImageEncryptionKey)
PutTimeouts(value *GoogleComputeMachineImageTimeouts)
ResetDescription()
ResetGuestFlush()
ResetId()
ResetMachineImageEncryptionKey()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_compute_machine_image google_compute_machine_image}.
func NewGoogleComputeMachineImage ¶
func NewGoogleComputeMachineImage(scope constructs.Construct, id *string, config *GoogleComputeMachineImageConfig) GoogleComputeMachineImage
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_compute_machine_image google_compute_machine_image} Resource.
type GoogleComputeMachineImageConfig ¶
type GoogleComputeMachineImageConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Name of the resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_compute_machine_image#name GoogleComputeMachineImage#name}
Name *string `field:"required" json:"name" yaml:"name"`
// The source instance used to create the machine image.
//
// You can provide this as a partial or full URL to the resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_compute_machine_image#source_instance GoogleComputeMachineImage#source_instance}
SourceInstance *string `field:"required" json:"sourceInstance" yaml:"sourceInstance"`
// A text description of the resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_compute_machine_image#description GoogleComputeMachineImage#description}
Description *string `field:"optional" json:"description" yaml:"description"`
// Specify this to create an application consistent machine image by informing the OS to prepare for the snapshot process.
//
// Currently only supported on Windows instances using the Volume Shadow Copy Service (VSS).
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_compute_machine_image#guest_flush GoogleComputeMachineImage#guest_flush}
GuestFlush interface{} `field:"optional" json:"guestFlush" yaml:"guestFlush"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_compute_machine_image#id GoogleComputeMachineImage#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// machine_image_encryption_key block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_compute_machine_image#machine_image_encryption_key GoogleComputeMachineImage#machine_image_encryption_key}
MachineImageEncryptionKey *GoogleComputeMachineImageMachineImageEncryptionKey `field:"optional" json:"machineImageEncryptionKey" yaml:"machineImageEncryptionKey"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_compute_machine_image#project GoogleComputeMachineImage#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_compute_machine_image#timeouts GoogleComputeMachineImage#timeouts}
Timeouts *GoogleComputeMachineImageTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type GoogleComputeMachineImageMachineImageEncryptionKey ¶
type GoogleComputeMachineImageMachineImageEncryptionKey struct {
// The name of the encryption key that is stored in Google Cloud KMS.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_compute_machine_image#kms_key_name GoogleComputeMachineImage#kms_key_name}
KmsKeyName *string `field:"optional" json:"kmsKeyName" yaml:"kmsKeyName"`
// The service account used for the encryption request for the given KMS key.
//
// If absent, the Compute Engine Service Agent service account is used.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_compute_machine_image#kms_key_service_account GoogleComputeMachineImage#kms_key_service_account}
KmsKeyServiceAccount *string `field:"optional" json:"kmsKeyServiceAccount" yaml:"kmsKeyServiceAccount"`
// Specifies a 256-bit customer-supplied encryption key, encoded in RFC 4648 base64 to either encrypt or decrypt this resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_compute_machine_image#raw_key GoogleComputeMachineImage#raw_key}
RawKey *string `field:"optional" json:"rawKey" yaml:"rawKey"`
}
type GoogleComputeMachineImageMachineImageEncryptionKeyOutputReference ¶
type GoogleComputeMachineImageMachineImageEncryptionKeyOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleComputeMachineImageMachineImageEncryptionKey
SetInternalValue(val *GoogleComputeMachineImageMachineImageEncryptionKey)
KmsKeyName() *string
SetKmsKeyName(val *string)
KmsKeyNameInput() *string
KmsKeyServiceAccount() *string
SetKmsKeyServiceAccount(val *string)
KmsKeyServiceAccountInput() *string
RawKey() *string
SetRawKey(val *string)
RawKeyInput() *string
Sha256() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetKmsKeyName()
ResetKmsKeyServiceAccount()
ResetRawKey()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleComputeMachineImageMachineImageEncryptionKeyOutputReference ¶
func NewGoogleComputeMachineImageMachineImageEncryptionKeyOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleComputeMachineImageMachineImageEncryptionKeyOutputReference
type GoogleComputeMachineImageTimeouts ¶
type GoogleComputeMachineImageTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_compute_machine_image#create GoogleComputeMachineImage#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_compute_machine_image#delete GoogleComputeMachineImage#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
}
type GoogleComputeMachineImageTimeoutsOutputReference ¶
type GoogleComputeMachineImageTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleComputeMachineImageTimeoutsOutputReference ¶
func NewGoogleComputeMachineImageTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleComputeMachineImageTimeoutsOutputReference
Source Files
¶
- GoogleComputeMachineImage.go
- GoogleComputeMachineImageConfig.go
- GoogleComputeMachineImageMachineImageEncryptionKey.go
- GoogleComputeMachineImageMachineImageEncryptionKeyOutputReference.go
- GoogleComputeMachineImageMachineImageEncryptionKeyOutputReference__checks.go
- GoogleComputeMachineImageTimeouts.go
- GoogleComputeMachineImageTimeoutsOutputReference.go
- GoogleComputeMachineImageTimeoutsOutputReference__checks.go
- GoogleComputeMachineImage__checks.go
- main.go