Documentation
¶
Index ¶
- func GoogleComputeNodeTemplate_IsConstruct(x interface{}) *bool
- func GoogleComputeNodeTemplate_IsTerraformElement(x interface{}) *bool
- func GoogleComputeNodeTemplate_IsTerraformResource(x interface{}) *bool
- func GoogleComputeNodeTemplate_TfResourceType() *string
- func NewGoogleComputeNodeTemplateNodeTypeFlexibilityOutputReference_Override(g GoogleComputeNodeTemplateNodeTypeFlexibilityOutputReference, ...)
- func NewGoogleComputeNodeTemplateServerBindingOutputReference_Override(g GoogleComputeNodeTemplateServerBindingOutputReference, ...)
- func NewGoogleComputeNodeTemplateTimeoutsOutputReference_Override(g GoogleComputeNodeTemplateTimeoutsOutputReference, ...)
- func NewGoogleComputeNodeTemplate_Override(g GoogleComputeNodeTemplate, scope constructs.Construct, id *string, ...)
- type GoogleComputeNodeTemplate
- type GoogleComputeNodeTemplateConfig
- type GoogleComputeNodeTemplateNodeTypeFlexibility
- type GoogleComputeNodeTemplateNodeTypeFlexibilityOutputReference
- type GoogleComputeNodeTemplateServerBinding
- type GoogleComputeNodeTemplateServerBindingOutputReference
- type GoogleComputeNodeTemplateTimeouts
- type GoogleComputeNodeTemplateTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleComputeNodeTemplate_IsConstruct ¶
func GoogleComputeNodeTemplate_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleComputeNodeTemplate_IsTerraformElement ¶
func GoogleComputeNodeTemplate_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleComputeNodeTemplate_IsTerraformResource ¶
func GoogleComputeNodeTemplate_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleComputeNodeTemplate_TfResourceType ¶
func GoogleComputeNodeTemplate_TfResourceType() *string
func NewGoogleComputeNodeTemplateNodeTypeFlexibilityOutputReference_Override ¶
func NewGoogleComputeNodeTemplateNodeTypeFlexibilityOutputReference_Override(g GoogleComputeNodeTemplateNodeTypeFlexibilityOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleComputeNodeTemplateServerBindingOutputReference_Override ¶
func NewGoogleComputeNodeTemplateServerBindingOutputReference_Override(g GoogleComputeNodeTemplateServerBindingOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleComputeNodeTemplateTimeoutsOutputReference_Override ¶
func NewGoogleComputeNodeTemplateTimeoutsOutputReference_Override(g GoogleComputeNodeTemplateTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleComputeNodeTemplate_Override ¶
func NewGoogleComputeNodeTemplate_Override(g GoogleComputeNodeTemplate, scope constructs.Construct, id *string, config *GoogleComputeNodeTemplateConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_compute_node_template google_compute_node_template} Resource.
Types ¶
type GoogleComputeNodeTemplate ¶
type GoogleComputeNodeTemplate interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
CpuOvercommitType() *string
SetCpuOvercommitType(val *string)
CpuOvercommitTypeInput() *string
CreationTimestamp() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
NodeAffinityLabels() *map[string]*string
SetNodeAffinityLabels(val *map[string]*string)
NodeAffinityLabelsInput() *map[string]*string
NodeType() *string
SetNodeType(val *string)
NodeTypeFlexibility() GoogleComputeNodeTemplateNodeTypeFlexibilityOutputReference
NodeTypeFlexibilityInput() *GoogleComputeNodeTemplateNodeTypeFlexibility
NodeTypeInput() *string
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Region() *string
SetRegion(val *string)
RegionInput() *string
SelfLink() *string
ServerBinding() GoogleComputeNodeTemplateServerBindingOutputReference
ServerBindingInput() *GoogleComputeNodeTemplateServerBinding
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GoogleComputeNodeTemplateTimeoutsOutputReference
TimeoutsInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutNodeTypeFlexibility(value *GoogleComputeNodeTemplateNodeTypeFlexibility)
PutServerBinding(value *GoogleComputeNodeTemplateServerBinding)
PutTimeouts(value *GoogleComputeNodeTemplateTimeouts)
ResetCpuOvercommitType()
ResetDescription()
ResetId()
ResetName()
ResetNodeAffinityLabels()
ResetNodeType()
ResetNodeTypeFlexibility()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
ResetRegion()
ResetServerBinding()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_compute_node_template google_compute_node_template}.
func NewGoogleComputeNodeTemplate ¶
func NewGoogleComputeNodeTemplate(scope constructs.Construct, id *string, config *GoogleComputeNodeTemplateConfig) GoogleComputeNodeTemplate
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_compute_node_template google_compute_node_template} Resource.
type GoogleComputeNodeTemplateConfig ¶
type GoogleComputeNodeTemplateConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// CPU overcommit. Default value: "NONE" Possible values: ["ENABLED", "NONE"].
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_compute_node_template#cpu_overcommit_type GoogleComputeNodeTemplate#cpu_overcommit_type}
CpuOvercommitType *string `field:"optional" json:"cpuOvercommitType" yaml:"cpuOvercommitType"`
// An optional textual description of the resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_compute_node_template#description GoogleComputeNodeTemplate#description}
Description *string `field:"optional" json:"description" yaml:"description"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_compute_node_template#id GoogleComputeNodeTemplate#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Name of the resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_compute_node_template#name GoogleComputeNodeTemplate#name}
Name *string `field:"optional" json:"name" yaml:"name"`
// Labels to use for node affinity, which will be used in instance scheduling.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_compute_node_template#node_affinity_labels GoogleComputeNodeTemplate#node_affinity_labels}
NodeAffinityLabels *map[string]*string `field:"optional" json:"nodeAffinityLabels" yaml:"nodeAffinityLabels"`
// Node type to use for nodes group that are created from this template.
//
// Only one of nodeTypeFlexibility and nodeType can be specified.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_compute_node_template#node_type GoogleComputeNodeTemplate#node_type}
NodeType *string `field:"optional" json:"nodeType" yaml:"nodeType"`
// node_type_flexibility block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_compute_node_template#node_type_flexibility GoogleComputeNodeTemplate#node_type_flexibility}
NodeTypeFlexibility *GoogleComputeNodeTemplateNodeTypeFlexibility `field:"optional" json:"nodeTypeFlexibility" yaml:"nodeTypeFlexibility"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_compute_node_template#project GoogleComputeNodeTemplate#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// Region where nodes using the node template will be created. If it is not provided, the provider region is used.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_compute_node_template#region GoogleComputeNodeTemplate#region}
Region *string `field:"optional" json:"region" yaml:"region"`
// server_binding block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_compute_node_template#server_binding GoogleComputeNodeTemplate#server_binding}
ServerBinding *GoogleComputeNodeTemplateServerBinding `field:"optional" json:"serverBinding" yaml:"serverBinding"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_compute_node_template#timeouts GoogleComputeNodeTemplate#timeouts}
Timeouts *GoogleComputeNodeTemplateTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type GoogleComputeNodeTemplateNodeTypeFlexibility ¶
type GoogleComputeNodeTemplateNodeTypeFlexibility struct {
// Number of virtual CPUs to use.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_compute_node_template#cpus GoogleComputeNodeTemplate#cpus}
Cpus *string `field:"optional" json:"cpus" yaml:"cpus"`
// Physical memory available to the node, defined in MB.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_compute_node_template#memory GoogleComputeNodeTemplate#memory}
Memory *string `field:"optional" json:"memory" yaml:"memory"`
}
type GoogleComputeNodeTemplateNodeTypeFlexibilityOutputReference ¶
type GoogleComputeNodeTemplateNodeTypeFlexibilityOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Cpus() *string
SetCpus(val *string)
CpusInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleComputeNodeTemplateNodeTypeFlexibility
SetInternalValue(val *GoogleComputeNodeTemplateNodeTypeFlexibility)
LocalSsd() *string
Memory() *string
SetMemory(val *string)
MemoryInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCpus()
ResetMemory()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleComputeNodeTemplateNodeTypeFlexibilityOutputReference ¶
func NewGoogleComputeNodeTemplateNodeTypeFlexibilityOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleComputeNodeTemplateNodeTypeFlexibilityOutputReference
type GoogleComputeNodeTemplateServerBinding ¶
type GoogleComputeNodeTemplateServerBinding struct {
// Type of server binding policy. If 'RESTART_NODE_ON_ANY_SERVER', nodes using this template will restart on any physical server following a maintenance event.
//
// If 'RESTART_NODE_ON_MINIMAL_SERVER', nodes using this template
// will restart on the same physical server following a maintenance
// event, instead of being live migrated to or restarted on a new
// physical server. This option may be useful if you are using
// software licenses tied to the underlying server characteristics
// such as physical sockets or cores, to avoid the need for
// additional licenses when maintenance occurs. However, VMs on such
// nodes will experience outages while maintenance is applied. Possible values: ["RESTART_NODE_ON_ANY_SERVER", "RESTART_NODE_ON_MINIMAL_SERVERS"]
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_compute_node_template#type GoogleComputeNodeTemplate#type}
Type *string `field:"required" json:"type" yaml:"type"`
}
type GoogleComputeNodeTemplateServerBindingOutputReference ¶
type GoogleComputeNodeTemplateServerBindingOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleComputeNodeTemplateServerBinding
SetInternalValue(val *GoogleComputeNodeTemplateServerBinding)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
SetType(val *string)
TypeInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleComputeNodeTemplateServerBindingOutputReference ¶
func NewGoogleComputeNodeTemplateServerBindingOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleComputeNodeTemplateServerBindingOutputReference
type GoogleComputeNodeTemplateTimeouts ¶
type GoogleComputeNodeTemplateTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_compute_node_template#create GoogleComputeNodeTemplate#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_compute_node_template#delete GoogleComputeNodeTemplate#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
}
type GoogleComputeNodeTemplateTimeoutsOutputReference ¶
type GoogleComputeNodeTemplateTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleComputeNodeTemplateTimeoutsOutputReference ¶
func NewGoogleComputeNodeTemplateTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleComputeNodeTemplateTimeoutsOutputReference
Source Files
¶
- GoogleComputeNodeTemplate.go
- GoogleComputeNodeTemplateConfig.go
- GoogleComputeNodeTemplateNodeTypeFlexibility.go
- GoogleComputeNodeTemplateNodeTypeFlexibilityOutputReference.go
- GoogleComputeNodeTemplateNodeTypeFlexibilityOutputReference__checks.go
- GoogleComputeNodeTemplateServerBinding.go
- GoogleComputeNodeTemplateServerBindingOutputReference.go
- GoogleComputeNodeTemplateServerBindingOutputReference__checks.go
- GoogleComputeNodeTemplateTimeouts.go
- GoogleComputeNodeTemplateTimeoutsOutputReference.go
- GoogleComputeNodeTemplateTimeoutsOutputReference__checks.go
- GoogleComputeNodeTemplate__checks.go
- main.go