Documentation
¶
Index ¶
- func GoogleDialogflowCxWebhook_IsConstruct(x interface{}) *bool
- func GoogleDialogflowCxWebhook_IsTerraformElement(x interface{}) *bool
- func GoogleDialogflowCxWebhook_IsTerraformResource(x interface{}) *bool
- func GoogleDialogflowCxWebhook_TfResourceType() *string
- func NewGoogleDialogflowCxWebhookGenericWebServiceOutputReference_Override(g GoogleDialogflowCxWebhookGenericWebServiceOutputReference, ...)
- func NewGoogleDialogflowCxWebhookServiceDirectoryGenericWebServiceOutputReference_Override(g GoogleDialogflowCxWebhookServiceDirectoryGenericWebServiceOutputReference, ...)
- func NewGoogleDialogflowCxWebhookServiceDirectoryOutputReference_Override(g GoogleDialogflowCxWebhookServiceDirectoryOutputReference, ...)
- func NewGoogleDialogflowCxWebhookTimeoutsOutputReference_Override(g GoogleDialogflowCxWebhookTimeoutsOutputReference, ...)
- func NewGoogleDialogflowCxWebhook_Override(g GoogleDialogflowCxWebhook, scope constructs.Construct, id *string, ...)
- type GoogleDialogflowCxWebhook
- type GoogleDialogflowCxWebhookConfig
- type GoogleDialogflowCxWebhookGenericWebService
- type GoogleDialogflowCxWebhookGenericWebServiceOutputReference
- type GoogleDialogflowCxWebhookServiceDirectory
- type GoogleDialogflowCxWebhookServiceDirectoryGenericWebService
- type GoogleDialogflowCxWebhookServiceDirectoryGenericWebServiceOutputReference
- type GoogleDialogflowCxWebhookServiceDirectoryOutputReference
- type GoogleDialogflowCxWebhookTimeouts
- type GoogleDialogflowCxWebhookTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleDialogflowCxWebhook_IsConstruct ¶
func GoogleDialogflowCxWebhook_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleDialogflowCxWebhook_IsTerraformElement ¶
func GoogleDialogflowCxWebhook_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleDialogflowCxWebhook_IsTerraformResource ¶
func GoogleDialogflowCxWebhook_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleDialogflowCxWebhook_TfResourceType ¶
func GoogleDialogflowCxWebhook_TfResourceType() *string
func NewGoogleDialogflowCxWebhookGenericWebServiceOutputReference_Override ¶
func NewGoogleDialogflowCxWebhookGenericWebServiceOutputReference_Override(g GoogleDialogflowCxWebhookGenericWebServiceOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleDialogflowCxWebhookServiceDirectoryGenericWebServiceOutputReference_Override ¶
func NewGoogleDialogflowCxWebhookServiceDirectoryGenericWebServiceOutputReference_Override(g GoogleDialogflowCxWebhookServiceDirectoryGenericWebServiceOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleDialogflowCxWebhookServiceDirectoryOutputReference_Override ¶
func NewGoogleDialogflowCxWebhookServiceDirectoryOutputReference_Override(g GoogleDialogflowCxWebhookServiceDirectoryOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleDialogflowCxWebhookTimeoutsOutputReference_Override ¶
func NewGoogleDialogflowCxWebhookTimeoutsOutputReference_Override(g GoogleDialogflowCxWebhookTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleDialogflowCxWebhook_Override ¶
func NewGoogleDialogflowCxWebhook_Override(g GoogleDialogflowCxWebhook, scope constructs.Construct, id *string, config *GoogleDialogflowCxWebhookConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_dialogflow_cx_webhook google_dialogflow_cx_webhook} Resource.
Types ¶
type GoogleDialogflowCxWebhook ¶
type GoogleDialogflowCxWebhook interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Disabled() interface{}
SetDisabled(val interface{})
DisabledInput() interface{}
DisplayName() *string
SetDisplayName(val *string)
DisplayNameInput() *string
EnableSpellCorrection() interface{}
SetEnableSpellCorrection(val interface{})
EnableSpellCorrectionInput() interface{}
EnableStackdriverLogging() interface{}
SetEnableStackdriverLogging(val interface{})
EnableStackdriverLoggingInput() interface{}
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
GenericWebService() GoogleDialogflowCxWebhookGenericWebServiceOutputReference
GenericWebServiceInput() *GoogleDialogflowCxWebhookGenericWebService
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
// The tree node.
Node() constructs.Node
Parent() *string
SetParent(val *string)
ParentInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
SecuritySettings() *string
SetSecuritySettings(val *string)
SecuritySettingsInput() *string
ServiceDirectory() GoogleDialogflowCxWebhookServiceDirectoryOutputReference
ServiceDirectoryInput() *GoogleDialogflowCxWebhookServiceDirectory
StartFlow() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeout() *string
SetTimeout(val *string)
TimeoutInput() *string
Timeouts() GoogleDialogflowCxWebhookTimeoutsOutputReference
TimeoutsInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutGenericWebService(value *GoogleDialogflowCxWebhookGenericWebService)
PutServiceDirectory(value *GoogleDialogflowCxWebhookServiceDirectory)
PutTimeouts(value *GoogleDialogflowCxWebhookTimeouts)
ResetDisabled()
ResetEnableSpellCorrection()
ResetEnableStackdriverLogging()
ResetGenericWebService()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetParent()
ResetSecuritySettings()
ResetServiceDirectory()
ResetTimeout()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_dialogflow_cx_webhook google_dialogflow_cx_webhook}.
func NewGoogleDialogflowCxWebhook ¶
func NewGoogleDialogflowCxWebhook(scope constructs.Construct, id *string, config *GoogleDialogflowCxWebhookConfig) GoogleDialogflowCxWebhook
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_dialogflow_cx_webhook google_dialogflow_cx_webhook} Resource.
type GoogleDialogflowCxWebhookConfig ¶
type GoogleDialogflowCxWebhookConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// The human-readable name of the webhook, unique within the agent.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_dialogflow_cx_webhook#display_name GoogleDialogflowCxWebhook#display_name}
DisplayName *string `field:"required" json:"displayName" yaml:"displayName"`
// Indicates whether the webhook is disabled.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_dialogflow_cx_webhook#disabled GoogleDialogflowCxWebhook#disabled}
Disabled interface{} `field:"optional" json:"disabled" yaml:"disabled"`
// Indicates if automatic spell correction is enabled in detect intent requests.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_dialogflow_cx_webhook#enable_spell_correction GoogleDialogflowCxWebhook#enable_spell_correction}
EnableSpellCorrection interface{} `field:"optional" json:"enableSpellCorrection" yaml:"enableSpellCorrection"`
// Determines whether this agent should log conversation queries.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_dialogflow_cx_webhook#enable_stackdriver_logging GoogleDialogflowCxWebhook#enable_stackdriver_logging}
EnableStackdriverLogging interface{} `field:"optional" json:"enableStackdriverLogging" yaml:"enableStackdriverLogging"`
// generic_web_service block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_dialogflow_cx_webhook#generic_web_service GoogleDialogflowCxWebhook#generic_web_service}
GenericWebService *GoogleDialogflowCxWebhookGenericWebService `field:"optional" json:"genericWebService" yaml:"genericWebService"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_dialogflow_cx_webhook#id GoogleDialogflowCxWebhook#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// The agent to create a webhook for. Format: projects/<Project ID>/locations/<Location ID>/agents/<Agent ID>.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_dialogflow_cx_webhook#parent GoogleDialogflowCxWebhook#parent}
Parent *string `field:"optional" json:"parent" yaml:"parent"`
// Name of the SecuritySettings reference for the agent. Format: projects/<Project ID>/locations/<Location ID>/securitySettings/<Security Settings ID>.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_dialogflow_cx_webhook#security_settings GoogleDialogflowCxWebhook#security_settings}
SecuritySettings *string `field:"optional" json:"securitySettings" yaml:"securitySettings"`
// service_directory block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_dialogflow_cx_webhook#service_directory GoogleDialogflowCxWebhook#service_directory}
ServiceDirectory *GoogleDialogflowCxWebhookServiceDirectory `field:"optional" json:"serviceDirectory" yaml:"serviceDirectory"`
// Webhook execution timeout.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_dialogflow_cx_webhook#timeout GoogleDialogflowCxWebhook#timeout}
Timeout *string `field:"optional" json:"timeout" yaml:"timeout"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_dialogflow_cx_webhook#timeouts GoogleDialogflowCxWebhook#timeouts}
Timeouts *GoogleDialogflowCxWebhookTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type GoogleDialogflowCxWebhookGenericWebService ¶
type GoogleDialogflowCxWebhookGenericWebService struct {
// Whether to use speech adaptation for speech recognition.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_dialogflow_cx_webhook#uri GoogleDialogflowCxWebhook#uri}
Uri *string `field:"required" json:"uri" yaml:"uri"`
// Specifies a list of allowed custom CA certificates (in DER format) for HTTPS verification.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_dialogflow_cx_webhook#allowed_ca_certs GoogleDialogflowCxWebhook#allowed_ca_certs}
AllowedCaCerts *[]*string `field:"optional" json:"allowedCaCerts" yaml:"allowedCaCerts"`
// The HTTP request headers to send together with webhook requests.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_dialogflow_cx_webhook#request_headers GoogleDialogflowCxWebhook#request_headers}
RequestHeaders *map[string]*string `field:"optional" json:"requestHeaders" yaml:"requestHeaders"`
}
type GoogleDialogflowCxWebhookGenericWebServiceOutputReference ¶
type GoogleDialogflowCxWebhookGenericWebServiceOutputReference interface {
cdktf.ComplexObject
AllowedCaCerts() *[]*string
SetAllowedCaCerts(val *[]*string)
AllowedCaCertsInput() *[]*string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleDialogflowCxWebhookGenericWebService
SetInternalValue(val *GoogleDialogflowCxWebhookGenericWebService)
RequestHeaders() *map[string]*string
SetRequestHeaders(val *map[string]*string)
RequestHeadersInput() *map[string]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Uri() *string
SetUri(val *string)
UriInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetAllowedCaCerts()
ResetRequestHeaders()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleDialogflowCxWebhookGenericWebServiceOutputReference ¶
func NewGoogleDialogflowCxWebhookGenericWebServiceOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleDialogflowCxWebhookGenericWebServiceOutputReference
type GoogleDialogflowCxWebhookServiceDirectory ¶
type GoogleDialogflowCxWebhookServiceDirectory struct {
// generic_web_service block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_dialogflow_cx_webhook#generic_web_service GoogleDialogflowCxWebhook#generic_web_service}
GenericWebService *GoogleDialogflowCxWebhookServiceDirectoryGenericWebService `field:"required" json:"genericWebService" yaml:"genericWebService"`
// The name of Service Directory service.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_dialogflow_cx_webhook#service GoogleDialogflowCxWebhook#service}
Service *string `field:"required" json:"service" yaml:"service"`
}
type GoogleDialogflowCxWebhookServiceDirectoryGenericWebService ¶
type GoogleDialogflowCxWebhookServiceDirectoryGenericWebService struct {
// Whether to use speech adaptation for speech recognition.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_dialogflow_cx_webhook#uri GoogleDialogflowCxWebhook#uri}
Uri *string `field:"required" json:"uri" yaml:"uri"`
// Specifies a list of allowed custom CA certificates (in DER format) for HTTPS verification.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_dialogflow_cx_webhook#allowed_ca_certs GoogleDialogflowCxWebhook#allowed_ca_certs}
AllowedCaCerts *[]*string `field:"optional" json:"allowedCaCerts" yaml:"allowedCaCerts"`
// The HTTP request headers to send together with webhook requests.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_dialogflow_cx_webhook#request_headers GoogleDialogflowCxWebhook#request_headers}
RequestHeaders *map[string]*string `field:"optional" json:"requestHeaders" yaml:"requestHeaders"`
}
type GoogleDialogflowCxWebhookServiceDirectoryGenericWebServiceOutputReference ¶
type GoogleDialogflowCxWebhookServiceDirectoryGenericWebServiceOutputReference interface {
cdktf.ComplexObject
AllowedCaCerts() *[]*string
SetAllowedCaCerts(val *[]*string)
AllowedCaCertsInput() *[]*string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleDialogflowCxWebhookServiceDirectoryGenericWebService
SetInternalValue(val *GoogleDialogflowCxWebhookServiceDirectoryGenericWebService)
RequestHeaders() *map[string]*string
SetRequestHeaders(val *map[string]*string)
RequestHeadersInput() *map[string]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Uri() *string
SetUri(val *string)
UriInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetAllowedCaCerts()
ResetRequestHeaders()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleDialogflowCxWebhookServiceDirectoryGenericWebServiceOutputReference ¶
func NewGoogleDialogflowCxWebhookServiceDirectoryGenericWebServiceOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleDialogflowCxWebhookServiceDirectoryGenericWebServiceOutputReference
type GoogleDialogflowCxWebhookServiceDirectoryOutputReference ¶
type GoogleDialogflowCxWebhookServiceDirectoryOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
GenericWebService() GoogleDialogflowCxWebhookServiceDirectoryGenericWebServiceOutputReference
GenericWebServiceInput() *GoogleDialogflowCxWebhookServiceDirectoryGenericWebService
InternalValue() *GoogleDialogflowCxWebhookServiceDirectory
SetInternalValue(val *GoogleDialogflowCxWebhookServiceDirectory)
Service() *string
SetService(val *string)
ServiceInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutGenericWebService(value *GoogleDialogflowCxWebhookServiceDirectoryGenericWebService)
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleDialogflowCxWebhookServiceDirectoryOutputReference ¶
func NewGoogleDialogflowCxWebhookServiceDirectoryOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleDialogflowCxWebhookServiceDirectoryOutputReference
type GoogleDialogflowCxWebhookTimeouts ¶
type GoogleDialogflowCxWebhookTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_dialogflow_cx_webhook#create GoogleDialogflowCxWebhook#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_dialogflow_cx_webhook#delete GoogleDialogflowCxWebhook#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_dialogflow_cx_webhook#update GoogleDialogflowCxWebhook#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type GoogleDialogflowCxWebhookTimeoutsOutputReference ¶
type GoogleDialogflowCxWebhookTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleDialogflowCxWebhookTimeoutsOutputReference ¶
func NewGoogleDialogflowCxWebhookTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleDialogflowCxWebhookTimeoutsOutputReference
Source Files
¶
- GoogleDialogflowCxWebhook.go
- GoogleDialogflowCxWebhookConfig.go
- GoogleDialogflowCxWebhookGenericWebService.go
- GoogleDialogflowCxWebhookGenericWebServiceOutputReference.go
- GoogleDialogflowCxWebhookGenericWebServiceOutputReference__checks.go
- GoogleDialogflowCxWebhookServiceDirectory.go
- GoogleDialogflowCxWebhookServiceDirectoryGenericWebService.go
- GoogleDialogflowCxWebhookServiceDirectoryGenericWebServiceOutputReference.go
- GoogleDialogflowCxWebhookServiceDirectoryGenericWebServiceOutputReference__checks.go
- GoogleDialogflowCxWebhookServiceDirectoryOutputReference.go
- GoogleDialogflowCxWebhookServiceDirectoryOutputReference__checks.go
- GoogleDialogflowCxWebhookTimeouts.go
- GoogleDialogflowCxWebhookTimeoutsOutputReference.go
- GoogleDialogflowCxWebhookTimeoutsOutputReference__checks.go
- GoogleDialogflowCxWebhook__checks.go
- main.go