Documentation
¶
Index ¶
- func GoogleLoggingFolderExclusion_IsConstruct(x interface{}) *bool
- func GoogleLoggingFolderExclusion_IsTerraformElement(x interface{}) *bool
- func GoogleLoggingFolderExclusion_IsTerraformResource(x interface{}) *bool
- func GoogleLoggingFolderExclusion_TfResourceType() *string
- func NewGoogleLoggingFolderExclusion_Override(g GoogleLoggingFolderExclusion, scope constructs.Construct, id *string, ...)
- type GoogleLoggingFolderExclusion
- type GoogleLoggingFolderExclusionConfig
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleLoggingFolderExclusion_IsConstruct ¶
func GoogleLoggingFolderExclusion_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleLoggingFolderExclusion_IsTerraformElement ¶
func GoogleLoggingFolderExclusion_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleLoggingFolderExclusion_IsTerraformResource ¶
func GoogleLoggingFolderExclusion_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleLoggingFolderExclusion_TfResourceType ¶
func GoogleLoggingFolderExclusion_TfResourceType() *string
func NewGoogleLoggingFolderExclusion_Override ¶
func NewGoogleLoggingFolderExclusion_Override(g GoogleLoggingFolderExclusion, scope constructs.Construct, id *string, config *GoogleLoggingFolderExclusionConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_logging_folder_exclusion google_logging_folder_exclusion} Resource.
Types ¶
type GoogleLoggingFolderExclusion ¶
type GoogleLoggingFolderExclusion interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
Disabled() interface{}
SetDisabled(val interface{})
DisabledInput() interface{}
Filter() *string
SetFilter(val *string)
FilterInput() *string
Folder() *string
SetFolder(val *string)
FolderInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetDescription()
ResetDisabled()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_logging_folder_exclusion google_logging_folder_exclusion}.
func NewGoogleLoggingFolderExclusion ¶
func NewGoogleLoggingFolderExclusion(scope constructs.Construct, id *string, config *GoogleLoggingFolderExclusionConfig) GoogleLoggingFolderExclusion
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_logging_folder_exclusion google_logging_folder_exclusion} Resource.
type GoogleLoggingFolderExclusionConfig ¶
type GoogleLoggingFolderExclusionConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// The filter to apply when excluding logs. Only log entries that match the filter are excluded.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_logging_folder_exclusion#filter GoogleLoggingFolderExclusion#filter}
Filter *string `field:"required" json:"filter" yaml:"filter"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_logging_folder_exclusion#folder GoogleLoggingFolderExclusion#folder}.
Folder *string `field:"required" json:"folder" yaml:"folder"`
// The name of the logging exclusion.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_logging_folder_exclusion#name GoogleLoggingFolderExclusion#name}
Name *string `field:"required" json:"name" yaml:"name"`
// A human-readable description.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_logging_folder_exclusion#description GoogleLoggingFolderExclusion#description}
Description *string `field:"optional" json:"description" yaml:"description"`
// Whether this exclusion rule should be disabled or not. This defaults to false.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_logging_folder_exclusion#disabled GoogleLoggingFolderExclusion#disabled}
Disabled interface{} `field:"optional" json:"disabled" yaml:"disabled"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_logging_folder_exclusion#id GoogleLoggingFolderExclusion#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
}