Documentation
¶
Index ¶
- func GoogleSecretManagerSecret_IsConstruct(x interface{}) *bool
- func GoogleSecretManagerSecret_IsTerraformElement(x interface{}) *bool
- func GoogleSecretManagerSecret_IsTerraformResource(x interface{}) *bool
- func GoogleSecretManagerSecret_TfResourceType() *string
- func NewGoogleSecretManagerSecretReplicationAutoCustomerManagedEncryptionOutputReference_Override(...)
- func NewGoogleSecretManagerSecretReplicationAutoOutputReference_Override(g GoogleSecretManagerSecretReplicationAutoOutputReference, ...)
- func NewGoogleSecretManagerSecretReplicationOutputReference_Override(g GoogleSecretManagerSecretReplicationOutputReference, ...)
- func NewGoogleSecretManagerSecretReplicationUserManagedOutputReference_Override(g GoogleSecretManagerSecretReplicationUserManagedOutputReference, ...)
- func NewGoogleSecretManagerSecretReplicationUserManagedReplicasCustomerManagedEncryptionOutputReference_Override(...)
- func NewGoogleSecretManagerSecretReplicationUserManagedReplicasList_Override(g GoogleSecretManagerSecretReplicationUserManagedReplicasList, ...)
- func NewGoogleSecretManagerSecretReplicationUserManagedReplicasOutputReference_Override(g GoogleSecretManagerSecretReplicationUserManagedReplicasOutputReference, ...)
- func NewGoogleSecretManagerSecretRotationOutputReference_Override(g GoogleSecretManagerSecretRotationOutputReference, ...)
- func NewGoogleSecretManagerSecretTimeoutsOutputReference_Override(g GoogleSecretManagerSecretTimeoutsOutputReference, ...)
- func NewGoogleSecretManagerSecretTopicsList_Override(g GoogleSecretManagerSecretTopicsList, ...)
- func NewGoogleSecretManagerSecretTopicsOutputReference_Override(g GoogleSecretManagerSecretTopicsOutputReference, ...)
- func NewGoogleSecretManagerSecret_Override(g GoogleSecretManagerSecret, scope constructs.Construct, id *string, ...)
- type GoogleSecretManagerSecret
- type GoogleSecretManagerSecretConfig
- type GoogleSecretManagerSecretReplication
- type GoogleSecretManagerSecretReplicationAuto
- type GoogleSecretManagerSecretReplicationAutoCustomerManagedEncryption
- type GoogleSecretManagerSecretReplicationAutoCustomerManagedEncryptionOutputReference
- type GoogleSecretManagerSecretReplicationAutoOutputReference
- type GoogleSecretManagerSecretReplicationOutputReference
- type GoogleSecretManagerSecretReplicationUserManaged
- type GoogleSecretManagerSecretReplicationUserManagedOutputReference
- type GoogleSecretManagerSecretReplicationUserManagedReplicas
- type GoogleSecretManagerSecretReplicationUserManagedReplicasCustomerManagedEncryption
- type GoogleSecretManagerSecretReplicationUserManagedReplicasCustomerManagedEncryptionOutputReference
- type GoogleSecretManagerSecretReplicationUserManagedReplicasList
- type GoogleSecretManagerSecretReplicationUserManagedReplicasOutputReference
- type GoogleSecretManagerSecretRotation
- type GoogleSecretManagerSecretRotationOutputReference
- type GoogleSecretManagerSecretTimeouts
- type GoogleSecretManagerSecretTimeoutsOutputReference
- type GoogleSecretManagerSecretTopics
- type GoogleSecretManagerSecretTopicsList
- type GoogleSecretManagerSecretTopicsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleSecretManagerSecret_IsConstruct ¶
func GoogleSecretManagerSecret_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleSecretManagerSecret_IsTerraformElement ¶
func GoogleSecretManagerSecret_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleSecretManagerSecret_IsTerraformResource ¶
func GoogleSecretManagerSecret_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleSecretManagerSecret_TfResourceType ¶
func GoogleSecretManagerSecret_TfResourceType() *string
func NewGoogleSecretManagerSecretReplicationAutoCustomerManagedEncryptionOutputReference_Override ¶
func NewGoogleSecretManagerSecretReplicationAutoCustomerManagedEncryptionOutputReference_Override(g GoogleSecretManagerSecretReplicationAutoCustomerManagedEncryptionOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleSecretManagerSecretReplicationAutoOutputReference_Override ¶
func NewGoogleSecretManagerSecretReplicationAutoOutputReference_Override(g GoogleSecretManagerSecretReplicationAutoOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleSecretManagerSecretReplicationOutputReference_Override ¶
func NewGoogleSecretManagerSecretReplicationOutputReference_Override(g GoogleSecretManagerSecretReplicationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleSecretManagerSecretReplicationUserManagedOutputReference_Override ¶
func NewGoogleSecretManagerSecretReplicationUserManagedOutputReference_Override(g GoogleSecretManagerSecretReplicationUserManagedOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleSecretManagerSecretReplicationUserManagedReplicasCustomerManagedEncryptionOutputReference_Override ¶
func NewGoogleSecretManagerSecretReplicationUserManagedReplicasCustomerManagedEncryptionOutputReference_Override(g GoogleSecretManagerSecretReplicationUserManagedReplicasCustomerManagedEncryptionOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleSecretManagerSecretReplicationUserManagedReplicasList_Override ¶
func NewGoogleSecretManagerSecretReplicationUserManagedReplicasList_Override(g GoogleSecretManagerSecretReplicationUserManagedReplicasList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGoogleSecretManagerSecretReplicationUserManagedReplicasOutputReference_Override ¶
func NewGoogleSecretManagerSecretReplicationUserManagedReplicasOutputReference_Override(g GoogleSecretManagerSecretReplicationUserManagedReplicasOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGoogleSecretManagerSecretRotationOutputReference_Override ¶
func NewGoogleSecretManagerSecretRotationOutputReference_Override(g GoogleSecretManagerSecretRotationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleSecretManagerSecretTimeoutsOutputReference_Override ¶
func NewGoogleSecretManagerSecretTimeoutsOutputReference_Override(g GoogleSecretManagerSecretTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleSecretManagerSecretTopicsList_Override ¶
func NewGoogleSecretManagerSecretTopicsList_Override(g GoogleSecretManagerSecretTopicsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGoogleSecretManagerSecretTopicsOutputReference_Override ¶
func NewGoogleSecretManagerSecretTopicsOutputReference_Override(g GoogleSecretManagerSecretTopicsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGoogleSecretManagerSecret_Override ¶
func NewGoogleSecretManagerSecret_Override(g GoogleSecretManagerSecret, scope constructs.Construct, id *string, config *GoogleSecretManagerSecretConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_secret_manager_secret google_secret_manager_secret} Resource.
Types ¶
type GoogleSecretManagerSecret ¶
type GoogleSecretManagerSecret interface {
cdktf.TerraformResource
Annotations() *map[string]*string
SetAnnotations(val *map[string]*string)
AnnotationsInput() *map[string]*string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
CreateTime() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
EffectiveAnnotations() cdktf.StringMap
EffectiveLabels() cdktf.StringMap
ExpireTime() *string
SetExpireTime(val *string)
ExpireTimeInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
Labels() *map[string]*string
SetLabels(val *map[string]*string)
LabelsInput() *map[string]*string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
// The tree node.
Node() constructs.Node
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Replication() GoogleSecretManagerSecretReplicationOutputReference
ReplicationInput() *GoogleSecretManagerSecretReplication
Rotation() GoogleSecretManagerSecretRotationOutputReference
RotationInput() *GoogleSecretManagerSecretRotation
SecretId() *string
SetSecretId(val *string)
SecretIdInput() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
TerraformLabels() cdktf.StringMap
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GoogleSecretManagerSecretTimeoutsOutputReference
TimeoutsInput() interface{}
Topics() GoogleSecretManagerSecretTopicsList
TopicsInput() interface{}
Ttl() *string
SetTtl(val *string)
TtlInput() *string
VersionAliases() *map[string]*string
SetVersionAliases(val *map[string]*string)
VersionAliasesInput() *map[string]*string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutReplication(value *GoogleSecretManagerSecretReplication)
PutRotation(value *GoogleSecretManagerSecretRotation)
PutTimeouts(value *GoogleSecretManagerSecretTimeouts)
PutTopics(value interface{})
ResetAnnotations()
ResetExpireTime()
ResetId()
ResetLabels()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
ResetRotation()
ResetTimeouts()
ResetTopics()
ResetTtl()
ResetVersionAliases()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_secret_manager_secret google_secret_manager_secret}.
func NewGoogleSecretManagerSecret ¶
func NewGoogleSecretManagerSecret(scope constructs.Construct, id *string, config *GoogleSecretManagerSecretConfig) GoogleSecretManagerSecret
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_secret_manager_secret google_secret_manager_secret} Resource.
type GoogleSecretManagerSecretConfig ¶
type GoogleSecretManagerSecretConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// replication block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_secret_manager_secret#replication GoogleSecretManagerSecret#replication}
Replication *GoogleSecretManagerSecretReplication `field:"required" json:"replication" yaml:"replication"`
// This must be unique within the project.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_secret_manager_secret#secret_id GoogleSecretManagerSecret#secret_id}
SecretId *string `field:"required" json:"secretId" yaml:"secretId"`
// Custom metadata about the secret.
//
// Annotations are distinct from various forms of labels. Annotations exist to allow
// client tools to store their own state information without requiring a database.
//
// Annotation keys must be between 1 and 63 characters long, have a UTF-8 encoding of
// maximum 128 bytes, begin and end with an alphanumeric character ([a-z0-9A-Z]), and
// may have dashes (-), underscores (_), dots (.), and alphanumerics in between these
// symbols.
//
// The total size of annotation keys and values must be less than 16KiB.
//
// An object containing a list of "key": value pairs. Example:
// { "name": "wrench", "mass": "1.3kg", "count": "3" }.
//
//
// **Note**: This field is non-authoritative, and will only manage the annotations present in your configuration.
// Please refer to the field 'effective_annotations' for all of the annotations present on the resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_secret_manager_secret#annotations GoogleSecretManagerSecret#annotations}
Annotations *map[string]*string `field:"optional" json:"annotations" yaml:"annotations"`
// Timestamp in UTC when the Secret is scheduled to expire.
//
// This is always provided on output, regardless of what was sent on input.
// A timestamp in RFC3339 UTC "Zulu" format, with nanosecond resolution and up to nine fractional digits. Examples: "2014-10-02T15:01:23Z" and "2014-10-02T15:01:23.045123456Z".
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_secret_manager_secret#expire_time GoogleSecretManagerSecret#expire_time}
ExpireTime *string `field:"optional" json:"expireTime" yaml:"expireTime"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_secret_manager_secret#id GoogleSecretManagerSecret#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// The labels assigned to this Secret.
//
// Label keys must be between 1 and 63 characters long, have a UTF-8 encoding of maximum 128 bytes,
// and must conform to the following PCRE regular expression: [\p{Ll}\p{Lo}][\p{Ll}\p{Lo}\p{N}_-]{0,62}
//
// Label values must be between 0 and 63 characters long, have a UTF-8 encoding of maximum 128 bytes,
// and must conform to the following PCRE regular expression: [\p{Ll}\p{Lo}\p{N}_-]{0,63}
//
// No more than 64 labels can be assigned to a given resource.
//
// An object containing a list of "key": value pairs. Example:
// { "name": "wrench", "mass": "1.3kg", "count": "3" }.
//
//
// **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
// Please refer to the field 'effective_labels' for all of the labels present on the resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_secret_manager_secret#labels GoogleSecretManagerSecret#labels}
Labels *map[string]*string `field:"optional" json:"labels" yaml:"labels"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_secret_manager_secret#project GoogleSecretManagerSecret#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// rotation block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_secret_manager_secret#rotation GoogleSecretManagerSecret#rotation}
Rotation *GoogleSecretManagerSecretRotation `field:"optional" json:"rotation" yaml:"rotation"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_secret_manager_secret#timeouts GoogleSecretManagerSecret#timeouts}
Timeouts *GoogleSecretManagerSecretTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
// topics block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_secret_manager_secret#topics GoogleSecretManagerSecret#topics}
Topics interface{} `field:"optional" json:"topics" yaml:"topics"`
// The TTL for the Secret. A duration in seconds with up to nine fractional digits, terminated by 's'. Example: "3.5s".
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_secret_manager_secret#ttl GoogleSecretManagerSecret#ttl}
Ttl *string `field:"optional" json:"ttl" yaml:"ttl"`
// Mapping from version alias to version name.
//
// A version alias is a string with a maximum length of 63 characters and can contain
// uppercase and lowercase letters, numerals, and the hyphen (-) and underscore ('_')
// characters. An alias string must start with a letter and cannot be the string
// 'latest' or 'NEW'. No more than 50 aliases can be assigned to a given secret.
//
// An object containing a list of "key": value pairs. Example:
// { "name": "wrench", "mass": "1.3kg", "count": "3" }.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_secret_manager_secret#version_aliases GoogleSecretManagerSecret#version_aliases}
VersionAliases *map[string]*string `field:"optional" json:"versionAliases" yaml:"versionAliases"`
}
type GoogleSecretManagerSecretReplication ¶
type GoogleSecretManagerSecretReplication struct {
// auto block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_secret_manager_secret#auto GoogleSecretManagerSecret#auto}
Auto *GoogleSecretManagerSecretReplicationAuto `field:"optional" json:"auto" yaml:"auto"`
// user_managed block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_secret_manager_secret#user_managed GoogleSecretManagerSecret#user_managed}
UserManaged *GoogleSecretManagerSecretReplicationUserManaged `field:"optional" json:"userManaged" yaml:"userManaged"`
}
type GoogleSecretManagerSecretReplicationAuto ¶
type GoogleSecretManagerSecretReplicationAuto struct {
// customer_managed_encryption block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_secret_manager_secret#customer_managed_encryption GoogleSecretManagerSecret#customer_managed_encryption}
CustomerManagedEncryption *GoogleSecretManagerSecretReplicationAutoCustomerManagedEncryption `field:"optional" json:"customerManagedEncryption" yaml:"customerManagedEncryption"`
}
type GoogleSecretManagerSecretReplicationAutoCustomerManagedEncryption ¶
type GoogleSecretManagerSecretReplicationAutoCustomerManagedEncryption struct {
// The resource name of the Cloud KMS CryptoKey used to encrypt secret payloads.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_secret_manager_secret#kms_key_name GoogleSecretManagerSecret#kms_key_name}
KmsKeyName *string `field:"required" json:"kmsKeyName" yaml:"kmsKeyName"`
}
type GoogleSecretManagerSecretReplicationAutoCustomerManagedEncryptionOutputReference ¶
type GoogleSecretManagerSecretReplicationAutoCustomerManagedEncryptionOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleSecretManagerSecretReplicationAutoCustomerManagedEncryption
SetInternalValue(val *GoogleSecretManagerSecretReplicationAutoCustomerManagedEncryption)
KmsKeyName() *string
SetKmsKeyName(val *string)
KmsKeyNameInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleSecretManagerSecretReplicationAutoCustomerManagedEncryptionOutputReference ¶
func NewGoogleSecretManagerSecretReplicationAutoCustomerManagedEncryptionOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleSecretManagerSecretReplicationAutoCustomerManagedEncryptionOutputReference
type GoogleSecretManagerSecretReplicationAutoOutputReference ¶
type GoogleSecretManagerSecretReplicationAutoOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
CustomerManagedEncryption() GoogleSecretManagerSecretReplicationAutoCustomerManagedEncryptionOutputReference
CustomerManagedEncryptionInput() *GoogleSecretManagerSecretReplicationAutoCustomerManagedEncryption
// Experimental.
Fqn() *string
InternalValue() *GoogleSecretManagerSecretReplicationAuto
SetInternalValue(val *GoogleSecretManagerSecretReplicationAuto)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutCustomerManagedEncryption(value *GoogleSecretManagerSecretReplicationAutoCustomerManagedEncryption)
ResetCustomerManagedEncryption()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleSecretManagerSecretReplicationAutoOutputReference ¶
func NewGoogleSecretManagerSecretReplicationAutoOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleSecretManagerSecretReplicationAutoOutputReference
type GoogleSecretManagerSecretReplicationOutputReference ¶
type GoogleSecretManagerSecretReplicationOutputReference interface {
cdktf.ComplexObject
Auto() GoogleSecretManagerSecretReplicationAutoOutputReference
AutoInput() *GoogleSecretManagerSecretReplicationAuto
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleSecretManagerSecretReplication
SetInternalValue(val *GoogleSecretManagerSecretReplication)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
UserManaged() GoogleSecretManagerSecretReplicationUserManagedOutputReference
UserManagedInput() *GoogleSecretManagerSecretReplicationUserManaged
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutAuto(value *GoogleSecretManagerSecretReplicationAuto)
PutUserManaged(value *GoogleSecretManagerSecretReplicationUserManaged)
ResetAuto()
ResetUserManaged()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleSecretManagerSecretReplicationOutputReference ¶
func NewGoogleSecretManagerSecretReplicationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleSecretManagerSecretReplicationOutputReference
type GoogleSecretManagerSecretReplicationUserManaged ¶
type GoogleSecretManagerSecretReplicationUserManaged struct {
// replicas block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_secret_manager_secret#replicas GoogleSecretManagerSecret#replicas}
Replicas interface{} `field:"required" json:"replicas" yaml:"replicas"`
}
type GoogleSecretManagerSecretReplicationUserManagedOutputReference ¶
type GoogleSecretManagerSecretReplicationUserManagedOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleSecretManagerSecretReplicationUserManaged
SetInternalValue(val *GoogleSecretManagerSecretReplicationUserManaged)
Replicas() GoogleSecretManagerSecretReplicationUserManagedReplicasList
ReplicasInput() interface{}
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutReplicas(value interface{})
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleSecretManagerSecretReplicationUserManagedOutputReference ¶
func NewGoogleSecretManagerSecretReplicationUserManagedOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleSecretManagerSecretReplicationUserManagedOutputReference
type GoogleSecretManagerSecretReplicationUserManagedReplicas ¶
type GoogleSecretManagerSecretReplicationUserManagedReplicas struct {
// The canonical IDs of the location to replicate data. For example: "us-east1".
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_secret_manager_secret#location GoogleSecretManagerSecret#location}
Location *string `field:"required" json:"location" yaml:"location"`
// customer_managed_encryption block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_secret_manager_secret#customer_managed_encryption GoogleSecretManagerSecret#customer_managed_encryption}
CustomerManagedEncryption *GoogleSecretManagerSecretReplicationUserManagedReplicasCustomerManagedEncryption `field:"optional" json:"customerManagedEncryption" yaml:"customerManagedEncryption"`
}
type GoogleSecretManagerSecretReplicationUserManagedReplicasCustomerManagedEncryption ¶
type GoogleSecretManagerSecretReplicationUserManagedReplicasCustomerManagedEncryption struct {
// Describes the Cloud KMS encryption key that will be used to protect destination secret.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_secret_manager_secret#kms_key_name GoogleSecretManagerSecret#kms_key_name}
KmsKeyName *string `field:"required" json:"kmsKeyName" yaml:"kmsKeyName"`
}
type GoogleSecretManagerSecretReplicationUserManagedReplicasCustomerManagedEncryptionOutputReference ¶
type GoogleSecretManagerSecretReplicationUserManagedReplicasCustomerManagedEncryptionOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleSecretManagerSecretReplicationUserManagedReplicasCustomerManagedEncryption
SetInternalValue(val *GoogleSecretManagerSecretReplicationUserManagedReplicasCustomerManagedEncryption)
KmsKeyName() *string
SetKmsKeyName(val *string)
KmsKeyNameInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleSecretManagerSecretReplicationUserManagedReplicasCustomerManagedEncryptionOutputReference ¶
func NewGoogleSecretManagerSecretReplicationUserManagedReplicasCustomerManagedEncryptionOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleSecretManagerSecretReplicationUserManagedReplicasCustomerManagedEncryptionOutputReference
type GoogleSecretManagerSecretReplicationUserManagedReplicasList ¶
type GoogleSecretManagerSecretReplicationUserManagedReplicasList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) GoogleSecretManagerSecretReplicationUserManagedReplicasOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleSecretManagerSecretReplicationUserManagedReplicasList ¶
func NewGoogleSecretManagerSecretReplicationUserManagedReplicasList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GoogleSecretManagerSecretReplicationUserManagedReplicasList
type GoogleSecretManagerSecretReplicationUserManagedReplicasOutputReference ¶
type GoogleSecretManagerSecretReplicationUserManagedReplicasOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
CustomerManagedEncryption() GoogleSecretManagerSecretReplicationUserManagedReplicasCustomerManagedEncryptionOutputReference
CustomerManagedEncryptionInput() *GoogleSecretManagerSecretReplicationUserManagedReplicasCustomerManagedEncryption
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Location() *string
SetLocation(val *string)
LocationInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutCustomerManagedEncryption(value *GoogleSecretManagerSecretReplicationUserManagedReplicasCustomerManagedEncryption)
ResetCustomerManagedEncryption()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleSecretManagerSecretReplicationUserManagedReplicasOutputReference ¶
func NewGoogleSecretManagerSecretReplicationUserManagedReplicasOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GoogleSecretManagerSecretReplicationUserManagedReplicasOutputReference
type GoogleSecretManagerSecretRotation ¶
type GoogleSecretManagerSecretRotation struct {
// Timestamp in UTC at which the Secret is scheduled to rotate.
//
// A timestamp in RFC3339 UTC "Zulu" format, with nanosecond resolution and up to nine fractional digits. Examples: "2014-10-02T15:01:23Z" and "2014-10-02T15:01:23.045123456Z".
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_secret_manager_secret#next_rotation_time GoogleSecretManagerSecret#next_rotation_time}
NextRotationTime *string `field:"optional" json:"nextRotationTime" yaml:"nextRotationTime"`
// The Duration between rotation notifications.
//
// Must be in seconds and at least 3600s (1h) and at most 3153600000s (100 years).
// If rotationPeriod is set, 'next_rotation_time' must be set. 'next_rotation_time' will be advanced by this period when the service automatically sends rotation notifications.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_secret_manager_secret#rotation_period GoogleSecretManagerSecret#rotation_period}
RotationPeriod *string `field:"optional" json:"rotationPeriod" yaml:"rotationPeriod"`
}
type GoogleSecretManagerSecretRotationOutputReference ¶
type GoogleSecretManagerSecretRotationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleSecretManagerSecretRotation
SetInternalValue(val *GoogleSecretManagerSecretRotation)
NextRotationTime() *string
SetNextRotationTime(val *string)
NextRotationTimeInput() *string
RotationPeriod() *string
SetRotationPeriod(val *string)
RotationPeriodInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetNextRotationTime()
ResetRotationPeriod()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleSecretManagerSecretRotationOutputReference ¶
func NewGoogleSecretManagerSecretRotationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleSecretManagerSecretRotationOutputReference
type GoogleSecretManagerSecretTimeouts ¶
type GoogleSecretManagerSecretTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_secret_manager_secret#create GoogleSecretManagerSecret#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_secret_manager_secret#delete GoogleSecretManagerSecret#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_secret_manager_secret#update GoogleSecretManagerSecret#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type GoogleSecretManagerSecretTimeoutsOutputReference ¶
type GoogleSecretManagerSecretTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleSecretManagerSecretTimeoutsOutputReference ¶
func NewGoogleSecretManagerSecretTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleSecretManagerSecretTimeoutsOutputReference
type GoogleSecretManagerSecretTopics ¶
type GoogleSecretManagerSecretTopics struct {
// The resource name of the Pub/Sub topic that will be published to, in the following format: projects/* /topics/*.
//
// For publication to succeed, the Secret Manager Service Agent service account must have pubsub.publisher permissions on the topic.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.2.0/docs/resources/google_secret_manager_secret#name GoogleSecretManagerSecret#name}
//
// Note: The above comment contained a comment block ending sequence (* followed by /). We have introduced a space between to prevent syntax errors. Please ignore the space.
Name *string `field:"required" json:"name" yaml:"name"`
}
type GoogleSecretManagerSecretTopicsList ¶
type GoogleSecretManagerSecretTopicsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) GoogleSecretManagerSecretTopicsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleSecretManagerSecretTopicsList ¶
func NewGoogleSecretManagerSecretTopicsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GoogleSecretManagerSecretTopicsList
type GoogleSecretManagerSecretTopicsOutputReference ¶
type GoogleSecretManagerSecretTopicsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Name() *string
SetName(val *string)
NameInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleSecretManagerSecretTopicsOutputReference ¶
func NewGoogleSecretManagerSecretTopicsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GoogleSecretManagerSecretTopicsOutputReference
Source Files
¶
- GoogleSecretManagerSecret.go
- GoogleSecretManagerSecretConfig.go
- GoogleSecretManagerSecretReplication.go
- GoogleSecretManagerSecretReplicationAuto.go
- GoogleSecretManagerSecretReplicationAutoCustomerManagedEncryption.go
- GoogleSecretManagerSecretReplicationAutoCustomerManagedEncryptionOutputReference.go
- GoogleSecretManagerSecretReplicationAutoCustomerManagedEncryptionOutputReference__checks.go
- GoogleSecretManagerSecretReplicationAutoOutputReference.go
- GoogleSecretManagerSecretReplicationAutoOutputReference__checks.go
- GoogleSecretManagerSecretReplicationOutputReference.go
- GoogleSecretManagerSecretReplicationOutputReference__checks.go
- GoogleSecretManagerSecretReplicationUserManaged.go
- GoogleSecretManagerSecretReplicationUserManagedOutputReference.go
- GoogleSecretManagerSecretReplicationUserManagedOutputReference__checks.go
- GoogleSecretManagerSecretReplicationUserManagedReplicas.go
- GoogleSecretManagerSecretReplicationUserManagedReplicasCustomerManagedEncryption.go
- GoogleSecretManagerSecretReplicationUserManagedReplicasCustomerManagedEncryptionOutputReference.go
- GoogleSecretManagerSecretReplicationUserManagedReplicasCustomerManagedEncryptionOutputReference__checks.go
- GoogleSecretManagerSecretReplicationUserManagedReplicasList.go
- GoogleSecretManagerSecretReplicationUserManagedReplicasList__checks.go
- GoogleSecretManagerSecretReplicationUserManagedReplicasOutputReference.go
- GoogleSecretManagerSecretReplicationUserManagedReplicasOutputReference__checks.go
- GoogleSecretManagerSecretRotation.go
- GoogleSecretManagerSecretRotationOutputReference.go
- GoogleSecretManagerSecretRotationOutputReference__checks.go
- GoogleSecretManagerSecretTimeouts.go
- GoogleSecretManagerSecretTimeoutsOutputReference.go
- GoogleSecretManagerSecretTimeoutsOutputReference__checks.go
- GoogleSecretManagerSecretTopics.go
- GoogleSecretManagerSecretTopicsList.go
- GoogleSecretManagerSecretTopicsList__checks.go
- GoogleSecretManagerSecretTopicsOutputReference.go
- GoogleSecretManagerSecretTopicsOutputReference__checks.go
- GoogleSecretManagerSecret__checks.go
- main.go