Documentation
¶
Index ¶
- func DataGoogleKmsSecretAsymmetric_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func DataGoogleKmsSecretAsymmetric_IsConstruct(x interface{}) *bool
- func DataGoogleKmsSecretAsymmetric_IsTerraformDataSource(x interface{}) *bool
- func DataGoogleKmsSecretAsymmetric_IsTerraformElement(x interface{}) *bool
- func DataGoogleKmsSecretAsymmetric_TfResourceType() *string
- func NewDataGoogleKmsSecretAsymmetric_Override(d DataGoogleKmsSecretAsymmetric, scope constructs.Construct, id *string, ...)
- type DataGoogleKmsSecretAsymmetric
- type DataGoogleKmsSecretAsymmetricConfig
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataGoogleKmsSecretAsymmetric_GenerateConfigForImport ¶
func DataGoogleKmsSecretAsymmetric_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a DataGoogleKmsSecretAsymmetric resource upon running "cdktf plan <stack-name>".
func DataGoogleKmsSecretAsymmetric_IsConstruct ¶
func DataGoogleKmsSecretAsymmetric_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataGoogleKmsSecretAsymmetric_IsTerraformDataSource ¶
func DataGoogleKmsSecretAsymmetric_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataGoogleKmsSecretAsymmetric_IsTerraformElement ¶
func DataGoogleKmsSecretAsymmetric_IsTerraformElement(x interface{}) *bool
Experimental.
func DataGoogleKmsSecretAsymmetric_TfResourceType ¶
func DataGoogleKmsSecretAsymmetric_TfResourceType() *string
func NewDataGoogleKmsSecretAsymmetric_Override ¶
func NewDataGoogleKmsSecretAsymmetric_Override(d DataGoogleKmsSecretAsymmetric, scope constructs.Construct, id *string, config *DataGoogleKmsSecretAsymmetricConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/data-sources/google_kms_secret_asymmetric google_kms_secret_asymmetric} Data Source.
Types ¶
type DataGoogleKmsSecretAsymmetric ¶
type DataGoogleKmsSecretAsymmetric interface {
cdktf.TerraformDataSource
// Experimental.
CdktfStack() cdktf.TerraformStack
Ciphertext() *string
SetCiphertext(val *string)
CiphertextInput() *string
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
Crc32() *string
SetCrc32(val *string)
Crc32Input() *string
CryptoKeyVersion() *string
SetCryptoKeyVersion(val *string)
CryptoKeyVersionInput() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
Plaintext() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetCrc32()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/data-sources/google_kms_secret_asymmetric google_kms_secret_asymmetric}.
func NewDataGoogleKmsSecretAsymmetric ¶
func NewDataGoogleKmsSecretAsymmetric(scope constructs.Construct, id *string, config *DataGoogleKmsSecretAsymmetricConfig) DataGoogleKmsSecretAsymmetric
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/data-sources/google_kms_secret_asymmetric google_kms_secret_asymmetric} Data Source.
type DataGoogleKmsSecretAsymmetricConfig ¶
type DataGoogleKmsSecretAsymmetricConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// The public key encrypted ciphertext in base64 encoding.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/data-sources/google_kms_secret_asymmetric#ciphertext DataGoogleKmsSecretAsymmetric#ciphertext}
Ciphertext *string `field:"required" json:"ciphertext" yaml:"ciphertext"`
// The fully qualified KMS crypto key version name.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/data-sources/google_kms_secret_asymmetric#crypto_key_version DataGoogleKmsSecretAsymmetric#crypto_key_version}
CryptoKeyVersion *string `field:"required" json:"cryptoKeyVersion" yaml:"cryptoKeyVersion"`
// The crc32 checksum of the ciphertext, hexadecimal encoding. If not specified, it will be computed.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/data-sources/google_kms_secret_asymmetric#crc32 DataGoogleKmsSecretAsymmetric#crc32}
Crc32 *string `field:"optional" json:"crc32" yaml:"crc32"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/data-sources/google_kms_secret_asymmetric#id DataGoogleKmsSecretAsymmetric#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
}