Documentation
¶
Index ¶
- func GoogleApikeysKey_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func GoogleApikeysKey_IsConstruct(x interface{}) *bool
- func GoogleApikeysKey_IsTerraformElement(x interface{}) *bool
- func GoogleApikeysKey_IsTerraformResource(x interface{}) *bool
- func GoogleApikeysKey_TfResourceType() *string
- func NewGoogleApikeysKeyRestrictionsAndroidKeyRestrictionsAllowedApplicationsList_Override(g GoogleApikeysKeyRestrictionsAndroidKeyRestrictionsAllowedApplicationsList, ...)
- func NewGoogleApikeysKeyRestrictionsAndroidKeyRestrictionsAllowedApplicationsOutputReference_Override(...)
- func NewGoogleApikeysKeyRestrictionsAndroidKeyRestrictionsOutputReference_Override(g GoogleApikeysKeyRestrictionsAndroidKeyRestrictionsOutputReference, ...)
- func NewGoogleApikeysKeyRestrictionsApiTargetsList_Override(g GoogleApikeysKeyRestrictionsApiTargetsList, ...)
- func NewGoogleApikeysKeyRestrictionsApiTargetsOutputReference_Override(g GoogleApikeysKeyRestrictionsApiTargetsOutputReference, ...)
- func NewGoogleApikeysKeyRestrictionsBrowserKeyRestrictionsOutputReference_Override(g GoogleApikeysKeyRestrictionsBrowserKeyRestrictionsOutputReference, ...)
- func NewGoogleApikeysKeyRestrictionsIosKeyRestrictionsOutputReference_Override(g GoogleApikeysKeyRestrictionsIosKeyRestrictionsOutputReference, ...)
- func NewGoogleApikeysKeyRestrictionsOutputReference_Override(g GoogleApikeysKeyRestrictionsOutputReference, ...)
- func NewGoogleApikeysKeyRestrictionsServerKeyRestrictionsOutputReference_Override(g GoogleApikeysKeyRestrictionsServerKeyRestrictionsOutputReference, ...)
- func NewGoogleApikeysKeyTimeoutsOutputReference_Override(g GoogleApikeysKeyTimeoutsOutputReference, ...)
- func NewGoogleApikeysKey_Override(g GoogleApikeysKey, scope constructs.Construct, id *string, ...)
- type GoogleApikeysKey
- type GoogleApikeysKeyConfig
- type GoogleApikeysKeyRestrictions
- type GoogleApikeysKeyRestrictionsAndroidKeyRestrictions
- type GoogleApikeysKeyRestrictionsAndroidKeyRestrictionsAllowedApplications
- type GoogleApikeysKeyRestrictionsAndroidKeyRestrictionsAllowedApplicationsList
- type GoogleApikeysKeyRestrictionsAndroidKeyRestrictionsAllowedApplicationsOutputReference
- type GoogleApikeysKeyRestrictionsAndroidKeyRestrictionsOutputReference
- type GoogleApikeysKeyRestrictionsApiTargets
- type GoogleApikeysKeyRestrictionsApiTargetsList
- type GoogleApikeysKeyRestrictionsApiTargetsOutputReference
- type GoogleApikeysKeyRestrictionsBrowserKeyRestrictions
- type GoogleApikeysKeyRestrictionsBrowserKeyRestrictionsOutputReference
- type GoogleApikeysKeyRestrictionsIosKeyRestrictions
- type GoogleApikeysKeyRestrictionsIosKeyRestrictionsOutputReference
- type GoogleApikeysKeyRestrictionsOutputReference
- type GoogleApikeysKeyRestrictionsServerKeyRestrictions
- type GoogleApikeysKeyRestrictionsServerKeyRestrictionsOutputReference
- type GoogleApikeysKeyTimeouts
- type GoogleApikeysKeyTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleApikeysKey_GenerateConfigForImport ¶
func GoogleApikeysKey_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a GoogleApikeysKey resource upon running "cdktf plan <stack-name>".
func GoogleApikeysKey_IsConstruct ¶
func GoogleApikeysKey_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleApikeysKey_IsTerraformElement ¶
func GoogleApikeysKey_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleApikeysKey_IsTerraformResource ¶
func GoogleApikeysKey_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleApikeysKey_TfResourceType ¶
func GoogleApikeysKey_TfResourceType() *string
func NewGoogleApikeysKeyRestrictionsAndroidKeyRestrictionsAllowedApplicationsList_Override ¶
func NewGoogleApikeysKeyRestrictionsAndroidKeyRestrictionsAllowedApplicationsList_Override(g GoogleApikeysKeyRestrictionsAndroidKeyRestrictionsAllowedApplicationsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGoogleApikeysKeyRestrictionsAndroidKeyRestrictionsAllowedApplicationsOutputReference_Override ¶
func NewGoogleApikeysKeyRestrictionsAndroidKeyRestrictionsAllowedApplicationsOutputReference_Override(g GoogleApikeysKeyRestrictionsAndroidKeyRestrictionsAllowedApplicationsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGoogleApikeysKeyRestrictionsAndroidKeyRestrictionsOutputReference_Override ¶
func NewGoogleApikeysKeyRestrictionsAndroidKeyRestrictionsOutputReference_Override(g GoogleApikeysKeyRestrictionsAndroidKeyRestrictionsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleApikeysKeyRestrictionsApiTargetsList_Override ¶
func NewGoogleApikeysKeyRestrictionsApiTargetsList_Override(g GoogleApikeysKeyRestrictionsApiTargetsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGoogleApikeysKeyRestrictionsApiTargetsOutputReference_Override ¶
func NewGoogleApikeysKeyRestrictionsApiTargetsOutputReference_Override(g GoogleApikeysKeyRestrictionsApiTargetsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGoogleApikeysKeyRestrictionsBrowserKeyRestrictionsOutputReference_Override ¶
func NewGoogleApikeysKeyRestrictionsBrowserKeyRestrictionsOutputReference_Override(g GoogleApikeysKeyRestrictionsBrowserKeyRestrictionsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleApikeysKeyRestrictionsIosKeyRestrictionsOutputReference_Override ¶
func NewGoogleApikeysKeyRestrictionsIosKeyRestrictionsOutputReference_Override(g GoogleApikeysKeyRestrictionsIosKeyRestrictionsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleApikeysKeyRestrictionsOutputReference_Override ¶
func NewGoogleApikeysKeyRestrictionsOutputReference_Override(g GoogleApikeysKeyRestrictionsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleApikeysKeyRestrictionsServerKeyRestrictionsOutputReference_Override ¶
func NewGoogleApikeysKeyRestrictionsServerKeyRestrictionsOutputReference_Override(g GoogleApikeysKeyRestrictionsServerKeyRestrictionsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleApikeysKeyTimeoutsOutputReference_Override ¶
func NewGoogleApikeysKeyTimeoutsOutputReference_Override(g GoogleApikeysKeyTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleApikeysKey_Override ¶
func NewGoogleApikeysKey_Override(g GoogleApikeysKey, scope constructs.Construct, id *string, config *GoogleApikeysKeyConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_apikeys_key google_apikeys_key} Resource.
Types ¶
type GoogleApikeysKey ¶
type GoogleApikeysKey interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DisplayName() *string
SetDisplayName(val *string)
DisplayNameInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
KeyString() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Restrictions() GoogleApikeysKeyRestrictionsOutputReference
RestrictionsInput() *GoogleApikeysKeyRestrictions
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GoogleApikeysKeyTimeoutsOutputReference
TimeoutsInput() interface{}
Uid() *string
// Adds a user defined moveTarget string to this resource to be later used in .moveTo(moveTarget) to resolve the location of the move.
// Experimental.
AddMoveTarget(moveTarget *string)
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
HasResourceMove() interface{}
// Experimental.
ImportFrom(id *string, provider cdktf.TerraformProvider)
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Move the resource corresponding to "id" to this resource.
//
// Note that the resource being moved from must be marked as moved using it's instance function.
// Experimental.
MoveFromId(id *string)
// Moves this resource to the target resource given by moveTarget.
// Experimental.
MoveTo(moveTarget *string, index interface{})
// Moves this resource to the resource corresponding to "id".
// Experimental.
MoveToId(id *string)
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutRestrictions(value *GoogleApikeysKeyRestrictions)
PutTimeouts(value *GoogleApikeysKeyTimeouts)
ResetDisplayName()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
ResetRestrictions()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_apikeys_key google_apikeys_key}.
func NewGoogleApikeysKey ¶
func NewGoogleApikeysKey(scope constructs.Construct, id *string, config *GoogleApikeysKeyConfig) GoogleApikeysKey
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_apikeys_key google_apikeys_key} Resource.
type GoogleApikeysKeyConfig ¶
type GoogleApikeysKeyConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// The resource name of the key.
//
// The name must be unique within the project, must conform with RFC-1034, is restricted to lower-cased letters, and has a maximum length of 63 characters. In another word, the name must match the regular expression: `[a-z]([a-z0-9-]{0,61}[a-z0-9])?`.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_apikeys_key#name GoogleApikeysKey#name}
Name *string `field:"required" json:"name" yaml:"name"`
// Human-readable display name of this API key. Modifiable by user.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_apikeys_key#display_name GoogleApikeysKey#display_name}
DisplayName *string `field:"optional" json:"displayName" yaml:"displayName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_apikeys_key#id GoogleApikeysKey#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// The project for the resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_apikeys_key#project GoogleApikeysKey#project}
Project *string `field:"optional" json:"project" yaml:"project"`
// restrictions block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_apikeys_key#restrictions GoogleApikeysKey#restrictions}
Restrictions *GoogleApikeysKeyRestrictions `field:"optional" json:"restrictions" yaml:"restrictions"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_apikeys_key#timeouts GoogleApikeysKey#timeouts}
Timeouts *GoogleApikeysKeyTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type GoogleApikeysKeyRestrictions ¶
type GoogleApikeysKeyRestrictions struct {
// android_key_restrictions block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_apikeys_key#android_key_restrictions GoogleApikeysKey#android_key_restrictions}
AndroidKeyRestrictions *GoogleApikeysKeyRestrictionsAndroidKeyRestrictions `field:"optional" json:"androidKeyRestrictions" yaml:"androidKeyRestrictions"`
// api_targets block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_apikeys_key#api_targets GoogleApikeysKey#api_targets}
ApiTargets interface{} `field:"optional" json:"apiTargets" yaml:"apiTargets"`
// browser_key_restrictions block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_apikeys_key#browser_key_restrictions GoogleApikeysKey#browser_key_restrictions}
BrowserKeyRestrictions *GoogleApikeysKeyRestrictionsBrowserKeyRestrictions `field:"optional" json:"browserKeyRestrictions" yaml:"browserKeyRestrictions"`
// ios_key_restrictions block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_apikeys_key#ios_key_restrictions GoogleApikeysKey#ios_key_restrictions}
IosKeyRestrictions *GoogleApikeysKeyRestrictionsIosKeyRestrictions `field:"optional" json:"iosKeyRestrictions" yaml:"iosKeyRestrictions"`
// server_key_restrictions block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_apikeys_key#server_key_restrictions GoogleApikeysKey#server_key_restrictions}
ServerKeyRestrictions *GoogleApikeysKeyRestrictionsServerKeyRestrictions `field:"optional" json:"serverKeyRestrictions" yaml:"serverKeyRestrictions"`
}
type GoogleApikeysKeyRestrictionsAndroidKeyRestrictions ¶
type GoogleApikeysKeyRestrictionsAndroidKeyRestrictions struct {
// allowed_applications block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_apikeys_key#allowed_applications GoogleApikeysKey#allowed_applications}
AllowedApplications interface{} `field:"required" json:"allowedApplications" yaml:"allowedApplications"`
}
type GoogleApikeysKeyRestrictionsAndroidKeyRestrictionsAllowedApplications ¶
type GoogleApikeysKeyRestrictionsAndroidKeyRestrictionsAllowedApplications struct {
// The package name of the application.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_apikeys_key#package_name GoogleApikeysKey#package_name}
PackageName *string `field:"required" json:"packageName" yaml:"packageName"`
// The SHA1 fingerprint of the application.
//
// For example, both sha1 formats are acceptable : DA:39:A3:EE:5E:6B:4B:0D:32:55:BF:EF:95:60:18:90:AF:D8:07:09 or DA39A3EE5E6B4B0D3255BFEF95601890AFD80709. Output format is the latter.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_apikeys_key#sha1_fingerprint GoogleApikeysKey#sha1_fingerprint}
Sha1Fingerprint *string `field:"required" json:"sha1Fingerprint" yaml:"sha1Fingerprint"`
}
type GoogleApikeysKeyRestrictionsAndroidKeyRestrictionsAllowedApplicationsList ¶
type GoogleApikeysKeyRestrictionsAndroidKeyRestrictionsAllowedApplicationsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) GoogleApikeysKeyRestrictionsAndroidKeyRestrictionsAllowedApplicationsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleApikeysKeyRestrictionsAndroidKeyRestrictionsAllowedApplicationsList ¶
func NewGoogleApikeysKeyRestrictionsAndroidKeyRestrictionsAllowedApplicationsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GoogleApikeysKeyRestrictionsAndroidKeyRestrictionsAllowedApplicationsList
type GoogleApikeysKeyRestrictionsAndroidKeyRestrictionsAllowedApplicationsOutputReference ¶
type GoogleApikeysKeyRestrictionsAndroidKeyRestrictionsAllowedApplicationsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
PackageName() *string
SetPackageName(val *string)
PackageNameInput() *string
Sha1Fingerprint() *string
SetSha1Fingerprint(val *string)
Sha1FingerprintInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleApikeysKeyRestrictionsAndroidKeyRestrictionsAllowedApplicationsOutputReference ¶
func NewGoogleApikeysKeyRestrictionsAndroidKeyRestrictionsAllowedApplicationsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GoogleApikeysKeyRestrictionsAndroidKeyRestrictionsAllowedApplicationsOutputReference
type GoogleApikeysKeyRestrictionsAndroidKeyRestrictionsOutputReference ¶
type GoogleApikeysKeyRestrictionsAndroidKeyRestrictionsOutputReference interface {
cdktf.ComplexObject
AllowedApplications() GoogleApikeysKeyRestrictionsAndroidKeyRestrictionsAllowedApplicationsList
AllowedApplicationsInput() interface{}
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleApikeysKeyRestrictionsAndroidKeyRestrictions
SetInternalValue(val *GoogleApikeysKeyRestrictionsAndroidKeyRestrictions)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutAllowedApplications(value interface{})
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleApikeysKeyRestrictionsAndroidKeyRestrictionsOutputReference ¶
func NewGoogleApikeysKeyRestrictionsAndroidKeyRestrictionsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleApikeysKeyRestrictionsAndroidKeyRestrictionsOutputReference
type GoogleApikeysKeyRestrictionsApiTargets ¶
type GoogleApikeysKeyRestrictionsApiTargets struct {
// The service for this restriction.
//
// It should be the canonical service name, for example: `translate.googleapis.com`. You can use `gcloud services list` to get a list of services that are enabled in the project.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_apikeys_key#service GoogleApikeysKey#service}
Service *string `field:"required" json:"service" yaml:"service"`
// Optional.
//
// List of one or more methods that can be called. If empty, all methods for the service are allowed. A wildcard (*) can be used as the last symbol. Valid examples: `google.cloud.translate.v2.TranslateService.GetSupportedLanguage` `TranslateText` `Get*` `translate.googleapis.com.Get*`
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_apikeys_key#methods GoogleApikeysKey#methods}
Methods *[]*string `field:"optional" json:"methods" yaml:"methods"`
}
type GoogleApikeysKeyRestrictionsApiTargetsList ¶
type GoogleApikeysKeyRestrictionsApiTargetsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) GoogleApikeysKeyRestrictionsApiTargetsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleApikeysKeyRestrictionsApiTargetsList ¶
func NewGoogleApikeysKeyRestrictionsApiTargetsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GoogleApikeysKeyRestrictionsApiTargetsList
type GoogleApikeysKeyRestrictionsApiTargetsOutputReference ¶
type GoogleApikeysKeyRestrictionsApiTargetsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Methods() *[]*string
SetMethods(val *[]*string)
MethodsInput() *[]*string
Service() *string
SetService(val *string)
ServiceInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetMethods()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleApikeysKeyRestrictionsApiTargetsOutputReference ¶
func NewGoogleApikeysKeyRestrictionsApiTargetsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GoogleApikeysKeyRestrictionsApiTargetsOutputReference
type GoogleApikeysKeyRestrictionsBrowserKeyRestrictions ¶
type GoogleApikeysKeyRestrictionsBrowserKeyRestrictions struct {
// A list of regular expressions for the referrer URLs that are allowed to make API calls with this key.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_apikeys_key#allowed_referrers GoogleApikeysKey#allowed_referrers}
AllowedReferrers *[]*string `field:"required" json:"allowedReferrers" yaml:"allowedReferrers"`
}
type GoogleApikeysKeyRestrictionsBrowserKeyRestrictionsOutputReference ¶
type GoogleApikeysKeyRestrictionsBrowserKeyRestrictionsOutputReference interface {
cdktf.ComplexObject
AllowedReferrers() *[]*string
SetAllowedReferrers(val *[]*string)
AllowedReferrersInput() *[]*string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleApikeysKeyRestrictionsBrowserKeyRestrictions
SetInternalValue(val *GoogleApikeysKeyRestrictionsBrowserKeyRestrictions)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleApikeysKeyRestrictionsBrowserKeyRestrictionsOutputReference ¶
func NewGoogleApikeysKeyRestrictionsBrowserKeyRestrictionsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleApikeysKeyRestrictionsBrowserKeyRestrictionsOutputReference
type GoogleApikeysKeyRestrictionsIosKeyRestrictions ¶
type GoogleApikeysKeyRestrictionsIosKeyRestrictions struct {
// A list of bundle IDs that are allowed when making API calls with this key.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_apikeys_key#allowed_bundle_ids GoogleApikeysKey#allowed_bundle_ids}
AllowedBundleIds *[]*string `field:"required" json:"allowedBundleIds" yaml:"allowedBundleIds"`
}
type GoogleApikeysKeyRestrictionsIosKeyRestrictionsOutputReference ¶
type GoogleApikeysKeyRestrictionsIosKeyRestrictionsOutputReference interface {
cdktf.ComplexObject
AllowedBundleIds() *[]*string
SetAllowedBundleIds(val *[]*string)
AllowedBundleIdsInput() *[]*string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleApikeysKeyRestrictionsIosKeyRestrictions
SetInternalValue(val *GoogleApikeysKeyRestrictionsIosKeyRestrictions)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleApikeysKeyRestrictionsIosKeyRestrictionsOutputReference ¶
func NewGoogleApikeysKeyRestrictionsIosKeyRestrictionsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleApikeysKeyRestrictionsIosKeyRestrictionsOutputReference
type GoogleApikeysKeyRestrictionsOutputReference ¶
type GoogleApikeysKeyRestrictionsOutputReference interface {
cdktf.ComplexObject
AndroidKeyRestrictions() GoogleApikeysKeyRestrictionsAndroidKeyRestrictionsOutputReference
AndroidKeyRestrictionsInput() *GoogleApikeysKeyRestrictionsAndroidKeyRestrictions
ApiTargets() GoogleApikeysKeyRestrictionsApiTargetsList
ApiTargetsInput() interface{}
BrowserKeyRestrictions() GoogleApikeysKeyRestrictionsBrowserKeyRestrictionsOutputReference
BrowserKeyRestrictionsInput() *GoogleApikeysKeyRestrictionsBrowserKeyRestrictions
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleApikeysKeyRestrictions
SetInternalValue(val *GoogleApikeysKeyRestrictions)
IosKeyRestrictions() GoogleApikeysKeyRestrictionsIosKeyRestrictionsOutputReference
IosKeyRestrictionsInput() *GoogleApikeysKeyRestrictionsIosKeyRestrictions
ServerKeyRestrictions() GoogleApikeysKeyRestrictionsServerKeyRestrictionsOutputReference
ServerKeyRestrictionsInput() *GoogleApikeysKeyRestrictionsServerKeyRestrictions
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutAndroidKeyRestrictions(value *GoogleApikeysKeyRestrictionsAndroidKeyRestrictions)
PutApiTargets(value interface{})
PutBrowserKeyRestrictions(value *GoogleApikeysKeyRestrictionsBrowserKeyRestrictions)
PutIosKeyRestrictions(value *GoogleApikeysKeyRestrictionsIosKeyRestrictions)
PutServerKeyRestrictions(value *GoogleApikeysKeyRestrictionsServerKeyRestrictions)
ResetAndroidKeyRestrictions()
ResetApiTargets()
ResetBrowserKeyRestrictions()
ResetIosKeyRestrictions()
ResetServerKeyRestrictions()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleApikeysKeyRestrictionsOutputReference ¶
func NewGoogleApikeysKeyRestrictionsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleApikeysKeyRestrictionsOutputReference
type GoogleApikeysKeyRestrictionsServerKeyRestrictions ¶
type GoogleApikeysKeyRestrictionsServerKeyRestrictions struct {
// A list of the caller IP addresses that are allowed to make API calls with this key.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_apikeys_key#allowed_ips GoogleApikeysKey#allowed_ips}
AllowedIps *[]*string `field:"required" json:"allowedIps" yaml:"allowedIps"`
}
type GoogleApikeysKeyRestrictionsServerKeyRestrictionsOutputReference ¶
type GoogleApikeysKeyRestrictionsServerKeyRestrictionsOutputReference interface {
cdktf.ComplexObject
AllowedIps() *[]*string
SetAllowedIps(val *[]*string)
AllowedIpsInput() *[]*string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleApikeysKeyRestrictionsServerKeyRestrictions
SetInternalValue(val *GoogleApikeysKeyRestrictionsServerKeyRestrictions)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleApikeysKeyRestrictionsServerKeyRestrictionsOutputReference ¶
func NewGoogleApikeysKeyRestrictionsServerKeyRestrictionsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleApikeysKeyRestrictionsServerKeyRestrictionsOutputReference
type GoogleApikeysKeyTimeouts ¶
type GoogleApikeysKeyTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_apikeys_key#create GoogleApikeysKey#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_apikeys_key#delete GoogleApikeysKey#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_apikeys_key#update GoogleApikeysKey#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type GoogleApikeysKeyTimeoutsOutputReference ¶
type GoogleApikeysKeyTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleApikeysKeyTimeoutsOutputReference ¶
func NewGoogleApikeysKeyTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleApikeysKeyTimeoutsOutputReference
Source Files
¶
- GoogleApikeysKey.go
- GoogleApikeysKeyConfig.go
- GoogleApikeysKeyRestrictions.go
- GoogleApikeysKeyRestrictionsAndroidKeyRestrictions.go
- GoogleApikeysKeyRestrictionsAndroidKeyRestrictionsAllowedApplications.go
- GoogleApikeysKeyRestrictionsAndroidKeyRestrictionsAllowedApplicationsList.go
- GoogleApikeysKeyRestrictionsAndroidKeyRestrictionsAllowedApplicationsList__checks.go
- GoogleApikeysKeyRestrictionsAndroidKeyRestrictionsAllowedApplicationsOutputReference.go
- GoogleApikeysKeyRestrictionsAndroidKeyRestrictionsAllowedApplicationsOutputReference__checks.go
- GoogleApikeysKeyRestrictionsAndroidKeyRestrictionsOutputReference.go
- GoogleApikeysKeyRestrictionsAndroidKeyRestrictionsOutputReference__checks.go
- GoogleApikeysKeyRestrictionsApiTargets.go
- GoogleApikeysKeyRestrictionsApiTargetsList.go
- GoogleApikeysKeyRestrictionsApiTargetsList__checks.go
- GoogleApikeysKeyRestrictionsApiTargetsOutputReference.go
- GoogleApikeysKeyRestrictionsApiTargetsOutputReference__checks.go
- GoogleApikeysKeyRestrictionsBrowserKeyRestrictions.go
- GoogleApikeysKeyRestrictionsBrowserKeyRestrictionsOutputReference.go
- GoogleApikeysKeyRestrictionsBrowserKeyRestrictionsOutputReference__checks.go
- GoogleApikeysKeyRestrictionsIosKeyRestrictions.go
- GoogleApikeysKeyRestrictionsIosKeyRestrictionsOutputReference.go
- GoogleApikeysKeyRestrictionsIosKeyRestrictionsOutputReference__checks.go
- GoogleApikeysKeyRestrictionsOutputReference.go
- GoogleApikeysKeyRestrictionsOutputReference__checks.go
- GoogleApikeysKeyRestrictionsServerKeyRestrictions.go
- GoogleApikeysKeyRestrictionsServerKeyRestrictionsOutputReference.go
- GoogleApikeysKeyRestrictionsServerKeyRestrictionsOutputReference__checks.go
- GoogleApikeysKeyTimeouts.go
- GoogleApikeysKeyTimeoutsOutputReference.go
- GoogleApikeysKeyTimeoutsOutputReference__checks.go
- GoogleApikeysKey__checks.go
- main.go