Documentation
¶
Index ¶
- func GoogleAppEngineDomainMapping_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func GoogleAppEngineDomainMapping_IsConstruct(x interface{}) *bool
- func GoogleAppEngineDomainMapping_IsTerraformElement(x interface{}) *bool
- func GoogleAppEngineDomainMapping_IsTerraformResource(x interface{}) *bool
- func GoogleAppEngineDomainMapping_TfResourceType() *string
- func NewGoogleAppEngineDomainMappingResourceRecordsList_Override(g GoogleAppEngineDomainMappingResourceRecordsList, ...)
- func NewGoogleAppEngineDomainMappingResourceRecordsOutputReference_Override(g GoogleAppEngineDomainMappingResourceRecordsOutputReference, ...)
- func NewGoogleAppEngineDomainMappingSslSettingsOutputReference_Override(g GoogleAppEngineDomainMappingSslSettingsOutputReference, ...)
- func NewGoogleAppEngineDomainMappingTimeoutsOutputReference_Override(g GoogleAppEngineDomainMappingTimeoutsOutputReference, ...)
- func NewGoogleAppEngineDomainMapping_Override(g GoogleAppEngineDomainMapping, scope constructs.Construct, id *string, ...)
- type GoogleAppEngineDomainMapping
- type GoogleAppEngineDomainMappingConfig
- type GoogleAppEngineDomainMappingResourceRecords
- type GoogleAppEngineDomainMappingResourceRecordsList
- type GoogleAppEngineDomainMappingResourceRecordsOutputReference
- type GoogleAppEngineDomainMappingSslSettings
- type GoogleAppEngineDomainMappingSslSettingsOutputReference
- type GoogleAppEngineDomainMappingTimeouts
- type GoogleAppEngineDomainMappingTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleAppEngineDomainMapping_GenerateConfigForImport ¶
func GoogleAppEngineDomainMapping_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a GoogleAppEngineDomainMapping resource upon running "cdktf plan <stack-name>".
func GoogleAppEngineDomainMapping_IsConstruct ¶
func GoogleAppEngineDomainMapping_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleAppEngineDomainMapping_IsTerraformElement ¶
func GoogleAppEngineDomainMapping_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleAppEngineDomainMapping_IsTerraformResource ¶
func GoogleAppEngineDomainMapping_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleAppEngineDomainMapping_TfResourceType ¶
func GoogleAppEngineDomainMapping_TfResourceType() *string
func NewGoogleAppEngineDomainMappingResourceRecordsList_Override ¶
func NewGoogleAppEngineDomainMappingResourceRecordsList_Override(g GoogleAppEngineDomainMappingResourceRecordsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGoogleAppEngineDomainMappingResourceRecordsOutputReference_Override ¶
func NewGoogleAppEngineDomainMappingResourceRecordsOutputReference_Override(g GoogleAppEngineDomainMappingResourceRecordsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGoogleAppEngineDomainMappingSslSettingsOutputReference_Override ¶
func NewGoogleAppEngineDomainMappingSslSettingsOutputReference_Override(g GoogleAppEngineDomainMappingSslSettingsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleAppEngineDomainMappingTimeoutsOutputReference_Override ¶
func NewGoogleAppEngineDomainMappingTimeoutsOutputReference_Override(g GoogleAppEngineDomainMappingTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleAppEngineDomainMapping_Override ¶
func NewGoogleAppEngineDomainMapping_Override(g GoogleAppEngineDomainMapping, scope constructs.Construct, id *string, config *GoogleAppEngineDomainMappingConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_app_engine_domain_mapping google_app_engine_domain_mapping} Resource.
Types ¶
type GoogleAppEngineDomainMapping ¶
type GoogleAppEngineDomainMapping interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DomainName() *string
SetDomainName(val *string)
DomainNameInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
// The tree node.
Node() constructs.Node
OverrideStrategy() *string
SetOverrideStrategy(val *string)
OverrideStrategyInput() *string
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
ResourceRecords() GoogleAppEngineDomainMappingResourceRecordsList
SslSettings() GoogleAppEngineDomainMappingSslSettingsOutputReference
SslSettingsInput() *GoogleAppEngineDomainMappingSslSettings
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GoogleAppEngineDomainMappingTimeoutsOutputReference
TimeoutsInput() interface{}
// Adds a user defined moveTarget string to this resource to be later used in .moveTo(moveTarget) to resolve the location of the move.
// Experimental.
AddMoveTarget(moveTarget *string)
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
HasResourceMove() interface{}
// Experimental.
ImportFrom(id *string, provider cdktf.TerraformProvider)
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Move the resource corresponding to "id" to this resource.
//
// Note that the resource being moved from must be marked as moved using it's instance function.
// Experimental.
MoveFromId(id *string)
// Moves this resource to the target resource given by moveTarget.
// Experimental.
MoveTo(moveTarget *string, index interface{})
// Moves this resource to the resource corresponding to "id".
// Experimental.
MoveToId(id *string)
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutSslSettings(value *GoogleAppEngineDomainMappingSslSettings)
PutTimeouts(value *GoogleAppEngineDomainMappingTimeouts)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetOverrideStrategy()
ResetProject()
ResetSslSettings()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_app_engine_domain_mapping google_app_engine_domain_mapping}.
func NewGoogleAppEngineDomainMapping ¶
func NewGoogleAppEngineDomainMapping(scope constructs.Construct, id *string, config *GoogleAppEngineDomainMappingConfig) GoogleAppEngineDomainMapping
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_app_engine_domain_mapping google_app_engine_domain_mapping} Resource.
type GoogleAppEngineDomainMappingConfig ¶
type GoogleAppEngineDomainMappingConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Relative name of the domain serving the application. Example: example.com.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_app_engine_domain_mapping#domain_name GoogleAppEngineDomainMapping#domain_name}
DomainName *string `field:"required" json:"domainName" yaml:"domainName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_app_engine_domain_mapping#id GoogleAppEngineDomainMapping#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Whether the domain creation should override any existing mappings for this domain.
//
// By default, overrides are rejected. Default value: "STRICT" Possible values: ["STRICT", "OVERRIDE"]
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_app_engine_domain_mapping#override_strategy GoogleAppEngineDomainMapping#override_strategy}
OverrideStrategy *string `field:"optional" json:"overrideStrategy" yaml:"overrideStrategy"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_app_engine_domain_mapping#project GoogleAppEngineDomainMapping#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// ssl_settings block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_app_engine_domain_mapping#ssl_settings GoogleAppEngineDomainMapping#ssl_settings}
SslSettings *GoogleAppEngineDomainMappingSslSettings `field:"optional" json:"sslSettings" yaml:"sslSettings"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_app_engine_domain_mapping#timeouts GoogleAppEngineDomainMapping#timeouts}
Timeouts *GoogleAppEngineDomainMappingTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type GoogleAppEngineDomainMappingResourceRecords ¶
type GoogleAppEngineDomainMappingResourceRecords struct {
}
type GoogleAppEngineDomainMappingResourceRecordsList ¶
type GoogleAppEngineDomainMappingResourceRecordsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) GoogleAppEngineDomainMappingResourceRecordsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleAppEngineDomainMappingResourceRecordsList ¶
func NewGoogleAppEngineDomainMappingResourceRecordsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GoogleAppEngineDomainMappingResourceRecordsList
type GoogleAppEngineDomainMappingResourceRecordsOutputReference ¶
type GoogleAppEngineDomainMappingResourceRecordsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleAppEngineDomainMappingResourceRecords
SetInternalValue(val *GoogleAppEngineDomainMappingResourceRecords)
Name() *string
Rrdata() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleAppEngineDomainMappingResourceRecordsOutputReference ¶
func NewGoogleAppEngineDomainMappingResourceRecordsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GoogleAppEngineDomainMappingResourceRecordsOutputReference
type GoogleAppEngineDomainMappingSslSettings ¶
type GoogleAppEngineDomainMappingSslSettings struct {
// SSL management type for this domain.
//
// If 'AUTOMATIC', a managed certificate is automatically provisioned.
// If 'MANUAL', 'certificateId' must be manually specified in order to configure SSL for this domain. Possible values: ["AUTOMATIC", "MANUAL"]
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_app_engine_domain_mapping#ssl_management_type GoogleAppEngineDomainMapping#ssl_management_type}
SslManagementType *string `field:"required" json:"sslManagementType" yaml:"sslManagementType"`
// ID of the AuthorizedCertificate resource configuring SSL for the application.
//
// Clearing this field will
// remove SSL support.
// By default, a managed certificate is automatically created for every domain mapping. To omit SSL support
// or to configure SSL manually, specify 'SslManagementType.MANUAL' on a 'CREATE' or 'UPDATE' request. You must be
// authorized to administer the 'AuthorizedCertificate' resource to manually map it to a DomainMapping resource.
// Example: 12345.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_app_engine_domain_mapping#certificate_id GoogleAppEngineDomainMapping#certificate_id}
CertificateId *string `field:"optional" json:"certificateId" yaml:"certificateId"`
}
type GoogleAppEngineDomainMappingSslSettingsOutputReference ¶
type GoogleAppEngineDomainMappingSslSettingsOutputReference interface {
cdktf.ComplexObject
CertificateId() *string
SetCertificateId(val *string)
CertificateIdInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleAppEngineDomainMappingSslSettings
SetInternalValue(val *GoogleAppEngineDomainMappingSslSettings)
PendingManagedCertificateId() *string
SslManagementType() *string
SetSslManagementType(val *string)
SslManagementTypeInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCertificateId()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleAppEngineDomainMappingSslSettingsOutputReference ¶
func NewGoogleAppEngineDomainMappingSslSettingsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleAppEngineDomainMappingSslSettingsOutputReference
type GoogleAppEngineDomainMappingTimeouts ¶
type GoogleAppEngineDomainMappingTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_app_engine_domain_mapping#create GoogleAppEngineDomainMapping#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_app_engine_domain_mapping#delete GoogleAppEngineDomainMapping#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_app_engine_domain_mapping#update GoogleAppEngineDomainMapping#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type GoogleAppEngineDomainMappingTimeoutsOutputReference ¶
type GoogleAppEngineDomainMappingTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleAppEngineDomainMappingTimeoutsOutputReference ¶
func NewGoogleAppEngineDomainMappingTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleAppEngineDomainMappingTimeoutsOutputReference
Source Files
¶
- GoogleAppEngineDomainMapping.go
- GoogleAppEngineDomainMappingConfig.go
- GoogleAppEngineDomainMappingResourceRecords.go
- GoogleAppEngineDomainMappingResourceRecordsList.go
- GoogleAppEngineDomainMappingResourceRecordsList__checks.go
- GoogleAppEngineDomainMappingResourceRecordsOutputReference.go
- GoogleAppEngineDomainMappingResourceRecordsOutputReference__checks.go
- GoogleAppEngineDomainMappingSslSettings.go
- GoogleAppEngineDomainMappingSslSettingsOutputReference.go
- GoogleAppEngineDomainMappingSslSettingsOutputReference__checks.go
- GoogleAppEngineDomainMappingTimeouts.go
- GoogleAppEngineDomainMappingTimeoutsOutputReference.go
- GoogleAppEngineDomainMappingTimeoutsOutputReference__checks.go
- GoogleAppEngineDomainMapping__checks.go
- main.go