Documentation
¶
Index ¶
- func GoogleBigqueryBiReservation_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func GoogleBigqueryBiReservation_IsConstruct(x interface{}) *bool
- func GoogleBigqueryBiReservation_IsTerraformElement(x interface{}) *bool
- func GoogleBigqueryBiReservation_IsTerraformResource(x interface{}) *bool
- func GoogleBigqueryBiReservation_TfResourceType() *string
- func NewGoogleBigqueryBiReservationPreferredTablesList_Override(g GoogleBigqueryBiReservationPreferredTablesList, ...)
- func NewGoogleBigqueryBiReservationPreferredTablesOutputReference_Override(g GoogleBigqueryBiReservationPreferredTablesOutputReference, ...)
- func NewGoogleBigqueryBiReservationTimeoutsOutputReference_Override(g GoogleBigqueryBiReservationTimeoutsOutputReference, ...)
- func NewGoogleBigqueryBiReservation_Override(g GoogleBigqueryBiReservation, scope constructs.Construct, id *string, ...)
- type GoogleBigqueryBiReservation
- type GoogleBigqueryBiReservationConfig
- type GoogleBigqueryBiReservationPreferredTables
- type GoogleBigqueryBiReservationPreferredTablesList
- type GoogleBigqueryBiReservationPreferredTablesOutputReference
- type GoogleBigqueryBiReservationTimeouts
- type GoogleBigqueryBiReservationTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleBigqueryBiReservation_GenerateConfigForImport ¶
func GoogleBigqueryBiReservation_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a GoogleBigqueryBiReservation resource upon running "cdktf plan <stack-name>".
func GoogleBigqueryBiReservation_IsConstruct ¶
func GoogleBigqueryBiReservation_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleBigqueryBiReservation_IsTerraformElement ¶
func GoogleBigqueryBiReservation_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleBigqueryBiReservation_IsTerraformResource ¶
func GoogleBigqueryBiReservation_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleBigqueryBiReservation_TfResourceType ¶
func GoogleBigqueryBiReservation_TfResourceType() *string
func NewGoogleBigqueryBiReservationPreferredTablesList_Override ¶
func NewGoogleBigqueryBiReservationPreferredTablesList_Override(g GoogleBigqueryBiReservationPreferredTablesList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGoogleBigqueryBiReservationPreferredTablesOutputReference_Override ¶
func NewGoogleBigqueryBiReservationPreferredTablesOutputReference_Override(g GoogleBigqueryBiReservationPreferredTablesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGoogleBigqueryBiReservationTimeoutsOutputReference_Override ¶
func NewGoogleBigqueryBiReservationTimeoutsOutputReference_Override(g GoogleBigqueryBiReservationTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleBigqueryBiReservation_Override ¶
func NewGoogleBigqueryBiReservation_Override(g GoogleBigqueryBiReservation, scope constructs.Construct, id *string, config *GoogleBigqueryBiReservationConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_bigquery_bi_reservation google_bigquery_bi_reservation} Resource.
Types ¶
type GoogleBigqueryBiReservation ¶
type GoogleBigqueryBiReservation interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Location() *string
SetLocation(val *string)
LocationInput() *string
Name() *string
// The tree node.
Node() constructs.Node
PreferredTables() GoogleBigqueryBiReservationPreferredTablesList
PreferredTablesInput() interface{}
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Size() *float64
SetSize(val *float64)
SizeInput() *float64
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GoogleBigqueryBiReservationTimeoutsOutputReference
TimeoutsInput() interface{}
UpdateTime() *string
// Adds a user defined moveTarget string to this resource to be later used in .moveTo(moveTarget) to resolve the location of the move.
// Experimental.
AddMoveTarget(moveTarget *string)
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
HasResourceMove() interface{}
// Experimental.
ImportFrom(id *string, provider cdktf.TerraformProvider)
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Move the resource corresponding to "id" to this resource.
//
// Note that the resource being moved from must be marked as moved using it's instance function.
// Experimental.
MoveFromId(id *string)
// Moves this resource to the target resource given by moveTarget.
// Experimental.
MoveTo(moveTarget *string, index interface{})
// Moves this resource to the resource corresponding to "id".
// Experimental.
MoveToId(id *string)
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutPreferredTables(value interface{})
PutTimeouts(value *GoogleBigqueryBiReservationTimeouts)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetPreferredTables()
ResetProject()
ResetSize()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_bigquery_bi_reservation google_bigquery_bi_reservation}.
func NewGoogleBigqueryBiReservation ¶
func NewGoogleBigqueryBiReservation(scope constructs.Construct, id *string, config *GoogleBigqueryBiReservationConfig) GoogleBigqueryBiReservation
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_bigquery_bi_reservation google_bigquery_bi_reservation} Resource.
type GoogleBigqueryBiReservationConfig ¶
type GoogleBigqueryBiReservationConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// LOCATION_DESCRIPTION.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_bigquery_bi_reservation#location GoogleBigqueryBiReservation#location}
Location *string `field:"required" json:"location" yaml:"location"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_bigquery_bi_reservation#id GoogleBigqueryBiReservation#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// preferred_tables block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_bigquery_bi_reservation#preferred_tables GoogleBigqueryBiReservation#preferred_tables}
PreferredTables interface{} `field:"optional" json:"preferredTables" yaml:"preferredTables"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_bigquery_bi_reservation#project GoogleBigqueryBiReservation#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// Size of a reservation, in bytes.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_bigquery_bi_reservation#size GoogleBigqueryBiReservation#size}
Size *float64 `field:"optional" json:"size" yaml:"size"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_bigquery_bi_reservation#timeouts GoogleBigqueryBiReservation#timeouts}
Timeouts *GoogleBigqueryBiReservationTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type GoogleBigqueryBiReservationPreferredTables ¶
type GoogleBigqueryBiReservationPreferredTables struct {
// The ID of the dataset in the above project.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_bigquery_bi_reservation#dataset_id GoogleBigqueryBiReservation#dataset_id}
DatasetId *string `field:"optional" json:"datasetId" yaml:"datasetId"`
// The assigned project ID of the project.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_bigquery_bi_reservation#project_id GoogleBigqueryBiReservation#project_id}
ProjectId *string `field:"optional" json:"projectId" yaml:"projectId"`
// The ID of the table in the above dataset.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_bigquery_bi_reservation#table_id GoogleBigqueryBiReservation#table_id}
TableId *string `field:"optional" json:"tableId" yaml:"tableId"`
}
type GoogleBigqueryBiReservationPreferredTablesList ¶
type GoogleBigqueryBiReservationPreferredTablesList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) GoogleBigqueryBiReservationPreferredTablesOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleBigqueryBiReservationPreferredTablesList ¶
func NewGoogleBigqueryBiReservationPreferredTablesList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GoogleBigqueryBiReservationPreferredTablesList
type GoogleBigqueryBiReservationPreferredTablesOutputReference ¶
type GoogleBigqueryBiReservationPreferredTablesOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DatasetId() *string
SetDatasetId(val *string)
DatasetIdInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
ProjectId() *string
SetProjectId(val *string)
ProjectIdInput() *string
TableId() *string
SetTableId(val *string)
TableIdInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetDatasetId()
ResetProjectId()
ResetTableId()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleBigqueryBiReservationPreferredTablesOutputReference ¶
func NewGoogleBigqueryBiReservationPreferredTablesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GoogleBigqueryBiReservationPreferredTablesOutputReference
type GoogleBigqueryBiReservationTimeouts ¶
type GoogleBigqueryBiReservationTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_bigquery_bi_reservation#create GoogleBigqueryBiReservation#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_bigquery_bi_reservation#delete GoogleBigqueryBiReservation#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_bigquery_bi_reservation#update GoogleBigqueryBiReservation#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type GoogleBigqueryBiReservationTimeoutsOutputReference ¶
type GoogleBigqueryBiReservationTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleBigqueryBiReservationTimeoutsOutputReference ¶
func NewGoogleBigqueryBiReservationTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleBigqueryBiReservationTimeoutsOutputReference
Source Files
¶
- GoogleBigqueryBiReservation.go
- GoogleBigqueryBiReservationConfig.go
- GoogleBigqueryBiReservationPreferredTables.go
- GoogleBigqueryBiReservationPreferredTablesList.go
- GoogleBigqueryBiReservationPreferredTablesList__checks.go
- GoogleBigqueryBiReservationPreferredTablesOutputReference.go
- GoogleBigqueryBiReservationPreferredTablesOutputReference__checks.go
- GoogleBigqueryBiReservationTimeouts.go
- GoogleBigqueryBiReservationTimeoutsOutputReference.go
- GoogleBigqueryBiReservationTimeoutsOutputReference__checks.go
- GoogleBigqueryBiReservation__checks.go
- main.go