Documentation
¶
Index ¶
- func GoogleCloudAssetOrganizationFeed_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func GoogleCloudAssetOrganizationFeed_IsConstruct(x interface{}) *bool
- func GoogleCloudAssetOrganizationFeed_IsTerraformElement(x interface{}) *bool
- func GoogleCloudAssetOrganizationFeed_IsTerraformResource(x interface{}) *bool
- func GoogleCloudAssetOrganizationFeed_TfResourceType() *string
- func NewGoogleCloudAssetOrganizationFeedConditionOutputReference_Override(g GoogleCloudAssetOrganizationFeedConditionOutputReference, ...)
- func NewGoogleCloudAssetOrganizationFeedFeedOutputConfigOutputReference_Override(g GoogleCloudAssetOrganizationFeedFeedOutputConfigOutputReference, ...)
- func NewGoogleCloudAssetOrganizationFeedFeedOutputConfigPubsubDestinationOutputReference_Override(...)
- func NewGoogleCloudAssetOrganizationFeedTimeoutsOutputReference_Override(g GoogleCloudAssetOrganizationFeedTimeoutsOutputReference, ...)
- func NewGoogleCloudAssetOrganizationFeed_Override(g GoogleCloudAssetOrganizationFeed, scope constructs.Construct, id *string, ...)
- type GoogleCloudAssetOrganizationFeed
- type GoogleCloudAssetOrganizationFeedCondition
- type GoogleCloudAssetOrganizationFeedConditionOutputReference
- type GoogleCloudAssetOrganizationFeedConfig
- type GoogleCloudAssetOrganizationFeedFeedOutputConfig
- type GoogleCloudAssetOrganizationFeedFeedOutputConfigOutputReference
- type GoogleCloudAssetOrganizationFeedFeedOutputConfigPubsubDestination
- type GoogleCloudAssetOrganizationFeedFeedOutputConfigPubsubDestinationOutputReference
- type GoogleCloudAssetOrganizationFeedTimeouts
- type GoogleCloudAssetOrganizationFeedTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleCloudAssetOrganizationFeed_GenerateConfigForImport ¶
func GoogleCloudAssetOrganizationFeed_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a GoogleCloudAssetOrganizationFeed resource upon running "cdktf plan <stack-name>".
func GoogleCloudAssetOrganizationFeed_IsConstruct ¶
func GoogleCloudAssetOrganizationFeed_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleCloudAssetOrganizationFeed_IsTerraformElement ¶
func GoogleCloudAssetOrganizationFeed_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleCloudAssetOrganizationFeed_IsTerraformResource ¶
func GoogleCloudAssetOrganizationFeed_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleCloudAssetOrganizationFeed_TfResourceType ¶
func GoogleCloudAssetOrganizationFeed_TfResourceType() *string
func NewGoogleCloudAssetOrganizationFeedConditionOutputReference_Override ¶
func NewGoogleCloudAssetOrganizationFeedConditionOutputReference_Override(g GoogleCloudAssetOrganizationFeedConditionOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleCloudAssetOrganizationFeedFeedOutputConfigOutputReference_Override ¶
func NewGoogleCloudAssetOrganizationFeedFeedOutputConfigOutputReference_Override(g GoogleCloudAssetOrganizationFeedFeedOutputConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleCloudAssetOrganizationFeedFeedOutputConfigPubsubDestinationOutputReference_Override ¶
func NewGoogleCloudAssetOrganizationFeedFeedOutputConfigPubsubDestinationOutputReference_Override(g GoogleCloudAssetOrganizationFeedFeedOutputConfigPubsubDestinationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleCloudAssetOrganizationFeedTimeoutsOutputReference_Override ¶
func NewGoogleCloudAssetOrganizationFeedTimeoutsOutputReference_Override(g GoogleCloudAssetOrganizationFeedTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleCloudAssetOrganizationFeed_Override ¶
func NewGoogleCloudAssetOrganizationFeed_Override(g GoogleCloudAssetOrganizationFeed, scope constructs.Construct, id *string, config *GoogleCloudAssetOrganizationFeedConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_cloud_asset_organization_feed google_cloud_asset_organization_feed} Resource.
Types ¶
type GoogleCloudAssetOrganizationFeed ¶
type GoogleCloudAssetOrganizationFeed interface {
cdktf.TerraformResource
AssetNames() *[]*string
SetAssetNames(val *[]*string)
AssetNamesInput() *[]*string
AssetTypes() *[]*string
SetAssetTypes(val *[]*string)
AssetTypesInput() *[]*string
BillingProject() *string
SetBillingProject(val *string)
BillingProjectInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
Condition() GoogleCloudAssetOrganizationFeedConditionOutputReference
ConditionInput() *GoogleCloudAssetOrganizationFeedCondition
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
ContentType() *string
SetContentType(val *string)
ContentTypeInput() *string
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
FeedId() *string
SetFeedId(val *string)
FeedIdInput() *string
FeedOutputConfig() GoogleCloudAssetOrganizationFeedFeedOutputConfigOutputReference
FeedOutputConfigInput() *GoogleCloudAssetOrganizationFeedFeedOutputConfig
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
// The tree node.
Node() constructs.Node
OrgId() *string
SetOrgId(val *string)
OrgIdInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GoogleCloudAssetOrganizationFeedTimeoutsOutputReference
TimeoutsInput() interface{}
// Adds a user defined moveTarget string to this resource to be later used in .moveTo(moveTarget) to resolve the location of the move.
// Experimental.
AddMoveTarget(moveTarget *string)
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
HasResourceMove() interface{}
// Experimental.
ImportFrom(id *string, provider cdktf.TerraformProvider)
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Move the resource corresponding to "id" to this resource.
//
// Note that the resource being moved from must be marked as moved using it's instance function.
// Experimental.
MoveFromId(id *string)
// Moves this resource to the target resource given by moveTarget.
// Experimental.
MoveTo(moveTarget *string, index interface{})
// Moves this resource to the resource corresponding to "id".
// Experimental.
MoveToId(id *string)
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutCondition(value *GoogleCloudAssetOrganizationFeedCondition)
PutFeedOutputConfig(value *GoogleCloudAssetOrganizationFeedFeedOutputConfig)
PutTimeouts(value *GoogleCloudAssetOrganizationFeedTimeouts)
ResetAssetNames()
ResetAssetTypes()
ResetCondition()
ResetContentType()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_cloud_asset_organization_feed google_cloud_asset_organization_feed}.
func NewGoogleCloudAssetOrganizationFeed ¶
func NewGoogleCloudAssetOrganizationFeed(scope constructs.Construct, id *string, config *GoogleCloudAssetOrganizationFeedConfig) GoogleCloudAssetOrganizationFeed
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_cloud_asset_organization_feed google_cloud_asset_organization_feed} Resource.
type GoogleCloudAssetOrganizationFeedCondition ¶
type GoogleCloudAssetOrganizationFeedCondition struct {
// Textual representation of an expression in Common Expression Language syntax.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_cloud_asset_organization_feed#expression GoogleCloudAssetOrganizationFeed#expression}
Expression *string `field:"required" json:"expression" yaml:"expression"`
// Description of the expression.
//
// This is a longer text which describes the expression,
// e.g. when hovered over it in a UI.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_cloud_asset_organization_feed#description GoogleCloudAssetOrganizationFeed#description}
Description *string `field:"optional" json:"description" yaml:"description"`
// String indicating the location of the expression for error reporting, e.g. a file name and a position in the file.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_cloud_asset_organization_feed#location GoogleCloudAssetOrganizationFeed#location}
Location *string `field:"optional" json:"location" yaml:"location"`
// Title for the expression, i.e. a short string describing its purpose. This can be used e.g. in UIs which allow to enter the expression.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_cloud_asset_organization_feed#title GoogleCloudAssetOrganizationFeed#title}
Title *string `field:"optional" json:"title" yaml:"title"`
}
type GoogleCloudAssetOrganizationFeedConditionOutputReference ¶
type GoogleCloudAssetOrganizationFeedConditionOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Description() *string
SetDescription(val *string)
DescriptionInput() *string
Expression() *string
SetExpression(val *string)
ExpressionInput() *string
// Experimental.
Fqn() *string
InternalValue() *GoogleCloudAssetOrganizationFeedCondition
SetInternalValue(val *GoogleCloudAssetOrganizationFeedCondition)
Location() *string
SetLocation(val *string)
LocationInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Title() *string
SetTitle(val *string)
TitleInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetDescription()
ResetLocation()
ResetTitle()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleCloudAssetOrganizationFeedConditionOutputReference ¶
func NewGoogleCloudAssetOrganizationFeedConditionOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleCloudAssetOrganizationFeedConditionOutputReference
type GoogleCloudAssetOrganizationFeedConfig ¶
type GoogleCloudAssetOrganizationFeedConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// The project whose identity will be used when sending messages to the destination pubsub topic.
//
// It also specifies the project for API
// enablement check, quota, and billing.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_cloud_asset_organization_feed#billing_project GoogleCloudAssetOrganizationFeed#billing_project}
BillingProject *string `field:"required" json:"billingProject" yaml:"billingProject"`
// This is the client-assigned asset feed identifier and it needs to be unique under a specific parent.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_cloud_asset_organization_feed#feed_id GoogleCloudAssetOrganizationFeed#feed_id}
FeedId *string `field:"required" json:"feedId" yaml:"feedId"`
// feed_output_config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_cloud_asset_organization_feed#feed_output_config GoogleCloudAssetOrganizationFeed#feed_output_config}
FeedOutputConfig *GoogleCloudAssetOrganizationFeedFeedOutputConfig `field:"required" json:"feedOutputConfig" yaml:"feedOutputConfig"`
// The organization this feed should be created in.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_cloud_asset_organization_feed#org_id GoogleCloudAssetOrganizationFeed#org_id}
OrgId *string `field:"required" json:"orgId" yaml:"orgId"`
// A list of the full names of the assets to receive updates.
//
// You must specify either or both of
// assetNames and assetTypes. Only asset updates matching specified assetNames and assetTypes are
// exported to the feed. For example: //compute.googleapis.com/projects/my_project_123/zones/zone1/instances/instance1.
// See https://cloud.google.com/apis/design/resourceNames#fullResourceName for more info.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_cloud_asset_organization_feed#asset_names GoogleCloudAssetOrganizationFeed#asset_names}
AssetNames *[]*string `field:"optional" json:"assetNames" yaml:"assetNames"`
// A list of types of the assets to receive updates.
//
// You must specify either or both of assetNames
// and assetTypes. Only asset updates matching specified assetNames and assetTypes are exported to
// the feed. For example: "compute.googleapis.com/Disk"
// See https://cloud.google.com/asset-inventory/docs/supported-asset-types for a list of all
// supported asset types.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_cloud_asset_organization_feed#asset_types GoogleCloudAssetOrganizationFeed#asset_types}
AssetTypes *[]*string `field:"optional" json:"assetTypes" yaml:"assetTypes"`
// condition block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_cloud_asset_organization_feed#condition GoogleCloudAssetOrganizationFeed#condition}
Condition *GoogleCloudAssetOrganizationFeedCondition `field:"optional" json:"condition" yaml:"condition"`
// Asset content type.
//
// If not specified, no content but the asset name and type will be returned. Possible values: ["CONTENT_TYPE_UNSPECIFIED", "RESOURCE", "IAM_POLICY", "ORG_POLICY", "OS_INVENTORY", "ACCESS_POLICY"]
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_cloud_asset_organization_feed#content_type GoogleCloudAssetOrganizationFeed#content_type}
ContentType *string `field:"optional" json:"contentType" yaml:"contentType"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_cloud_asset_organization_feed#id GoogleCloudAssetOrganizationFeed#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_cloud_asset_organization_feed#timeouts GoogleCloudAssetOrganizationFeed#timeouts}
Timeouts *GoogleCloudAssetOrganizationFeedTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type GoogleCloudAssetOrganizationFeedFeedOutputConfig ¶
type GoogleCloudAssetOrganizationFeedFeedOutputConfig struct {
// pubsub_destination block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_cloud_asset_organization_feed#pubsub_destination GoogleCloudAssetOrganizationFeed#pubsub_destination}
PubsubDestination *GoogleCloudAssetOrganizationFeedFeedOutputConfigPubsubDestination `field:"required" json:"pubsubDestination" yaml:"pubsubDestination"`
}
type GoogleCloudAssetOrganizationFeedFeedOutputConfigOutputReference ¶
type GoogleCloudAssetOrganizationFeedFeedOutputConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleCloudAssetOrganizationFeedFeedOutputConfig
SetInternalValue(val *GoogleCloudAssetOrganizationFeedFeedOutputConfig)
PubsubDestination() GoogleCloudAssetOrganizationFeedFeedOutputConfigPubsubDestinationOutputReference
PubsubDestinationInput() *GoogleCloudAssetOrganizationFeedFeedOutputConfigPubsubDestination
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutPubsubDestination(value *GoogleCloudAssetOrganizationFeedFeedOutputConfigPubsubDestination)
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleCloudAssetOrganizationFeedFeedOutputConfigOutputReference ¶
func NewGoogleCloudAssetOrganizationFeedFeedOutputConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleCloudAssetOrganizationFeedFeedOutputConfigOutputReference
type GoogleCloudAssetOrganizationFeedFeedOutputConfigPubsubDestination ¶
type GoogleCloudAssetOrganizationFeedFeedOutputConfigPubsubDestination struct {
// Destination on Cloud Pubsub topic.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_cloud_asset_organization_feed#topic GoogleCloudAssetOrganizationFeed#topic}
Topic *string `field:"required" json:"topic" yaml:"topic"`
}
type GoogleCloudAssetOrganizationFeedFeedOutputConfigPubsubDestinationOutputReference ¶
type GoogleCloudAssetOrganizationFeedFeedOutputConfigPubsubDestinationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleCloudAssetOrganizationFeedFeedOutputConfigPubsubDestination
SetInternalValue(val *GoogleCloudAssetOrganizationFeedFeedOutputConfigPubsubDestination)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Topic() *string
SetTopic(val *string)
TopicInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleCloudAssetOrganizationFeedFeedOutputConfigPubsubDestinationOutputReference ¶
func NewGoogleCloudAssetOrganizationFeedFeedOutputConfigPubsubDestinationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleCloudAssetOrganizationFeedFeedOutputConfigPubsubDestinationOutputReference
type GoogleCloudAssetOrganizationFeedTimeouts ¶
type GoogleCloudAssetOrganizationFeedTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_cloud_asset_organization_feed#create GoogleCloudAssetOrganizationFeed#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_cloud_asset_organization_feed#delete GoogleCloudAssetOrganizationFeed#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_cloud_asset_organization_feed#update GoogleCloudAssetOrganizationFeed#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type GoogleCloudAssetOrganizationFeedTimeoutsOutputReference ¶
type GoogleCloudAssetOrganizationFeedTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleCloudAssetOrganizationFeedTimeoutsOutputReference ¶
func NewGoogleCloudAssetOrganizationFeedTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleCloudAssetOrganizationFeedTimeoutsOutputReference
Source Files
¶
- GoogleCloudAssetOrganizationFeed.go
- GoogleCloudAssetOrganizationFeedCondition.go
- GoogleCloudAssetOrganizationFeedConditionOutputReference.go
- GoogleCloudAssetOrganizationFeedConditionOutputReference__checks.go
- GoogleCloudAssetOrganizationFeedConfig.go
- GoogleCloudAssetOrganizationFeedFeedOutputConfig.go
- GoogleCloudAssetOrganizationFeedFeedOutputConfigOutputReference.go
- GoogleCloudAssetOrganizationFeedFeedOutputConfigOutputReference__checks.go
- GoogleCloudAssetOrganizationFeedFeedOutputConfigPubsubDestination.go
- GoogleCloudAssetOrganizationFeedFeedOutputConfigPubsubDestinationOutputReference.go
- GoogleCloudAssetOrganizationFeedFeedOutputConfigPubsubDestinationOutputReference__checks.go
- GoogleCloudAssetOrganizationFeedTimeouts.go
- GoogleCloudAssetOrganizationFeedTimeoutsOutputReference.go
- GoogleCloudAssetOrganizationFeedTimeoutsOutputReference__checks.go
- GoogleCloudAssetOrganizationFeed__checks.go
- main.go