Documentation
¶
Index ¶
- func GoogleDnsResponsePolicy_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func GoogleDnsResponsePolicy_IsConstruct(x interface{}) *bool
- func GoogleDnsResponsePolicy_IsTerraformElement(x interface{}) *bool
- func GoogleDnsResponsePolicy_IsTerraformResource(x interface{}) *bool
- func GoogleDnsResponsePolicy_TfResourceType() *string
- func NewGoogleDnsResponsePolicyGkeClustersList_Override(g GoogleDnsResponsePolicyGkeClustersList, ...)
- func NewGoogleDnsResponsePolicyGkeClustersOutputReference_Override(g GoogleDnsResponsePolicyGkeClustersOutputReference, ...)
- func NewGoogleDnsResponsePolicyNetworksList_Override(g GoogleDnsResponsePolicyNetworksList, ...)
- func NewGoogleDnsResponsePolicyNetworksOutputReference_Override(g GoogleDnsResponsePolicyNetworksOutputReference, ...)
- func NewGoogleDnsResponsePolicyTimeoutsOutputReference_Override(g GoogleDnsResponsePolicyTimeoutsOutputReference, ...)
- func NewGoogleDnsResponsePolicy_Override(g GoogleDnsResponsePolicy, scope constructs.Construct, id *string, ...)
- type GoogleDnsResponsePolicy
- type GoogleDnsResponsePolicyConfig
- type GoogleDnsResponsePolicyGkeClusters
- type GoogleDnsResponsePolicyGkeClustersList
- type GoogleDnsResponsePolicyGkeClustersOutputReference
- type GoogleDnsResponsePolicyNetworks
- type GoogleDnsResponsePolicyNetworksList
- type GoogleDnsResponsePolicyNetworksOutputReference
- type GoogleDnsResponsePolicyTimeouts
- type GoogleDnsResponsePolicyTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleDnsResponsePolicy_GenerateConfigForImport ¶
func GoogleDnsResponsePolicy_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a GoogleDnsResponsePolicy resource upon running "cdktf plan <stack-name>".
func GoogleDnsResponsePolicy_IsConstruct ¶
func GoogleDnsResponsePolicy_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleDnsResponsePolicy_IsTerraformElement ¶
func GoogleDnsResponsePolicy_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleDnsResponsePolicy_IsTerraformResource ¶
func GoogleDnsResponsePolicy_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleDnsResponsePolicy_TfResourceType ¶
func GoogleDnsResponsePolicy_TfResourceType() *string
func NewGoogleDnsResponsePolicyGkeClustersList_Override ¶
func NewGoogleDnsResponsePolicyGkeClustersList_Override(g GoogleDnsResponsePolicyGkeClustersList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGoogleDnsResponsePolicyGkeClustersOutputReference_Override ¶
func NewGoogleDnsResponsePolicyGkeClustersOutputReference_Override(g GoogleDnsResponsePolicyGkeClustersOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGoogleDnsResponsePolicyNetworksList_Override ¶
func NewGoogleDnsResponsePolicyNetworksList_Override(g GoogleDnsResponsePolicyNetworksList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGoogleDnsResponsePolicyNetworksOutputReference_Override ¶
func NewGoogleDnsResponsePolicyNetworksOutputReference_Override(g GoogleDnsResponsePolicyNetworksOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGoogleDnsResponsePolicyTimeoutsOutputReference_Override ¶
func NewGoogleDnsResponsePolicyTimeoutsOutputReference_Override(g GoogleDnsResponsePolicyTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleDnsResponsePolicy_Override ¶
func NewGoogleDnsResponsePolicy_Override(g GoogleDnsResponsePolicy, scope constructs.Construct, id *string, config *GoogleDnsResponsePolicyConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_dns_response_policy google_dns_response_policy} Resource.
Types ¶
type GoogleDnsResponsePolicy ¶
type GoogleDnsResponsePolicy interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
GkeClusters() GoogleDnsResponsePolicyGkeClustersList
GkeClustersInput() interface{}
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Networks() GoogleDnsResponsePolicyNetworksList
NetworksInput() interface{}
// The tree node.
Node() constructs.Node
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
ResponsePolicyName() *string
SetResponsePolicyName(val *string)
ResponsePolicyNameInput() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GoogleDnsResponsePolicyTimeoutsOutputReference
TimeoutsInput() interface{}
// Adds a user defined moveTarget string to this resource to be later used in .moveTo(moveTarget) to resolve the location of the move.
// Experimental.
AddMoveTarget(moveTarget *string)
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
HasResourceMove() interface{}
// Experimental.
ImportFrom(id *string, provider cdktf.TerraformProvider)
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Move the resource corresponding to "id" to this resource.
//
// Note that the resource being moved from must be marked as moved using it's instance function.
// Experimental.
MoveFromId(id *string)
// Moves this resource to the target resource given by moveTarget.
// Experimental.
MoveTo(moveTarget *string, index interface{})
// Moves this resource to the resource corresponding to "id".
// Experimental.
MoveToId(id *string)
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutGkeClusters(value interface{})
PutNetworks(value interface{})
PutTimeouts(value *GoogleDnsResponsePolicyTimeouts)
ResetDescription()
ResetGkeClusters()
ResetId()
ResetNetworks()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_dns_response_policy google_dns_response_policy}.
func NewGoogleDnsResponsePolicy ¶
func NewGoogleDnsResponsePolicy(scope constructs.Construct, id *string, config *GoogleDnsResponsePolicyConfig) GoogleDnsResponsePolicy
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_dns_response_policy google_dns_response_policy} Resource.
type GoogleDnsResponsePolicyConfig ¶
type GoogleDnsResponsePolicyConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// The user assigned name for this Response Policy, such as 'myresponsepolicy'.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_dns_response_policy#response_policy_name GoogleDnsResponsePolicy#response_policy_name}
ResponsePolicyName *string `field:"required" json:"responsePolicyName" yaml:"responsePolicyName"`
// The description of the response policy, such as 'My new response policy'.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_dns_response_policy#description GoogleDnsResponsePolicy#description}
Description *string `field:"optional" json:"description" yaml:"description"`
// gke_clusters block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_dns_response_policy#gke_clusters GoogleDnsResponsePolicy#gke_clusters}
GkeClusters interface{} `field:"optional" json:"gkeClusters" yaml:"gkeClusters"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_dns_response_policy#id GoogleDnsResponsePolicy#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// networks block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_dns_response_policy#networks GoogleDnsResponsePolicy#networks}
Networks interface{} `field:"optional" json:"networks" yaml:"networks"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_dns_response_policy#project GoogleDnsResponsePolicy#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_dns_response_policy#timeouts GoogleDnsResponsePolicy#timeouts}
Timeouts *GoogleDnsResponsePolicyTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type GoogleDnsResponsePolicyGkeClusters ¶
type GoogleDnsResponsePolicyGkeClusters struct {
// The resource name of the cluster to bind this ManagedZone to.
//
// This should be specified in the format like
// 'projects/* /locations/* /clusters/*'
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_dns_response_policy#gke_cluster_name GoogleDnsResponsePolicy#gke_cluster_name}
//
// Note: The above comment contained a comment block ending sequence (* followed by /). We have introduced a space between to prevent syntax errors. Please ignore the space.
GkeClusterName *string `field:"required" json:"gkeClusterName" yaml:"gkeClusterName"`
}
type GoogleDnsResponsePolicyGkeClustersList ¶
type GoogleDnsResponsePolicyGkeClustersList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) GoogleDnsResponsePolicyGkeClustersOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleDnsResponsePolicyGkeClustersList ¶
func NewGoogleDnsResponsePolicyGkeClustersList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GoogleDnsResponsePolicyGkeClustersList
type GoogleDnsResponsePolicyGkeClustersOutputReference ¶
type GoogleDnsResponsePolicyGkeClustersOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
GkeClusterName() *string
SetGkeClusterName(val *string)
GkeClusterNameInput() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleDnsResponsePolicyGkeClustersOutputReference ¶
func NewGoogleDnsResponsePolicyGkeClustersOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GoogleDnsResponsePolicyGkeClustersOutputReference
type GoogleDnsResponsePolicyNetworks ¶
type GoogleDnsResponsePolicyNetworks struct {
// The fully qualified URL of the VPC network to bind to. This should be formatted like 'https://www.googleapis.com/compute/v1/projects/{project}/global/networks/{network}'.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_dns_response_policy#network_url GoogleDnsResponsePolicy#network_url}
NetworkUrl *string `field:"required" json:"networkUrl" yaml:"networkUrl"`
}
type GoogleDnsResponsePolicyNetworksList ¶
type GoogleDnsResponsePolicyNetworksList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) GoogleDnsResponsePolicyNetworksOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleDnsResponsePolicyNetworksList ¶
func NewGoogleDnsResponsePolicyNetworksList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GoogleDnsResponsePolicyNetworksList
type GoogleDnsResponsePolicyNetworksOutputReference ¶
type GoogleDnsResponsePolicyNetworksOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
NetworkUrl() *string
SetNetworkUrl(val *string)
NetworkUrlInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleDnsResponsePolicyNetworksOutputReference ¶
func NewGoogleDnsResponsePolicyNetworksOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GoogleDnsResponsePolicyNetworksOutputReference
type GoogleDnsResponsePolicyTimeouts ¶
type GoogleDnsResponsePolicyTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_dns_response_policy#create GoogleDnsResponsePolicy#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_dns_response_policy#delete GoogleDnsResponsePolicy#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_dns_response_policy#update GoogleDnsResponsePolicy#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type GoogleDnsResponsePolicyTimeoutsOutputReference ¶
type GoogleDnsResponsePolicyTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleDnsResponsePolicyTimeoutsOutputReference ¶
func NewGoogleDnsResponsePolicyTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleDnsResponsePolicyTimeoutsOutputReference
Source Files
¶
- GoogleDnsResponsePolicy.go
- GoogleDnsResponsePolicyConfig.go
- GoogleDnsResponsePolicyGkeClusters.go
- GoogleDnsResponsePolicyGkeClustersList.go
- GoogleDnsResponsePolicyGkeClustersList__checks.go
- GoogleDnsResponsePolicyGkeClustersOutputReference.go
- GoogleDnsResponsePolicyGkeClustersOutputReference__checks.go
- GoogleDnsResponsePolicyNetworks.go
- GoogleDnsResponsePolicyNetworksList.go
- GoogleDnsResponsePolicyNetworksList__checks.go
- GoogleDnsResponsePolicyNetworksOutputReference.go
- GoogleDnsResponsePolicyNetworksOutputReference__checks.go
- GoogleDnsResponsePolicyTimeouts.go
- GoogleDnsResponsePolicyTimeoutsOutputReference.go
- GoogleDnsResponsePolicyTimeoutsOutputReference__checks.go
- GoogleDnsResponsePolicy__checks.go
- main.go