Documentation
¶
Index ¶
- func GoogleFirebaseHostingVersion_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func GoogleFirebaseHostingVersion_IsConstruct(x interface{}) *bool
- func GoogleFirebaseHostingVersion_IsTerraformElement(x interface{}) *bool
- func GoogleFirebaseHostingVersion_IsTerraformResource(x interface{}) *bool
- func GoogleFirebaseHostingVersion_TfResourceType() *string
- func NewGoogleFirebaseHostingVersionConfigAOutputReference_Override(g GoogleFirebaseHostingVersionConfigAOutputReference, ...)
- func NewGoogleFirebaseHostingVersionConfigRedirectsList_Override(g GoogleFirebaseHostingVersionConfigRedirectsList, ...)
- func NewGoogleFirebaseHostingVersionConfigRedirectsOutputReference_Override(g GoogleFirebaseHostingVersionConfigRedirectsOutputReference, ...)
- func NewGoogleFirebaseHostingVersionConfigRewritesList_Override(g GoogleFirebaseHostingVersionConfigRewritesList, ...)
- func NewGoogleFirebaseHostingVersionConfigRewritesOutputReference_Override(g GoogleFirebaseHostingVersionConfigRewritesOutputReference, ...)
- func NewGoogleFirebaseHostingVersionConfigRewritesRunOutputReference_Override(g GoogleFirebaseHostingVersionConfigRewritesRunOutputReference, ...)
- func NewGoogleFirebaseHostingVersionTimeoutsOutputReference_Override(g GoogleFirebaseHostingVersionTimeoutsOutputReference, ...)
- func NewGoogleFirebaseHostingVersion_Override(g GoogleFirebaseHostingVersion, scope constructs.Construct, id *string, ...)
- type GoogleFirebaseHostingVersion
- type GoogleFirebaseHostingVersionConfig
- type GoogleFirebaseHostingVersionConfigA
- type GoogleFirebaseHostingVersionConfigAOutputReference
- type GoogleFirebaseHostingVersionConfigRedirects
- type GoogleFirebaseHostingVersionConfigRedirectsList
- type GoogleFirebaseHostingVersionConfigRedirectsOutputReference
- type GoogleFirebaseHostingVersionConfigRewrites
- type GoogleFirebaseHostingVersionConfigRewritesList
- type GoogleFirebaseHostingVersionConfigRewritesOutputReference
- type GoogleFirebaseHostingVersionConfigRewritesRun
- type GoogleFirebaseHostingVersionConfigRewritesRunOutputReference
- type GoogleFirebaseHostingVersionTimeouts
- type GoogleFirebaseHostingVersionTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleFirebaseHostingVersion_GenerateConfigForImport ¶
func GoogleFirebaseHostingVersion_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a GoogleFirebaseHostingVersion resource upon running "cdktf plan <stack-name>".
func GoogleFirebaseHostingVersion_IsConstruct ¶
func GoogleFirebaseHostingVersion_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleFirebaseHostingVersion_IsTerraformElement ¶
func GoogleFirebaseHostingVersion_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleFirebaseHostingVersion_IsTerraformResource ¶
func GoogleFirebaseHostingVersion_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleFirebaseHostingVersion_TfResourceType ¶
func GoogleFirebaseHostingVersion_TfResourceType() *string
func NewGoogleFirebaseHostingVersionConfigAOutputReference_Override ¶
func NewGoogleFirebaseHostingVersionConfigAOutputReference_Override(g GoogleFirebaseHostingVersionConfigAOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleFirebaseHostingVersionConfigRedirectsList_Override ¶
func NewGoogleFirebaseHostingVersionConfigRedirectsList_Override(g GoogleFirebaseHostingVersionConfigRedirectsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGoogleFirebaseHostingVersionConfigRedirectsOutputReference_Override ¶
func NewGoogleFirebaseHostingVersionConfigRedirectsOutputReference_Override(g GoogleFirebaseHostingVersionConfigRedirectsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGoogleFirebaseHostingVersionConfigRewritesList_Override ¶
func NewGoogleFirebaseHostingVersionConfigRewritesList_Override(g GoogleFirebaseHostingVersionConfigRewritesList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGoogleFirebaseHostingVersionConfigRewritesOutputReference_Override ¶
func NewGoogleFirebaseHostingVersionConfigRewritesOutputReference_Override(g GoogleFirebaseHostingVersionConfigRewritesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGoogleFirebaseHostingVersionConfigRewritesRunOutputReference_Override ¶
func NewGoogleFirebaseHostingVersionConfigRewritesRunOutputReference_Override(g GoogleFirebaseHostingVersionConfigRewritesRunOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleFirebaseHostingVersionTimeoutsOutputReference_Override ¶
func NewGoogleFirebaseHostingVersionTimeoutsOutputReference_Override(g GoogleFirebaseHostingVersionTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleFirebaseHostingVersion_Override ¶
func NewGoogleFirebaseHostingVersion_Override(g GoogleFirebaseHostingVersion, scope constructs.Construct, id *string, config *GoogleFirebaseHostingVersionConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_firebase_hosting_version google_firebase_hosting_version} Resource.
Types ¶
type GoogleFirebaseHostingVersion ¶
type GoogleFirebaseHostingVersion interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
Config() GoogleFirebaseHostingVersionConfigAOutputReference
ConfigInput() *GoogleFirebaseHostingVersionConfigA
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
// The tree node.
Node() constructs.Node
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
SiteId() *string
SetSiteId(val *string)
SiteIdInput() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GoogleFirebaseHostingVersionTimeoutsOutputReference
TimeoutsInput() interface{}
VersionId() *string
// Adds a user defined moveTarget string to this resource to be later used in .moveTo(moveTarget) to resolve the location of the move.
// Experimental.
AddMoveTarget(moveTarget *string)
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
HasResourceMove() interface{}
// Experimental.
ImportFrom(id *string, provider cdktf.TerraformProvider)
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Move the resource corresponding to "id" to this resource.
//
// Note that the resource being moved from must be marked as moved using it's instance function.
// Experimental.
MoveFromId(id *string)
// Moves this resource to the target resource given by moveTarget.
// Experimental.
MoveTo(moveTarget *string, index interface{})
// Moves this resource to the resource corresponding to "id".
// Experimental.
MoveToId(id *string)
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutConfig(value *GoogleFirebaseHostingVersionConfigA)
PutTimeouts(value *GoogleFirebaseHostingVersionTimeouts)
ResetConfig()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_firebase_hosting_version google_firebase_hosting_version}.
func NewGoogleFirebaseHostingVersion ¶
func NewGoogleFirebaseHostingVersion(scope constructs.Construct, id *string, config *GoogleFirebaseHostingVersionConfig) GoogleFirebaseHostingVersion
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_firebase_hosting_version google_firebase_hosting_version} Resource.
type GoogleFirebaseHostingVersionConfig ¶
type GoogleFirebaseHostingVersionConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Required. The ID of the site in which to create this Version.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_firebase_hosting_version#site_id GoogleFirebaseHostingVersion#site_id}
SiteId *string `field:"required" json:"siteId" yaml:"siteId"`
// config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_firebase_hosting_version#config GoogleFirebaseHostingVersion#config}
Config *GoogleFirebaseHostingVersionConfigA `field:"optional" json:"config" yaml:"config"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_firebase_hosting_version#id GoogleFirebaseHostingVersion#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_firebase_hosting_version#timeouts GoogleFirebaseHostingVersion#timeouts}
Timeouts *GoogleFirebaseHostingVersionTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type GoogleFirebaseHostingVersionConfigA ¶
type GoogleFirebaseHostingVersionConfigA struct {
// redirects block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_firebase_hosting_version#redirects GoogleFirebaseHostingVersion#redirects}
Redirects interface{} `field:"optional" json:"redirects" yaml:"redirects"`
// rewrites block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_firebase_hosting_version#rewrites GoogleFirebaseHostingVersion#rewrites}
Rewrites interface{} `field:"optional" json:"rewrites" yaml:"rewrites"`
}
type GoogleFirebaseHostingVersionConfigAOutputReference ¶
type GoogleFirebaseHostingVersionConfigAOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleFirebaseHostingVersionConfigA
SetInternalValue(val *GoogleFirebaseHostingVersionConfigA)
Redirects() GoogleFirebaseHostingVersionConfigRedirectsList
RedirectsInput() interface{}
Rewrites() GoogleFirebaseHostingVersionConfigRewritesList
RewritesInput() interface{}
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutRedirects(value interface{})
PutRewrites(value interface{})
ResetRedirects()
ResetRewrites()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleFirebaseHostingVersionConfigAOutputReference ¶
func NewGoogleFirebaseHostingVersionConfigAOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleFirebaseHostingVersionConfigAOutputReference
type GoogleFirebaseHostingVersionConfigRedirects ¶
type GoogleFirebaseHostingVersionConfigRedirects struct {
// The value to put in the HTTP location header of the response.
//
// The location can contain capture group values from the pattern using a : prefix to identify
// the segment and an optional * to capture the rest of the URL. For example:
//
// “`hcl
// redirects {
// glob = "/:capture*"
// status_code = 302
// location = "https://example.com/foo/:capture"
// }
// “`
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_firebase_hosting_version#location GoogleFirebaseHostingVersion#location}
Location *string `field:"required" json:"location" yaml:"location"`
// The status HTTP code to return in the response. It must be a valid 3xx status code.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_firebase_hosting_version#status_code GoogleFirebaseHostingVersion#status_code}
StatusCode *float64 `field:"required" json:"statusCode" yaml:"statusCode"`
// The user-supplied glob to match against the request URL path.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_firebase_hosting_version#glob GoogleFirebaseHostingVersion#glob}
Glob *string `field:"optional" json:"glob" yaml:"glob"`
// The user-supplied RE2 regular expression to match against the request URL path.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_firebase_hosting_version#regex GoogleFirebaseHostingVersion#regex}
Regex *string `field:"optional" json:"regex" yaml:"regex"`
}
type GoogleFirebaseHostingVersionConfigRedirectsList ¶
type GoogleFirebaseHostingVersionConfigRedirectsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) GoogleFirebaseHostingVersionConfigRedirectsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleFirebaseHostingVersionConfigRedirectsList ¶
func NewGoogleFirebaseHostingVersionConfigRedirectsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GoogleFirebaseHostingVersionConfigRedirectsList
type GoogleFirebaseHostingVersionConfigRedirectsOutputReference ¶
type GoogleFirebaseHostingVersionConfigRedirectsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Glob() *string
SetGlob(val *string)
GlobInput() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Location() *string
SetLocation(val *string)
LocationInput() *string
Regex() *string
SetRegex(val *string)
RegexInput() *string
StatusCode() *float64
SetStatusCode(val *float64)
StatusCodeInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetGlob()
ResetRegex()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleFirebaseHostingVersionConfigRedirectsOutputReference ¶
func NewGoogleFirebaseHostingVersionConfigRedirectsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GoogleFirebaseHostingVersionConfigRedirectsOutputReference
type GoogleFirebaseHostingVersionConfigRewrites ¶
type GoogleFirebaseHostingVersionConfigRewrites struct {
// The function to proxy requests to. Must match the exported function name exactly.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_firebase_hosting_version#function GoogleFirebaseHostingVersion#function}
Function *string `field:"optional" json:"function" yaml:"function"`
// The user-supplied glob to match against the request URL path.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_firebase_hosting_version#glob GoogleFirebaseHostingVersion#glob}
Glob *string `field:"optional" json:"glob" yaml:"glob"`
// The user-supplied RE2 regular expression to match against the request URL path.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_firebase_hosting_version#regex GoogleFirebaseHostingVersion#regex}
Regex *string `field:"optional" json:"regex" yaml:"regex"`
// run block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_firebase_hosting_version#run GoogleFirebaseHostingVersion#run}
Run *GoogleFirebaseHostingVersionConfigRewritesRun `field:"optional" json:"run" yaml:"run"`
}
type GoogleFirebaseHostingVersionConfigRewritesList ¶
type GoogleFirebaseHostingVersionConfigRewritesList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) GoogleFirebaseHostingVersionConfigRewritesOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleFirebaseHostingVersionConfigRewritesList ¶
func NewGoogleFirebaseHostingVersionConfigRewritesList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GoogleFirebaseHostingVersionConfigRewritesList
type GoogleFirebaseHostingVersionConfigRewritesOutputReference ¶
type GoogleFirebaseHostingVersionConfigRewritesOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Function() *string
SetFunction(val *string)
FunctionInput() *string
Glob() *string
SetGlob(val *string)
GlobInput() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Regex() *string
SetRegex(val *string)
RegexInput() *string
Run() GoogleFirebaseHostingVersionConfigRewritesRunOutputReference
RunInput() *GoogleFirebaseHostingVersionConfigRewritesRun
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutRun(value *GoogleFirebaseHostingVersionConfigRewritesRun)
ResetFunction()
ResetGlob()
ResetRegex()
ResetRun()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleFirebaseHostingVersionConfigRewritesOutputReference ¶
func NewGoogleFirebaseHostingVersionConfigRewritesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GoogleFirebaseHostingVersionConfigRewritesOutputReference
type GoogleFirebaseHostingVersionConfigRewritesRun ¶
type GoogleFirebaseHostingVersionConfigRewritesRun struct {
// User-defined ID of the Cloud Run service.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_firebase_hosting_version#service_id GoogleFirebaseHostingVersion#service_id}
ServiceId *string `field:"required" json:"serviceId" yaml:"serviceId"`
// Optional. User-provided region where the Cloud Run service is hosted. Defaults to 'us-central1' if not supplied.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_firebase_hosting_version#region GoogleFirebaseHostingVersion#region}
Region *string `field:"optional" json:"region" yaml:"region"`
}
type GoogleFirebaseHostingVersionConfigRewritesRunOutputReference ¶
type GoogleFirebaseHostingVersionConfigRewritesRunOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleFirebaseHostingVersionConfigRewritesRun
SetInternalValue(val *GoogleFirebaseHostingVersionConfigRewritesRun)
Region() *string
SetRegion(val *string)
RegionInput() *string
ServiceId() *string
SetServiceId(val *string)
ServiceIdInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetRegion()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleFirebaseHostingVersionConfigRewritesRunOutputReference ¶
func NewGoogleFirebaseHostingVersionConfigRewritesRunOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleFirebaseHostingVersionConfigRewritesRunOutputReference
type GoogleFirebaseHostingVersionTimeouts ¶
type GoogleFirebaseHostingVersionTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_firebase_hosting_version#create GoogleFirebaseHostingVersion#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_firebase_hosting_version#delete GoogleFirebaseHostingVersion#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
}
type GoogleFirebaseHostingVersionTimeoutsOutputReference ¶
type GoogleFirebaseHostingVersionTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleFirebaseHostingVersionTimeoutsOutputReference ¶
func NewGoogleFirebaseHostingVersionTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleFirebaseHostingVersionTimeoutsOutputReference
Source Files
¶
- GoogleFirebaseHostingVersion.go
- GoogleFirebaseHostingVersionConfig.go
- GoogleFirebaseHostingVersionConfigA.go
- GoogleFirebaseHostingVersionConfigAOutputReference.go
- GoogleFirebaseHostingVersionConfigAOutputReference__checks.go
- GoogleFirebaseHostingVersionConfigRedirects.go
- GoogleFirebaseHostingVersionConfigRedirectsList.go
- GoogleFirebaseHostingVersionConfigRedirectsList__checks.go
- GoogleFirebaseHostingVersionConfigRedirectsOutputReference.go
- GoogleFirebaseHostingVersionConfigRedirectsOutputReference__checks.go
- GoogleFirebaseHostingVersionConfigRewrites.go
- GoogleFirebaseHostingVersionConfigRewritesList.go
- GoogleFirebaseHostingVersionConfigRewritesList__checks.go
- GoogleFirebaseHostingVersionConfigRewritesOutputReference.go
- GoogleFirebaseHostingVersionConfigRewritesOutputReference__checks.go
- GoogleFirebaseHostingVersionConfigRewritesRun.go
- GoogleFirebaseHostingVersionConfigRewritesRunOutputReference.go
- GoogleFirebaseHostingVersionConfigRewritesRunOutputReference__checks.go
- GoogleFirebaseHostingVersionTimeouts.go
- GoogleFirebaseHostingVersionTimeoutsOutputReference.go
- GoogleFirebaseHostingVersionTimeoutsOutputReference__checks.go
- GoogleFirebaseHostingVersion__checks.go
- main.go