Documentation
¶
Index ¶
- func GoogleLoggingOrganizationSink_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func GoogleLoggingOrganizationSink_IsConstruct(x interface{}) *bool
- func GoogleLoggingOrganizationSink_IsTerraformElement(x interface{}) *bool
- func GoogleLoggingOrganizationSink_IsTerraformResource(x interface{}) *bool
- func GoogleLoggingOrganizationSink_TfResourceType() *string
- func NewGoogleLoggingOrganizationSinkBigqueryOptionsOutputReference_Override(g GoogleLoggingOrganizationSinkBigqueryOptionsOutputReference, ...)
- func NewGoogleLoggingOrganizationSinkExclusionsList_Override(g GoogleLoggingOrganizationSinkExclusionsList, ...)
- func NewGoogleLoggingOrganizationSinkExclusionsOutputReference_Override(g GoogleLoggingOrganizationSinkExclusionsOutputReference, ...)
- func NewGoogleLoggingOrganizationSink_Override(g GoogleLoggingOrganizationSink, scope constructs.Construct, id *string, ...)
- type GoogleLoggingOrganizationSink
- type GoogleLoggingOrganizationSinkBigqueryOptions
- type GoogleLoggingOrganizationSinkBigqueryOptionsOutputReference
- type GoogleLoggingOrganizationSinkConfig
- type GoogleLoggingOrganizationSinkExclusions
- type GoogleLoggingOrganizationSinkExclusionsList
- type GoogleLoggingOrganizationSinkExclusionsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleLoggingOrganizationSink_GenerateConfigForImport ¶
func GoogleLoggingOrganizationSink_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a GoogleLoggingOrganizationSink resource upon running "cdktf plan <stack-name>".
func GoogleLoggingOrganizationSink_IsConstruct ¶
func GoogleLoggingOrganizationSink_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleLoggingOrganizationSink_IsTerraformElement ¶
func GoogleLoggingOrganizationSink_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleLoggingOrganizationSink_IsTerraformResource ¶
func GoogleLoggingOrganizationSink_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleLoggingOrganizationSink_TfResourceType ¶
func GoogleLoggingOrganizationSink_TfResourceType() *string
func NewGoogleLoggingOrganizationSinkBigqueryOptionsOutputReference_Override ¶
func NewGoogleLoggingOrganizationSinkBigqueryOptionsOutputReference_Override(g GoogleLoggingOrganizationSinkBigqueryOptionsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleLoggingOrganizationSinkExclusionsList_Override ¶
func NewGoogleLoggingOrganizationSinkExclusionsList_Override(g GoogleLoggingOrganizationSinkExclusionsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGoogleLoggingOrganizationSinkExclusionsOutputReference_Override ¶
func NewGoogleLoggingOrganizationSinkExclusionsOutputReference_Override(g GoogleLoggingOrganizationSinkExclusionsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGoogleLoggingOrganizationSink_Override ¶
func NewGoogleLoggingOrganizationSink_Override(g GoogleLoggingOrganizationSink, scope constructs.Construct, id *string, config *GoogleLoggingOrganizationSinkConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_logging_organization_sink google_logging_organization_sink} Resource.
Types ¶
type GoogleLoggingOrganizationSink ¶
type GoogleLoggingOrganizationSink interface {
cdktf.TerraformResource
BigqueryOptions() GoogleLoggingOrganizationSinkBigqueryOptionsOutputReference
BigqueryOptionsInput() *GoogleLoggingOrganizationSinkBigqueryOptions
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
Destination() *string
SetDestination(val *string)
DestinationInput() *string
Disabled() interface{}
SetDisabled(val interface{})
DisabledInput() interface{}
Exclusions() GoogleLoggingOrganizationSinkExclusionsList
ExclusionsInput() interface{}
Filter() *string
SetFilter(val *string)
FilterInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
IncludeChildren() interface{}
SetIncludeChildren(val interface{})
IncludeChildrenInput() interface{}
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
OrgId() *string
SetOrgId(val *string)
OrgIdInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
WriterIdentity() *string
// Adds a user defined moveTarget string to this resource to be later used in .moveTo(moveTarget) to resolve the location of the move.
// Experimental.
AddMoveTarget(moveTarget *string)
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
HasResourceMove() interface{}
// Experimental.
ImportFrom(id *string, provider cdktf.TerraformProvider)
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Move the resource corresponding to "id" to this resource.
//
// Note that the resource being moved from must be marked as moved using it's instance function.
// Experimental.
MoveFromId(id *string)
// Moves this resource to the target resource given by moveTarget.
// Experimental.
MoveTo(moveTarget *string, index interface{})
// Moves this resource to the resource corresponding to "id".
// Experimental.
MoveToId(id *string)
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutBigqueryOptions(value *GoogleLoggingOrganizationSinkBigqueryOptions)
PutExclusions(value interface{})
ResetBigqueryOptions()
ResetDescription()
ResetDisabled()
ResetExclusions()
ResetFilter()
ResetId()
ResetIncludeChildren()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_logging_organization_sink google_logging_organization_sink}.
func NewGoogleLoggingOrganizationSink ¶
func NewGoogleLoggingOrganizationSink(scope constructs.Construct, id *string, config *GoogleLoggingOrganizationSinkConfig) GoogleLoggingOrganizationSink
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_logging_organization_sink google_logging_organization_sink} Resource.
type GoogleLoggingOrganizationSinkBigqueryOptions ¶
type GoogleLoggingOrganizationSinkBigqueryOptions struct {
// Whether to use BigQuery's partition tables.
//
// By default, Logging creates dated tables based on the log entries' timestamps, e.g. syslog_20170523. With partitioned tables the date suffix is no longer present and special query syntax has to be used instead. In both cases, tables are sharded based on UTC timezone.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_logging_organization_sink#use_partitioned_tables GoogleLoggingOrganizationSink#use_partitioned_tables}
UsePartitionedTables interface{} `field:"required" json:"usePartitionedTables" yaml:"usePartitionedTables"`
}
type GoogleLoggingOrganizationSinkBigqueryOptionsOutputReference ¶
type GoogleLoggingOrganizationSinkBigqueryOptionsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleLoggingOrganizationSinkBigqueryOptions
SetInternalValue(val *GoogleLoggingOrganizationSinkBigqueryOptions)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
UsePartitionedTables() interface{}
SetUsePartitionedTables(val interface{})
UsePartitionedTablesInput() interface{}
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleLoggingOrganizationSinkBigqueryOptionsOutputReference ¶
func NewGoogleLoggingOrganizationSinkBigqueryOptionsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleLoggingOrganizationSinkBigqueryOptionsOutputReference
type GoogleLoggingOrganizationSinkConfig ¶
type GoogleLoggingOrganizationSinkConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// The destination of the sink (or, in other words, where logs are written to).
//
// Can be a Cloud Storage bucket, a PubSub topic, or a BigQuery dataset. Examples: "storage.googleapis.com/[GCS_BUCKET]" "bigquery.googleapis.com/projects/[PROJECT_ID]/datasets/[DATASET]" "pubsub.googleapis.com/projects/[PROJECT_ID]/topics/[TOPIC_ID]" The writer associated with the sink must have access to write to the above resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_logging_organization_sink#destination GoogleLoggingOrganizationSink#destination}
Destination *string `field:"required" json:"destination" yaml:"destination"`
// The name of the logging sink.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_logging_organization_sink#name GoogleLoggingOrganizationSink#name}
Name *string `field:"required" json:"name" yaml:"name"`
// The numeric ID of the organization to be exported to the sink.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_logging_organization_sink#org_id GoogleLoggingOrganizationSink#org_id}
OrgId *string `field:"required" json:"orgId" yaml:"orgId"`
// bigquery_options block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_logging_organization_sink#bigquery_options GoogleLoggingOrganizationSink#bigquery_options}
BigqueryOptions *GoogleLoggingOrganizationSinkBigqueryOptions `field:"optional" json:"bigqueryOptions" yaml:"bigqueryOptions"`
// A description of this sink. The maximum length of the description is 8000 characters.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_logging_organization_sink#description GoogleLoggingOrganizationSink#description}
Description *string `field:"optional" json:"description" yaml:"description"`
// If set to True, then this sink is disabled and it does not export any log entries.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_logging_organization_sink#disabled GoogleLoggingOrganizationSink#disabled}
Disabled interface{} `field:"optional" json:"disabled" yaml:"disabled"`
// exclusions block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_logging_organization_sink#exclusions GoogleLoggingOrganizationSink#exclusions}
Exclusions interface{} `field:"optional" json:"exclusions" yaml:"exclusions"`
// The filter to apply when exporting logs. Only log entries that match the filter are exported.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_logging_organization_sink#filter GoogleLoggingOrganizationSink#filter}
Filter *string `field:"optional" json:"filter" yaml:"filter"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_logging_organization_sink#id GoogleLoggingOrganizationSink#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Whether or not to include children organizations in the sink export.
//
// If true, logs associated with child projects are also exported; otherwise only logs relating to the provided organization are included.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_logging_organization_sink#include_children GoogleLoggingOrganizationSink#include_children}
IncludeChildren interface{} `field:"optional" json:"includeChildren" yaml:"includeChildren"`
}
type GoogleLoggingOrganizationSinkExclusions ¶
type GoogleLoggingOrganizationSinkExclusions struct {
// An advanced logs filter that matches the log entries to be excluded.
//
// By using the sample function, you can exclude less than 100% of the matching log entries
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_logging_organization_sink#filter GoogleLoggingOrganizationSink#filter}
Filter *string `field:"required" json:"filter" yaml:"filter"`
// A client-assigned identifier, such as "load-balancer-exclusion".
//
// Identifiers are limited to 100 characters and can include only letters, digits, underscores, hyphens, and periods. First character has to be alphanumeric.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_logging_organization_sink#name GoogleLoggingOrganizationSink#name}
Name *string `field:"required" json:"name" yaml:"name"`
// A description of this exclusion.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_logging_organization_sink#description GoogleLoggingOrganizationSink#description}
Description *string `field:"optional" json:"description" yaml:"description"`
// If set to True, then this exclusion is disabled and it does not exclude any log entries.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_logging_organization_sink#disabled GoogleLoggingOrganizationSink#disabled}
Disabled interface{} `field:"optional" json:"disabled" yaml:"disabled"`
}
type GoogleLoggingOrganizationSinkExclusionsList ¶
type GoogleLoggingOrganizationSinkExclusionsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) GoogleLoggingOrganizationSinkExclusionsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleLoggingOrganizationSinkExclusionsList ¶
func NewGoogleLoggingOrganizationSinkExclusionsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GoogleLoggingOrganizationSinkExclusionsList
type GoogleLoggingOrganizationSinkExclusionsOutputReference ¶
type GoogleLoggingOrganizationSinkExclusionsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Description() *string
SetDescription(val *string)
DescriptionInput() *string
Disabled() interface{}
SetDisabled(val interface{})
DisabledInput() interface{}
Filter() *string
SetFilter(val *string)
FilterInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Name() *string
SetName(val *string)
NameInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetDescription()
ResetDisabled()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleLoggingOrganizationSinkExclusionsOutputReference ¶
func NewGoogleLoggingOrganizationSinkExclusionsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GoogleLoggingOrganizationSinkExclusionsOutputReference
Source Files
¶
- GoogleLoggingOrganizationSink.go
- GoogleLoggingOrganizationSinkBigqueryOptions.go
- GoogleLoggingOrganizationSinkBigqueryOptionsOutputReference.go
- GoogleLoggingOrganizationSinkBigqueryOptionsOutputReference__checks.go
- GoogleLoggingOrganizationSinkConfig.go
- GoogleLoggingOrganizationSinkExclusions.go
- GoogleLoggingOrganizationSinkExclusionsList.go
- GoogleLoggingOrganizationSinkExclusionsList__checks.go
- GoogleLoggingOrganizationSinkExclusionsOutputReference.go
- GoogleLoggingOrganizationSinkExclusionsOutputReference__checks.go
- GoogleLoggingOrganizationSink__checks.go
- main.go