Documentation
¶
Index ¶
- func GoogleMonitoringCustomService_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func GoogleMonitoringCustomService_IsConstruct(x interface{}) *bool
- func GoogleMonitoringCustomService_IsTerraformElement(x interface{}) *bool
- func GoogleMonitoringCustomService_IsTerraformResource(x interface{}) *bool
- func GoogleMonitoringCustomService_TfResourceType() *string
- func NewGoogleMonitoringCustomServiceTelemetryOutputReference_Override(g GoogleMonitoringCustomServiceTelemetryOutputReference, ...)
- func NewGoogleMonitoringCustomServiceTimeoutsOutputReference_Override(g GoogleMonitoringCustomServiceTimeoutsOutputReference, ...)
- func NewGoogleMonitoringCustomService_Override(g GoogleMonitoringCustomService, scope constructs.Construct, id *string, ...)
- type GoogleMonitoringCustomService
- type GoogleMonitoringCustomServiceConfig
- type GoogleMonitoringCustomServiceTelemetry
- type GoogleMonitoringCustomServiceTelemetryOutputReference
- type GoogleMonitoringCustomServiceTimeouts
- type GoogleMonitoringCustomServiceTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleMonitoringCustomService_GenerateConfigForImport ¶
func GoogleMonitoringCustomService_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a GoogleMonitoringCustomService resource upon running "cdktf plan <stack-name>".
func GoogleMonitoringCustomService_IsConstruct ¶
func GoogleMonitoringCustomService_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleMonitoringCustomService_IsTerraformElement ¶
func GoogleMonitoringCustomService_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleMonitoringCustomService_IsTerraformResource ¶
func GoogleMonitoringCustomService_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleMonitoringCustomService_TfResourceType ¶
func GoogleMonitoringCustomService_TfResourceType() *string
func NewGoogleMonitoringCustomServiceTelemetryOutputReference_Override ¶
func NewGoogleMonitoringCustomServiceTelemetryOutputReference_Override(g GoogleMonitoringCustomServiceTelemetryOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleMonitoringCustomServiceTimeoutsOutputReference_Override ¶
func NewGoogleMonitoringCustomServiceTimeoutsOutputReference_Override(g GoogleMonitoringCustomServiceTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleMonitoringCustomService_Override ¶
func NewGoogleMonitoringCustomService_Override(g GoogleMonitoringCustomService, scope constructs.Construct, id *string, config *GoogleMonitoringCustomServiceConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_monitoring_custom_service google_monitoring_custom_service} Resource.
Types ¶
type GoogleMonitoringCustomService ¶
type GoogleMonitoringCustomService interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DisplayName() *string
SetDisplayName(val *string)
DisplayNameInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
// The tree node.
Node() constructs.Node
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
ServiceId() *string
SetServiceId(val *string)
ServiceIdInput() *string
Telemetry() GoogleMonitoringCustomServiceTelemetryOutputReference
TelemetryInput() *GoogleMonitoringCustomServiceTelemetry
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GoogleMonitoringCustomServiceTimeoutsOutputReference
TimeoutsInput() interface{}
UserLabels() *map[string]*string
SetUserLabels(val *map[string]*string)
UserLabelsInput() *map[string]*string
// Adds a user defined moveTarget string to this resource to be later used in .moveTo(moveTarget) to resolve the location of the move.
// Experimental.
AddMoveTarget(moveTarget *string)
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
HasResourceMove() interface{}
// Experimental.
ImportFrom(id *string, provider cdktf.TerraformProvider)
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Move the resource corresponding to "id" to this resource.
//
// Note that the resource being moved from must be marked as moved using it's instance function.
// Experimental.
MoveFromId(id *string)
// Moves this resource to the target resource given by moveTarget.
// Experimental.
MoveTo(moveTarget *string, index interface{})
// Moves this resource to the resource corresponding to "id".
// Experimental.
MoveToId(id *string)
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutTelemetry(value *GoogleMonitoringCustomServiceTelemetry)
PutTimeouts(value *GoogleMonitoringCustomServiceTimeouts)
ResetDisplayName()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
ResetServiceId()
ResetTelemetry()
ResetTimeouts()
ResetUserLabels()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_monitoring_custom_service google_monitoring_custom_service}.
func NewGoogleMonitoringCustomService ¶
func NewGoogleMonitoringCustomService(scope constructs.Construct, id *string, config *GoogleMonitoringCustomServiceConfig) GoogleMonitoringCustomService
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_monitoring_custom_service google_monitoring_custom_service} Resource.
type GoogleMonitoringCustomServiceConfig ¶
type GoogleMonitoringCustomServiceConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Name used for UI elements listing this Service.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_monitoring_custom_service#display_name GoogleMonitoringCustomService#display_name}
DisplayName *string `field:"optional" json:"displayName" yaml:"displayName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_monitoring_custom_service#id GoogleMonitoringCustomService#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_monitoring_custom_service#project GoogleMonitoringCustomService#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// An optional service ID to use. If not given, the server will generate a service ID.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_monitoring_custom_service#service_id GoogleMonitoringCustomService#service_id}
ServiceId *string `field:"optional" json:"serviceId" yaml:"serviceId"`
// telemetry block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_monitoring_custom_service#telemetry GoogleMonitoringCustomService#telemetry}
Telemetry *GoogleMonitoringCustomServiceTelemetry `field:"optional" json:"telemetry" yaml:"telemetry"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_monitoring_custom_service#timeouts GoogleMonitoringCustomService#timeouts}
Timeouts *GoogleMonitoringCustomServiceTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
// Labels which have been used to annotate the service.
//
// Label keys must start
// with a letter. Label keys and values may contain lowercase letters,
// numbers, underscores, and dashes. Label keys and values have a maximum
// length of 63 characters, and must be less than 128 bytes in size. Up to 64
// label entries may be stored. For labels which do not have a semantic value,
// the empty string may be supplied for the label value.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_monitoring_custom_service#user_labels GoogleMonitoringCustomService#user_labels}
UserLabels *map[string]*string `field:"optional" json:"userLabels" yaml:"userLabels"`
}
type GoogleMonitoringCustomServiceTelemetry ¶
type GoogleMonitoringCustomServiceTelemetry struct {
// The full name of the resource that defines this service. Formatted as described in https://cloud.google.com/apis/design/resource_names.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_monitoring_custom_service#resource_name GoogleMonitoringCustomService#resource_name}
ResourceName *string `field:"optional" json:"resourceName" yaml:"resourceName"`
}
type GoogleMonitoringCustomServiceTelemetryOutputReference ¶
type GoogleMonitoringCustomServiceTelemetryOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleMonitoringCustomServiceTelemetry
SetInternalValue(val *GoogleMonitoringCustomServiceTelemetry)
ResourceName() *string
SetResourceName(val *string)
ResourceNameInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetResourceName()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleMonitoringCustomServiceTelemetryOutputReference ¶
func NewGoogleMonitoringCustomServiceTelemetryOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleMonitoringCustomServiceTelemetryOutputReference
type GoogleMonitoringCustomServiceTimeouts ¶
type GoogleMonitoringCustomServiceTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_monitoring_custom_service#create GoogleMonitoringCustomService#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_monitoring_custom_service#delete GoogleMonitoringCustomService#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_monitoring_custom_service#update GoogleMonitoringCustomService#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type GoogleMonitoringCustomServiceTimeoutsOutputReference ¶
type GoogleMonitoringCustomServiceTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleMonitoringCustomServiceTimeoutsOutputReference ¶
func NewGoogleMonitoringCustomServiceTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleMonitoringCustomServiceTimeoutsOutputReference
Source Files
¶
- GoogleMonitoringCustomService.go
- GoogleMonitoringCustomServiceConfig.go
- GoogleMonitoringCustomServiceTelemetry.go
- GoogleMonitoringCustomServiceTelemetryOutputReference.go
- GoogleMonitoringCustomServiceTelemetryOutputReference__checks.go
- GoogleMonitoringCustomServiceTimeouts.go
- GoogleMonitoringCustomServiceTimeoutsOutputReference.go
- GoogleMonitoringCustomServiceTimeoutsOutputReference__checks.go
- GoogleMonitoringCustomService__checks.go
- main.go