Documentation
¶
Index ¶
- func GoogleNetworkConnectivityPolicyBasedRoute_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func GoogleNetworkConnectivityPolicyBasedRoute_IsConstruct(x interface{}) *bool
- func GoogleNetworkConnectivityPolicyBasedRoute_IsTerraformElement(x interface{}) *bool
- func GoogleNetworkConnectivityPolicyBasedRoute_IsTerraformResource(x interface{}) *bool
- func GoogleNetworkConnectivityPolicyBasedRoute_TfResourceType() *string
- func NewGoogleNetworkConnectivityPolicyBasedRouteFilterOutputReference_Override(g GoogleNetworkConnectivityPolicyBasedRouteFilterOutputReference, ...)
- func NewGoogleNetworkConnectivityPolicyBasedRouteInterconnectAttachmentOutputReference_Override(...)
- func NewGoogleNetworkConnectivityPolicyBasedRouteTimeoutsOutputReference_Override(g GoogleNetworkConnectivityPolicyBasedRouteTimeoutsOutputReference, ...)
- func NewGoogleNetworkConnectivityPolicyBasedRouteVirtualMachineOutputReference_Override(g GoogleNetworkConnectivityPolicyBasedRouteVirtualMachineOutputReference, ...)
- func NewGoogleNetworkConnectivityPolicyBasedRouteWarningsList_Override(g GoogleNetworkConnectivityPolicyBasedRouteWarningsList, ...)
- func NewGoogleNetworkConnectivityPolicyBasedRouteWarningsOutputReference_Override(g GoogleNetworkConnectivityPolicyBasedRouteWarningsOutputReference, ...)
- func NewGoogleNetworkConnectivityPolicyBasedRoute_Override(g GoogleNetworkConnectivityPolicyBasedRoute, scope constructs.Construct, ...)
- type GoogleNetworkConnectivityPolicyBasedRoute
- type GoogleNetworkConnectivityPolicyBasedRouteConfig
- type GoogleNetworkConnectivityPolicyBasedRouteFilter
- type GoogleNetworkConnectivityPolicyBasedRouteFilterOutputReference
- type GoogleNetworkConnectivityPolicyBasedRouteInterconnectAttachment
- type GoogleNetworkConnectivityPolicyBasedRouteInterconnectAttachmentOutputReference
- type GoogleNetworkConnectivityPolicyBasedRouteTimeouts
- type GoogleNetworkConnectivityPolicyBasedRouteTimeoutsOutputReference
- type GoogleNetworkConnectivityPolicyBasedRouteVirtualMachine
- type GoogleNetworkConnectivityPolicyBasedRouteVirtualMachineOutputReference
- type GoogleNetworkConnectivityPolicyBasedRouteWarnings
- type GoogleNetworkConnectivityPolicyBasedRouteWarningsList
- type GoogleNetworkConnectivityPolicyBasedRouteWarningsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleNetworkConnectivityPolicyBasedRoute_GenerateConfigForImport ¶
func GoogleNetworkConnectivityPolicyBasedRoute_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a GoogleNetworkConnectivityPolicyBasedRoute resource upon running "cdktf plan <stack-name>".
func GoogleNetworkConnectivityPolicyBasedRoute_IsConstruct ¶
func GoogleNetworkConnectivityPolicyBasedRoute_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleNetworkConnectivityPolicyBasedRoute_IsTerraformElement ¶
func GoogleNetworkConnectivityPolicyBasedRoute_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleNetworkConnectivityPolicyBasedRoute_IsTerraformResource ¶
func GoogleNetworkConnectivityPolicyBasedRoute_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleNetworkConnectivityPolicyBasedRoute_TfResourceType ¶
func GoogleNetworkConnectivityPolicyBasedRoute_TfResourceType() *string
func NewGoogleNetworkConnectivityPolicyBasedRouteFilterOutputReference_Override ¶
func NewGoogleNetworkConnectivityPolicyBasedRouteFilterOutputReference_Override(g GoogleNetworkConnectivityPolicyBasedRouteFilterOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleNetworkConnectivityPolicyBasedRouteInterconnectAttachmentOutputReference_Override ¶
func NewGoogleNetworkConnectivityPolicyBasedRouteInterconnectAttachmentOutputReference_Override(g GoogleNetworkConnectivityPolicyBasedRouteInterconnectAttachmentOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleNetworkConnectivityPolicyBasedRouteTimeoutsOutputReference_Override ¶
func NewGoogleNetworkConnectivityPolicyBasedRouteTimeoutsOutputReference_Override(g GoogleNetworkConnectivityPolicyBasedRouteTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleNetworkConnectivityPolicyBasedRouteVirtualMachineOutputReference_Override ¶
func NewGoogleNetworkConnectivityPolicyBasedRouteVirtualMachineOutputReference_Override(g GoogleNetworkConnectivityPolicyBasedRouteVirtualMachineOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleNetworkConnectivityPolicyBasedRouteWarningsList_Override ¶
func NewGoogleNetworkConnectivityPolicyBasedRouteWarningsList_Override(g GoogleNetworkConnectivityPolicyBasedRouteWarningsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGoogleNetworkConnectivityPolicyBasedRouteWarningsOutputReference_Override ¶
func NewGoogleNetworkConnectivityPolicyBasedRouteWarningsOutputReference_Override(g GoogleNetworkConnectivityPolicyBasedRouteWarningsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGoogleNetworkConnectivityPolicyBasedRoute_Override ¶
func NewGoogleNetworkConnectivityPolicyBasedRoute_Override(g GoogleNetworkConnectivityPolicyBasedRoute, scope constructs.Construct, id *string, config *GoogleNetworkConnectivityPolicyBasedRouteConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_network_connectivity_policy_based_route google_network_connectivity_policy_based_route} Resource.
Types ¶
type GoogleNetworkConnectivityPolicyBasedRoute ¶
type GoogleNetworkConnectivityPolicyBasedRoute interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
CreateTime() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
EffectiveLabels() cdktf.StringMap
Filter() GoogleNetworkConnectivityPolicyBasedRouteFilterOutputReference
FilterInput() *GoogleNetworkConnectivityPolicyBasedRouteFilter
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
InterconnectAttachment() GoogleNetworkConnectivityPolicyBasedRouteInterconnectAttachmentOutputReference
InterconnectAttachmentInput() *GoogleNetworkConnectivityPolicyBasedRouteInterconnectAttachment
Kind() *string
Labels() *map[string]*string
SetLabels(val *map[string]*string)
LabelsInput() *map[string]*string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
Network() *string
SetNetwork(val *string)
NetworkInput() *string
NextHopIlbIp() *string
SetNextHopIlbIp(val *string)
NextHopIlbIpInput() *string
NextHopOtherRoutes() *string
SetNextHopOtherRoutes(val *string)
NextHopOtherRoutesInput() *string
// The tree node.
Node() constructs.Node
Priority() *float64
SetPriority(val *float64)
PriorityInput() *float64
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
TerraformLabels() cdktf.StringMap
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GoogleNetworkConnectivityPolicyBasedRouteTimeoutsOutputReference
TimeoutsInput() interface{}
UpdateTime() *string
VirtualMachine() GoogleNetworkConnectivityPolicyBasedRouteVirtualMachineOutputReference
VirtualMachineInput() *GoogleNetworkConnectivityPolicyBasedRouteVirtualMachine
Warnings() GoogleNetworkConnectivityPolicyBasedRouteWarningsList
// Adds a user defined moveTarget string to this resource to be later used in .moveTo(moveTarget) to resolve the location of the move.
// Experimental.
AddMoveTarget(moveTarget *string)
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
HasResourceMove() interface{}
// Experimental.
ImportFrom(id *string, provider cdktf.TerraformProvider)
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Move the resource corresponding to "id" to this resource.
//
// Note that the resource being moved from must be marked as moved using it's instance function.
// Experimental.
MoveFromId(id *string)
// Moves this resource to the target resource given by moveTarget.
// Experimental.
MoveTo(moveTarget *string, index interface{})
// Moves this resource to the resource corresponding to "id".
// Experimental.
MoveToId(id *string)
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutFilter(value *GoogleNetworkConnectivityPolicyBasedRouteFilter)
PutInterconnectAttachment(value *GoogleNetworkConnectivityPolicyBasedRouteInterconnectAttachment)
PutTimeouts(value *GoogleNetworkConnectivityPolicyBasedRouteTimeouts)
PutVirtualMachine(value *GoogleNetworkConnectivityPolicyBasedRouteVirtualMachine)
ResetDescription()
ResetId()
ResetInterconnectAttachment()
ResetLabels()
ResetNextHopIlbIp()
ResetNextHopOtherRoutes()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetPriority()
ResetProject()
ResetTimeouts()
ResetVirtualMachine()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_network_connectivity_policy_based_route google_network_connectivity_policy_based_route}.
func NewGoogleNetworkConnectivityPolicyBasedRoute ¶
func NewGoogleNetworkConnectivityPolicyBasedRoute(scope constructs.Construct, id *string, config *GoogleNetworkConnectivityPolicyBasedRouteConfig) GoogleNetworkConnectivityPolicyBasedRoute
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_network_connectivity_policy_based_route google_network_connectivity_policy_based_route} Resource.
type GoogleNetworkConnectivityPolicyBasedRouteConfig ¶
type GoogleNetworkConnectivityPolicyBasedRouteConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// filter block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_network_connectivity_policy_based_route#filter GoogleNetworkConnectivityPolicyBasedRoute#filter}
Filter *GoogleNetworkConnectivityPolicyBasedRouteFilter `field:"required" json:"filter" yaml:"filter"`
// The name of the policy based route.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_network_connectivity_policy_based_route#name GoogleNetworkConnectivityPolicyBasedRoute#name}
Name *string `field:"required" json:"name" yaml:"name"`
// Fully-qualified URL of the network that this route applies to, for example: projects/my-project/global/networks/my-network.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_network_connectivity_policy_based_route#network GoogleNetworkConnectivityPolicyBasedRoute#network}
Network *string `field:"required" json:"network" yaml:"network"`
// An optional description of this resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_network_connectivity_policy_based_route#description GoogleNetworkConnectivityPolicyBasedRoute#description}
Description *string `field:"optional" json:"description" yaml:"description"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_network_connectivity_policy_based_route#id GoogleNetworkConnectivityPolicyBasedRoute#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// interconnect_attachment block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_network_connectivity_policy_based_route#interconnect_attachment GoogleNetworkConnectivityPolicyBasedRoute#interconnect_attachment}
InterconnectAttachment *GoogleNetworkConnectivityPolicyBasedRouteInterconnectAttachment `field:"optional" json:"interconnectAttachment" yaml:"interconnectAttachment"`
// User-defined labels.
//
// **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
// Please refer to the field 'effective_labels' for all of the labels present on the resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_network_connectivity_policy_based_route#labels GoogleNetworkConnectivityPolicyBasedRoute#labels}
Labels *map[string]*string `field:"optional" json:"labels" yaml:"labels"`
// The IP address of a global-access-enabled L4 ILB that is the next hop for matching packets.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_network_connectivity_policy_based_route#next_hop_ilb_ip GoogleNetworkConnectivityPolicyBasedRoute#next_hop_ilb_ip}
NextHopIlbIp *string `field:"optional" json:"nextHopIlbIp" yaml:"nextHopIlbIp"`
// Other routes that will be referenced to determine the next hop of the packet. Possible values: ["DEFAULT_ROUTING"].
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_network_connectivity_policy_based_route#next_hop_other_routes GoogleNetworkConnectivityPolicyBasedRoute#next_hop_other_routes}
NextHopOtherRoutes *string `field:"optional" json:"nextHopOtherRoutes" yaml:"nextHopOtherRoutes"`
// The priority of this policy-based route.
//
// Priority is used to break ties in cases where there are more than one matching policy-based routes found. In cases where multiple policy-based routes are matched, the one with the lowest-numbered priority value wins. The default value is 1000. The priority value must be from 1 to 65535, inclusive.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_network_connectivity_policy_based_route#priority GoogleNetworkConnectivityPolicyBasedRoute#priority}
Priority *float64 `field:"optional" json:"priority" yaml:"priority"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_network_connectivity_policy_based_route#project GoogleNetworkConnectivityPolicyBasedRoute#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_network_connectivity_policy_based_route#timeouts GoogleNetworkConnectivityPolicyBasedRoute#timeouts}
Timeouts *GoogleNetworkConnectivityPolicyBasedRouteTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
// virtual_machine block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_network_connectivity_policy_based_route#virtual_machine GoogleNetworkConnectivityPolicyBasedRoute#virtual_machine}
VirtualMachine *GoogleNetworkConnectivityPolicyBasedRouteVirtualMachine `field:"optional" json:"virtualMachine" yaml:"virtualMachine"`
}
type GoogleNetworkConnectivityPolicyBasedRouteFilter ¶
type GoogleNetworkConnectivityPolicyBasedRouteFilter struct {
// Internet protocol versions this policy-based route applies to. Possible values: ["IPV4"].
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_network_connectivity_policy_based_route#protocol_version GoogleNetworkConnectivityPolicyBasedRoute#protocol_version}
ProtocolVersion *string `field:"required" json:"protocolVersion" yaml:"protocolVersion"`
// The destination IP range of outgoing packets that this policy-based route applies to.
//
// Default is "0.0.0.0/0" if protocol version is IPv4.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_network_connectivity_policy_based_route#dest_range GoogleNetworkConnectivityPolicyBasedRoute#dest_range}
DestRange *string `field:"optional" json:"destRange" yaml:"destRange"`
// The IP protocol that this policy-based route applies to. Valid values are 'TCP', 'UDP', and 'ALL'. Default is 'ALL'.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_network_connectivity_policy_based_route#ip_protocol GoogleNetworkConnectivityPolicyBasedRoute#ip_protocol}
IpProtocol *string `field:"optional" json:"ipProtocol" yaml:"ipProtocol"`
// The source IP range of outgoing packets that this policy-based route applies to.
//
// Default is "0.0.0.0/0" if protocol version is IPv4.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_network_connectivity_policy_based_route#src_range GoogleNetworkConnectivityPolicyBasedRoute#src_range}
SrcRange *string `field:"optional" json:"srcRange" yaml:"srcRange"`
}
type GoogleNetworkConnectivityPolicyBasedRouteFilterOutputReference ¶
type GoogleNetworkConnectivityPolicyBasedRouteFilterOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DestRange() *string
SetDestRange(val *string)
DestRangeInput() *string
// Experimental.
Fqn() *string
InternalValue() *GoogleNetworkConnectivityPolicyBasedRouteFilter
SetInternalValue(val *GoogleNetworkConnectivityPolicyBasedRouteFilter)
IpProtocol() *string
SetIpProtocol(val *string)
IpProtocolInput() *string
ProtocolVersion() *string
SetProtocolVersion(val *string)
ProtocolVersionInput() *string
SrcRange() *string
SetSrcRange(val *string)
SrcRangeInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetDestRange()
ResetIpProtocol()
ResetSrcRange()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleNetworkConnectivityPolicyBasedRouteFilterOutputReference ¶
func NewGoogleNetworkConnectivityPolicyBasedRouteFilterOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleNetworkConnectivityPolicyBasedRouteFilterOutputReference
type GoogleNetworkConnectivityPolicyBasedRouteInterconnectAttachment ¶
type GoogleNetworkConnectivityPolicyBasedRouteInterconnectAttachment struct {
// Cloud region to install this policy-based route on for Interconnect attachments.
//
// Use 'all' to install it on all Interconnect attachments.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_network_connectivity_policy_based_route#region GoogleNetworkConnectivityPolicyBasedRoute#region}
Region *string `field:"required" json:"region" yaml:"region"`
}
type GoogleNetworkConnectivityPolicyBasedRouteInterconnectAttachmentOutputReference ¶
type GoogleNetworkConnectivityPolicyBasedRouteInterconnectAttachmentOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleNetworkConnectivityPolicyBasedRouteInterconnectAttachment
SetInternalValue(val *GoogleNetworkConnectivityPolicyBasedRouteInterconnectAttachment)
Region() *string
SetRegion(val *string)
RegionInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleNetworkConnectivityPolicyBasedRouteInterconnectAttachmentOutputReference ¶
func NewGoogleNetworkConnectivityPolicyBasedRouteInterconnectAttachmentOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleNetworkConnectivityPolicyBasedRouteInterconnectAttachmentOutputReference
type GoogleNetworkConnectivityPolicyBasedRouteTimeouts ¶
type GoogleNetworkConnectivityPolicyBasedRouteTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_network_connectivity_policy_based_route#create GoogleNetworkConnectivityPolicyBasedRoute#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_network_connectivity_policy_based_route#delete GoogleNetworkConnectivityPolicyBasedRoute#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
}
type GoogleNetworkConnectivityPolicyBasedRouteTimeoutsOutputReference ¶
type GoogleNetworkConnectivityPolicyBasedRouteTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleNetworkConnectivityPolicyBasedRouteTimeoutsOutputReference ¶
func NewGoogleNetworkConnectivityPolicyBasedRouteTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleNetworkConnectivityPolicyBasedRouteTimeoutsOutputReference
type GoogleNetworkConnectivityPolicyBasedRouteVirtualMachine ¶
type GoogleNetworkConnectivityPolicyBasedRouteVirtualMachine struct {
// A list of VM instance tags that this policy-based route applies to.
//
// VM instances that have ANY of tags specified here will install this PBR.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_network_connectivity_policy_based_route#tags GoogleNetworkConnectivityPolicyBasedRoute#tags}
Tags *[]*string `field:"required" json:"tags" yaml:"tags"`
}
type GoogleNetworkConnectivityPolicyBasedRouteVirtualMachineOutputReference ¶
type GoogleNetworkConnectivityPolicyBasedRouteVirtualMachineOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleNetworkConnectivityPolicyBasedRouteVirtualMachine
SetInternalValue(val *GoogleNetworkConnectivityPolicyBasedRouteVirtualMachine)
Tags() *[]*string
SetTags(val *[]*string)
TagsInput() *[]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleNetworkConnectivityPolicyBasedRouteVirtualMachineOutputReference ¶
func NewGoogleNetworkConnectivityPolicyBasedRouteVirtualMachineOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleNetworkConnectivityPolicyBasedRouteVirtualMachineOutputReference
type GoogleNetworkConnectivityPolicyBasedRouteWarnings ¶
type GoogleNetworkConnectivityPolicyBasedRouteWarnings struct {
}
type GoogleNetworkConnectivityPolicyBasedRouteWarningsList ¶
type GoogleNetworkConnectivityPolicyBasedRouteWarningsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) GoogleNetworkConnectivityPolicyBasedRouteWarningsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleNetworkConnectivityPolicyBasedRouteWarningsList ¶
func NewGoogleNetworkConnectivityPolicyBasedRouteWarningsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GoogleNetworkConnectivityPolicyBasedRouteWarningsList
type GoogleNetworkConnectivityPolicyBasedRouteWarningsOutputReference ¶
type GoogleNetworkConnectivityPolicyBasedRouteWarningsOutputReference interface {
cdktf.ComplexObject
Code() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Data() cdktf.StringMap
// Experimental.
Fqn() *string
InternalValue() *GoogleNetworkConnectivityPolicyBasedRouteWarnings
SetInternalValue(val *GoogleNetworkConnectivityPolicyBasedRouteWarnings)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
WarningMessage() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleNetworkConnectivityPolicyBasedRouteWarningsOutputReference ¶
func NewGoogleNetworkConnectivityPolicyBasedRouteWarningsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GoogleNetworkConnectivityPolicyBasedRouteWarningsOutputReference
Source Files
¶
- GoogleNetworkConnectivityPolicyBasedRoute.go
- GoogleNetworkConnectivityPolicyBasedRouteConfig.go
- GoogleNetworkConnectivityPolicyBasedRouteFilter.go
- GoogleNetworkConnectivityPolicyBasedRouteFilterOutputReference.go
- GoogleNetworkConnectivityPolicyBasedRouteFilterOutputReference__checks.go
- GoogleNetworkConnectivityPolicyBasedRouteInterconnectAttachment.go
- GoogleNetworkConnectivityPolicyBasedRouteInterconnectAttachmentOutputReference.go
- GoogleNetworkConnectivityPolicyBasedRouteInterconnectAttachmentOutputReference__checks.go
- GoogleNetworkConnectivityPolicyBasedRouteTimeouts.go
- GoogleNetworkConnectivityPolicyBasedRouteTimeoutsOutputReference.go
- GoogleNetworkConnectivityPolicyBasedRouteTimeoutsOutputReference__checks.go
- GoogleNetworkConnectivityPolicyBasedRouteVirtualMachine.go
- GoogleNetworkConnectivityPolicyBasedRouteVirtualMachineOutputReference.go
- GoogleNetworkConnectivityPolicyBasedRouteVirtualMachineOutputReference__checks.go
- GoogleNetworkConnectivityPolicyBasedRouteWarnings.go
- GoogleNetworkConnectivityPolicyBasedRouteWarningsList.go
- GoogleNetworkConnectivityPolicyBasedRouteWarningsList__checks.go
- GoogleNetworkConnectivityPolicyBasedRouteWarningsOutputReference.go
- GoogleNetworkConnectivityPolicyBasedRouteWarningsOutputReference__checks.go
- GoogleNetworkConnectivityPolicyBasedRoute__checks.go
- main.go