Documentation
¶
Index ¶
- func GoogleSccNotificationConfig_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func GoogleSccNotificationConfig_IsConstruct(x interface{}) *bool
- func GoogleSccNotificationConfig_IsTerraformElement(x interface{}) *bool
- func GoogleSccNotificationConfig_IsTerraformResource(x interface{}) *bool
- func GoogleSccNotificationConfig_TfResourceType() *string
- func NewGoogleSccNotificationConfigStreamingConfigOutputReference_Override(g GoogleSccNotificationConfigStreamingConfigOutputReference, ...)
- func NewGoogleSccNotificationConfigTimeoutsOutputReference_Override(g GoogleSccNotificationConfigTimeoutsOutputReference, ...)
- func NewGoogleSccNotificationConfig_Override(g GoogleSccNotificationConfig, scope constructs.Construct, id *string, ...)
- type GoogleSccNotificationConfig
- type GoogleSccNotificationConfigConfig
- type GoogleSccNotificationConfigStreamingConfig
- type GoogleSccNotificationConfigStreamingConfigOutputReference
- type GoogleSccNotificationConfigTimeouts
- type GoogleSccNotificationConfigTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleSccNotificationConfig_GenerateConfigForImport ¶
func GoogleSccNotificationConfig_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a GoogleSccNotificationConfig resource upon running "cdktf plan <stack-name>".
func GoogleSccNotificationConfig_IsConstruct ¶
func GoogleSccNotificationConfig_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleSccNotificationConfig_IsTerraformElement ¶
func GoogleSccNotificationConfig_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleSccNotificationConfig_IsTerraformResource ¶
func GoogleSccNotificationConfig_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleSccNotificationConfig_TfResourceType ¶
func GoogleSccNotificationConfig_TfResourceType() *string
func NewGoogleSccNotificationConfigStreamingConfigOutputReference_Override ¶
func NewGoogleSccNotificationConfigStreamingConfigOutputReference_Override(g GoogleSccNotificationConfigStreamingConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleSccNotificationConfigTimeoutsOutputReference_Override ¶
func NewGoogleSccNotificationConfigTimeoutsOutputReference_Override(g GoogleSccNotificationConfigTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleSccNotificationConfig_Override ¶
func NewGoogleSccNotificationConfig_Override(g GoogleSccNotificationConfig, scope constructs.Construct, id *string, config *GoogleSccNotificationConfigConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_scc_notification_config google_scc_notification_config} Resource.
Types ¶
type GoogleSccNotificationConfig ¶
type GoogleSccNotificationConfig interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
ConfigId() *string
SetConfigId(val *string)
ConfigIdInput() *string
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
// The tree node.
Node() constructs.Node
Organization() *string
SetOrganization(val *string)
OrganizationInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
PubsubTopic() *string
SetPubsubTopic(val *string)
PubsubTopicInput() *string
// Experimental.
RawOverrides() interface{}
ServiceAccount() *string
StreamingConfig() GoogleSccNotificationConfigStreamingConfigOutputReference
StreamingConfigInput() *GoogleSccNotificationConfigStreamingConfig
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GoogleSccNotificationConfigTimeoutsOutputReference
TimeoutsInput() interface{}
// Adds a user defined moveTarget string to this resource to be later used in .moveTo(moveTarget) to resolve the location of the move.
// Experimental.
AddMoveTarget(moveTarget *string)
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
HasResourceMove() interface{}
// Experimental.
ImportFrom(id *string, provider cdktf.TerraformProvider)
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Move the resource corresponding to "id" to this resource.
//
// Note that the resource being moved from must be marked as moved using it's instance function.
// Experimental.
MoveFromId(id *string)
// Moves this resource to the target resource given by moveTarget.
// Experimental.
MoveTo(moveTarget *string, index interface{})
// Moves this resource to the resource corresponding to "id".
// Experimental.
MoveToId(id *string)
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutStreamingConfig(value *GoogleSccNotificationConfigStreamingConfig)
PutTimeouts(value *GoogleSccNotificationConfigTimeouts)
ResetDescription()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_scc_notification_config google_scc_notification_config}.
func NewGoogleSccNotificationConfig ¶
func NewGoogleSccNotificationConfig(scope constructs.Construct, id *string, config *GoogleSccNotificationConfigConfig) GoogleSccNotificationConfig
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_scc_notification_config google_scc_notification_config} Resource.
type GoogleSccNotificationConfigConfig ¶
type GoogleSccNotificationConfigConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// This must be unique within the organization.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_scc_notification_config#config_id GoogleSccNotificationConfig#config_id}
ConfigId *string `field:"required" json:"configId" yaml:"configId"`
// The organization whose Cloud Security Command Center the Notification Config lives in.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_scc_notification_config#organization GoogleSccNotificationConfig#organization}
Organization *string `field:"required" json:"organization" yaml:"organization"`
// The Pub/Sub topic to send notifications to. Its format is "projects/[project_id]/topics/[topic]".
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_scc_notification_config#pubsub_topic GoogleSccNotificationConfig#pubsub_topic}
PubsubTopic *string `field:"required" json:"pubsubTopic" yaml:"pubsubTopic"`
// streaming_config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_scc_notification_config#streaming_config GoogleSccNotificationConfig#streaming_config}
StreamingConfig *GoogleSccNotificationConfigStreamingConfig `field:"required" json:"streamingConfig" yaml:"streamingConfig"`
// The description of the notification config (max of 1024 characters).
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_scc_notification_config#description GoogleSccNotificationConfig#description}
Description *string `field:"optional" json:"description" yaml:"description"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_scc_notification_config#id GoogleSccNotificationConfig#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_scc_notification_config#timeouts GoogleSccNotificationConfig#timeouts}
Timeouts *GoogleSccNotificationConfigTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type GoogleSccNotificationConfigStreamingConfig ¶
type GoogleSccNotificationConfigStreamingConfig struct {
// Expression that defines the filter to apply across create/update events of assets or findings as specified by the event type.
//
// The
// expression is a list of zero or more restrictions combined via
// logical operators AND and OR. Parentheses are supported, and OR
// has higher precedence than AND.
//
// Restrictions have the form <field> <operator> <value> and may have
// a - character in front of them to indicate negation. The fields
// map to those defined in the corresponding resource.
//
// The supported operators are:
//
// * = for all value types.
// * >, <, >=, <= for integer values.
// * :, meaning substring matching, for strings.
//
// The supported value types are:
//
// * string literals in quotes.
// * integer literals without quotes.
// * boolean literals true and false without quotes.
//
// See
// [Filtering notifications](https://cloud.google.com/security-command-center/docs/how-to-api-filter-notifications)
// for information on how to write a filter.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_scc_notification_config#filter GoogleSccNotificationConfig#filter}
Filter *string `field:"required" json:"filter" yaml:"filter"`
}
type GoogleSccNotificationConfigStreamingConfigOutputReference ¶
type GoogleSccNotificationConfigStreamingConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Filter() *string
SetFilter(val *string)
FilterInput() *string
// Experimental.
Fqn() *string
InternalValue() *GoogleSccNotificationConfigStreamingConfig
SetInternalValue(val *GoogleSccNotificationConfigStreamingConfig)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleSccNotificationConfigStreamingConfigOutputReference ¶
func NewGoogleSccNotificationConfigStreamingConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleSccNotificationConfigStreamingConfigOutputReference
type GoogleSccNotificationConfigTimeouts ¶
type GoogleSccNotificationConfigTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_scc_notification_config#create GoogleSccNotificationConfig#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_scc_notification_config#delete GoogleSccNotificationConfig#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_scc_notification_config#update GoogleSccNotificationConfig#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type GoogleSccNotificationConfigTimeoutsOutputReference ¶
type GoogleSccNotificationConfigTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleSccNotificationConfigTimeoutsOutputReference ¶
func NewGoogleSccNotificationConfigTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleSccNotificationConfigTimeoutsOutputReference
Source Files
¶
- GoogleSccNotificationConfig.go
- GoogleSccNotificationConfigConfig.go
- GoogleSccNotificationConfigStreamingConfig.go
- GoogleSccNotificationConfigStreamingConfigOutputReference.go
- GoogleSccNotificationConfigStreamingConfigOutputReference__checks.go
- GoogleSccNotificationConfigTimeouts.go
- GoogleSccNotificationConfigTimeoutsOutputReference.go
- GoogleSccNotificationConfigTimeoutsOutputReference__checks.go
- GoogleSccNotificationConfig__checks.go
- main.go