Documentation
¶
Index ¶
- func GoogleSqlSourceRepresentationInstance_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func GoogleSqlSourceRepresentationInstance_IsConstruct(x interface{}) *bool
- func GoogleSqlSourceRepresentationInstance_IsTerraformElement(x interface{}) *bool
- func GoogleSqlSourceRepresentationInstance_IsTerraformResource(x interface{}) *bool
- func GoogleSqlSourceRepresentationInstance_TfResourceType() *string
- func NewGoogleSqlSourceRepresentationInstanceTimeoutsOutputReference_Override(g GoogleSqlSourceRepresentationInstanceTimeoutsOutputReference, ...)
- func NewGoogleSqlSourceRepresentationInstance_Override(g GoogleSqlSourceRepresentationInstance, scope constructs.Construct, ...)
- type GoogleSqlSourceRepresentationInstance
- type GoogleSqlSourceRepresentationInstanceConfig
- type GoogleSqlSourceRepresentationInstanceTimeouts
- type GoogleSqlSourceRepresentationInstanceTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleSqlSourceRepresentationInstance_GenerateConfigForImport ¶
func GoogleSqlSourceRepresentationInstance_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a GoogleSqlSourceRepresentationInstance resource upon running "cdktf plan <stack-name>".
func GoogleSqlSourceRepresentationInstance_IsConstruct ¶
func GoogleSqlSourceRepresentationInstance_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleSqlSourceRepresentationInstance_IsTerraformElement ¶
func GoogleSqlSourceRepresentationInstance_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleSqlSourceRepresentationInstance_IsTerraformResource ¶
func GoogleSqlSourceRepresentationInstance_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleSqlSourceRepresentationInstance_TfResourceType ¶
func GoogleSqlSourceRepresentationInstance_TfResourceType() *string
func NewGoogleSqlSourceRepresentationInstanceTimeoutsOutputReference_Override ¶
func NewGoogleSqlSourceRepresentationInstanceTimeoutsOutputReference_Override(g GoogleSqlSourceRepresentationInstanceTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleSqlSourceRepresentationInstance_Override ¶
func NewGoogleSqlSourceRepresentationInstance_Override(g GoogleSqlSourceRepresentationInstance, scope constructs.Construct, id *string, config *GoogleSqlSourceRepresentationInstanceConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_sql_source_representation_instance google_sql_source_representation_instance} Resource.
Types ¶
type GoogleSqlSourceRepresentationInstance ¶
type GoogleSqlSourceRepresentationInstance interface {
cdktf.TerraformResource
CaCertificate() *string
SetCaCertificate(val *string)
CaCertificateInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
ClientCertificate() *string
SetClientCertificate(val *string)
ClientCertificateInput() *string
ClientKey() *string
SetClientKey(val *string)
ClientKeyInput() *string
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
DatabaseVersion() *string
SetDatabaseVersion(val *string)
DatabaseVersionInput() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DumpFilePath() *string
SetDumpFilePath(val *string)
DumpFilePathInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Host() *string
SetHost(val *string)
HostInput() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
Password() *string
SetPassword(val *string)
PasswordInput() *string
Port() *float64
SetPort(val *float64)
PortInput() *float64
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Region() *string
SetRegion(val *string)
RegionInput() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GoogleSqlSourceRepresentationInstanceTimeoutsOutputReference
TimeoutsInput() interface{}
Username() *string
SetUsername(val *string)
UsernameInput() *string
// Adds a user defined moveTarget string to this resource to be later used in .moveTo(moveTarget) to resolve the location of the move.
// Experimental.
AddMoveTarget(moveTarget *string)
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
HasResourceMove() interface{}
// Experimental.
ImportFrom(id *string, provider cdktf.TerraformProvider)
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Move the resource corresponding to "id" to this resource.
//
// Note that the resource being moved from must be marked as moved using it's instance function.
// Experimental.
MoveFromId(id *string)
// Moves this resource to the target resource given by moveTarget.
// Experimental.
MoveTo(moveTarget *string, index interface{})
// Moves this resource to the resource corresponding to "id".
// Experimental.
MoveToId(id *string)
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutTimeouts(value *GoogleSqlSourceRepresentationInstanceTimeouts)
ResetCaCertificate()
ResetClientCertificate()
ResetClientKey()
ResetDumpFilePath()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetPassword()
ResetPort()
ResetProject()
ResetRegion()
ResetTimeouts()
ResetUsername()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_sql_source_representation_instance google_sql_source_representation_instance}.
func NewGoogleSqlSourceRepresentationInstance ¶
func NewGoogleSqlSourceRepresentationInstance(scope constructs.Construct, id *string, config *GoogleSqlSourceRepresentationInstanceConfig) GoogleSqlSourceRepresentationInstance
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_sql_source_representation_instance google_sql_source_representation_instance} Resource.
type GoogleSqlSourceRepresentationInstanceConfig ¶
type GoogleSqlSourceRepresentationInstanceConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// The MySQL version running on your source database server.
//
// Possible values: ["MYSQL_5_6", "MYSQL_5_7", "MYSQL_8_0", "POSTGRES_9_6", "POSTGRES_10", "POSTGRES_11", "POSTGRES_12", "POSTGRES_13", "POSTGRES_14"]
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_sql_source_representation_instance#database_version GoogleSqlSourceRepresentationInstance#database_version}
DatabaseVersion *string `field:"required" json:"databaseVersion" yaml:"databaseVersion"`
// The IPv4 address and port for the external server, or the the DNS address for the external server.
//
// If the external server is hosted on Cloud SQL, the port is 5432.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_sql_source_representation_instance#host GoogleSqlSourceRepresentationInstance#host}
Host *string `field:"required" json:"host" yaml:"host"`
// The name of the source representation instance. Use any valid Cloud SQL instance name.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_sql_source_representation_instance#name GoogleSqlSourceRepresentationInstance#name}
Name *string `field:"required" json:"name" yaml:"name"`
// The CA certificate on the external server. Include only if SSL/TLS is used on the external server.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_sql_source_representation_instance#ca_certificate GoogleSqlSourceRepresentationInstance#ca_certificate}
CaCertificate *string `field:"optional" json:"caCertificate" yaml:"caCertificate"`
// The client certificate on the external server.
//
// Required only for server-client authentication. Include only if SSL/TLS is used on the external server.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_sql_source_representation_instance#client_certificate GoogleSqlSourceRepresentationInstance#client_certificate}
ClientCertificate *string `field:"optional" json:"clientCertificate" yaml:"clientCertificate"`
// The private key file for the client certificate on the external server.
//
// Required only for server-client authentication. Include only if SSL/TLS is used on the external server.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_sql_source_representation_instance#client_key GoogleSqlSourceRepresentationInstance#client_key}
ClientKey *string `field:"optional" json:"clientKey" yaml:"clientKey"`
// A file in the bucket that contains the data from the external server.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_sql_source_representation_instance#dump_file_path GoogleSqlSourceRepresentationInstance#dump_file_path}
DumpFilePath *string `field:"optional" json:"dumpFilePath" yaml:"dumpFilePath"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_sql_source_representation_instance#id GoogleSqlSourceRepresentationInstance#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// The password for the replication user account.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_sql_source_representation_instance#password GoogleSqlSourceRepresentationInstance#password}
Password *string `field:"optional" json:"password" yaml:"password"`
// The externally accessible port for the source database server. Defaults to 3306.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_sql_source_representation_instance#port GoogleSqlSourceRepresentationInstance#port}
Port *float64 `field:"optional" json:"port" yaml:"port"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_sql_source_representation_instance#project GoogleSqlSourceRepresentationInstance#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// The Region in which the created instance should reside. If it is not provided, the provider region is used.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_sql_source_representation_instance#region GoogleSqlSourceRepresentationInstance#region}
Region *string `field:"optional" json:"region" yaml:"region"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_sql_source_representation_instance#timeouts GoogleSqlSourceRepresentationInstance#timeouts}
Timeouts *GoogleSqlSourceRepresentationInstanceTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
// The replication user account on the external server.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_sql_source_representation_instance#username GoogleSqlSourceRepresentationInstance#username}
Username *string `field:"optional" json:"username" yaml:"username"`
}
type GoogleSqlSourceRepresentationInstanceTimeouts ¶
type GoogleSqlSourceRepresentationInstanceTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_sql_source_representation_instance#create GoogleSqlSourceRepresentationInstance#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_sql_source_representation_instance#delete GoogleSqlSourceRepresentationInstance#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
}
type GoogleSqlSourceRepresentationInstanceTimeoutsOutputReference ¶
type GoogleSqlSourceRepresentationInstanceTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleSqlSourceRepresentationInstanceTimeoutsOutputReference ¶
func NewGoogleSqlSourceRepresentationInstanceTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleSqlSourceRepresentationInstanceTimeoutsOutputReference
Source Files
¶
- GoogleSqlSourceRepresentationInstance.go
- GoogleSqlSourceRepresentationInstanceConfig.go
- GoogleSqlSourceRepresentationInstanceTimeouts.go
- GoogleSqlSourceRepresentationInstanceTimeoutsOutputReference.go
- GoogleSqlSourceRepresentationInstanceTimeoutsOutputReference__checks.go
- GoogleSqlSourceRepresentationInstance__checks.go
- main.go