Documentation
¶
Index ¶
- func GoogleStorageInsightsReportConfig_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func GoogleStorageInsightsReportConfig_IsConstruct(x interface{}) *bool
- func GoogleStorageInsightsReportConfig_IsTerraformElement(x interface{}) *bool
- func GoogleStorageInsightsReportConfig_IsTerraformResource(x interface{}) *bool
- func GoogleStorageInsightsReportConfig_TfResourceType() *string
- func NewGoogleStorageInsightsReportConfigCsvOptionsOutputReference_Override(g GoogleStorageInsightsReportConfigCsvOptionsOutputReference, ...)
- func NewGoogleStorageInsightsReportConfigFrequencyOptionsEndDateOutputReference_Override(g GoogleStorageInsightsReportConfigFrequencyOptionsEndDateOutputReference, ...)
- func NewGoogleStorageInsightsReportConfigFrequencyOptionsOutputReference_Override(g GoogleStorageInsightsReportConfigFrequencyOptionsOutputReference, ...)
- func NewGoogleStorageInsightsReportConfigFrequencyOptionsStartDateOutputReference_Override(g GoogleStorageInsightsReportConfigFrequencyOptionsStartDateOutputReference, ...)
- func NewGoogleStorageInsightsReportConfigObjectMetadataReportOptionsOutputReference_Override(g GoogleStorageInsightsReportConfigObjectMetadataReportOptionsOutputReference, ...)
- func NewGoogleStorageInsightsReportConfigObjectMetadataReportOptionsStorageDestinationOptionsOutputReference_Override(...)
- func NewGoogleStorageInsightsReportConfigObjectMetadataReportOptionsStorageFiltersOutputReference_Override(...)
- func NewGoogleStorageInsightsReportConfigTimeoutsOutputReference_Override(g GoogleStorageInsightsReportConfigTimeoutsOutputReference, ...)
- func NewGoogleStorageInsightsReportConfig_Override(g GoogleStorageInsightsReportConfig, scope constructs.Construct, id *string, ...)
- type GoogleStorageInsightsReportConfig
- type GoogleStorageInsightsReportConfigConfig
- type GoogleStorageInsightsReportConfigCsvOptions
- type GoogleStorageInsightsReportConfigCsvOptionsOutputReference
- type GoogleStorageInsightsReportConfigFrequencyOptions
- type GoogleStorageInsightsReportConfigFrequencyOptionsEndDate
- type GoogleStorageInsightsReportConfigFrequencyOptionsEndDateOutputReference
- type GoogleStorageInsightsReportConfigFrequencyOptionsOutputReference
- type GoogleStorageInsightsReportConfigFrequencyOptionsStartDate
- type GoogleStorageInsightsReportConfigFrequencyOptionsStartDateOutputReference
- type GoogleStorageInsightsReportConfigObjectMetadataReportOptions
- type GoogleStorageInsightsReportConfigObjectMetadataReportOptionsOutputReference
- type GoogleStorageInsightsReportConfigObjectMetadataReportOptionsStorageDestinationOptions
- type GoogleStorageInsightsReportConfigObjectMetadataReportOptionsStorageDestinationOptionsOutputReference
- type GoogleStorageInsightsReportConfigObjectMetadataReportOptionsStorageFilters
- type GoogleStorageInsightsReportConfigObjectMetadataReportOptionsStorageFiltersOutputReference
- type GoogleStorageInsightsReportConfigTimeouts
- type GoogleStorageInsightsReportConfigTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleStorageInsightsReportConfig_GenerateConfigForImport ¶
func GoogleStorageInsightsReportConfig_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a GoogleStorageInsightsReportConfig resource upon running "cdktf plan <stack-name>".
func GoogleStorageInsightsReportConfig_IsConstruct ¶
func GoogleStorageInsightsReportConfig_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleStorageInsightsReportConfig_IsTerraformElement ¶
func GoogleStorageInsightsReportConfig_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleStorageInsightsReportConfig_IsTerraformResource ¶
func GoogleStorageInsightsReportConfig_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleStorageInsightsReportConfig_TfResourceType ¶
func GoogleStorageInsightsReportConfig_TfResourceType() *string
func NewGoogleStorageInsightsReportConfigCsvOptionsOutputReference_Override ¶
func NewGoogleStorageInsightsReportConfigCsvOptionsOutputReference_Override(g GoogleStorageInsightsReportConfigCsvOptionsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleStorageInsightsReportConfigFrequencyOptionsEndDateOutputReference_Override ¶
func NewGoogleStorageInsightsReportConfigFrequencyOptionsEndDateOutputReference_Override(g GoogleStorageInsightsReportConfigFrequencyOptionsEndDateOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleStorageInsightsReportConfigFrequencyOptionsOutputReference_Override ¶
func NewGoogleStorageInsightsReportConfigFrequencyOptionsOutputReference_Override(g GoogleStorageInsightsReportConfigFrequencyOptionsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleStorageInsightsReportConfigFrequencyOptionsStartDateOutputReference_Override ¶
func NewGoogleStorageInsightsReportConfigFrequencyOptionsStartDateOutputReference_Override(g GoogleStorageInsightsReportConfigFrequencyOptionsStartDateOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleStorageInsightsReportConfigObjectMetadataReportOptionsOutputReference_Override ¶
func NewGoogleStorageInsightsReportConfigObjectMetadataReportOptionsOutputReference_Override(g GoogleStorageInsightsReportConfigObjectMetadataReportOptionsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleStorageInsightsReportConfigObjectMetadataReportOptionsStorageDestinationOptionsOutputReference_Override ¶
func NewGoogleStorageInsightsReportConfigObjectMetadataReportOptionsStorageDestinationOptionsOutputReference_Override(g GoogleStorageInsightsReportConfigObjectMetadataReportOptionsStorageDestinationOptionsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleStorageInsightsReportConfigObjectMetadataReportOptionsStorageFiltersOutputReference_Override ¶
func NewGoogleStorageInsightsReportConfigObjectMetadataReportOptionsStorageFiltersOutputReference_Override(g GoogleStorageInsightsReportConfigObjectMetadataReportOptionsStorageFiltersOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleStorageInsightsReportConfigTimeoutsOutputReference_Override ¶
func NewGoogleStorageInsightsReportConfigTimeoutsOutputReference_Override(g GoogleStorageInsightsReportConfigTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleStorageInsightsReportConfig_Override ¶
func NewGoogleStorageInsightsReportConfig_Override(g GoogleStorageInsightsReportConfig, scope constructs.Construct, id *string, config *GoogleStorageInsightsReportConfigConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_storage_insights_report_config google_storage_insights_report_config} Resource.
Types ¶
type GoogleStorageInsightsReportConfig ¶
type GoogleStorageInsightsReportConfig interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
CsvOptions() GoogleStorageInsightsReportConfigCsvOptionsOutputReference
CsvOptionsInput() *GoogleStorageInsightsReportConfigCsvOptions
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DisplayName() *string
SetDisplayName(val *string)
DisplayNameInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
FrequencyOptions() GoogleStorageInsightsReportConfigFrequencyOptionsOutputReference
FrequencyOptionsInput() *GoogleStorageInsightsReportConfigFrequencyOptions
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Location() *string
SetLocation(val *string)
LocationInput() *string
Name() *string
// The tree node.
Node() constructs.Node
ObjectMetadataReportOptions() GoogleStorageInsightsReportConfigObjectMetadataReportOptionsOutputReference
ObjectMetadataReportOptionsInput() *GoogleStorageInsightsReportConfigObjectMetadataReportOptions
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GoogleStorageInsightsReportConfigTimeoutsOutputReference
TimeoutsInput() interface{}
// Adds a user defined moveTarget string to this resource to be later used in .moveTo(moveTarget) to resolve the location of the move.
// Experimental.
AddMoveTarget(moveTarget *string)
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
HasResourceMove() interface{}
// Experimental.
ImportFrom(id *string, provider cdktf.TerraformProvider)
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Move the resource corresponding to "id" to this resource.
//
// Note that the resource being moved from must be marked as moved using it's instance function.
// Experimental.
MoveFromId(id *string)
// Moves this resource to the target resource given by moveTarget.
// Experimental.
MoveTo(moveTarget *string, index interface{})
// Moves this resource to the resource corresponding to "id".
// Experimental.
MoveToId(id *string)
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutCsvOptions(value *GoogleStorageInsightsReportConfigCsvOptions)
PutFrequencyOptions(value *GoogleStorageInsightsReportConfigFrequencyOptions)
PutObjectMetadataReportOptions(value *GoogleStorageInsightsReportConfigObjectMetadataReportOptions)
PutTimeouts(value *GoogleStorageInsightsReportConfigTimeouts)
ResetDisplayName()
ResetFrequencyOptions()
ResetId()
ResetObjectMetadataReportOptions()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_storage_insights_report_config google_storage_insights_report_config}.
func NewGoogleStorageInsightsReportConfig ¶
func NewGoogleStorageInsightsReportConfig(scope constructs.Construct, id *string, config *GoogleStorageInsightsReportConfigConfig) GoogleStorageInsightsReportConfig
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_storage_insights_report_config google_storage_insights_report_config} Resource.
type GoogleStorageInsightsReportConfigConfig ¶
type GoogleStorageInsightsReportConfigConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// csv_options block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_storage_insights_report_config#csv_options GoogleStorageInsightsReportConfig#csv_options}
CsvOptions *GoogleStorageInsightsReportConfigCsvOptions `field:"required" json:"csvOptions" yaml:"csvOptions"`
// The location of the ReportConfig. The source and destination buckets specified in the ReportConfig must be in the same location.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_storage_insights_report_config#location GoogleStorageInsightsReportConfig#location}
Location *string `field:"required" json:"location" yaml:"location"`
// The editable display name of the inventory report configuration. Has a limit of 256 characters. Can be empty.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_storage_insights_report_config#display_name GoogleStorageInsightsReportConfig#display_name}
DisplayName *string `field:"optional" json:"displayName" yaml:"displayName"`
// frequency_options block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_storage_insights_report_config#frequency_options GoogleStorageInsightsReportConfig#frequency_options}
FrequencyOptions *GoogleStorageInsightsReportConfigFrequencyOptions `field:"optional" json:"frequencyOptions" yaml:"frequencyOptions"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_storage_insights_report_config#id GoogleStorageInsightsReportConfig#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// object_metadata_report_options block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_storage_insights_report_config#object_metadata_report_options GoogleStorageInsightsReportConfig#object_metadata_report_options}
ObjectMetadataReportOptions *GoogleStorageInsightsReportConfigObjectMetadataReportOptions `field:"optional" json:"objectMetadataReportOptions" yaml:"objectMetadataReportOptions"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_storage_insights_report_config#project GoogleStorageInsightsReportConfig#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_storage_insights_report_config#timeouts GoogleStorageInsightsReportConfig#timeouts}
Timeouts *GoogleStorageInsightsReportConfigTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type GoogleStorageInsightsReportConfigCsvOptions ¶
type GoogleStorageInsightsReportConfigCsvOptions struct {
// The delimiter used to separate the fields in the inventory report CSV file.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_storage_insights_report_config#delimiter GoogleStorageInsightsReportConfig#delimiter}
Delimiter *string `field:"optional" json:"delimiter" yaml:"delimiter"`
// The boolean that indicates whether or not headers are included in the inventory report CSV file.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_storage_insights_report_config#header_required GoogleStorageInsightsReportConfig#header_required}
HeaderRequired interface{} `field:"optional" json:"headerRequired" yaml:"headerRequired"`
// The character used to separate the records in the inventory report CSV file.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_storage_insights_report_config#record_separator GoogleStorageInsightsReportConfig#record_separator}
RecordSeparator *string `field:"optional" json:"recordSeparator" yaml:"recordSeparator"`
}
type GoogleStorageInsightsReportConfigCsvOptionsOutputReference ¶
type GoogleStorageInsightsReportConfigCsvOptionsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delimiter() *string
SetDelimiter(val *string)
DelimiterInput() *string
// Experimental.
Fqn() *string
HeaderRequired() interface{}
SetHeaderRequired(val interface{})
HeaderRequiredInput() interface{}
InternalValue() *GoogleStorageInsightsReportConfigCsvOptions
SetInternalValue(val *GoogleStorageInsightsReportConfigCsvOptions)
RecordSeparator() *string
SetRecordSeparator(val *string)
RecordSeparatorInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetDelimiter()
ResetHeaderRequired()
ResetRecordSeparator()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleStorageInsightsReportConfigCsvOptionsOutputReference ¶
func NewGoogleStorageInsightsReportConfigCsvOptionsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleStorageInsightsReportConfigCsvOptionsOutputReference
type GoogleStorageInsightsReportConfigFrequencyOptions ¶
type GoogleStorageInsightsReportConfigFrequencyOptions struct {
// end_date block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_storage_insights_report_config#end_date GoogleStorageInsightsReportConfig#end_date}
EndDate *GoogleStorageInsightsReportConfigFrequencyOptionsEndDate `field:"required" json:"endDate" yaml:"endDate"`
// The frequency in which inventory reports are generated. Values are DAILY or WEEKLY. Possible values: ["DAILY", "WEEKLY"].
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_storage_insights_report_config#frequency GoogleStorageInsightsReportConfig#frequency}
Frequency *string `field:"required" json:"frequency" yaml:"frequency"`
// start_date block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_storage_insights_report_config#start_date GoogleStorageInsightsReportConfig#start_date}
StartDate *GoogleStorageInsightsReportConfigFrequencyOptionsStartDate `field:"required" json:"startDate" yaml:"startDate"`
}
type GoogleStorageInsightsReportConfigFrequencyOptionsEndDate ¶
type GoogleStorageInsightsReportConfigFrequencyOptionsEndDate struct {
// The day of the month to stop generating inventory reports.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_storage_insights_report_config#day GoogleStorageInsightsReportConfig#day}
Day *float64 `field:"required" json:"day" yaml:"day"`
// The month to stop generating inventory reports.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_storage_insights_report_config#month GoogleStorageInsightsReportConfig#month}
Month *float64 `field:"required" json:"month" yaml:"month"`
// The year to stop generating inventory reports.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_storage_insights_report_config#year GoogleStorageInsightsReportConfig#year}
Year *float64 `field:"required" json:"year" yaml:"year"`
}
type GoogleStorageInsightsReportConfigFrequencyOptionsEndDateOutputReference ¶
type GoogleStorageInsightsReportConfigFrequencyOptionsEndDateOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Day() *float64
SetDay(val *float64)
DayInput() *float64
// Experimental.
Fqn() *string
InternalValue() *GoogleStorageInsightsReportConfigFrequencyOptionsEndDate
SetInternalValue(val *GoogleStorageInsightsReportConfigFrequencyOptionsEndDate)
Month() *float64
SetMonth(val *float64)
MonthInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Year() *float64
SetYear(val *float64)
YearInput() *float64
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleStorageInsightsReportConfigFrequencyOptionsEndDateOutputReference ¶
func NewGoogleStorageInsightsReportConfigFrequencyOptionsEndDateOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleStorageInsightsReportConfigFrequencyOptionsEndDateOutputReference
type GoogleStorageInsightsReportConfigFrequencyOptionsOutputReference ¶
type GoogleStorageInsightsReportConfigFrequencyOptionsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
EndDate() GoogleStorageInsightsReportConfigFrequencyOptionsEndDateOutputReference
EndDateInput() *GoogleStorageInsightsReportConfigFrequencyOptionsEndDate
// Experimental.
Fqn() *string
Frequency() *string
SetFrequency(val *string)
FrequencyInput() *string
InternalValue() *GoogleStorageInsightsReportConfigFrequencyOptions
SetInternalValue(val *GoogleStorageInsightsReportConfigFrequencyOptions)
StartDate() GoogleStorageInsightsReportConfigFrequencyOptionsStartDateOutputReference
StartDateInput() *GoogleStorageInsightsReportConfigFrequencyOptionsStartDate
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutEndDate(value *GoogleStorageInsightsReportConfigFrequencyOptionsEndDate)
PutStartDate(value *GoogleStorageInsightsReportConfigFrequencyOptionsStartDate)
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleStorageInsightsReportConfigFrequencyOptionsOutputReference ¶
func NewGoogleStorageInsightsReportConfigFrequencyOptionsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleStorageInsightsReportConfigFrequencyOptionsOutputReference
type GoogleStorageInsightsReportConfigFrequencyOptionsStartDate ¶
type GoogleStorageInsightsReportConfigFrequencyOptionsStartDate struct {
// The day of the month to start generating inventory reports.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_storage_insights_report_config#day GoogleStorageInsightsReportConfig#day}
Day *float64 `field:"required" json:"day" yaml:"day"`
// The month to start generating inventory reports.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_storage_insights_report_config#month GoogleStorageInsightsReportConfig#month}
Month *float64 `field:"required" json:"month" yaml:"month"`
// The year to start generating inventory reports.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_storage_insights_report_config#year GoogleStorageInsightsReportConfig#year}
Year *float64 `field:"required" json:"year" yaml:"year"`
}
type GoogleStorageInsightsReportConfigFrequencyOptionsStartDateOutputReference ¶
type GoogleStorageInsightsReportConfigFrequencyOptionsStartDateOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Day() *float64
SetDay(val *float64)
DayInput() *float64
// Experimental.
Fqn() *string
InternalValue() *GoogleStorageInsightsReportConfigFrequencyOptionsStartDate
SetInternalValue(val *GoogleStorageInsightsReportConfigFrequencyOptionsStartDate)
Month() *float64
SetMonth(val *float64)
MonthInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Year() *float64
SetYear(val *float64)
YearInput() *float64
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleStorageInsightsReportConfigFrequencyOptionsStartDateOutputReference ¶
func NewGoogleStorageInsightsReportConfigFrequencyOptionsStartDateOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleStorageInsightsReportConfigFrequencyOptionsStartDateOutputReference
type GoogleStorageInsightsReportConfigObjectMetadataReportOptions ¶
type GoogleStorageInsightsReportConfigObjectMetadataReportOptions struct {
// The metadata fields included in an inventory report.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_storage_insights_report_config#metadata_fields GoogleStorageInsightsReportConfig#metadata_fields}
MetadataFields *[]*string `field:"required" json:"metadataFields" yaml:"metadataFields"`
// storage_destination_options block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_storage_insights_report_config#storage_destination_options GoogleStorageInsightsReportConfig#storage_destination_options}
StorageDestinationOptions *GoogleStorageInsightsReportConfigObjectMetadataReportOptionsStorageDestinationOptions `field:"required" json:"storageDestinationOptions" yaml:"storageDestinationOptions"`
// storage_filters block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_storage_insights_report_config#storage_filters GoogleStorageInsightsReportConfig#storage_filters}
StorageFilters *GoogleStorageInsightsReportConfigObjectMetadataReportOptionsStorageFilters `field:"optional" json:"storageFilters" yaml:"storageFilters"`
}
type GoogleStorageInsightsReportConfigObjectMetadataReportOptionsOutputReference ¶
type GoogleStorageInsightsReportConfigObjectMetadataReportOptionsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleStorageInsightsReportConfigObjectMetadataReportOptions
SetInternalValue(val *GoogleStorageInsightsReportConfigObjectMetadataReportOptions)
MetadataFields() *[]*string
SetMetadataFields(val *[]*string)
MetadataFieldsInput() *[]*string
StorageDestinationOptions() GoogleStorageInsightsReportConfigObjectMetadataReportOptionsStorageDestinationOptionsOutputReference
StorageDestinationOptionsInput() *GoogleStorageInsightsReportConfigObjectMetadataReportOptionsStorageDestinationOptions
StorageFilters() GoogleStorageInsightsReportConfigObjectMetadataReportOptionsStorageFiltersOutputReference
StorageFiltersInput() *GoogleStorageInsightsReportConfigObjectMetadataReportOptionsStorageFilters
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutStorageDestinationOptions(value *GoogleStorageInsightsReportConfigObjectMetadataReportOptionsStorageDestinationOptions)
PutStorageFilters(value *GoogleStorageInsightsReportConfigObjectMetadataReportOptionsStorageFilters)
ResetStorageFilters()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleStorageInsightsReportConfigObjectMetadataReportOptionsOutputReference ¶
func NewGoogleStorageInsightsReportConfigObjectMetadataReportOptionsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleStorageInsightsReportConfigObjectMetadataReportOptionsOutputReference
type GoogleStorageInsightsReportConfigObjectMetadataReportOptionsStorageDestinationOptions ¶
type GoogleStorageInsightsReportConfigObjectMetadataReportOptionsStorageDestinationOptions struct {
// The destination bucket that stores the generated inventory reports.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_storage_insights_report_config#bucket GoogleStorageInsightsReportConfig#bucket}
Bucket *string `field:"required" json:"bucket" yaml:"bucket"`
// The path within the destination bucket to store generated inventory reports.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_storage_insights_report_config#destination_path GoogleStorageInsightsReportConfig#destination_path}
DestinationPath *string `field:"optional" json:"destinationPath" yaml:"destinationPath"`
}
type GoogleStorageInsightsReportConfigObjectMetadataReportOptionsStorageDestinationOptionsOutputReference ¶
type GoogleStorageInsightsReportConfigObjectMetadataReportOptionsStorageDestinationOptionsOutputReference interface {
cdktf.ComplexObject
Bucket() *string
SetBucket(val *string)
BucketInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DestinationPath() *string
SetDestinationPath(val *string)
DestinationPathInput() *string
// Experimental.
Fqn() *string
InternalValue() *GoogleStorageInsightsReportConfigObjectMetadataReportOptionsStorageDestinationOptions
SetInternalValue(val *GoogleStorageInsightsReportConfigObjectMetadataReportOptionsStorageDestinationOptions)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetDestinationPath()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleStorageInsightsReportConfigObjectMetadataReportOptionsStorageDestinationOptionsOutputReference ¶
func NewGoogleStorageInsightsReportConfigObjectMetadataReportOptionsStorageDestinationOptionsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleStorageInsightsReportConfigObjectMetadataReportOptionsStorageDestinationOptionsOutputReference
type GoogleStorageInsightsReportConfigObjectMetadataReportOptionsStorageFilters ¶
type GoogleStorageInsightsReportConfigObjectMetadataReportOptionsStorageFilters struct {
// The filter to use when specifying which bucket to generate inventory reports for.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_storage_insights_report_config#bucket GoogleStorageInsightsReportConfig#bucket}
Bucket *string `field:"optional" json:"bucket" yaml:"bucket"`
}
type GoogleStorageInsightsReportConfigObjectMetadataReportOptionsStorageFiltersOutputReference ¶
type GoogleStorageInsightsReportConfigObjectMetadataReportOptionsStorageFiltersOutputReference interface {
cdktf.ComplexObject
Bucket() *string
SetBucket(val *string)
BucketInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleStorageInsightsReportConfigObjectMetadataReportOptionsStorageFilters
SetInternalValue(val *GoogleStorageInsightsReportConfigObjectMetadataReportOptionsStorageFilters)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetBucket()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleStorageInsightsReportConfigObjectMetadataReportOptionsStorageFiltersOutputReference ¶
func NewGoogleStorageInsightsReportConfigObjectMetadataReportOptionsStorageFiltersOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleStorageInsightsReportConfigObjectMetadataReportOptionsStorageFiltersOutputReference
type GoogleStorageInsightsReportConfigTimeouts ¶
type GoogleStorageInsightsReportConfigTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_storage_insights_report_config#create GoogleStorageInsightsReportConfig#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_storage_insights_report_config#delete GoogleStorageInsightsReportConfig#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_storage_insights_report_config#update GoogleStorageInsightsReportConfig#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type GoogleStorageInsightsReportConfigTimeoutsOutputReference ¶
type GoogleStorageInsightsReportConfigTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleStorageInsightsReportConfigTimeoutsOutputReference ¶
func NewGoogleStorageInsightsReportConfigTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleStorageInsightsReportConfigTimeoutsOutputReference
Source Files
¶
- GoogleStorageInsightsReportConfig.go
- GoogleStorageInsightsReportConfigConfig.go
- GoogleStorageInsightsReportConfigCsvOptions.go
- GoogleStorageInsightsReportConfigCsvOptionsOutputReference.go
- GoogleStorageInsightsReportConfigCsvOptionsOutputReference__checks.go
- GoogleStorageInsightsReportConfigFrequencyOptions.go
- GoogleStorageInsightsReportConfigFrequencyOptionsEndDate.go
- GoogleStorageInsightsReportConfigFrequencyOptionsEndDateOutputReference.go
- GoogleStorageInsightsReportConfigFrequencyOptionsEndDateOutputReference__checks.go
- GoogleStorageInsightsReportConfigFrequencyOptionsOutputReference.go
- GoogleStorageInsightsReportConfigFrequencyOptionsOutputReference__checks.go
- GoogleStorageInsightsReportConfigFrequencyOptionsStartDate.go
- GoogleStorageInsightsReportConfigFrequencyOptionsStartDateOutputReference.go
- GoogleStorageInsightsReportConfigFrequencyOptionsStartDateOutputReference__checks.go
- GoogleStorageInsightsReportConfigObjectMetadataReportOptions.go
- GoogleStorageInsightsReportConfigObjectMetadataReportOptionsOutputReference.go
- GoogleStorageInsightsReportConfigObjectMetadataReportOptionsOutputReference__checks.go
- GoogleStorageInsightsReportConfigObjectMetadataReportOptionsStorageDestinationOptions.go
- GoogleStorageInsightsReportConfigObjectMetadataReportOptionsStorageDestinationOptionsOutputReference.go
- GoogleStorageInsightsReportConfigObjectMetadataReportOptionsStorageDestinationOptionsOutputReference__checks.go
- GoogleStorageInsightsReportConfigObjectMetadataReportOptionsStorageFilters.go
- GoogleStorageInsightsReportConfigObjectMetadataReportOptionsStorageFiltersOutputReference.go
- GoogleStorageInsightsReportConfigObjectMetadataReportOptionsStorageFiltersOutputReference__checks.go
- GoogleStorageInsightsReportConfigTimeouts.go
- GoogleStorageInsightsReportConfigTimeoutsOutputReference.go
- GoogleStorageInsightsReportConfigTimeoutsOutputReference__checks.go
- GoogleStorageInsightsReportConfig__checks.go
- main.go