Documentation
¶
Index ¶
- func GoogleWorkstationsWorkstationCluster_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func GoogleWorkstationsWorkstationCluster_IsConstruct(x interface{}) *bool
- func GoogleWorkstationsWorkstationCluster_IsTerraformElement(x interface{}) *bool
- func GoogleWorkstationsWorkstationCluster_IsTerraformResource(x interface{}) *bool
- func GoogleWorkstationsWorkstationCluster_TfResourceType() *string
- func NewGoogleWorkstationsWorkstationClusterConditionsList_Override(g GoogleWorkstationsWorkstationClusterConditionsList, ...)
- func NewGoogleWorkstationsWorkstationClusterConditionsOutputReference_Override(g GoogleWorkstationsWorkstationClusterConditionsOutputReference, ...)
- func NewGoogleWorkstationsWorkstationClusterDomainConfigOutputReference_Override(g GoogleWorkstationsWorkstationClusterDomainConfigOutputReference, ...)
- func NewGoogleWorkstationsWorkstationClusterPrivateClusterConfigOutputReference_Override(g GoogleWorkstationsWorkstationClusterPrivateClusterConfigOutputReference, ...)
- func NewGoogleWorkstationsWorkstationClusterTimeoutsOutputReference_Override(g GoogleWorkstationsWorkstationClusterTimeoutsOutputReference, ...)
- func NewGoogleWorkstationsWorkstationCluster_Override(g GoogleWorkstationsWorkstationCluster, scope constructs.Construct, id *string, ...)
- type GoogleWorkstationsWorkstationCluster
- type GoogleWorkstationsWorkstationClusterConditions
- type GoogleWorkstationsWorkstationClusterConditionsList
- type GoogleWorkstationsWorkstationClusterConditionsOutputReference
- type GoogleWorkstationsWorkstationClusterConfig
- type GoogleWorkstationsWorkstationClusterDomainConfig
- type GoogleWorkstationsWorkstationClusterDomainConfigOutputReference
- type GoogleWorkstationsWorkstationClusterPrivateClusterConfig
- type GoogleWorkstationsWorkstationClusterPrivateClusterConfigOutputReference
- type GoogleWorkstationsWorkstationClusterTimeouts
- type GoogleWorkstationsWorkstationClusterTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleWorkstationsWorkstationCluster_GenerateConfigForImport ¶
func GoogleWorkstationsWorkstationCluster_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a GoogleWorkstationsWorkstationCluster resource upon running "cdktf plan <stack-name>".
func GoogleWorkstationsWorkstationCluster_IsConstruct ¶
func GoogleWorkstationsWorkstationCluster_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleWorkstationsWorkstationCluster_IsTerraformElement ¶
func GoogleWorkstationsWorkstationCluster_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleWorkstationsWorkstationCluster_IsTerraformResource ¶
func GoogleWorkstationsWorkstationCluster_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleWorkstationsWorkstationCluster_TfResourceType ¶
func GoogleWorkstationsWorkstationCluster_TfResourceType() *string
func NewGoogleWorkstationsWorkstationClusterConditionsList_Override ¶
func NewGoogleWorkstationsWorkstationClusterConditionsList_Override(g GoogleWorkstationsWorkstationClusterConditionsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGoogleWorkstationsWorkstationClusterConditionsOutputReference_Override ¶
func NewGoogleWorkstationsWorkstationClusterConditionsOutputReference_Override(g GoogleWorkstationsWorkstationClusterConditionsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGoogleWorkstationsWorkstationClusterDomainConfigOutputReference_Override ¶ added in v12.0.4
func NewGoogleWorkstationsWorkstationClusterDomainConfigOutputReference_Override(g GoogleWorkstationsWorkstationClusterDomainConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleWorkstationsWorkstationClusterPrivateClusterConfigOutputReference_Override ¶
func NewGoogleWorkstationsWorkstationClusterPrivateClusterConfigOutputReference_Override(g GoogleWorkstationsWorkstationClusterPrivateClusterConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleWorkstationsWorkstationClusterTimeoutsOutputReference_Override ¶
func NewGoogleWorkstationsWorkstationClusterTimeoutsOutputReference_Override(g GoogleWorkstationsWorkstationClusterTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleWorkstationsWorkstationCluster_Override ¶
func NewGoogleWorkstationsWorkstationCluster_Override(g GoogleWorkstationsWorkstationCluster, scope constructs.Construct, id *string, config *GoogleWorkstationsWorkstationClusterConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_workstations_workstation_cluster google_workstations_workstation_cluster} Resource.
Types ¶
type GoogleWorkstationsWorkstationCluster ¶
type GoogleWorkstationsWorkstationCluster interface {
cdktf.TerraformResource
Annotations() *map[string]*string
SetAnnotations(val *map[string]*string)
AnnotationsInput() *map[string]*string
// Experimental.
CdktfStack() cdktf.TerraformStack
Conditions() GoogleWorkstationsWorkstationClusterConditionsList
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
CreateTime() *string
Degraded() cdktf.IResolvable
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DisplayName() *string
SetDisplayName(val *string)
DisplayNameInput() *string
DomainConfig() GoogleWorkstationsWorkstationClusterDomainConfigOutputReference
DomainConfigInput() *GoogleWorkstationsWorkstationClusterDomainConfig
EffectiveAnnotations() cdktf.StringMap
EffectiveLabels() cdktf.StringMap
Etag() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
Labels() *map[string]*string
SetLabels(val *map[string]*string)
LabelsInput() *map[string]*string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Location() *string
SetLocation(val *string)
LocationInput() *string
Name() *string
Network() *string
SetNetwork(val *string)
NetworkInput() *string
// The tree node.
Node() constructs.Node
PrivateClusterConfig() GoogleWorkstationsWorkstationClusterPrivateClusterConfigOutputReference
PrivateClusterConfigInput() *GoogleWorkstationsWorkstationClusterPrivateClusterConfig
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Subnetwork() *string
SetSubnetwork(val *string)
SubnetworkInput() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
TerraformLabels() cdktf.StringMap
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GoogleWorkstationsWorkstationClusterTimeoutsOutputReference
TimeoutsInput() interface{}
Uid() *string
WorkstationClusterId() *string
SetWorkstationClusterId(val *string)
WorkstationClusterIdInput() *string
// Adds a user defined moveTarget string to this resource to be later used in .moveTo(moveTarget) to resolve the location of the move.
// Experimental.
AddMoveTarget(moveTarget *string)
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
HasResourceMove() interface{}
// Experimental.
ImportFrom(id *string, provider cdktf.TerraformProvider)
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Move the resource corresponding to "id" to this resource.
//
// Note that the resource being moved from must be marked as moved using it's instance function.
// Experimental.
MoveFromId(id *string)
// Moves this resource to the target resource given by moveTarget.
// Experimental.
MoveTo(moveTarget *string, index interface{})
// Moves this resource to the resource corresponding to "id".
// Experimental.
MoveToId(id *string)
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutDomainConfig(value *GoogleWorkstationsWorkstationClusterDomainConfig)
PutPrivateClusterConfig(value *GoogleWorkstationsWorkstationClusterPrivateClusterConfig)
PutTimeouts(value *GoogleWorkstationsWorkstationClusterTimeouts)
ResetAnnotations()
ResetDisplayName()
ResetDomainConfig()
ResetId()
ResetLabels()
ResetLocation()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetPrivateClusterConfig()
ResetProject()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_workstations_workstation_cluster google_workstations_workstation_cluster}.
func NewGoogleWorkstationsWorkstationCluster ¶
func NewGoogleWorkstationsWorkstationCluster(scope constructs.Construct, id *string, config *GoogleWorkstationsWorkstationClusterConfig) GoogleWorkstationsWorkstationCluster
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_workstations_workstation_cluster google_workstations_workstation_cluster} Resource.
type GoogleWorkstationsWorkstationClusterConditions ¶
type GoogleWorkstationsWorkstationClusterConditions struct {
}
type GoogleWorkstationsWorkstationClusterConditionsList ¶
type GoogleWorkstationsWorkstationClusterConditionsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) GoogleWorkstationsWorkstationClusterConditionsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleWorkstationsWorkstationClusterConditionsList ¶
func NewGoogleWorkstationsWorkstationClusterConditionsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GoogleWorkstationsWorkstationClusterConditionsList
type GoogleWorkstationsWorkstationClusterConditionsOutputReference ¶
type GoogleWorkstationsWorkstationClusterConditionsOutputReference interface {
cdktf.ComplexObject
Code() *float64
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Details() cdktf.StringMapList
// Experimental.
Fqn() *string
InternalValue() *GoogleWorkstationsWorkstationClusterConditions
SetInternalValue(val *GoogleWorkstationsWorkstationClusterConditions)
Message() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleWorkstationsWorkstationClusterConditionsOutputReference ¶
func NewGoogleWorkstationsWorkstationClusterConditionsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GoogleWorkstationsWorkstationClusterConditionsOutputReference
type GoogleWorkstationsWorkstationClusterConfig ¶
type GoogleWorkstationsWorkstationClusterConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// The relative resource name of the VPC network on which the instance can be accessed.
//
// It is specified in the following form: "projects/{projectNumber}/global/networks/{network_id}".
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_workstations_workstation_cluster#network GoogleWorkstationsWorkstationCluster#network}
Network *string `field:"required" json:"network" yaml:"network"`
// Name of the Compute Engine subnetwork in which instances associated with this cluster will be created.
//
// Must be part of the subnetwork specified for this cluster.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_workstations_workstation_cluster#subnetwork GoogleWorkstationsWorkstationCluster#subnetwork}
Subnetwork *string `field:"required" json:"subnetwork" yaml:"subnetwork"`
// ID to use for the workstation cluster.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_workstations_workstation_cluster#workstation_cluster_id GoogleWorkstationsWorkstationCluster#workstation_cluster_id}
WorkstationClusterId *string `field:"required" json:"workstationClusterId" yaml:"workstationClusterId"`
// Client-specified annotations. This is distinct from labels.
//
// **Note**: This field is non-authoritative, and will only manage the annotations present in your configuration.
// Please refer to the field 'effective_annotations' for all of the annotations present on the resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_workstations_workstation_cluster#annotations GoogleWorkstationsWorkstationCluster#annotations}
Annotations *map[string]*string `field:"optional" json:"annotations" yaml:"annotations"`
// Human-readable name for this resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_workstations_workstation_cluster#display_name GoogleWorkstationsWorkstationCluster#display_name}
DisplayName *string `field:"optional" json:"displayName" yaml:"displayName"`
// domain_config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_workstations_workstation_cluster#domain_config GoogleWorkstationsWorkstationCluster#domain_config}
DomainConfig *GoogleWorkstationsWorkstationClusterDomainConfig `field:"optional" json:"domainConfig" yaml:"domainConfig"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_workstations_workstation_cluster#id GoogleWorkstationsWorkstationCluster#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Client-specified labels that are applied to the resource and that are also propagated to the underlying Compute Engine resources.
//
// **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
// Please refer to the field 'effective_labels' for all of the labels present on the resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_workstations_workstation_cluster#labels GoogleWorkstationsWorkstationCluster#labels}
Labels *map[string]*string `field:"optional" json:"labels" yaml:"labels"`
// The location where the workstation cluster should reside.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_workstations_workstation_cluster#location GoogleWorkstationsWorkstationCluster#location}
Location *string `field:"optional" json:"location" yaml:"location"`
// private_cluster_config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_workstations_workstation_cluster#private_cluster_config GoogleWorkstationsWorkstationCluster#private_cluster_config}
PrivateClusterConfig *GoogleWorkstationsWorkstationClusterPrivateClusterConfig `field:"optional" json:"privateClusterConfig" yaml:"privateClusterConfig"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_workstations_workstation_cluster#project GoogleWorkstationsWorkstationCluster#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_workstations_workstation_cluster#timeouts GoogleWorkstationsWorkstationCluster#timeouts}
Timeouts *GoogleWorkstationsWorkstationClusterTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type GoogleWorkstationsWorkstationClusterDomainConfig ¶ added in v12.0.4
type GoogleWorkstationsWorkstationClusterDomainConfig struct {
// Domain used by Workstations for HTTP ingress.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_workstations_workstation_cluster#domain GoogleWorkstationsWorkstationCluster#domain}
Domain *string `field:"required" json:"domain" yaml:"domain"`
}
type GoogleWorkstationsWorkstationClusterDomainConfigOutputReference ¶ added in v12.0.4
type GoogleWorkstationsWorkstationClusterDomainConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Domain() *string
SetDomain(val *string)
DomainInput() *string
// Experimental.
Fqn() *string
InternalValue() *GoogleWorkstationsWorkstationClusterDomainConfig
SetInternalValue(val *GoogleWorkstationsWorkstationClusterDomainConfig)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleWorkstationsWorkstationClusterDomainConfigOutputReference ¶ added in v12.0.4
func NewGoogleWorkstationsWorkstationClusterDomainConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleWorkstationsWorkstationClusterDomainConfigOutputReference
type GoogleWorkstationsWorkstationClusterPrivateClusterConfig ¶
type GoogleWorkstationsWorkstationClusterPrivateClusterConfig struct {
// Whether Workstations endpoint is private.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_workstations_workstation_cluster#enable_private_endpoint GoogleWorkstationsWorkstationCluster#enable_private_endpoint}
EnablePrivateEndpoint interface{} `field:"required" json:"enablePrivateEndpoint" yaml:"enablePrivateEndpoint"`
// Additional project IDs that are allowed to attach to the workstation cluster's service attachment.
//
// By default, the workstation cluster's project and the VPC host project (if different) are allowed.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_workstations_workstation_cluster#allowed_projects GoogleWorkstationsWorkstationCluster#allowed_projects}
AllowedProjects *[]*string `field:"optional" json:"allowedProjects" yaml:"allowedProjects"`
}
type GoogleWorkstationsWorkstationClusterPrivateClusterConfigOutputReference ¶
type GoogleWorkstationsWorkstationClusterPrivateClusterConfigOutputReference interface {
cdktf.ComplexObject
AllowedProjects() *[]*string
SetAllowedProjects(val *[]*string)
AllowedProjectsInput() *[]*string
ClusterHostname() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
EnablePrivateEndpoint() interface{}
SetEnablePrivateEndpoint(val interface{})
EnablePrivateEndpointInput() interface{}
// Experimental.
Fqn() *string
InternalValue() *GoogleWorkstationsWorkstationClusterPrivateClusterConfig
SetInternalValue(val *GoogleWorkstationsWorkstationClusterPrivateClusterConfig)
ServiceAttachmentUri() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetAllowedProjects()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleWorkstationsWorkstationClusterPrivateClusterConfigOutputReference ¶
func NewGoogleWorkstationsWorkstationClusterPrivateClusterConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleWorkstationsWorkstationClusterPrivateClusterConfigOutputReference
type GoogleWorkstationsWorkstationClusterTimeouts ¶
type GoogleWorkstationsWorkstationClusterTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_workstations_workstation_cluster#create GoogleWorkstationsWorkstationCluster#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_workstations_workstation_cluster#delete GoogleWorkstationsWorkstationCluster#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.11.0/docs/resources/google_workstations_workstation_cluster#update GoogleWorkstationsWorkstationCluster#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type GoogleWorkstationsWorkstationClusterTimeoutsOutputReference ¶
type GoogleWorkstationsWorkstationClusterTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleWorkstationsWorkstationClusterTimeoutsOutputReference ¶
func NewGoogleWorkstationsWorkstationClusterTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleWorkstationsWorkstationClusterTimeoutsOutputReference
Source Files
¶
- GoogleWorkstationsWorkstationCluster.go
- GoogleWorkstationsWorkstationClusterConditions.go
- GoogleWorkstationsWorkstationClusterConditionsList.go
- GoogleWorkstationsWorkstationClusterConditionsList__checks.go
- GoogleWorkstationsWorkstationClusterConditionsOutputReference.go
- GoogleWorkstationsWorkstationClusterConditionsOutputReference__checks.go
- GoogleWorkstationsWorkstationClusterConfig.go
- GoogleWorkstationsWorkstationClusterDomainConfig.go
- GoogleWorkstationsWorkstationClusterDomainConfigOutputReference.go
- GoogleWorkstationsWorkstationClusterDomainConfigOutputReference__checks.go
- GoogleWorkstationsWorkstationClusterPrivateClusterConfig.go
- GoogleWorkstationsWorkstationClusterPrivateClusterConfigOutputReference.go
- GoogleWorkstationsWorkstationClusterPrivateClusterConfigOutputReference__checks.go
- GoogleWorkstationsWorkstationClusterTimeouts.go
- GoogleWorkstationsWorkstationClusterTimeoutsOutputReference.go
- GoogleWorkstationsWorkstationClusterTimeoutsOutputReference__checks.go
- GoogleWorkstationsWorkstationCluster__checks.go
- main.go