Documentation
¶
Index ¶
- func DataGoogleBackupDrManagementServer_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func DataGoogleBackupDrManagementServer_IsConstruct(x interface{}) *bool
- func DataGoogleBackupDrManagementServer_IsTerraformDataSource(x interface{}) *bool
- func DataGoogleBackupDrManagementServer_IsTerraformElement(x interface{}) *bool
- func DataGoogleBackupDrManagementServer_TfResourceType() *string
- func NewDataGoogleBackupDrManagementServerManagementUriList_Override(d DataGoogleBackupDrManagementServerManagementUriList, ...)
- func NewDataGoogleBackupDrManagementServerManagementUriOutputReference_Override(d DataGoogleBackupDrManagementServerManagementUriOutputReference, ...)
- func NewDataGoogleBackupDrManagementServerNetworksList_Override(d DataGoogleBackupDrManagementServerNetworksList, ...)
- func NewDataGoogleBackupDrManagementServerNetworksOutputReference_Override(d DataGoogleBackupDrManagementServerNetworksOutputReference, ...)
- func NewDataGoogleBackupDrManagementServer_Override(d DataGoogleBackupDrManagementServer, scope constructs.Construct, id *string, ...)
- type DataGoogleBackupDrManagementServer
- type DataGoogleBackupDrManagementServerConfig
- type DataGoogleBackupDrManagementServerManagementUri
- type DataGoogleBackupDrManagementServerManagementUriList
- type DataGoogleBackupDrManagementServerManagementUriOutputReference
- type DataGoogleBackupDrManagementServerNetworks
- type DataGoogleBackupDrManagementServerNetworksList
- type DataGoogleBackupDrManagementServerNetworksOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataGoogleBackupDrManagementServer_GenerateConfigForImport ¶
func DataGoogleBackupDrManagementServer_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a DataGoogleBackupDrManagementServer resource upon running "cdktf plan <stack-name>".
func DataGoogleBackupDrManagementServer_IsConstruct ¶
func DataGoogleBackupDrManagementServer_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataGoogleBackupDrManagementServer_IsTerraformDataSource ¶
func DataGoogleBackupDrManagementServer_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataGoogleBackupDrManagementServer_IsTerraformElement ¶
func DataGoogleBackupDrManagementServer_IsTerraformElement(x interface{}) *bool
Experimental.
func DataGoogleBackupDrManagementServer_TfResourceType ¶
func DataGoogleBackupDrManagementServer_TfResourceType() *string
func NewDataGoogleBackupDrManagementServerManagementUriList_Override ¶
func NewDataGoogleBackupDrManagementServerManagementUriList_Override(d DataGoogleBackupDrManagementServerManagementUriList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataGoogleBackupDrManagementServerManagementUriOutputReference_Override ¶
func NewDataGoogleBackupDrManagementServerManagementUriOutputReference_Override(d DataGoogleBackupDrManagementServerManagementUriOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataGoogleBackupDrManagementServerNetworksList_Override ¶
func NewDataGoogleBackupDrManagementServerNetworksList_Override(d DataGoogleBackupDrManagementServerNetworksList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataGoogleBackupDrManagementServerNetworksOutputReference_Override ¶
func NewDataGoogleBackupDrManagementServerNetworksOutputReference_Override(d DataGoogleBackupDrManagementServerNetworksOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataGoogleBackupDrManagementServer_Override ¶
func NewDataGoogleBackupDrManagementServer_Override(d DataGoogleBackupDrManagementServer, scope constructs.Construct, id *string, config *DataGoogleBackupDrManagementServerConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/data-sources/google_backup_dr_management_server google_backup_dr_management_server} Data Source.
Types ¶
type DataGoogleBackupDrManagementServer ¶
type DataGoogleBackupDrManagementServer interface {
cdktf.TerraformDataSource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Location() *string
SetLocation(val *string)
LocationInput() *string
ManagementUri() DataGoogleBackupDrManagementServerManagementUriList
Name() *string
Networks() DataGoogleBackupDrManagementServerNetworksList
// The tree node.
Node() constructs.Node
Oauth2ClientId() *string
Project() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Type() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
SynthesizeAttributes() *map[string]interface{}
SynthesizeHclAttributes() *map[string]interface{}
// Adds this resource to the terraform JSON output.
// Experimental.
ToHclTerraform() interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/data-sources/google_backup_dr_management_server google_backup_dr_management_server}.
func NewDataGoogleBackupDrManagementServer ¶
func NewDataGoogleBackupDrManagementServer(scope constructs.Construct, id *string, config *DataGoogleBackupDrManagementServerConfig) DataGoogleBackupDrManagementServer
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/data-sources/google_backup_dr_management_server google_backup_dr_management_server} Data Source.
type DataGoogleBackupDrManagementServerConfig ¶
type DataGoogleBackupDrManagementServerConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// The location for the management server (management console).
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/data-sources/google_backup_dr_management_server#location DataGoogleBackupDrManagementServer#location}
Location *string `field:"required" json:"location" yaml:"location"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/data-sources/google_backup_dr_management_server#id DataGoogleBackupDrManagementServer#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
}
type DataGoogleBackupDrManagementServerManagementUri ¶
type DataGoogleBackupDrManagementServerManagementUri struct {
}
type DataGoogleBackupDrManagementServerManagementUriList ¶
type DataGoogleBackupDrManagementServerManagementUriList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) DataGoogleBackupDrManagementServerManagementUriOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleBackupDrManagementServerManagementUriList ¶
func NewDataGoogleBackupDrManagementServerManagementUriList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataGoogleBackupDrManagementServerManagementUriList
type DataGoogleBackupDrManagementServerManagementUriOutputReference ¶
type DataGoogleBackupDrManagementServerManagementUriOutputReference interface {
cdktf.ComplexObject
Api() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataGoogleBackupDrManagementServerManagementUri
SetInternalValue(val *DataGoogleBackupDrManagementServerManagementUri)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
WebUi() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleBackupDrManagementServerManagementUriOutputReference ¶
func NewDataGoogleBackupDrManagementServerManagementUriOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataGoogleBackupDrManagementServerManagementUriOutputReference
type DataGoogleBackupDrManagementServerNetworks ¶
type DataGoogleBackupDrManagementServerNetworks struct {
}
type DataGoogleBackupDrManagementServerNetworksList ¶
type DataGoogleBackupDrManagementServerNetworksList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) DataGoogleBackupDrManagementServerNetworksOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleBackupDrManagementServerNetworksList ¶
func NewDataGoogleBackupDrManagementServerNetworksList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataGoogleBackupDrManagementServerNetworksList
type DataGoogleBackupDrManagementServerNetworksOutputReference ¶
type DataGoogleBackupDrManagementServerNetworksOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataGoogleBackupDrManagementServerNetworks
SetInternalValue(val *DataGoogleBackupDrManagementServerNetworks)
Network() *string
PeeringMode() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleBackupDrManagementServerNetworksOutputReference ¶
func NewDataGoogleBackupDrManagementServerNetworksOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataGoogleBackupDrManagementServerNetworksOutputReference
Source Files
¶
- DataGoogleBackupDrManagementServer.go
- DataGoogleBackupDrManagementServerConfig.go
- DataGoogleBackupDrManagementServerManagementUri.go
- DataGoogleBackupDrManagementServerManagementUriList.go
- DataGoogleBackupDrManagementServerManagementUriList__checks.go
- DataGoogleBackupDrManagementServerManagementUriOutputReference.go
- DataGoogleBackupDrManagementServerManagementUriOutputReference__checks.go
- DataGoogleBackupDrManagementServerNetworks.go
- DataGoogleBackupDrManagementServerNetworksList.go
- DataGoogleBackupDrManagementServerNetworksList__checks.go
- DataGoogleBackupDrManagementServerNetworksOutputReference.go
- DataGoogleBackupDrManagementServerNetworksOutputReference__checks.go
- DataGoogleBackupDrManagementServer__checks.go
- main.go