Documentation
¶
Index ¶
- func DataGoogleComputeDisk_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func DataGoogleComputeDisk_IsConstruct(x interface{}) *bool
- func DataGoogleComputeDisk_IsTerraformDataSource(x interface{}) *bool
- func DataGoogleComputeDisk_IsTerraformElement(x interface{}) *bool
- func DataGoogleComputeDisk_TfResourceType() *string
- func NewDataGoogleComputeDiskAsyncPrimaryDiskList_Override(d DataGoogleComputeDiskAsyncPrimaryDiskList, ...)
- func NewDataGoogleComputeDiskAsyncPrimaryDiskOutputReference_Override(d DataGoogleComputeDiskAsyncPrimaryDiskOutputReference, ...)
- func NewDataGoogleComputeDiskDiskEncryptionKeyList_Override(d DataGoogleComputeDiskDiskEncryptionKeyList, ...)
- func NewDataGoogleComputeDiskDiskEncryptionKeyOutputReference_Override(d DataGoogleComputeDiskDiskEncryptionKeyOutputReference, ...)
- func NewDataGoogleComputeDiskGuestOsFeaturesList_Override(d DataGoogleComputeDiskGuestOsFeaturesList, ...)
- func NewDataGoogleComputeDiskGuestOsFeaturesOutputReference_Override(d DataGoogleComputeDiskGuestOsFeaturesOutputReference, ...)
- func NewDataGoogleComputeDiskSourceImageEncryptionKeyList_Override(d DataGoogleComputeDiskSourceImageEncryptionKeyList, ...)
- func NewDataGoogleComputeDiskSourceImageEncryptionKeyOutputReference_Override(d DataGoogleComputeDiskSourceImageEncryptionKeyOutputReference, ...)
- func NewDataGoogleComputeDiskSourceSnapshotEncryptionKeyList_Override(d DataGoogleComputeDiskSourceSnapshotEncryptionKeyList, ...)
- func NewDataGoogleComputeDiskSourceSnapshotEncryptionKeyOutputReference_Override(d DataGoogleComputeDiskSourceSnapshotEncryptionKeyOutputReference, ...)
- func NewDataGoogleComputeDisk_Override(d DataGoogleComputeDisk, scope constructs.Construct, id *string, ...)
- type DataGoogleComputeDisk
- type DataGoogleComputeDiskAsyncPrimaryDisk
- type DataGoogleComputeDiskAsyncPrimaryDiskList
- type DataGoogleComputeDiskAsyncPrimaryDiskOutputReference
- type DataGoogleComputeDiskConfig
- type DataGoogleComputeDiskDiskEncryptionKey
- type DataGoogleComputeDiskDiskEncryptionKeyList
- type DataGoogleComputeDiskDiskEncryptionKeyOutputReference
- type DataGoogleComputeDiskGuestOsFeatures
- type DataGoogleComputeDiskGuestOsFeaturesList
- type DataGoogleComputeDiskGuestOsFeaturesOutputReference
- type DataGoogleComputeDiskSourceImageEncryptionKey
- type DataGoogleComputeDiskSourceImageEncryptionKeyList
- type DataGoogleComputeDiskSourceImageEncryptionKeyOutputReference
- type DataGoogleComputeDiskSourceSnapshotEncryptionKey
- type DataGoogleComputeDiskSourceSnapshotEncryptionKeyList
- type DataGoogleComputeDiskSourceSnapshotEncryptionKeyOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataGoogleComputeDisk_GenerateConfigForImport ¶
func DataGoogleComputeDisk_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a DataGoogleComputeDisk resource upon running "cdktf plan <stack-name>".
func DataGoogleComputeDisk_IsConstruct ¶
func DataGoogleComputeDisk_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataGoogleComputeDisk_IsTerraformDataSource ¶
func DataGoogleComputeDisk_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataGoogleComputeDisk_IsTerraformElement ¶
func DataGoogleComputeDisk_IsTerraformElement(x interface{}) *bool
Experimental.
func DataGoogleComputeDisk_TfResourceType ¶
func DataGoogleComputeDisk_TfResourceType() *string
func NewDataGoogleComputeDiskAsyncPrimaryDiskList_Override ¶
func NewDataGoogleComputeDiskAsyncPrimaryDiskList_Override(d DataGoogleComputeDiskAsyncPrimaryDiskList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataGoogleComputeDiskAsyncPrimaryDiskOutputReference_Override ¶
func NewDataGoogleComputeDiskAsyncPrimaryDiskOutputReference_Override(d DataGoogleComputeDiskAsyncPrimaryDiskOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataGoogleComputeDiskDiskEncryptionKeyList_Override ¶
func NewDataGoogleComputeDiskDiskEncryptionKeyList_Override(d DataGoogleComputeDiskDiskEncryptionKeyList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataGoogleComputeDiskDiskEncryptionKeyOutputReference_Override ¶
func NewDataGoogleComputeDiskDiskEncryptionKeyOutputReference_Override(d DataGoogleComputeDiskDiskEncryptionKeyOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataGoogleComputeDiskGuestOsFeaturesList_Override ¶
func NewDataGoogleComputeDiskGuestOsFeaturesList_Override(d DataGoogleComputeDiskGuestOsFeaturesList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataGoogleComputeDiskGuestOsFeaturesOutputReference_Override ¶
func NewDataGoogleComputeDiskGuestOsFeaturesOutputReference_Override(d DataGoogleComputeDiskGuestOsFeaturesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataGoogleComputeDiskSourceImageEncryptionKeyList_Override ¶
func NewDataGoogleComputeDiskSourceImageEncryptionKeyList_Override(d DataGoogleComputeDiskSourceImageEncryptionKeyList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataGoogleComputeDiskSourceImageEncryptionKeyOutputReference_Override ¶
func NewDataGoogleComputeDiskSourceImageEncryptionKeyOutputReference_Override(d DataGoogleComputeDiskSourceImageEncryptionKeyOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataGoogleComputeDiskSourceSnapshotEncryptionKeyList_Override ¶
func NewDataGoogleComputeDiskSourceSnapshotEncryptionKeyList_Override(d DataGoogleComputeDiskSourceSnapshotEncryptionKeyList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataGoogleComputeDiskSourceSnapshotEncryptionKeyOutputReference_Override ¶
func NewDataGoogleComputeDiskSourceSnapshotEncryptionKeyOutputReference_Override(d DataGoogleComputeDiskSourceSnapshotEncryptionKeyOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataGoogleComputeDisk_Override ¶
func NewDataGoogleComputeDisk_Override(d DataGoogleComputeDisk, scope constructs.Construct, id *string, config *DataGoogleComputeDiskConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/data-sources/google_compute_disk google_compute_disk} Data Source.
Types ¶
type DataGoogleComputeDisk ¶
type DataGoogleComputeDisk interface {
cdktf.TerraformDataSource
AccessMode() *string
AsyncPrimaryDisk() DataGoogleComputeDiskAsyncPrimaryDiskList
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
CreationTimestamp() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
DiskEncryptionKey() DataGoogleComputeDiskDiskEncryptionKeyList
DiskId() *string
EffectiveLabels() cdktf.StringMap
EnableConfidentialCompute() cdktf.IResolvable
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
GuestOsFeatures() DataGoogleComputeDiskGuestOsFeaturesList
Id() *string
SetId(val *string)
IdInput() *string
Image() *string
Interface() *string
LabelFingerprint() *string
Labels() cdktf.StringMap
LastAttachTimestamp() *string
LastDetachTimestamp() *string
Licenses() *[]*string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
MultiWriter() cdktf.IResolvable
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
PhysicalBlockSizeBytes() *float64
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
ProvisionedIops() *float64
ProvisionedThroughput() *float64
// Experimental.
RawOverrides() interface{}
ResourcePolicies() *[]*string
SelfLink() *string
Size() *float64
Snapshot() *string
SourceDisk() *string
SourceDiskId() *string
SourceImageEncryptionKey() DataGoogleComputeDiskSourceImageEncryptionKeyList
SourceImageId() *string
SourceSnapshotEncryptionKey() DataGoogleComputeDiskSourceSnapshotEncryptionKeyList
SourceSnapshotId() *string
StoragePool() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
TerraformLabels() cdktf.StringMap
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Type() *string
Users() *[]*string
Zone() *string
SetZone(val *string)
ZoneInput() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
ResetZone()
SynthesizeAttributes() *map[string]interface{}
SynthesizeHclAttributes() *map[string]interface{}
// Adds this resource to the terraform JSON output.
// Experimental.
ToHclTerraform() interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/data-sources/google_compute_disk google_compute_disk}.
func NewDataGoogleComputeDisk ¶
func NewDataGoogleComputeDisk(scope constructs.Construct, id *string, config *DataGoogleComputeDiskConfig) DataGoogleComputeDisk
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/data-sources/google_compute_disk google_compute_disk} Data Source.
type DataGoogleComputeDiskAsyncPrimaryDisk ¶
type DataGoogleComputeDiskAsyncPrimaryDisk struct {
}
type DataGoogleComputeDiskAsyncPrimaryDiskList ¶
type DataGoogleComputeDiskAsyncPrimaryDiskList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) DataGoogleComputeDiskAsyncPrimaryDiskOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleComputeDiskAsyncPrimaryDiskList ¶
func NewDataGoogleComputeDiskAsyncPrimaryDiskList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataGoogleComputeDiskAsyncPrimaryDiskList
type DataGoogleComputeDiskAsyncPrimaryDiskOutputReference ¶
type DataGoogleComputeDiskAsyncPrimaryDiskOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Disk() *string
// Experimental.
Fqn() *string
InternalValue() *DataGoogleComputeDiskAsyncPrimaryDisk
SetInternalValue(val *DataGoogleComputeDiskAsyncPrimaryDisk)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleComputeDiskAsyncPrimaryDiskOutputReference ¶
func NewDataGoogleComputeDiskAsyncPrimaryDiskOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataGoogleComputeDiskAsyncPrimaryDiskOutputReference
type DataGoogleComputeDiskConfig ¶
type DataGoogleComputeDiskConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Name of the resource.
//
// Provided by the client when the resource is
// created. The name must be 1-63 characters long, and comply with
// RFC1035. Specifically, the name must be 1-63 characters long and match
// the regular expression '[a-z]([-a-z0-9]*[a-z0-9])?' which means the
// first character must be a lowercase letter, and all following
// characters must be a dash, lowercase letter, or digit, except the last
// character, which cannot be a dash.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/data-sources/google_compute_disk#name DataGoogleComputeDisk#name}
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/data-sources/google_compute_disk#id DataGoogleComputeDisk#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/data-sources/google_compute_disk#project DataGoogleComputeDisk#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// A reference to the zone where the disk resides.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/data-sources/google_compute_disk#zone DataGoogleComputeDisk#zone}
Zone *string `field:"optional" json:"zone" yaml:"zone"`
}
type DataGoogleComputeDiskDiskEncryptionKey ¶
type DataGoogleComputeDiskDiskEncryptionKey struct {
}
type DataGoogleComputeDiskDiskEncryptionKeyList ¶
type DataGoogleComputeDiskDiskEncryptionKeyList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) DataGoogleComputeDiskDiskEncryptionKeyOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleComputeDiskDiskEncryptionKeyList ¶
func NewDataGoogleComputeDiskDiskEncryptionKeyList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataGoogleComputeDiskDiskEncryptionKeyList
type DataGoogleComputeDiskDiskEncryptionKeyOutputReference ¶
type DataGoogleComputeDiskDiskEncryptionKeyOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataGoogleComputeDiskDiskEncryptionKey
SetInternalValue(val *DataGoogleComputeDiskDiskEncryptionKey)
KmsKeySelfLink() *string
KmsKeyServiceAccount() *string
RawKey() *string
RsaEncryptedKey() *string
Sha256() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleComputeDiskDiskEncryptionKeyOutputReference ¶
func NewDataGoogleComputeDiskDiskEncryptionKeyOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataGoogleComputeDiskDiskEncryptionKeyOutputReference
type DataGoogleComputeDiskGuestOsFeatures ¶
type DataGoogleComputeDiskGuestOsFeatures struct {
}
type DataGoogleComputeDiskGuestOsFeaturesList ¶
type DataGoogleComputeDiskGuestOsFeaturesList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) DataGoogleComputeDiskGuestOsFeaturesOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleComputeDiskGuestOsFeaturesList ¶
func NewDataGoogleComputeDiskGuestOsFeaturesList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataGoogleComputeDiskGuestOsFeaturesList
type DataGoogleComputeDiskGuestOsFeaturesOutputReference ¶
type DataGoogleComputeDiskGuestOsFeaturesOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataGoogleComputeDiskGuestOsFeatures
SetInternalValue(val *DataGoogleComputeDiskGuestOsFeatures)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleComputeDiskGuestOsFeaturesOutputReference ¶
func NewDataGoogleComputeDiskGuestOsFeaturesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataGoogleComputeDiskGuestOsFeaturesOutputReference
type DataGoogleComputeDiskSourceImageEncryptionKey ¶
type DataGoogleComputeDiskSourceImageEncryptionKey struct {
}
type DataGoogleComputeDiskSourceImageEncryptionKeyList ¶
type DataGoogleComputeDiskSourceImageEncryptionKeyList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) DataGoogleComputeDiskSourceImageEncryptionKeyOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleComputeDiskSourceImageEncryptionKeyList ¶
func NewDataGoogleComputeDiskSourceImageEncryptionKeyList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataGoogleComputeDiskSourceImageEncryptionKeyList
type DataGoogleComputeDiskSourceImageEncryptionKeyOutputReference ¶
type DataGoogleComputeDiskSourceImageEncryptionKeyOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataGoogleComputeDiskSourceImageEncryptionKey
SetInternalValue(val *DataGoogleComputeDiskSourceImageEncryptionKey)
KmsKeySelfLink() *string
KmsKeyServiceAccount() *string
RawKey() *string
Sha256() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleComputeDiskSourceImageEncryptionKeyOutputReference ¶
func NewDataGoogleComputeDiskSourceImageEncryptionKeyOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataGoogleComputeDiskSourceImageEncryptionKeyOutputReference
type DataGoogleComputeDiskSourceSnapshotEncryptionKey ¶
type DataGoogleComputeDiskSourceSnapshotEncryptionKey struct {
}
type DataGoogleComputeDiskSourceSnapshotEncryptionKeyList ¶
type DataGoogleComputeDiskSourceSnapshotEncryptionKeyList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) DataGoogleComputeDiskSourceSnapshotEncryptionKeyOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleComputeDiskSourceSnapshotEncryptionKeyList ¶
func NewDataGoogleComputeDiskSourceSnapshotEncryptionKeyList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataGoogleComputeDiskSourceSnapshotEncryptionKeyList
type DataGoogleComputeDiskSourceSnapshotEncryptionKeyOutputReference ¶
type DataGoogleComputeDiskSourceSnapshotEncryptionKeyOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataGoogleComputeDiskSourceSnapshotEncryptionKey
SetInternalValue(val *DataGoogleComputeDiskSourceSnapshotEncryptionKey)
KmsKeySelfLink() *string
KmsKeyServiceAccount() *string
RawKey() *string
Sha256() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleComputeDiskSourceSnapshotEncryptionKeyOutputReference ¶
func NewDataGoogleComputeDiskSourceSnapshotEncryptionKeyOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataGoogleComputeDiskSourceSnapshotEncryptionKeyOutputReference
Source Files
¶
- DataGoogleComputeDisk.go
- DataGoogleComputeDiskAsyncPrimaryDisk.go
- DataGoogleComputeDiskAsyncPrimaryDiskList.go
- DataGoogleComputeDiskAsyncPrimaryDiskList__checks.go
- DataGoogleComputeDiskAsyncPrimaryDiskOutputReference.go
- DataGoogleComputeDiskAsyncPrimaryDiskOutputReference__checks.go
- DataGoogleComputeDiskConfig.go
- DataGoogleComputeDiskDiskEncryptionKey.go
- DataGoogleComputeDiskDiskEncryptionKeyList.go
- DataGoogleComputeDiskDiskEncryptionKeyList__checks.go
- DataGoogleComputeDiskDiskEncryptionKeyOutputReference.go
- DataGoogleComputeDiskDiskEncryptionKeyOutputReference__checks.go
- DataGoogleComputeDiskGuestOsFeatures.go
- DataGoogleComputeDiskGuestOsFeaturesList.go
- DataGoogleComputeDiskGuestOsFeaturesList__checks.go
- DataGoogleComputeDiskGuestOsFeaturesOutputReference.go
- DataGoogleComputeDiskGuestOsFeaturesOutputReference__checks.go
- DataGoogleComputeDiskSourceImageEncryptionKey.go
- DataGoogleComputeDiskSourceImageEncryptionKeyList.go
- DataGoogleComputeDiskSourceImageEncryptionKeyList__checks.go
- DataGoogleComputeDiskSourceImageEncryptionKeyOutputReference.go
- DataGoogleComputeDiskSourceImageEncryptionKeyOutputReference__checks.go
- DataGoogleComputeDiskSourceSnapshotEncryptionKey.go
- DataGoogleComputeDiskSourceSnapshotEncryptionKeyList.go
- DataGoogleComputeDiskSourceSnapshotEncryptionKeyList__checks.go
- DataGoogleComputeDiskSourceSnapshotEncryptionKeyOutputReference.go
- DataGoogleComputeDiskSourceSnapshotEncryptionKeyOutputReference__checks.go
- DataGoogleComputeDisk__checks.go
- main.go