Documentation
¶
Index ¶
- func DataGoogleComputeHaVpnGateway_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func DataGoogleComputeHaVpnGateway_IsConstruct(x interface{}) *bool
- func DataGoogleComputeHaVpnGateway_IsTerraformDataSource(x interface{}) *bool
- func DataGoogleComputeHaVpnGateway_IsTerraformElement(x interface{}) *bool
- func DataGoogleComputeHaVpnGateway_TfResourceType() *string
- func NewDataGoogleComputeHaVpnGatewayVpnInterfacesList_Override(d DataGoogleComputeHaVpnGatewayVpnInterfacesList, ...)
- func NewDataGoogleComputeHaVpnGatewayVpnInterfacesOutputReference_Override(d DataGoogleComputeHaVpnGatewayVpnInterfacesOutputReference, ...)
- func NewDataGoogleComputeHaVpnGateway_Override(d DataGoogleComputeHaVpnGateway, scope constructs.Construct, id *string, ...)
- type DataGoogleComputeHaVpnGateway
- type DataGoogleComputeHaVpnGatewayConfig
- type DataGoogleComputeHaVpnGatewayVpnInterfaces
- type DataGoogleComputeHaVpnGatewayVpnInterfacesList
- type DataGoogleComputeHaVpnGatewayVpnInterfacesOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataGoogleComputeHaVpnGateway_GenerateConfigForImport ¶
func DataGoogleComputeHaVpnGateway_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a DataGoogleComputeHaVpnGateway resource upon running "cdktf plan <stack-name>".
func DataGoogleComputeHaVpnGateway_IsConstruct ¶
func DataGoogleComputeHaVpnGateway_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataGoogleComputeHaVpnGateway_IsTerraformDataSource ¶
func DataGoogleComputeHaVpnGateway_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataGoogleComputeHaVpnGateway_IsTerraformElement ¶
func DataGoogleComputeHaVpnGateway_IsTerraformElement(x interface{}) *bool
Experimental.
func DataGoogleComputeHaVpnGateway_TfResourceType ¶
func DataGoogleComputeHaVpnGateway_TfResourceType() *string
func NewDataGoogleComputeHaVpnGatewayVpnInterfacesList_Override ¶
func NewDataGoogleComputeHaVpnGatewayVpnInterfacesList_Override(d DataGoogleComputeHaVpnGatewayVpnInterfacesList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataGoogleComputeHaVpnGatewayVpnInterfacesOutputReference_Override ¶
func NewDataGoogleComputeHaVpnGatewayVpnInterfacesOutputReference_Override(d DataGoogleComputeHaVpnGatewayVpnInterfacesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataGoogleComputeHaVpnGateway_Override ¶
func NewDataGoogleComputeHaVpnGateway_Override(d DataGoogleComputeHaVpnGateway, scope constructs.Construct, id *string, config *DataGoogleComputeHaVpnGatewayConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/data-sources/google_compute_ha_vpn_gateway google_compute_ha_vpn_gateway} Data Source.
Types ¶
type DataGoogleComputeHaVpnGateway ¶
type DataGoogleComputeHaVpnGateway interface {
cdktf.TerraformDataSource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
GatewayIpVersion() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
Network() *string
// The tree node.
Node() constructs.Node
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
Region() *string
SetRegion(val *string)
RegionInput() *string
SelfLink() *string
StackType() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
VpnInterfaces() DataGoogleComputeHaVpnGatewayVpnInterfacesList
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
ResetRegion()
SynthesizeAttributes() *map[string]interface{}
SynthesizeHclAttributes() *map[string]interface{}
// Adds this resource to the terraform JSON output.
// Experimental.
ToHclTerraform() interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/data-sources/google_compute_ha_vpn_gateway google_compute_ha_vpn_gateway}.
func NewDataGoogleComputeHaVpnGateway ¶
func NewDataGoogleComputeHaVpnGateway(scope constructs.Construct, id *string, config *DataGoogleComputeHaVpnGatewayConfig) DataGoogleComputeHaVpnGateway
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/data-sources/google_compute_ha_vpn_gateway google_compute_ha_vpn_gateway} Data Source.
type DataGoogleComputeHaVpnGatewayConfig ¶
type DataGoogleComputeHaVpnGatewayConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Name of the resource.
//
// Provided by the client when the resource is
// created. The name must be 1-63 characters long, and comply with
// RFC1035. Specifically, the name must be 1-63 characters long and
// match the regular expression '[a-z]([-a-z0-9]*[a-z0-9])?' which means
// the first character must be a lowercase letter, and all following
// characters must be a dash, lowercase letter, or digit, except the last
// character, which cannot be a dash.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/data-sources/google_compute_ha_vpn_gateway#name DataGoogleComputeHaVpnGateway#name}
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/data-sources/google_compute_ha_vpn_gateway#id DataGoogleComputeHaVpnGateway#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/data-sources/google_compute_ha_vpn_gateway#project DataGoogleComputeHaVpnGateway#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// The region this gateway should sit in.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/data-sources/google_compute_ha_vpn_gateway#region DataGoogleComputeHaVpnGateway#region}
Region *string `field:"optional" json:"region" yaml:"region"`
}
type DataGoogleComputeHaVpnGatewayVpnInterfaces ¶
type DataGoogleComputeHaVpnGatewayVpnInterfaces struct {
}
type DataGoogleComputeHaVpnGatewayVpnInterfacesList ¶
type DataGoogleComputeHaVpnGatewayVpnInterfacesList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) DataGoogleComputeHaVpnGatewayVpnInterfacesOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleComputeHaVpnGatewayVpnInterfacesList ¶
func NewDataGoogleComputeHaVpnGatewayVpnInterfacesList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataGoogleComputeHaVpnGatewayVpnInterfacesList
type DataGoogleComputeHaVpnGatewayVpnInterfacesOutputReference ¶
type DataGoogleComputeHaVpnGatewayVpnInterfacesOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Id() *float64
InterconnectAttachment() *string
InternalValue() *DataGoogleComputeHaVpnGatewayVpnInterfaces
SetInternalValue(val *DataGoogleComputeHaVpnGatewayVpnInterfaces)
IpAddress() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleComputeHaVpnGatewayVpnInterfacesOutputReference ¶
func NewDataGoogleComputeHaVpnGatewayVpnInterfacesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataGoogleComputeHaVpnGatewayVpnInterfacesOutputReference
Source Files
¶
- DataGoogleComputeHaVpnGateway.go
- DataGoogleComputeHaVpnGatewayConfig.go
- DataGoogleComputeHaVpnGatewayVpnInterfaces.go
- DataGoogleComputeHaVpnGatewayVpnInterfacesList.go
- DataGoogleComputeHaVpnGatewayVpnInterfacesList__checks.go
- DataGoogleComputeHaVpnGatewayVpnInterfacesOutputReference.go
- DataGoogleComputeHaVpnGatewayVpnInterfacesOutputReference__checks.go
- DataGoogleComputeHaVpnGateway__checks.go
- main.go