Documentation
¶
Index ¶
- func DataGoogleProjectOrganizationPolicy_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func DataGoogleProjectOrganizationPolicy_IsConstruct(x interface{}) *bool
- func DataGoogleProjectOrganizationPolicy_IsTerraformDataSource(x interface{}) *bool
- func DataGoogleProjectOrganizationPolicy_IsTerraformElement(x interface{}) *bool
- func DataGoogleProjectOrganizationPolicy_TfResourceType() *string
- func NewDataGoogleProjectOrganizationPolicyBooleanPolicyList_Override(d DataGoogleProjectOrganizationPolicyBooleanPolicyList, ...)
- func NewDataGoogleProjectOrganizationPolicyBooleanPolicyOutputReference_Override(d DataGoogleProjectOrganizationPolicyBooleanPolicyOutputReference, ...)
- func NewDataGoogleProjectOrganizationPolicyListPolicyAllowList_Override(d DataGoogleProjectOrganizationPolicyListPolicyAllowList, ...)
- func NewDataGoogleProjectOrganizationPolicyListPolicyAllowOutputReference_Override(d DataGoogleProjectOrganizationPolicyListPolicyAllowOutputReference, ...)
- func NewDataGoogleProjectOrganizationPolicyListPolicyDenyList_Override(d DataGoogleProjectOrganizationPolicyListPolicyDenyList, ...)
- func NewDataGoogleProjectOrganizationPolicyListPolicyDenyOutputReference_Override(d DataGoogleProjectOrganizationPolicyListPolicyDenyOutputReference, ...)
- func NewDataGoogleProjectOrganizationPolicyListPolicyList_Override(d DataGoogleProjectOrganizationPolicyListPolicyList, ...)
- func NewDataGoogleProjectOrganizationPolicyListPolicyOutputReference_Override(d DataGoogleProjectOrganizationPolicyListPolicyOutputReference, ...)
- func NewDataGoogleProjectOrganizationPolicyRestorePolicyList_Override(d DataGoogleProjectOrganizationPolicyRestorePolicyList, ...)
- func NewDataGoogleProjectOrganizationPolicyRestorePolicyOutputReference_Override(d DataGoogleProjectOrganizationPolicyRestorePolicyOutputReference, ...)
- func NewDataGoogleProjectOrganizationPolicy_Override(d DataGoogleProjectOrganizationPolicy, scope constructs.Construct, id *string, ...)
- type DataGoogleProjectOrganizationPolicy
- type DataGoogleProjectOrganizationPolicyBooleanPolicy
- type DataGoogleProjectOrganizationPolicyBooleanPolicyList
- type DataGoogleProjectOrganizationPolicyBooleanPolicyOutputReference
- type DataGoogleProjectOrganizationPolicyConfig
- type DataGoogleProjectOrganizationPolicyListPolicy
- type DataGoogleProjectOrganizationPolicyListPolicyAllow
- type DataGoogleProjectOrganizationPolicyListPolicyAllowList
- type DataGoogleProjectOrganizationPolicyListPolicyAllowOutputReference
- type DataGoogleProjectOrganizationPolicyListPolicyDeny
- type DataGoogleProjectOrganizationPolicyListPolicyDenyList
- type DataGoogleProjectOrganizationPolicyListPolicyDenyOutputReference
- type DataGoogleProjectOrganizationPolicyListPolicyList
- type DataGoogleProjectOrganizationPolicyListPolicyOutputReference
- type DataGoogleProjectOrganizationPolicyRestorePolicy
- type DataGoogleProjectOrganizationPolicyRestorePolicyList
- type DataGoogleProjectOrganizationPolicyRestorePolicyOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataGoogleProjectOrganizationPolicy_GenerateConfigForImport ¶
func DataGoogleProjectOrganizationPolicy_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a DataGoogleProjectOrganizationPolicy resource upon running "cdktf plan <stack-name>".
func DataGoogleProjectOrganizationPolicy_IsConstruct ¶
func DataGoogleProjectOrganizationPolicy_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataGoogleProjectOrganizationPolicy_IsTerraformDataSource ¶
func DataGoogleProjectOrganizationPolicy_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataGoogleProjectOrganizationPolicy_IsTerraformElement ¶
func DataGoogleProjectOrganizationPolicy_IsTerraformElement(x interface{}) *bool
Experimental.
func DataGoogleProjectOrganizationPolicy_TfResourceType ¶
func DataGoogleProjectOrganizationPolicy_TfResourceType() *string
func NewDataGoogleProjectOrganizationPolicyBooleanPolicyList_Override ¶
func NewDataGoogleProjectOrganizationPolicyBooleanPolicyList_Override(d DataGoogleProjectOrganizationPolicyBooleanPolicyList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataGoogleProjectOrganizationPolicyBooleanPolicyOutputReference_Override ¶
func NewDataGoogleProjectOrganizationPolicyBooleanPolicyOutputReference_Override(d DataGoogleProjectOrganizationPolicyBooleanPolicyOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataGoogleProjectOrganizationPolicyListPolicyAllowList_Override ¶
func NewDataGoogleProjectOrganizationPolicyListPolicyAllowList_Override(d DataGoogleProjectOrganizationPolicyListPolicyAllowList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataGoogleProjectOrganizationPolicyListPolicyAllowOutputReference_Override ¶
func NewDataGoogleProjectOrganizationPolicyListPolicyAllowOutputReference_Override(d DataGoogleProjectOrganizationPolicyListPolicyAllowOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataGoogleProjectOrganizationPolicyListPolicyDenyList_Override ¶
func NewDataGoogleProjectOrganizationPolicyListPolicyDenyList_Override(d DataGoogleProjectOrganizationPolicyListPolicyDenyList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataGoogleProjectOrganizationPolicyListPolicyDenyOutputReference_Override ¶
func NewDataGoogleProjectOrganizationPolicyListPolicyDenyOutputReference_Override(d DataGoogleProjectOrganizationPolicyListPolicyDenyOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataGoogleProjectOrganizationPolicyListPolicyList_Override ¶
func NewDataGoogleProjectOrganizationPolicyListPolicyList_Override(d DataGoogleProjectOrganizationPolicyListPolicyList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataGoogleProjectOrganizationPolicyListPolicyOutputReference_Override ¶
func NewDataGoogleProjectOrganizationPolicyListPolicyOutputReference_Override(d DataGoogleProjectOrganizationPolicyListPolicyOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataGoogleProjectOrganizationPolicyRestorePolicyList_Override ¶
func NewDataGoogleProjectOrganizationPolicyRestorePolicyList_Override(d DataGoogleProjectOrganizationPolicyRestorePolicyList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataGoogleProjectOrganizationPolicyRestorePolicyOutputReference_Override ¶
func NewDataGoogleProjectOrganizationPolicyRestorePolicyOutputReference_Override(d DataGoogleProjectOrganizationPolicyRestorePolicyOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataGoogleProjectOrganizationPolicy_Override ¶
func NewDataGoogleProjectOrganizationPolicy_Override(d DataGoogleProjectOrganizationPolicy, scope constructs.Construct, id *string, config *DataGoogleProjectOrganizationPolicyConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/data-sources/google_project_organization_policy google_project_organization_policy} Data Source.
Types ¶
type DataGoogleProjectOrganizationPolicy ¶
type DataGoogleProjectOrganizationPolicy interface {
cdktf.TerraformDataSource
BooleanPolicy() DataGoogleProjectOrganizationPolicyBooleanPolicyList
// Experimental.
CdktfStack() cdktf.TerraformStack
Constraint() *string
SetConstraint(val *string)
ConstraintInput() *string
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Etag() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
ListPolicy() DataGoogleProjectOrganizationPolicyListPolicyList
// The tree node.
Node() constructs.Node
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
RestorePolicy() DataGoogleProjectOrganizationPolicyRestorePolicyList
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
UpdateTime() *string
Version() *float64
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
SynthesizeAttributes() *map[string]interface{}
SynthesizeHclAttributes() *map[string]interface{}
// Adds this resource to the terraform JSON output.
// Experimental.
ToHclTerraform() interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/data-sources/google_project_organization_policy google_project_organization_policy}.
func NewDataGoogleProjectOrganizationPolicy ¶
func NewDataGoogleProjectOrganizationPolicy(scope constructs.Construct, id *string, config *DataGoogleProjectOrganizationPolicyConfig) DataGoogleProjectOrganizationPolicy
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/data-sources/google_project_organization_policy google_project_organization_policy} Data Source.
type DataGoogleProjectOrganizationPolicyBooleanPolicy ¶
type DataGoogleProjectOrganizationPolicyBooleanPolicy struct {
}
type DataGoogleProjectOrganizationPolicyBooleanPolicyList ¶
type DataGoogleProjectOrganizationPolicyBooleanPolicyList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) DataGoogleProjectOrganizationPolicyBooleanPolicyOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleProjectOrganizationPolicyBooleanPolicyList ¶
func NewDataGoogleProjectOrganizationPolicyBooleanPolicyList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataGoogleProjectOrganizationPolicyBooleanPolicyList
type DataGoogleProjectOrganizationPolicyBooleanPolicyOutputReference ¶
type DataGoogleProjectOrganizationPolicyBooleanPolicyOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Enforced() cdktf.IResolvable
// Experimental.
Fqn() *string
InternalValue() *DataGoogleProjectOrganizationPolicyBooleanPolicy
SetInternalValue(val *DataGoogleProjectOrganizationPolicyBooleanPolicy)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleProjectOrganizationPolicyBooleanPolicyOutputReference ¶
func NewDataGoogleProjectOrganizationPolicyBooleanPolicyOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataGoogleProjectOrganizationPolicyBooleanPolicyOutputReference
type DataGoogleProjectOrganizationPolicyConfig ¶
type DataGoogleProjectOrganizationPolicyConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// The name of the Constraint the Policy is configuring, for example, serviceuser.services.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/data-sources/google_project_organization_policy#constraint DataGoogleProjectOrganizationPolicy#constraint}
Constraint *string `field:"required" json:"constraint" yaml:"constraint"`
// The project ID.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/data-sources/google_project_organization_policy#project DataGoogleProjectOrganizationPolicy#project}
Project *string `field:"required" json:"project" yaml:"project"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/data-sources/google_project_organization_policy#id DataGoogleProjectOrganizationPolicy#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
}
type DataGoogleProjectOrganizationPolicyListPolicy ¶
type DataGoogleProjectOrganizationPolicyListPolicy struct {
}
type DataGoogleProjectOrganizationPolicyListPolicyAllow ¶
type DataGoogleProjectOrganizationPolicyListPolicyAllow struct {
}
type DataGoogleProjectOrganizationPolicyListPolicyAllowList ¶
type DataGoogleProjectOrganizationPolicyListPolicyAllowList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) DataGoogleProjectOrganizationPolicyListPolicyAllowOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleProjectOrganizationPolicyListPolicyAllowList ¶
func NewDataGoogleProjectOrganizationPolicyListPolicyAllowList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataGoogleProjectOrganizationPolicyListPolicyAllowList
type DataGoogleProjectOrganizationPolicyListPolicyAllowOutputReference ¶
type DataGoogleProjectOrganizationPolicyListPolicyAllowOutputReference interface {
cdktf.ComplexObject
All() cdktf.IResolvable
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataGoogleProjectOrganizationPolicyListPolicyAllow
SetInternalValue(val *DataGoogleProjectOrganizationPolicyListPolicyAllow)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Values() *[]*string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleProjectOrganizationPolicyListPolicyAllowOutputReference ¶
func NewDataGoogleProjectOrganizationPolicyListPolicyAllowOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataGoogleProjectOrganizationPolicyListPolicyAllowOutputReference
type DataGoogleProjectOrganizationPolicyListPolicyDeny ¶
type DataGoogleProjectOrganizationPolicyListPolicyDeny struct {
}
type DataGoogleProjectOrganizationPolicyListPolicyDenyList ¶
type DataGoogleProjectOrganizationPolicyListPolicyDenyList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) DataGoogleProjectOrganizationPolicyListPolicyDenyOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleProjectOrganizationPolicyListPolicyDenyList ¶
func NewDataGoogleProjectOrganizationPolicyListPolicyDenyList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataGoogleProjectOrganizationPolicyListPolicyDenyList
type DataGoogleProjectOrganizationPolicyListPolicyDenyOutputReference ¶
type DataGoogleProjectOrganizationPolicyListPolicyDenyOutputReference interface {
cdktf.ComplexObject
All() cdktf.IResolvable
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataGoogleProjectOrganizationPolicyListPolicyDeny
SetInternalValue(val *DataGoogleProjectOrganizationPolicyListPolicyDeny)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Values() *[]*string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleProjectOrganizationPolicyListPolicyDenyOutputReference ¶
func NewDataGoogleProjectOrganizationPolicyListPolicyDenyOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataGoogleProjectOrganizationPolicyListPolicyDenyOutputReference
type DataGoogleProjectOrganizationPolicyListPolicyList ¶
type DataGoogleProjectOrganizationPolicyListPolicyList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) DataGoogleProjectOrganizationPolicyListPolicyOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleProjectOrganizationPolicyListPolicyList ¶
func NewDataGoogleProjectOrganizationPolicyListPolicyList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataGoogleProjectOrganizationPolicyListPolicyList
type DataGoogleProjectOrganizationPolicyListPolicyOutputReference ¶
type DataGoogleProjectOrganizationPolicyListPolicyOutputReference interface {
cdktf.ComplexObject
Allow() DataGoogleProjectOrganizationPolicyListPolicyAllowList
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Deny() DataGoogleProjectOrganizationPolicyListPolicyDenyList
// Experimental.
Fqn() *string
InheritFromParent() cdktf.IResolvable
InternalValue() *DataGoogleProjectOrganizationPolicyListPolicy
SetInternalValue(val *DataGoogleProjectOrganizationPolicyListPolicy)
SuggestedValue() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleProjectOrganizationPolicyListPolicyOutputReference ¶
func NewDataGoogleProjectOrganizationPolicyListPolicyOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataGoogleProjectOrganizationPolicyListPolicyOutputReference
type DataGoogleProjectOrganizationPolicyRestorePolicy ¶
type DataGoogleProjectOrganizationPolicyRestorePolicy struct {
}
type DataGoogleProjectOrganizationPolicyRestorePolicyList ¶
type DataGoogleProjectOrganizationPolicyRestorePolicyList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) DataGoogleProjectOrganizationPolicyRestorePolicyOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleProjectOrganizationPolicyRestorePolicyList ¶
func NewDataGoogleProjectOrganizationPolicyRestorePolicyList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataGoogleProjectOrganizationPolicyRestorePolicyList
type DataGoogleProjectOrganizationPolicyRestorePolicyOutputReference ¶
type DataGoogleProjectOrganizationPolicyRestorePolicyOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Default() cdktf.IResolvable
// Experimental.
Fqn() *string
InternalValue() *DataGoogleProjectOrganizationPolicyRestorePolicy
SetInternalValue(val *DataGoogleProjectOrganizationPolicyRestorePolicy)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleProjectOrganizationPolicyRestorePolicyOutputReference ¶
func NewDataGoogleProjectOrganizationPolicyRestorePolicyOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataGoogleProjectOrganizationPolicyRestorePolicyOutputReference
Source Files
¶
- DataGoogleProjectOrganizationPolicy.go
- DataGoogleProjectOrganizationPolicyBooleanPolicy.go
- DataGoogleProjectOrganizationPolicyBooleanPolicyList.go
- DataGoogleProjectOrganizationPolicyBooleanPolicyList__checks.go
- DataGoogleProjectOrganizationPolicyBooleanPolicyOutputReference.go
- DataGoogleProjectOrganizationPolicyBooleanPolicyOutputReference__checks.go
- DataGoogleProjectOrganizationPolicyConfig.go
- DataGoogleProjectOrganizationPolicyListPolicy.go
- DataGoogleProjectOrganizationPolicyListPolicyAllow.go
- DataGoogleProjectOrganizationPolicyListPolicyAllowList.go
- DataGoogleProjectOrganizationPolicyListPolicyAllowList__checks.go
- DataGoogleProjectOrganizationPolicyListPolicyAllowOutputReference.go
- DataGoogleProjectOrganizationPolicyListPolicyAllowOutputReference__checks.go
- DataGoogleProjectOrganizationPolicyListPolicyDeny.go
- DataGoogleProjectOrganizationPolicyListPolicyDenyList.go
- DataGoogleProjectOrganizationPolicyListPolicyDenyList__checks.go
- DataGoogleProjectOrganizationPolicyListPolicyDenyOutputReference.go
- DataGoogleProjectOrganizationPolicyListPolicyDenyOutputReference__checks.go
- DataGoogleProjectOrganizationPolicyListPolicyList.go
- DataGoogleProjectOrganizationPolicyListPolicyList__checks.go
- DataGoogleProjectOrganizationPolicyListPolicyOutputReference.go
- DataGoogleProjectOrganizationPolicyListPolicyOutputReference__checks.go
- DataGoogleProjectOrganizationPolicyRestorePolicy.go
- DataGoogleProjectOrganizationPolicyRestorePolicyList.go
- DataGoogleProjectOrganizationPolicyRestorePolicyList__checks.go
- DataGoogleProjectOrganizationPolicyRestorePolicyOutputReference.go
- DataGoogleProjectOrganizationPolicyRestorePolicyOutputReference__checks.go
- DataGoogleProjectOrganizationPolicy__checks.go
- main.go