Documentation
¶
Index ¶
- func GoogleApigeeAddonsConfig_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func GoogleApigeeAddonsConfig_IsConstruct(x interface{}) *bool
- func GoogleApigeeAddonsConfig_IsTerraformElement(x interface{}) *bool
- func GoogleApigeeAddonsConfig_IsTerraformResource(x interface{}) *bool
- func GoogleApigeeAddonsConfig_TfResourceType() *string
- func NewGoogleApigeeAddonsConfigAddonsConfigAdvancedApiOpsConfigOutputReference_Override(g GoogleApigeeAddonsConfigAddonsConfigAdvancedApiOpsConfigOutputReference, ...)
- func NewGoogleApigeeAddonsConfigAddonsConfigApiSecurityConfigOutputReference_Override(g GoogleApigeeAddonsConfigAddonsConfigApiSecurityConfigOutputReference, ...)
- func NewGoogleApigeeAddonsConfigAddonsConfigConnectorsPlatformConfigOutputReference_Override(g GoogleApigeeAddonsConfigAddonsConfigConnectorsPlatformConfigOutputReference, ...)
- func NewGoogleApigeeAddonsConfigAddonsConfigIntegrationConfigOutputReference_Override(g GoogleApigeeAddonsConfigAddonsConfigIntegrationConfigOutputReference, ...)
- func NewGoogleApigeeAddonsConfigAddonsConfigMonetizationConfigOutputReference_Override(g GoogleApigeeAddonsConfigAddonsConfigMonetizationConfigOutputReference, ...)
- func NewGoogleApigeeAddonsConfigAddonsConfigOutputReference_Override(g GoogleApigeeAddonsConfigAddonsConfigOutputReference, ...)
- func NewGoogleApigeeAddonsConfigTimeoutsOutputReference_Override(g GoogleApigeeAddonsConfigTimeoutsOutputReference, ...)
- func NewGoogleApigeeAddonsConfig_Override(g GoogleApigeeAddonsConfig, scope constructs.Construct, id *string, ...)
- type GoogleApigeeAddonsConfig
- type GoogleApigeeAddonsConfigAddonsConfig
- type GoogleApigeeAddonsConfigAddonsConfigAdvancedApiOpsConfig
- type GoogleApigeeAddonsConfigAddonsConfigAdvancedApiOpsConfigOutputReference
- type GoogleApigeeAddonsConfigAddonsConfigApiSecurityConfig
- type GoogleApigeeAddonsConfigAddonsConfigApiSecurityConfigOutputReference
- type GoogleApigeeAddonsConfigAddonsConfigConnectorsPlatformConfig
- type GoogleApigeeAddonsConfigAddonsConfigConnectorsPlatformConfigOutputReference
- type GoogleApigeeAddonsConfigAddonsConfigIntegrationConfig
- type GoogleApigeeAddonsConfigAddonsConfigIntegrationConfigOutputReference
- type GoogleApigeeAddonsConfigAddonsConfigMonetizationConfig
- type GoogleApigeeAddonsConfigAddonsConfigMonetizationConfigOutputReference
- type GoogleApigeeAddonsConfigAddonsConfigOutputReference
- type GoogleApigeeAddonsConfigConfig
- type GoogleApigeeAddonsConfigTimeouts
- type GoogleApigeeAddonsConfigTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleApigeeAddonsConfig_GenerateConfigForImport ¶
func GoogleApigeeAddonsConfig_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a GoogleApigeeAddonsConfig resource upon running "cdktf plan <stack-name>".
func GoogleApigeeAddonsConfig_IsConstruct ¶
func GoogleApigeeAddonsConfig_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleApigeeAddonsConfig_IsTerraformElement ¶
func GoogleApigeeAddonsConfig_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleApigeeAddonsConfig_IsTerraformResource ¶
func GoogleApigeeAddonsConfig_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleApigeeAddonsConfig_TfResourceType ¶
func GoogleApigeeAddonsConfig_TfResourceType() *string
func NewGoogleApigeeAddonsConfigAddonsConfigAdvancedApiOpsConfigOutputReference_Override ¶
func NewGoogleApigeeAddonsConfigAddonsConfigAdvancedApiOpsConfigOutputReference_Override(g GoogleApigeeAddonsConfigAddonsConfigAdvancedApiOpsConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleApigeeAddonsConfigAddonsConfigApiSecurityConfigOutputReference_Override ¶
func NewGoogleApigeeAddonsConfigAddonsConfigApiSecurityConfigOutputReference_Override(g GoogleApigeeAddonsConfigAddonsConfigApiSecurityConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleApigeeAddonsConfigAddonsConfigConnectorsPlatformConfigOutputReference_Override ¶
func NewGoogleApigeeAddonsConfigAddonsConfigConnectorsPlatformConfigOutputReference_Override(g GoogleApigeeAddonsConfigAddonsConfigConnectorsPlatformConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleApigeeAddonsConfigAddonsConfigIntegrationConfigOutputReference_Override ¶
func NewGoogleApigeeAddonsConfigAddonsConfigIntegrationConfigOutputReference_Override(g GoogleApigeeAddonsConfigAddonsConfigIntegrationConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleApigeeAddonsConfigAddonsConfigMonetizationConfigOutputReference_Override ¶
func NewGoogleApigeeAddonsConfigAddonsConfigMonetizationConfigOutputReference_Override(g GoogleApigeeAddonsConfigAddonsConfigMonetizationConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleApigeeAddonsConfigAddonsConfigOutputReference_Override ¶
func NewGoogleApigeeAddonsConfigAddonsConfigOutputReference_Override(g GoogleApigeeAddonsConfigAddonsConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleApigeeAddonsConfigTimeoutsOutputReference_Override ¶
func NewGoogleApigeeAddonsConfigTimeoutsOutputReference_Override(g GoogleApigeeAddonsConfigTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleApigeeAddonsConfig_Override ¶
func NewGoogleApigeeAddonsConfig_Override(g GoogleApigeeAddonsConfig, scope constructs.Construct, id *string, config *GoogleApigeeAddonsConfigConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_apigee_addons_config google_apigee_addons_config} Resource.
Types ¶
type GoogleApigeeAddonsConfig ¶
type GoogleApigeeAddonsConfig interface {
cdktf.TerraformResource
AddonsConfig() GoogleApigeeAddonsConfigAddonsConfigOutputReference
AddonsConfigInput() *GoogleApigeeAddonsConfigAddonsConfig
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
// The tree node.
Node() constructs.Node
Org() *string
SetOrg(val *string)
OrgInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GoogleApigeeAddonsConfigTimeoutsOutputReference
TimeoutsInput() interface{}
// Adds a user defined moveTarget string to this resource to be later used in .moveTo(moveTarget) to resolve the location of the move.
// Experimental.
AddMoveTarget(moveTarget *string)
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
HasResourceMove() interface{}
// Experimental.
ImportFrom(id *string, provider cdktf.TerraformProvider)
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Move the resource corresponding to "id" to this resource.
//
// Note that the resource being moved from must be marked as moved using it's instance function.
// Experimental.
MoveFromId(id *string)
// Moves this resource to the target resource given by moveTarget.
// Experimental.
MoveTo(moveTarget *string, index interface{})
// Moves this resource to the resource corresponding to "id".
// Experimental.
MoveToId(id *string)
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutAddonsConfig(value *GoogleApigeeAddonsConfigAddonsConfig)
PutTimeouts(value *GoogleApigeeAddonsConfigTimeouts)
ResetAddonsConfig()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
SynthesizeHclAttributes() *map[string]interface{}
// Experimental.
ToHclTerraform() interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_apigee_addons_config google_apigee_addons_config}.
func NewGoogleApigeeAddonsConfig ¶
func NewGoogleApigeeAddonsConfig(scope constructs.Construct, id *string, config *GoogleApigeeAddonsConfigConfig) GoogleApigeeAddonsConfig
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_apigee_addons_config google_apigee_addons_config} Resource.
type GoogleApigeeAddonsConfigAddonsConfig ¶
type GoogleApigeeAddonsConfigAddonsConfig struct {
// advanced_api_ops_config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_apigee_addons_config#advanced_api_ops_config GoogleApigeeAddonsConfig#advanced_api_ops_config}
AdvancedApiOpsConfig *GoogleApigeeAddonsConfigAddonsConfigAdvancedApiOpsConfig `field:"optional" json:"advancedApiOpsConfig" yaml:"advancedApiOpsConfig"`
// api_security_config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_apigee_addons_config#api_security_config GoogleApigeeAddonsConfig#api_security_config}
ApiSecurityConfig *GoogleApigeeAddonsConfigAddonsConfigApiSecurityConfig `field:"optional" json:"apiSecurityConfig" yaml:"apiSecurityConfig"`
// connectors_platform_config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_apigee_addons_config#connectors_platform_config GoogleApigeeAddonsConfig#connectors_platform_config}
ConnectorsPlatformConfig *GoogleApigeeAddonsConfigAddonsConfigConnectorsPlatformConfig `field:"optional" json:"connectorsPlatformConfig" yaml:"connectorsPlatformConfig"`
// integration_config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_apigee_addons_config#integration_config GoogleApigeeAddonsConfig#integration_config}
IntegrationConfig *GoogleApigeeAddonsConfigAddonsConfigIntegrationConfig `field:"optional" json:"integrationConfig" yaml:"integrationConfig"`
// monetization_config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_apigee_addons_config#monetization_config GoogleApigeeAddonsConfig#monetization_config}
MonetizationConfig *GoogleApigeeAddonsConfigAddonsConfigMonetizationConfig `field:"optional" json:"monetizationConfig" yaml:"monetizationConfig"`
}
type GoogleApigeeAddonsConfigAddonsConfigAdvancedApiOpsConfig ¶
type GoogleApigeeAddonsConfigAddonsConfigAdvancedApiOpsConfig struct {
// Flag that specifies whether the Advanced API Ops add-on is enabled.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_apigee_addons_config#enabled GoogleApigeeAddonsConfig#enabled}
Enabled interface{} `field:"optional" json:"enabled" yaml:"enabled"`
}
type GoogleApigeeAddonsConfigAddonsConfigAdvancedApiOpsConfigOutputReference ¶
type GoogleApigeeAddonsConfigAddonsConfigAdvancedApiOpsConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Enabled() interface{}
SetEnabled(val interface{})
EnabledInput() interface{}
// Experimental.
Fqn() *string
InternalValue() *GoogleApigeeAddonsConfigAddonsConfigAdvancedApiOpsConfig
SetInternalValue(val *GoogleApigeeAddonsConfigAddonsConfigAdvancedApiOpsConfig)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetEnabled()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleApigeeAddonsConfigAddonsConfigAdvancedApiOpsConfigOutputReference ¶
func NewGoogleApigeeAddonsConfigAddonsConfigAdvancedApiOpsConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleApigeeAddonsConfigAddonsConfigAdvancedApiOpsConfigOutputReference
type GoogleApigeeAddonsConfigAddonsConfigApiSecurityConfig ¶
type GoogleApigeeAddonsConfigAddonsConfigApiSecurityConfig struct {
// Flag that specifies whether the Advanced API Ops add-on is enabled.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_apigee_addons_config#enabled GoogleApigeeAddonsConfig#enabled}
Enabled interface{} `field:"optional" json:"enabled" yaml:"enabled"`
}
type GoogleApigeeAddonsConfigAddonsConfigApiSecurityConfigOutputReference ¶
type GoogleApigeeAddonsConfigAddonsConfigApiSecurityConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Enabled() interface{}
SetEnabled(val interface{})
EnabledInput() interface{}
ExpiresAt() *string
// Experimental.
Fqn() *string
InternalValue() *GoogleApigeeAddonsConfigAddonsConfigApiSecurityConfig
SetInternalValue(val *GoogleApigeeAddonsConfigAddonsConfigApiSecurityConfig)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetEnabled()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleApigeeAddonsConfigAddonsConfigApiSecurityConfigOutputReference ¶
func NewGoogleApigeeAddonsConfigAddonsConfigApiSecurityConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleApigeeAddonsConfigAddonsConfigApiSecurityConfigOutputReference
type GoogleApigeeAddonsConfigAddonsConfigConnectorsPlatformConfig ¶
type GoogleApigeeAddonsConfigAddonsConfigConnectorsPlatformConfig struct {
// Flag that specifies whether the Advanced API Ops add-on is enabled.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_apigee_addons_config#enabled GoogleApigeeAddonsConfig#enabled}
Enabled interface{} `field:"optional" json:"enabled" yaml:"enabled"`
}
type GoogleApigeeAddonsConfigAddonsConfigConnectorsPlatformConfigOutputReference ¶
type GoogleApigeeAddonsConfigAddonsConfigConnectorsPlatformConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Enabled() interface{}
SetEnabled(val interface{})
EnabledInput() interface{}
ExpiresAt() *string
// Experimental.
Fqn() *string
InternalValue() *GoogleApigeeAddonsConfigAddonsConfigConnectorsPlatformConfig
SetInternalValue(val *GoogleApigeeAddonsConfigAddonsConfigConnectorsPlatformConfig)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetEnabled()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleApigeeAddonsConfigAddonsConfigConnectorsPlatformConfigOutputReference ¶
func NewGoogleApigeeAddonsConfigAddonsConfigConnectorsPlatformConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleApigeeAddonsConfigAddonsConfigConnectorsPlatformConfigOutputReference
type GoogleApigeeAddonsConfigAddonsConfigIntegrationConfig ¶
type GoogleApigeeAddonsConfigAddonsConfigIntegrationConfig struct {
// Flag that specifies whether the Advanced API Ops add-on is enabled.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_apigee_addons_config#enabled GoogleApigeeAddonsConfig#enabled}
Enabled interface{} `field:"optional" json:"enabled" yaml:"enabled"`
}
type GoogleApigeeAddonsConfigAddonsConfigIntegrationConfigOutputReference ¶
type GoogleApigeeAddonsConfigAddonsConfigIntegrationConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Enabled() interface{}
SetEnabled(val interface{})
EnabledInput() interface{}
// Experimental.
Fqn() *string
InternalValue() *GoogleApigeeAddonsConfigAddonsConfigIntegrationConfig
SetInternalValue(val *GoogleApigeeAddonsConfigAddonsConfigIntegrationConfig)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetEnabled()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleApigeeAddonsConfigAddonsConfigIntegrationConfigOutputReference ¶
func NewGoogleApigeeAddonsConfigAddonsConfigIntegrationConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleApigeeAddonsConfigAddonsConfigIntegrationConfigOutputReference
type GoogleApigeeAddonsConfigAddonsConfigMonetizationConfig ¶
type GoogleApigeeAddonsConfigAddonsConfigMonetizationConfig struct {
// Flag that specifies whether the Advanced API Ops add-on is enabled.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_apigee_addons_config#enabled GoogleApigeeAddonsConfig#enabled}
Enabled interface{} `field:"optional" json:"enabled" yaml:"enabled"`
}
type GoogleApigeeAddonsConfigAddonsConfigMonetizationConfigOutputReference ¶
type GoogleApigeeAddonsConfigAddonsConfigMonetizationConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Enabled() interface{}
SetEnabled(val interface{})
EnabledInput() interface{}
// Experimental.
Fqn() *string
InternalValue() *GoogleApigeeAddonsConfigAddonsConfigMonetizationConfig
SetInternalValue(val *GoogleApigeeAddonsConfigAddonsConfigMonetizationConfig)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetEnabled()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleApigeeAddonsConfigAddonsConfigMonetizationConfigOutputReference ¶
func NewGoogleApigeeAddonsConfigAddonsConfigMonetizationConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleApigeeAddonsConfigAddonsConfigMonetizationConfigOutputReference
type GoogleApigeeAddonsConfigAddonsConfigOutputReference ¶
type GoogleApigeeAddonsConfigAddonsConfigOutputReference interface {
cdktf.ComplexObject
AdvancedApiOpsConfig() GoogleApigeeAddonsConfigAddonsConfigAdvancedApiOpsConfigOutputReference
AdvancedApiOpsConfigInput() *GoogleApigeeAddonsConfigAddonsConfigAdvancedApiOpsConfig
ApiSecurityConfig() GoogleApigeeAddonsConfigAddonsConfigApiSecurityConfigOutputReference
ApiSecurityConfigInput() *GoogleApigeeAddonsConfigAddonsConfigApiSecurityConfig
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
ConnectorsPlatformConfig() GoogleApigeeAddonsConfigAddonsConfigConnectorsPlatformConfigOutputReference
ConnectorsPlatformConfigInput() *GoogleApigeeAddonsConfigAddonsConfigConnectorsPlatformConfig
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
IntegrationConfig() GoogleApigeeAddonsConfigAddonsConfigIntegrationConfigOutputReference
IntegrationConfigInput() *GoogleApigeeAddonsConfigAddonsConfigIntegrationConfig
InternalValue() *GoogleApigeeAddonsConfigAddonsConfig
SetInternalValue(val *GoogleApigeeAddonsConfigAddonsConfig)
MonetizationConfig() GoogleApigeeAddonsConfigAddonsConfigMonetizationConfigOutputReference
MonetizationConfigInput() *GoogleApigeeAddonsConfigAddonsConfigMonetizationConfig
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutAdvancedApiOpsConfig(value *GoogleApigeeAddonsConfigAddonsConfigAdvancedApiOpsConfig)
PutApiSecurityConfig(value *GoogleApigeeAddonsConfigAddonsConfigApiSecurityConfig)
PutConnectorsPlatformConfig(value *GoogleApigeeAddonsConfigAddonsConfigConnectorsPlatformConfig)
PutIntegrationConfig(value *GoogleApigeeAddonsConfigAddonsConfigIntegrationConfig)
PutMonetizationConfig(value *GoogleApigeeAddonsConfigAddonsConfigMonetizationConfig)
ResetAdvancedApiOpsConfig()
ResetApiSecurityConfig()
ResetConnectorsPlatformConfig()
ResetIntegrationConfig()
ResetMonetizationConfig()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleApigeeAddonsConfigAddonsConfigOutputReference ¶
func NewGoogleApigeeAddonsConfigAddonsConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleApigeeAddonsConfigAddonsConfigOutputReference
type GoogleApigeeAddonsConfigConfig ¶
type GoogleApigeeAddonsConfigConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Name of the Apigee organization.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_apigee_addons_config#org GoogleApigeeAddonsConfig#org}
Org *string `field:"required" json:"org" yaml:"org"`
// addons_config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_apigee_addons_config#addons_config GoogleApigeeAddonsConfig#addons_config}
AddonsConfig *GoogleApigeeAddonsConfigAddonsConfig `field:"optional" json:"addonsConfig" yaml:"addonsConfig"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_apigee_addons_config#id GoogleApigeeAddonsConfig#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_apigee_addons_config#timeouts GoogleApigeeAddonsConfig#timeouts}
Timeouts *GoogleApigeeAddonsConfigTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type GoogleApigeeAddonsConfigTimeouts ¶
type GoogleApigeeAddonsConfigTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_apigee_addons_config#create GoogleApigeeAddonsConfig#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_apigee_addons_config#delete GoogleApigeeAddonsConfig#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_apigee_addons_config#update GoogleApigeeAddonsConfig#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type GoogleApigeeAddonsConfigTimeoutsOutputReference ¶
type GoogleApigeeAddonsConfigTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleApigeeAddonsConfigTimeoutsOutputReference ¶
func NewGoogleApigeeAddonsConfigTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleApigeeAddonsConfigTimeoutsOutputReference
Source Files
¶
- GoogleApigeeAddonsConfig.go
- GoogleApigeeAddonsConfigAddonsConfig.go
- GoogleApigeeAddonsConfigAddonsConfigAdvancedApiOpsConfig.go
- GoogleApigeeAddonsConfigAddonsConfigAdvancedApiOpsConfigOutputReference.go
- GoogleApigeeAddonsConfigAddonsConfigAdvancedApiOpsConfigOutputReference__checks.go
- GoogleApigeeAddonsConfigAddonsConfigApiSecurityConfig.go
- GoogleApigeeAddonsConfigAddonsConfigApiSecurityConfigOutputReference.go
- GoogleApigeeAddonsConfigAddonsConfigApiSecurityConfigOutputReference__checks.go
- GoogleApigeeAddonsConfigAddonsConfigConnectorsPlatformConfig.go
- GoogleApigeeAddonsConfigAddonsConfigConnectorsPlatformConfigOutputReference.go
- GoogleApigeeAddonsConfigAddonsConfigConnectorsPlatformConfigOutputReference__checks.go
- GoogleApigeeAddonsConfigAddonsConfigIntegrationConfig.go
- GoogleApigeeAddonsConfigAddonsConfigIntegrationConfigOutputReference.go
- GoogleApigeeAddonsConfigAddonsConfigIntegrationConfigOutputReference__checks.go
- GoogleApigeeAddonsConfigAddonsConfigMonetizationConfig.go
- GoogleApigeeAddonsConfigAddonsConfigMonetizationConfigOutputReference.go
- GoogleApigeeAddonsConfigAddonsConfigMonetizationConfigOutputReference__checks.go
- GoogleApigeeAddonsConfigAddonsConfigOutputReference.go
- GoogleApigeeAddonsConfigAddonsConfigOutputReference__checks.go
- GoogleApigeeAddonsConfigConfig.go
- GoogleApigeeAddonsConfigTimeouts.go
- GoogleApigeeAddonsConfigTimeoutsOutputReference.go
- GoogleApigeeAddonsConfigTimeoutsOutputReference__checks.go
- GoogleApigeeAddonsConfig__checks.go
- main.go