Documentation
¶
Index ¶
- func GoogleApigeeInstance_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func GoogleApigeeInstance_IsConstruct(x interface{}) *bool
- func GoogleApigeeInstance_IsTerraformElement(x interface{}) *bool
- func GoogleApigeeInstance_IsTerraformResource(x interface{}) *bool
- func GoogleApigeeInstance_TfResourceType() *string
- func NewGoogleApigeeInstanceTimeoutsOutputReference_Override(g GoogleApigeeInstanceTimeoutsOutputReference, ...)
- func NewGoogleApigeeInstance_Override(g GoogleApigeeInstance, scope constructs.Construct, id *string, ...)
- type GoogleApigeeInstance
- type GoogleApigeeInstanceConfig
- type GoogleApigeeInstanceTimeouts
- type GoogleApigeeInstanceTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleApigeeInstance_GenerateConfigForImport ¶
func GoogleApigeeInstance_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a GoogleApigeeInstance resource upon running "cdktf plan <stack-name>".
func GoogleApigeeInstance_IsConstruct ¶
func GoogleApigeeInstance_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleApigeeInstance_IsTerraformElement ¶
func GoogleApigeeInstance_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleApigeeInstance_IsTerraformResource ¶
func GoogleApigeeInstance_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleApigeeInstance_TfResourceType ¶
func GoogleApigeeInstance_TfResourceType() *string
func NewGoogleApigeeInstanceTimeoutsOutputReference_Override ¶
func NewGoogleApigeeInstanceTimeoutsOutputReference_Override(g GoogleApigeeInstanceTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleApigeeInstance_Override ¶
func NewGoogleApigeeInstance_Override(g GoogleApigeeInstance, scope constructs.Construct, id *string, config *GoogleApigeeInstanceConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_apigee_instance google_apigee_instance} Resource.
Types ¶
type GoogleApigeeInstance ¶
type GoogleApigeeInstance interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
ConsumerAcceptList() *[]*string
SetConsumerAcceptList(val *[]*string)
ConsumerAcceptListInput() *[]*string
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
DiskEncryptionKeyName() *string
SetDiskEncryptionKeyName(val *string)
DiskEncryptionKeyNameInput() *string
DisplayName() *string
SetDisplayName(val *string)
DisplayNameInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Host() *string
Id() *string
SetId(val *string)
IdInput() *string
IpRange() *string
SetIpRange(val *string)
IpRangeInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Location() *string
SetLocation(val *string)
LocationInput() *string
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
OrgId() *string
SetOrgId(val *string)
OrgIdInput() *string
PeeringCidrRange() *string
SetPeeringCidrRange(val *string)
PeeringCidrRangeInput() *string
Port() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
ServiceAttachment() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GoogleApigeeInstanceTimeoutsOutputReference
TimeoutsInput() interface{}
// Adds a user defined moveTarget string to this resource to be later used in .moveTo(moveTarget) to resolve the location of the move.
// Experimental.
AddMoveTarget(moveTarget *string)
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
HasResourceMove() interface{}
// Experimental.
ImportFrom(id *string, provider cdktf.TerraformProvider)
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Move the resource corresponding to "id" to this resource.
//
// Note that the resource being moved from must be marked as moved using it's instance function.
// Experimental.
MoveFromId(id *string)
// Moves this resource to the target resource given by moveTarget.
// Experimental.
MoveTo(moveTarget *string, index interface{})
// Moves this resource to the resource corresponding to "id".
// Experimental.
MoveToId(id *string)
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutTimeouts(value *GoogleApigeeInstanceTimeouts)
ResetConsumerAcceptList()
ResetDescription()
ResetDiskEncryptionKeyName()
ResetDisplayName()
ResetId()
ResetIpRange()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetPeeringCidrRange()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
SynthesizeHclAttributes() *map[string]interface{}
// Experimental.
ToHclTerraform() interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_apigee_instance google_apigee_instance}.
func NewGoogleApigeeInstance ¶
func NewGoogleApigeeInstance(scope constructs.Construct, id *string, config *GoogleApigeeInstanceConfig) GoogleApigeeInstance
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_apigee_instance google_apigee_instance} Resource.
type GoogleApigeeInstanceConfig ¶
type GoogleApigeeInstanceConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Required. Compute Engine location where the instance resides.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_apigee_instance#location GoogleApigeeInstance#location}
Location *string `field:"required" json:"location" yaml:"location"`
// Resource ID of the instance.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_apigee_instance#name GoogleApigeeInstance#name}
Name *string `field:"required" json:"name" yaml:"name"`
// The Apigee Organization associated with the Apigee instance, in the format 'organizations/{{org_name}}'.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_apigee_instance#org_id GoogleApigeeInstance#org_id}
OrgId *string `field:"required" json:"orgId" yaml:"orgId"`
// Optional.
//
// Customer accept list represents the list of projects (id/number) on customer
// side that can privately connect to the service attachment. It is an optional field
// which the customers can provide during the instance creation. By default, the customer
// project associated with the Apigee organization will be included to the list.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_apigee_instance#consumer_accept_list GoogleApigeeInstance#consumer_accept_list}
ConsumerAcceptList *[]*string `field:"optional" json:"consumerAcceptList" yaml:"consumerAcceptList"`
// Description of the instance.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_apigee_instance#description GoogleApigeeInstance#description}
Description *string `field:"optional" json:"description" yaml:"description"`
// Customer Managed Encryption Key (CMEK) used for disk and volume encryption.
//
// Required for Apigee paid subscriptions only.
// Use the following format: 'projects/([^/]+)/locations/([^/]+)/keyRings/([^/]+)/cryptoKeys/([^/]+)'
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_apigee_instance#disk_encryption_key_name GoogleApigeeInstance#disk_encryption_key_name}
DiskEncryptionKeyName *string `field:"optional" json:"diskEncryptionKeyName" yaml:"diskEncryptionKeyName"`
// Display name of the instance.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_apigee_instance#display_name GoogleApigeeInstance#display_name}
DisplayName *string `field:"optional" json:"displayName" yaml:"displayName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_apigee_instance#id GoogleApigeeInstance#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// IP range represents the customer-provided CIDR block of length 22 that will be used for the Apigee instance creation.
//
// This optional range, if provided, should be freely
// available as part of larger named range the customer has allocated to the Service
// Networking peering. If this is not provided, Apigee will automatically request for any
// available /22 CIDR block from Service Networking. The customer should use this CIDR block
// for configuring their firewall needs to allow traffic from Apigee.
// Input format: "a.b.c.d/22"
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_apigee_instance#ip_range GoogleApigeeInstance#ip_range}
IpRange *string `field:"optional" json:"ipRange" yaml:"ipRange"`
// The size of the CIDR block range that will be reserved by the instance.
//
// For valid values,
// see [CidrRange](https://cloud.google.com/apigee/docs/reference/apis/apigee/rest/v1/organizations.instances#CidrRange) on the documentation.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_apigee_instance#peering_cidr_range GoogleApigeeInstance#peering_cidr_range}
PeeringCidrRange *string `field:"optional" json:"peeringCidrRange" yaml:"peeringCidrRange"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_apigee_instance#timeouts GoogleApigeeInstance#timeouts}
Timeouts *GoogleApigeeInstanceTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type GoogleApigeeInstanceTimeouts ¶
type GoogleApigeeInstanceTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_apigee_instance#create GoogleApigeeInstance#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_apigee_instance#delete GoogleApigeeInstance#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
}
type GoogleApigeeInstanceTimeoutsOutputReference ¶
type GoogleApigeeInstanceTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleApigeeInstanceTimeoutsOutputReference ¶
func NewGoogleApigeeInstanceTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleApigeeInstanceTimeoutsOutputReference