Documentation
¶
Index ¶
- func GoogleBigqueryAnalyticsHubListing_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func GoogleBigqueryAnalyticsHubListing_IsConstruct(x interface{}) *bool
- func GoogleBigqueryAnalyticsHubListing_IsTerraformElement(x interface{}) *bool
- func GoogleBigqueryAnalyticsHubListing_IsTerraformResource(x interface{}) *bool
- func GoogleBigqueryAnalyticsHubListing_TfResourceType() *string
- func NewGoogleBigqueryAnalyticsHubListingBigqueryDatasetOutputReference_Override(g GoogleBigqueryAnalyticsHubListingBigqueryDatasetOutputReference, ...)
- func NewGoogleBigqueryAnalyticsHubListingDataProviderOutputReference_Override(g GoogleBigqueryAnalyticsHubListingDataProviderOutputReference, ...)
- func NewGoogleBigqueryAnalyticsHubListingPublisherOutputReference_Override(g GoogleBigqueryAnalyticsHubListingPublisherOutputReference, ...)
- func NewGoogleBigqueryAnalyticsHubListingRestrictedExportConfigOutputReference_Override(g GoogleBigqueryAnalyticsHubListingRestrictedExportConfigOutputReference, ...)
- func NewGoogleBigqueryAnalyticsHubListingTimeoutsOutputReference_Override(g GoogleBigqueryAnalyticsHubListingTimeoutsOutputReference, ...)
- func NewGoogleBigqueryAnalyticsHubListing_Override(g GoogleBigqueryAnalyticsHubListing, scope constructs.Construct, id *string, ...)
- type GoogleBigqueryAnalyticsHubListing
- type GoogleBigqueryAnalyticsHubListingBigqueryDataset
- type GoogleBigqueryAnalyticsHubListingBigqueryDatasetOutputReference
- type GoogleBigqueryAnalyticsHubListingConfig
- type GoogleBigqueryAnalyticsHubListingDataProvider
- type GoogleBigqueryAnalyticsHubListingDataProviderOutputReference
- type GoogleBigqueryAnalyticsHubListingPublisher
- type GoogleBigqueryAnalyticsHubListingPublisherOutputReference
- type GoogleBigqueryAnalyticsHubListingRestrictedExportConfig
- type GoogleBigqueryAnalyticsHubListingRestrictedExportConfigOutputReference
- type GoogleBigqueryAnalyticsHubListingTimeouts
- type GoogleBigqueryAnalyticsHubListingTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleBigqueryAnalyticsHubListing_GenerateConfigForImport ¶
func GoogleBigqueryAnalyticsHubListing_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a GoogleBigqueryAnalyticsHubListing resource upon running "cdktf plan <stack-name>".
func GoogleBigqueryAnalyticsHubListing_IsConstruct ¶
func GoogleBigqueryAnalyticsHubListing_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleBigqueryAnalyticsHubListing_IsTerraformElement ¶
func GoogleBigqueryAnalyticsHubListing_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleBigqueryAnalyticsHubListing_IsTerraformResource ¶
func GoogleBigqueryAnalyticsHubListing_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleBigqueryAnalyticsHubListing_TfResourceType ¶
func GoogleBigqueryAnalyticsHubListing_TfResourceType() *string
func NewGoogleBigqueryAnalyticsHubListingBigqueryDatasetOutputReference_Override ¶
func NewGoogleBigqueryAnalyticsHubListingBigqueryDatasetOutputReference_Override(g GoogleBigqueryAnalyticsHubListingBigqueryDatasetOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleBigqueryAnalyticsHubListingDataProviderOutputReference_Override ¶
func NewGoogleBigqueryAnalyticsHubListingDataProviderOutputReference_Override(g GoogleBigqueryAnalyticsHubListingDataProviderOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleBigqueryAnalyticsHubListingPublisherOutputReference_Override ¶
func NewGoogleBigqueryAnalyticsHubListingPublisherOutputReference_Override(g GoogleBigqueryAnalyticsHubListingPublisherOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleBigqueryAnalyticsHubListingRestrictedExportConfigOutputReference_Override ¶
func NewGoogleBigqueryAnalyticsHubListingRestrictedExportConfigOutputReference_Override(g GoogleBigqueryAnalyticsHubListingRestrictedExportConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleBigqueryAnalyticsHubListingTimeoutsOutputReference_Override ¶
func NewGoogleBigqueryAnalyticsHubListingTimeoutsOutputReference_Override(g GoogleBigqueryAnalyticsHubListingTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleBigqueryAnalyticsHubListing_Override ¶
func NewGoogleBigqueryAnalyticsHubListing_Override(g GoogleBigqueryAnalyticsHubListing, scope constructs.Construct, id *string, config *GoogleBigqueryAnalyticsHubListingConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_bigquery_analytics_hub_listing google_bigquery_analytics_hub_listing} Resource.
Types ¶
type GoogleBigqueryAnalyticsHubListing ¶
type GoogleBigqueryAnalyticsHubListing interface {
cdktf.TerraformResource
BigqueryDataset() GoogleBigqueryAnalyticsHubListingBigqueryDatasetOutputReference
BigqueryDatasetInput() *GoogleBigqueryAnalyticsHubListingBigqueryDataset
Categories() *[]*string
SetCategories(val *[]*string)
CategoriesInput() *[]*string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
DataExchangeId() *string
SetDataExchangeId(val *string)
DataExchangeIdInput() *string
DataProvider() GoogleBigqueryAnalyticsHubListingDataProviderOutputReference
DataProviderInput() *GoogleBigqueryAnalyticsHubListingDataProvider
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
DisplayName() *string
SetDisplayName(val *string)
DisplayNameInput() *string
Documentation() *string
SetDocumentation(val *string)
DocumentationInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Icon() *string
SetIcon(val *string)
IconInput() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
ListingId() *string
SetListingId(val *string)
ListingIdInput() *string
Location() *string
SetLocation(val *string)
LocationInput() *string
Name() *string
// The tree node.
Node() constructs.Node
PrimaryContact() *string
SetPrimaryContact(val *string)
PrimaryContactInput() *string
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
Publisher() GoogleBigqueryAnalyticsHubListingPublisherOutputReference
PublisherInput() *GoogleBigqueryAnalyticsHubListingPublisher
// Experimental.
RawOverrides() interface{}
RequestAccess() *string
SetRequestAccess(val *string)
RequestAccessInput() *string
RestrictedExportConfig() GoogleBigqueryAnalyticsHubListingRestrictedExportConfigOutputReference
RestrictedExportConfigInput() *GoogleBigqueryAnalyticsHubListingRestrictedExportConfig
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GoogleBigqueryAnalyticsHubListingTimeoutsOutputReference
TimeoutsInput() interface{}
// Adds a user defined moveTarget string to this resource to be later used in .moveTo(moveTarget) to resolve the location of the move.
// Experimental.
AddMoveTarget(moveTarget *string)
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
HasResourceMove() interface{}
// Experimental.
ImportFrom(id *string, provider cdktf.TerraformProvider)
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Move the resource corresponding to "id" to this resource.
//
// Note that the resource being moved from must be marked as moved using it's instance function.
// Experimental.
MoveFromId(id *string)
// Moves this resource to the target resource given by moveTarget.
// Experimental.
MoveTo(moveTarget *string, index interface{})
// Moves this resource to the resource corresponding to "id".
// Experimental.
MoveToId(id *string)
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutBigqueryDataset(value *GoogleBigqueryAnalyticsHubListingBigqueryDataset)
PutDataProvider(value *GoogleBigqueryAnalyticsHubListingDataProvider)
PutPublisher(value *GoogleBigqueryAnalyticsHubListingPublisher)
PutRestrictedExportConfig(value *GoogleBigqueryAnalyticsHubListingRestrictedExportConfig)
PutTimeouts(value *GoogleBigqueryAnalyticsHubListingTimeouts)
ResetCategories()
ResetDataProvider()
ResetDescription()
ResetDocumentation()
ResetIcon()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetPrimaryContact()
ResetProject()
ResetPublisher()
ResetRequestAccess()
ResetRestrictedExportConfig()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
SynthesizeHclAttributes() *map[string]interface{}
// Experimental.
ToHclTerraform() interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_bigquery_analytics_hub_listing google_bigquery_analytics_hub_listing}.
func NewGoogleBigqueryAnalyticsHubListing ¶
func NewGoogleBigqueryAnalyticsHubListing(scope constructs.Construct, id *string, config *GoogleBigqueryAnalyticsHubListingConfig) GoogleBigqueryAnalyticsHubListing
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_bigquery_analytics_hub_listing google_bigquery_analytics_hub_listing} Resource.
type GoogleBigqueryAnalyticsHubListingBigqueryDataset ¶
type GoogleBigqueryAnalyticsHubListingBigqueryDataset struct {
// Resource name of the dataset source for this listing. e.g. projects/myproject/datasets/123.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_bigquery_analytics_hub_listing#dataset GoogleBigqueryAnalyticsHubListing#dataset}
Dataset *string `field:"required" json:"dataset" yaml:"dataset"`
}
type GoogleBigqueryAnalyticsHubListingBigqueryDatasetOutputReference ¶
type GoogleBigqueryAnalyticsHubListingBigqueryDatasetOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Dataset() *string
SetDataset(val *string)
DatasetInput() *string
// Experimental.
Fqn() *string
InternalValue() *GoogleBigqueryAnalyticsHubListingBigqueryDataset
SetInternalValue(val *GoogleBigqueryAnalyticsHubListingBigqueryDataset)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleBigqueryAnalyticsHubListingBigqueryDatasetOutputReference ¶
func NewGoogleBigqueryAnalyticsHubListingBigqueryDatasetOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleBigqueryAnalyticsHubListingBigqueryDatasetOutputReference
type GoogleBigqueryAnalyticsHubListingConfig ¶
type GoogleBigqueryAnalyticsHubListingConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// bigquery_dataset block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_bigquery_analytics_hub_listing#bigquery_dataset GoogleBigqueryAnalyticsHubListing#bigquery_dataset}
BigqueryDataset *GoogleBigqueryAnalyticsHubListingBigqueryDataset `field:"required" json:"bigqueryDataset" yaml:"bigqueryDataset"`
// The ID of the data exchange.
//
// Must contain only Unicode letters, numbers (0-9), underscores (_). Should not use characters that require URL-escaping, or characters outside of ASCII, spaces.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_bigquery_analytics_hub_listing#data_exchange_id GoogleBigqueryAnalyticsHubListing#data_exchange_id}
DataExchangeId *string `field:"required" json:"dataExchangeId" yaml:"dataExchangeId"`
// Human-readable display name of the listing.
//
// The display name must contain only Unicode letters, numbers (0-9), underscores (_), dashes (-), spaces ( ), ampersands (&) and can't start or end with spaces.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_bigquery_analytics_hub_listing#display_name GoogleBigqueryAnalyticsHubListing#display_name}
DisplayName *string `field:"required" json:"displayName" yaml:"displayName"`
// The ID of the listing.
//
// Must contain only Unicode letters, numbers (0-9), underscores (_). Should not use characters that require URL-escaping, or characters outside of ASCII, spaces.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_bigquery_analytics_hub_listing#listing_id GoogleBigqueryAnalyticsHubListing#listing_id}
ListingId *string `field:"required" json:"listingId" yaml:"listingId"`
// The name of the location this data exchange listing.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_bigquery_analytics_hub_listing#location GoogleBigqueryAnalyticsHubListing#location}
Location *string `field:"required" json:"location" yaml:"location"`
// Categories of the listing. Up to two categories are allowed.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_bigquery_analytics_hub_listing#categories GoogleBigqueryAnalyticsHubListing#categories}
Categories *[]*string `field:"optional" json:"categories" yaml:"categories"`
// data_provider block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_bigquery_analytics_hub_listing#data_provider GoogleBigqueryAnalyticsHubListing#data_provider}
DataProvider *GoogleBigqueryAnalyticsHubListingDataProvider `field:"optional" json:"dataProvider" yaml:"dataProvider"`
// Short description of the listing.
//
// The description must not contain Unicode non-characters and C0 and C1 control codes except tabs (HT), new lines (LF), carriage returns (CR), and page breaks (FF).
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_bigquery_analytics_hub_listing#description GoogleBigqueryAnalyticsHubListing#description}
Description *string `field:"optional" json:"description" yaml:"description"`
// Documentation describing the listing.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_bigquery_analytics_hub_listing#documentation GoogleBigqueryAnalyticsHubListing#documentation}
Documentation *string `field:"optional" json:"documentation" yaml:"documentation"`
// Base64 encoded image representing the listing.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_bigquery_analytics_hub_listing#icon GoogleBigqueryAnalyticsHubListing#icon}
Icon *string `field:"optional" json:"icon" yaml:"icon"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_bigquery_analytics_hub_listing#id GoogleBigqueryAnalyticsHubListing#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Email or URL of the primary point of contact of the listing.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_bigquery_analytics_hub_listing#primary_contact GoogleBigqueryAnalyticsHubListing#primary_contact}
PrimaryContact *string `field:"optional" json:"primaryContact" yaml:"primaryContact"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_bigquery_analytics_hub_listing#project GoogleBigqueryAnalyticsHubListing#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// publisher block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_bigquery_analytics_hub_listing#publisher GoogleBigqueryAnalyticsHubListing#publisher}
Publisher *GoogleBigqueryAnalyticsHubListingPublisher `field:"optional" json:"publisher" yaml:"publisher"`
// Email or URL of the request access of the listing. Subscribers can use this reference to request access.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_bigquery_analytics_hub_listing#request_access GoogleBigqueryAnalyticsHubListing#request_access}
RequestAccess *string `field:"optional" json:"requestAccess" yaml:"requestAccess"`
// restricted_export_config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_bigquery_analytics_hub_listing#restricted_export_config GoogleBigqueryAnalyticsHubListing#restricted_export_config}
RestrictedExportConfig *GoogleBigqueryAnalyticsHubListingRestrictedExportConfig `field:"optional" json:"restrictedExportConfig" yaml:"restrictedExportConfig"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_bigquery_analytics_hub_listing#timeouts GoogleBigqueryAnalyticsHubListing#timeouts}
Timeouts *GoogleBigqueryAnalyticsHubListingTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type GoogleBigqueryAnalyticsHubListingDataProvider ¶
type GoogleBigqueryAnalyticsHubListingDataProvider struct {
// Name of the data provider.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_bigquery_analytics_hub_listing#name GoogleBigqueryAnalyticsHubListing#name}
Name *string `field:"required" json:"name" yaml:"name"`
// Email or URL of the data provider.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_bigquery_analytics_hub_listing#primary_contact GoogleBigqueryAnalyticsHubListing#primary_contact}
PrimaryContact *string `field:"optional" json:"primaryContact" yaml:"primaryContact"`
}
type GoogleBigqueryAnalyticsHubListingDataProviderOutputReference ¶
type GoogleBigqueryAnalyticsHubListingDataProviderOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleBigqueryAnalyticsHubListingDataProvider
SetInternalValue(val *GoogleBigqueryAnalyticsHubListingDataProvider)
Name() *string
SetName(val *string)
NameInput() *string
PrimaryContact() *string
SetPrimaryContact(val *string)
PrimaryContactInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetPrimaryContact()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleBigqueryAnalyticsHubListingDataProviderOutputReference ¶
func NewGoogleBigqueryAnalyticsHubListingDataProviderOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleBigqueryAnalyticsHubListingDataProviderOutputReference
type GoogleBigqueryAnalyticsHubListingPublisher ¶
type GoogleBigqueryAnalyticsHubListingPublisher struct {
// Name of the listing publisher.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_bigquery_analytics_hub_listing#name GoogleBigqueryAnalyticsHubListing#name}
Name *string `field:"required" json:"name" yaml:"name"`
// Email or URL of the listing publisher.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_bigquery_analytics_hub_listing#primary_contact GoogleBigqueryAnalyticsHubListing#primary_contact}
PrimaryContact *string `field:"optional" json:"primaryContact" yaml:"primaryContact"`
}
type GoogleBigqueryAnalyticsHubListingPublisherOutputReference ¶
type GoogleBigqueryAnalyticsHubListingPublisherOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleBigqueryAnalyticsHubListingPublisher
SetInternalValue(val *GoogleBigqueryAnalyticsHubListingPublisher)
Name() *string
SetName(val *string)
NameInput() *string
PrimaryContact() *string
SetPrimaryContact(val *string)
PrimaryContactInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetPrimaryContact()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleBigqueryAnalyticsHubListingPublisherOutputReference ¶
func NewGoogleBigqueryAnalyticsHubListingPublisherOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleBigqueryAnalyticsHubListingPublisherOutputReference
type GoogleBigqueryAnalyticsHubListingRestrictedExportConfig ¶
type GoogleBigqueryAnalyticsHubListingRestrictedExportConfig struct {
// If true, enable restricted export.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_bigquery_analytics_hub_listing#enabled GoogleBigqueryAnalyticsHubListing#enabled}
Enabled interface{} `field:"optional" json:"enabled" yaml:"enabled"`
// If true, restrict export of query result derived from restricted linked dataset table.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_bigquery_analytics_hub_listing#restrict_query_result GoogleBigqueryAnalyticsHubListing#restrict_query_result}
RestrictQueryResult interface{} `field:"optional" json:"restrictQueryResult" yaml:"restrictQueryResult"`
}
type GoogleBigqueryAnalyticsHubListingRestrictedExportConfigOutputReference ¶
type GoogleBigqueryAnalyticsHubListingRestrictedExportConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Enabled() interface{}
SetEnabled(val interface{})
EnabledInput() interface{}
// Experimental.
Fqn() *string
InternalValue() *GoogleBigqueryAnalyticsHubListingRestrictedExportConfig
SetInternalValue(val *GoogleBigqueryAnalyticsHubListingRestrictedExportConfig)
RestrictQueryResult() interface{}
SetRestrictQueryResult(val interface{})
RestrictQueryResultInput() interface{}
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetEnabled()
ResetRestrictQueryResult()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleBigqueryAnalyticsHubListingRestrictedExportConfigOutputReference ¶
func NewGoogleBigqueryAnalyticsHubListingRestrictedExportConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleBigqueryAnalyticsHubListingRestrictedExportConfigOutputReference
type GoogleBigqueryAnalyticsHubListingTimeouts ¶
type GoogleBigqueryAnalyticsHubListingTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_bigquery_analytics_hub_listing#create GoogleBigqueryAnalyticsHubListing#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_bigquery_analytics_hub_listing#delete GoogleBigqueryAnalyticsHubListing#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_bigquery_analytics_hub_listing#update GoogleBigqueryAnalyticsHubListing#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type GoogleBigqueryAnalyticsHubListingTimeoutsOutputReference ¶
type GoogleBigqueryAnalyticsHubListingTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleBigqueryAnalyticsHubListingTimeoutsOutputReference ¶
func NewGoogleBigqueryAnalyticsHubListingTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleBigqueryAnalyticsHubListingTimeoutsOutputReference
Source Files
¶
- GoogleBigqueryAnalyticsHubListing.go
- GoogleBigqueryAnalyticsHubListingBigqueryDataset.go
- GoogleBigqueryAnalyticsHubListingBigqueryDatasetOutputReference.go
- GoogleBigqueryAnalyticsHubListingBigqueryDatasetOutputReference__checks.go
- GoogleBigqueryAnalyticsHubListingConfig.go
- GoogleBigqueryAnalyticsHubListingDataProvider.go
- GoogleBigqueryAnalyticsHubListingDataProviderOutputReference.go
- GoogleBigqueryAnalyticsHubListingDataProviderOutputReference__checks.go
- GoogleBigqueryAnalyticsHubListingPublisher.go
- GoogleBigqueryAnalyticsHubListingPublisherOutputReference.go
- GoogleBigqueryAnalyticsHubListingPublisherOutputReference__checks.go
- GoogleBigqueryAnalyticsHubListingRestrictedExportConfig.go
- GoogleBigqueryAnalyticsHubListingRestrictedExportConfigOutputReference.go
- GoogleBigqueryAnalyticsHubListingRestrictedExportConfigOutputReference__checks.go
- GoogleBigqueryAnalyticsHubListingTimeouts.go
- GoogleBigqueryAnalyticsHubListingTimeoutsOutputReference.go
- GoogleBigqueryAnalyticsHubListingTimeoutsOutputReference__checks.go
- GoogleBigqueryAnalyticsHubListing__checks.go
- main.go