Documentation
¶
Index ¶
- func GoogleClouddeployTarget_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func GoogleClouddeployTarget_IsConstruct(x interface{}) *bool
- func GoogleClouddeployTarget_IsTerraformElement(x interface{}) *bool
- func GoogleClouddeployTarget_IsTerraformResource(x interface{}) *bool
- func GoogleClouddeployTarget_TfResourceType() *string
- func NewGoogleClouddeployTargetAnthosClusterOutputReference_Override(g GoogleClouddeployTargetAnthosClusterOutputReference, ...)
- func NewGoogleClouddeployTargetCustomTargetOutputReference_Override(g GoogleClouddeployTargetCustomTargetOutputReference, ...)
- func NewGoogleClouddeployTargetExecutionConfigsList_Override(g GoogleClouddeployTargetExecutionConfigsList, ...)
- func NewGoogleClouddeployTargetExecutionConfigsOutputReference_Override(g GoogleClouddeployTargetExecutionConfigsOutputReference, ...)
- func NewGoogleClouddeployTargetGkeOutputReference_Override(g GoogleClouddeployTargetGkeOutputReference, ...)
- func NewGoogleClouddeployTargetMultiTargetOutputReference_Override(g GoogleClouddeployTargetMultiTargetOutputReference, ...)
- func NewGoogleClouddeployTargetRunOutputReference_Override(g GoogleClouddeployTargetRunOutputReference, ...)
- func NewGoogleClouddeployTargetTimeoutsOutputReference_Override(g GoogleClouddeployTargetTimeoutsOutputReference, ...)
- func NewGoogleClouddeployTarget_Override(g GoogleClouddeployTarget, scope constructs.Construct, id *string, ...)
- type GoogleClouddeployTarget
- type GoogleClouddeployTargetAnthosCluster
- type GoogleClouddeployTargetAnthosClusterOutputReference
- type GoogleClouddeployTargetConfig
- type GoogleClouddeployTargetCustomTarget
- type GoogleClouddeployTargetCustomTargetOutputReference
- type GoogleClouddeployTargetExecutionConfigs
- type GoogleClouddeployTargetExecutionConfigsList
- type GoogleClouddeployTargetExecutionConfigsOutputReference
- type GoogleClouddeployTargetGke
- type GoogleClouddeployTargetGkeOutputReference
- type GoogleClouddeployTargetMultiTarget
- type GoogleClouddeployTargetMultiTargetOutputReference
- type GoogleClouddeployTargetRun
- type GoogleClouddeployTargetRunOutputReference
- type GoogleClouddeployTargetTimeouts
- type GoogleClouddeployTargetTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleClouddeployTarget_GenerateConfigForImport ¶
func GoogleClouddeployTarget_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a GoogleClouddeployTarget resource upon running "cdktf plan <stack-name>".
func GoogleClouddeployTarget_IsConstruct ¶
func GoogleClouddeployTarget_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleClouddeployTarget_IsTerraformElement ¶
func GoogleClouddeployTarget_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleClouddeployTarget_IsTerraformResource ¶
func GoogleClouddeployTarget_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleClouddeployTarget_TfResourceType ¶
func GoogleClouddeployTarget_TfResourceType() *string
func NewGoogleClouddeployTargetAnthosClusterOutputReference_Override ¶
func NewGoogleClouddeployTargetAnthosClusterOutputReference_Override(g GoogleClouddeployTargetAnthosClusterOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleClouddeployTargetCustomTargetOutputReference_Override ¶ added in v13.17.0
func NewGoogleClouddeployTargetCustomTargetOutputReference_Override(g GoogleClouddeployTargetCustomTargetOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleClouddeployTargetExecutionConfigsList_Override ¶
func NewGoogleClouddeployTargetExecutionConfigsList_Override(g GoogleClouddeployTargetExecutionConfigsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGoogleClouddeployTargetExecutionConfigsOutputReference_Override ¶
func NewGoogleClouddeployTargetExecutionConfigsOutputReference_Override(g GoogleClouddeployTargetExecutionConfigsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGoogleClouddeployTargetGkeOutputReference_Override ¶
func NewGoogleClouddeployTargetGkeOutputReference_Override(g GoogleClouddeployTargetGkeOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleClouddeployTargetMultiTargetOutputReference_Override ¶
func NewGoogleClouddeployTargetMultiTargetOutputReference_Override(g GoogleClouddeployTargetMultiTargetOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleClouddeployTargetRunOutputReference_Override ¶
func NewGoogleClouddeployTargetRunOutputReference_Override(g GoogleClouddeployTargetRunOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleClouddeployTargetTimeoutsOutputReference_Override ¶
func NewGoogleClouddeployTargetTimeoutsOutputReference_Override(g GoogleClouddeployTargetTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleClouddeployTarget_Override ¶
func NewGoogleClouddeployTarget_Override(g GoogleClouddeployTarget, scope constructs.Construct, id *string, config *GoogleClouddeployTargetConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_clouddeploy_target google_clouddeploy_target} Resource.
Types ¶
type GoogleClouddeployTarget ¶
type GoogleClouddeployTarget interface {
cdktf.TerraformResource
Annotations() *map[string]*string
SetAnnotations(val *map[string]*string)
AnnotationsInput() *map[string]*string
AnthosCluster() GoogleClouddeployTargetAnthosClusterOutputReference
AnthosClusterInput() *GoogleClouddeployTargetAnthosCluster
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
CreateTime() *string
CustomTarget() GoogleClouddeployTargetCustomTargetOutputReference
CustomTargetInput() *GoogleClouddeployTargetCustomTarget
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DeployParameters() *map[string]*string
SetDeployParameters(val *map[string]*string)
DeployParametersInput() *map[string]*string
Description() *string
SetDescription(val *string)
DescriptionInput() *string
EffectiveAnnotations() cdktf.StringMap
EffectiveLabels() cdktf.StringMap
Etag() *string
ExecutionConfigs() GoogleClouddeployTargetExecutionConfigsList
ExecutionConfigsInput() interface{}
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Gke() GoogleClouddeployTargetGkeOutputReference
GkeInput() *GoogleClouddeployTargetGke
Id() *string
SetId(val *string)
IdInput() *string
Labels() *map[string]*string
SetLabels(val *map[string]*string)
LabelsInput() *map[string]*string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Location() *string
SetLocation(val *string)
LocationInput() *string
MultiTarget() GoogleClouddeployTargetMultiTargetOutputReference
MultiTargetInput() *GoogleClouddeployTargetMultiTarget
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
RequireApproval() interface{}
SetRequireApproval(val interface{})
RequireApprovalInput() interface{}
Run() GoogleClouddeployTargetRunOutputReference
RunInput() *GoogleClouddeployTargetRun
TargetId() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
TerraformLabels() cdktf.StringMap
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GoogleClouddeployTargetTimeoutsOutputReference
TimeoutsInput() interface{}
Uid() *string
UpdateTime() *string
// Adds a user defined moveTarget string to this resource to be later used in .moveTo(moveTarget) to resolve the location of the move.
// Experimental.
AddMoveTarget(moveTarget *string)
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
HasResourceMove() interface{}
// Experimental.
ImportFrom(id *string, provider cdktf.TerraformProvider)
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Move the resource corresponding to "id" to this resource.
//
// Note that the resource being moved from must be marked as moved using it's instance function.
// Experimental.
MoveFromId(id *string)
// Moves this resource to the target resource given by moveTarget.
// Experimental.
MoveTo(moveTarget *string, index interface{})
// Moves this resource to the resource corresponding to "id".
// Experimental.
MoveToId(id *string)
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutAnthosCluster(value *GoogleClouddeployTargetAnthosCluster)
PutCustomTarget(value *GoogleClouddeployTargetCustomTarget)
PutExecutionConfigs(value interface{})
PutGke(value *GoogleClouddeployTargetGke)
PutMultiTarget(value *GoogleClouddeployTargetMultiTarget)
PutRun(value *GoogleClouddeployTargetRun)
PutTimeouts(value *GoogleClouddeployTargetTimeouts)
ResetAnnotations()
ResetAnthosCluster()
ResetCustomTarget()
ResetDeployParameters()
ResetDescription()
ResetExecutionConfigs()
ResetGke()
ResetId()
ResetLabels()
ResetMultiTarget()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
ResetRequireApproval()
ResetRun()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
SynthesizeHclAttributes() *map[string]interface{}
// Experimental.
ToHclTerraform() interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_clouddeploy_target google_clouddeploy_target}.
func NewGoogleClouddeployTarget ¶
func NewGoogleClouddeployTarget(scope constructs.Construct, id *string, config *GoogleClouddeployTargetConfig) GoogleClouddeployTarget
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_clouddeploy_target google_clouddeploy_target} Resource.
type GoogleClouddeployTargetAnthosCluster ¶
type GoogleClouddeployTargetAnthosCluster struct {
// Membership of the GKE Hub-registered cluster to which to apply the Skaffold configuration. Format is `projects/{project}/locations/{location}/memberships/{membership_name}`.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_clouddeploy_target#membership GoogleClouddeployTarget#membership}
Membership *string `field:"optional" json:"membership" yaml:"membership"`
}
type GoogleClouddeployTargetAnthosClusterOutputReference ¶
type GoogleClouddeployTargetAnthosClusterOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleClouddeployTargetAnthosCluster
SetInternalValue(val *GoogleClouddeployTargetAnthosCluster)
Membership() *string
SetMembership(val *string)
MembershipInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetMembership()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleClouddeployTargetAnthosClusterOutputReference ¶
func NewGoogleClouddeployTargetAnthosClusterOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleClouddeployTargetAnthosClusterOutputReference
type GoogleClouddeployTargetConfig ¶
type GoogleClouddeployTargetConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// The location for the resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_clouddeploy_target#location GoogleClouddeployTarget#location}
Location *string `field:"required" json:"location" yaml:"location"`
// Name of the `Target`. Format is `[a-z]([a-z0-9-]{0,61}[a-z0-9])?`.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_clouddeploy_target#name GoogleClouddeployTarget#name}
Name *string `field:"required" json:"name" yaml:"name"`
// Optional.
//
// User annotations. These attributes can only be set and used by the user, and not by Google Cloud Deploy. See https://google.aip.dev/128#annotations for more details such as format and size limitations.
//
// **Note**: This field is non-authoritative, and will only manage the annotations present in your configuration.
// Please refer to the field `effective_annotations` for all of the annotations present on the resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_clouddeploy_target#annotations GoogleClouddeployTarget#annotations}
Annotations *map[string]*string `field:"optional" json:"annotations" yaml:"annotations"`
// anthos_cluster block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_clouddeploy_target#anthos_cluster GoogleClouddeployTarget#anthos_cluster}
AnthosCluster *GoogleClouddeployTargetAnthosCluster `field:"optional" json:"anthosCluster" yaml:"anthosCluster"`
// custom_target block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_clouddeploy_target#custom_target GoogleClouddeployTarget#custom_target}
CustomTarget *GoogleClouddeployTargetCustomTarget `field:"optional" json:"customTarget" yaml:"customTarget"`
// Optional. The deploy parameters to use for this target.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_clouddeploy_target#deploy_parameters GoogleClouddeployTarget#deploy_parameters}
DeployParameters *map[string]*string `field:"optional" json:"deployParameters" yaml:"deployParameters"`
// Optional. Description of the `Target`. Max length is 255 characters.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_clouddeploy_target#description GoogleClouddeployTarget#description}
Description *string `field:"optional" json:"description" yaml:"description"`
// execution_configs block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_clouddeploy_target#execution_configs GoogleClouddeployTarget#execution_configs}
ExecutionConfigs interface{} `field:"optional" json:"executionConfigs" yaml:"executionConfigs"`
// gke block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_clouddeploy_target#gke GoogleClouddeployTarget#gke}
Gke *GoogleClouddeployTargetGke `field:"optional" json:"gke" yaml:"gke"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_clouddeploy_target#id GoogleClouddeployTarget#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Optional.
//
// Labels are attributes that can be set and used by both the user and by Google Cloud Deploy. Labels must meet the following constraints: * Keys and values can contain only lowercase letters, numeric characters, underscores, and dashes. * All characters must use UTF-8 encoding, and international characters are allowed. * Keys must start with a lowercase letter or international character. * Each resource is limited to a maximum of 64 labels. Both keys and values are additionally constrained to be <= 128 bytes.
//
// **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
// Please refer to the field `effective_labels` for all of the labels present on the resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_clouddeploy_target#labels GoogleClouddeployTarget#labels}
Labels *map[string]*string `field:"optional" json:"labels" yaml:"labels"`
// multi_target block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_clouddeploy_target#multi_target GoogleClouddeployTarget#multi_target}
MultiTarget *GoogleClouddeployTargetMultiTarget `field:"optional" json:"multiTarget" yaml:"multiTarget"`
// The project for the resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_clouddeploy_target#project GoogleClouddeployTarget#project}
Project *string `field:"optional" json:"project" yaml:"project"`
// Optional. Whether or not the `Target` requires approval.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_clouddeploy_target#require_approval GoogleClouddeployTarget#require_approval}
RequireApproval interface{} `field:"optional" json:"requireApproval" yaml:"requireApproval"`
// run block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_clouddeploy_target#run GoogleClouddeployTarget#run}
Run *GoogleClouddeployTargetRun `field:"optional" json:"run" yaml:"run"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_clouddeploy_target#timeouts GoogleClouddeployTarget#timeouts}
Timeouts *GoogleClouddeployTargetTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type GoogleClouddeployTargetCustomTarget ¶ added in v13.17.0
type GoogleClouddeployTargetCustomTarget struct {
// Required. The name of the CustomTargetType. Format must be `projects/{project}/locations/{location}/customTargetTypes/{custom_target_type}`.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_clouddeploy_target#custom_target_type GoogleClouddeployTarget#custom_target_type}
CustomTargetType *string `field:"required" json:"customTargetType" yaml:"customTargetType"`
}
type GoogleClouddeployTargetCustomTargetOutputReference ¶ added in v13.17.0
type GoogleClouddeployTargetCustomTargetOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
CustomTargetType() *string
SetCustomTargetType(val *string)
CustomTargetTypeInput() *string
// Experimental.
Fqn() *string
InternalValue() *GoogleClouddeployTargetCustomTarget
SetInternalValue(val *GoogleClouddeployTargetCustomTarget)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleClouddeployTargetCustomTargetOutputReference ¶ added in v13.17.0
func NewGoogleClouddeployTargetCustomTargetOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleClouddeployTargetCustomTargetOutputReference
type GoogleClouddeployTargetExecutionConfigs ¶
type GoogleClouddeployTargetExecutionConfigs struct {
// Required. Usages when this configuration should be applied.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_clouddeploy_target#usages GoogleClouddeployTarget#usages}
Usages *[]*string `field:"required" json:"usages" yaml:"usages"`
// Optional.
//
// Cloud Storage location in which to store execution outputs. This can either be a bucket ("gs://my-bucket") or a path within a bucket ("gs://my-bucket/my-dir"). If unspecified, a default bucket located in the same region will be used.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_clouddeploy_target#artifact_storage GoogleClouddeployTarget#artifact_storage}
ArtifactStorage *string `field:"optional" json:"artifactStorage" yaml:"artifactStorage"`
// Optional.
//
// Execution timeout for a Cloud Build Execution. This must be between 10m and 24h in seconds format. If unspecified, a default timeout of 1h is used.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_clouddeploy_target#execution_timeout GoogleClouddeployTarget#execution_timeout}
ExecutionTimeout *string `field:"optional" json:"executionTimeout" yaml:"executionTimeout"`
// Optional. Google service account to use for execution. If unspecified, the project execution service account (-compute@developer.gserviceaccount.com) is used.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_clouddeploy_target#service_account GoogleClouddeployTarget#service_account}
ServiceAccount *string `field:"optional" json:"serviceAccount" yaml:"serviceAccount"`
// Optional. If true, additional logging will be enabled when running builds in this execution environment.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_clouddeploy_target#verbose GoogleClouddeployTarget#verbose}
Verbose interface{} `field:"optional" json:"verbose" yaml:"verbose"`
// Optional.
//
// The resource name of the `WorkerPool`, with the format `projects/{project}/locations/{location}/workerPools/{worker_pool}`. If this optional field is unspecified, the default Cloud Build pool will be used.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_clouddeploy_target#worker_pool GoogleClouddeployTarget#worker_pool}
WorkerPool *string `field:"optional" json:"workerPool" yaml:"workerPool"`
}
type GoogleClouddeployTargetExecutionConfigsList ¶
type GoogleClouddeployTargetExecutionConfigsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) GoogleClouddeployTargetExecutionConfigsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleClouddeployTargetExecutionConfigsList ¶
func NewGoogleClouddeployTargetExecutionConfigsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GoogleClouddeployTargetExecutionConfigsList
type GoogleClouddeployTargetExecutionConfigsOutputReference ¶
type GoogleClouddeployTargetExecutionConfigsOutputReference interface {
cdktf.ComplexObject
ArtifactStorage() *string
SetArtifactStorage(val *string)
ArtifactStorageInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
ExecutionTimeout() *string
SetExecutionTimeout(val *string)
ExecutionTimeoutInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
ServiceAccount() *string
SetServiceAccount(val *string)
ServiceAccountInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Usages() *[]*string
SetUsages(val *[]*string)
UsagesInput() *[]*string
Verbose() interface{}
SetVerbose(val interface{})
VerboseInput() interface{}
WorkerPool() *string
SetWorkerPool(val *string)
WorkerPoolInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetArtifactStorage()
ResetExecutionTimeout()
ResetServiceAccount()
ResetVerbose()
ResetWorkerPool()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleClouddeployTargetExecutionConfigsOutputReference ¶
func NewGoogleClouddeployTargetExecutionConfigsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GoogleClouddeployTargetExecutionConfigsOutputReference
type GoogleClouddeployTargetGke ¶
type GoogleClouddeployTargetGke struct {
// Information specifying a GKE Cluster. Format is `projects/{project_id}/locations/{location_id}/clusters/{cluster_id}.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_clouddeploy_target#cluster GoogleClouddeployTarget#cluster}
Cluster *string `field:"optional" json:"cluster" yaml:"cluster"`
// Optional.
//
// If true, `cluster` is accessed using the private IP address of the control plane endpoint. Otherwise, the default IP address of the control plane endpoint is used. The default IP address is the private IP address for clusters with private control-plane endpoints and the public IP address otherwise. Only specify this option when `cluster` is a [private GKE cluster](https://cloud.google.com/kubernetes-engine/docs/concepts/private-cluster-concept).
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_clouddeploy_target#internal_ip GoogleClouddeployTarget#internal_ip}
InternalIp interface{} `field:"optional" json:"internalIp" yaml:"internalIp"`
// Optional. If set, used to configure a [proxy](https://kubernetes.io/docs/concepts/configuration/organize-cluster-access-kubeconfig/#proxy) to the Kubernetes server.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_clouddeploy_target#proxy_url GoogleClouddeployTarget#proxy_url}
ProxyUrl *string `field:"optional" json:"proxyUrl" yaml:"proxyUrl"`
}
type GoogleClouddeployTargetGkeOutputReference ¶
type GoogleClouddeployTargetGkeOutputReference interface {
cdktf.ComplexObject
Cluster() *string
SetCluster(val *string)
ClusterInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalIp() interface{}
SetInternalIp(val interface{})
InternalIpInput() interface{}
InternalValue() *GoogleClouddeployTargetGke
SetInternalValue(val *GoogleClouddeployTargetGke)
ProxyUrl() *string
SetProxyUrl(val *string)
ProxyUrlInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCluster()
ResetInternalIp()
ResetProxyUrl()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleClouddeployTargetGkeOutputReference ¶
func NewGoogleClouddeployTargetGkeOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleClouddeployTargetGkeOutputReference
type GoogleClouddeployTargetMultiTarget ¶
type GoogleClouddeployTargetMultiTarget struct {
// Required. The target_ids of this multiTarget.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_clouddeploy_target#target_ids GoogleClouddeployTarget#target_ids}
TargetIds *[]*string `field:"required" json:"targetIds" yaml:"targetIds"`
}
type GoogleClouddeployTargetMultiTargetOutputReference ¶
type GoogleClouddeployTargetMultiTargetOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleClouddeployTargetMultiTarget
SetInternalValue(val *GoogleClouddeployTargetMultiTarget)
TargetIds() *[]*string
SetTargetIds(val *[]*string)
TargetIdsInput() *[]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleClouddeployTargetMultiTargetOutputReference ¶
func NewGoogleClouddeployTargetMultiTargetOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleClouddeployTargetMultiTargetOutputReference
type GoogleClouddeployTargetRun ¶
type GoogleClouddeployTargetRun struct {
// Required. The location where the Cloud Run Service should be located. Format is `projects/{project}/locations/{location}`.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_clouddeploy_target#location GoogleClouddeployTarget#location}
Location *string `field:"required" json:"location" yaml:"location"`
}
type GoogleClouddeployTargetRunOutputReference ¶
type GoogleClouddeployTargetRunOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleClouddeployTargetRun
SetInternalValue(val *GoogleClouddeployTargetRun)
Location() *string
SetLocation(val *string)
LocationInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleClouddeployTargetRunOutputReference ¶
func NewGoogleClouddeployTargetRunOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleClouddeployTargetRunOutputReference
type GoogleClouddeployTargetTimeouts ¶
type GoogleClouddeployTargetTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_clouddeploy_target#create GoogleClouddeployTarget#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_clouddeploy_target#delete GoogleClouddeployTarget#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_clouddeploy_target#update GoogleClouddeployTarget#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type GoogleClouddeployTargetTimeoutsOutputReference ¶
type GoogleClouddeployTargetTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleClouddeployTargetTimeoutsOutputReference ¶
func NewGoogleClouddeployTargetTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleClouddeployTargetTimeoutsOutputReference
Source Files
¶
- GoogleClouddeployTarget.go
- GoogleClouddeployTargetAnthosCluster.go
- GoogleClouddeployTargetAnthosClusterOutputReference.go
- GoogleClouddeployTargetAnthosClusterOutputReference__checks.go
- GoogleClouddeployTargetConfig.go
- GoogleClouddeployTargetCustomTarget.go
- GoogleClouddeployTargetCustomTargetOutputReference.go
- GoogleClouddeployTargetCustomTargetOutputReference__checks.go
- GoogleClouddeployTargetExecutionConfigs.go
- GoogleClouddeployTargetExecutionConfigsList.go
- GoogleClouddeployTargetExecutionConfigsList__checks.go
- GoogleClouddeployTargetExecutionConfigsOutputReference.go
- GoogleClouddeployTargetExecutionConfigsOutputReference__checks.go
- GoogleClouddeployTargetGke.go
- GoogleClouddeployTargetGkeOutputReference.go
- GoogleClouddeployTargetGkeOutputReference__checks.go
- GoogleClouddeployTargetMultiTarget.go
- GoogleClouddeployTargetMultiTargetOutputReference.go
- GoogleClouddeployTargetMultiTargetOutputReference__checks.go
- GoogleClouddeployTargetRun.go
- GoogleClouddeployTargetRunOutputReference.go
- GoogleClouddeployTargetRunOutputReference__checks.go
- GoogleClouddeployTargetTimeouts.go
- GoogleClouddeployTargetTimeoutsOutputReference.go
- GoogleClouddeployTargetTimeoutsOutputReference__checks.go
- GoogleClouddeployTarget__checks.go
- main.go