Documentation
¶
Index ¶
- func GoogleComputeRegionDisk_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func GoogleComputeRegionDisk_IsConstruct(x interface{}) *bool
- func GoogleComputeRegionDisk_IsTerraformElement(x interface{}) *bool
- func GoogleComputeRegionDisk_IsTerraformResource(x interface{}) *bool
- func GoogleComputeRegionDisk_TfResourceType() *string
- func NewGoogleComputeRegionDiskAsyncPrimaryDiskOutputReference_Override(g GoogleComputeRegionDiskAsyncPrimaryDiskOutputReference, ...)
- func NewGoogleComputeRegionDiskDiskEncryptionKeyOutputReference_Override(g GoogleComputeRegionDiskDiskEncryptionKeyOutputReference, ...)
- func NewGoogleComputeRegionDiskGuestOsFeaturesList_Override(g GoogleComputeRegionDiskGuestOsFeaturesList, ...)
- func NewGoogleComputeRegionDiskGuestOsFeaturesOutputReference_Override(g GoogleComputeRegionDiskGuestOsFeaturesOutputReference, ...)
- func NewGoogleComputeRegionDiskSourceSnapshotEncryptionKeyOutputReference_Override(g GoogleComputeRegionDiskSourceSnapshotEncryptionKeyOutputReference, ...)
- func NewGoogleComputeRegionDiskTimeoutsOutputReference_Override(g GoogleComputeRegionDiskTimeoutsOutputReference, ...)
- func NewGoogleComputeRegionDisk_Override(g GoogleComputeRegionDisk, scope constructs.Construct, id *string, ...)
- type GoogleComputeRegionDisk
- type GoogleComputeRegionDiskAsyncPrimaryDisk
- type GoogleComputeRegionDiskAsyncPrimaryDiskOutputReference
- type GoogleComputeRegionDiskConfig
- type GoogleComputeRegionDiskDiskEncryptionKey
- type GoogleComputeRegionDiskDiskEncryptionKeyOutputReference
- type GoogleComputeRegionDiskGuestOsFeatures
- type GoogleComputeRegionDiskGuestOsFeaturesList
- type GoogleComputeRegionDiskGuestOsFeaturesOutputReference
- type GoogleComputeRegionDiskSourceSnapshotEncryptionKey
- type GoogleComputeRegionDiskSourceSnapshotEncryptionKeyOutputReference
- type GoogleComputeRegionDiskTimeouts
- type GoogleComputeRegionDiskTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleComputeRegionDisk_GenerateConfigForImport ¶
func GoogleComputeRegionDisk_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a GoogleComputeRegionDisk resource upon running "cdktf plan <stack-name>".
func GoogleComputeRegionDisk_IsConstruct ¶
func GoogleComputeRegionDisk_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleComputeRegionDisk_IsTerraformElement ¶
func GoogleComputeRegionDisk_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleComputeRegionDisk_IsTerraformResource ¶
func GoogleComputeRegionDisk_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleComputeRegionDisk_TfResourceType ¶
func GoogleComputeRegionDisk_TfResourceType() *string
func NewGoogleComputeRegionDiskAsyncPrimaryDiskOutputReference_Override ¶
func NewGoogleComputeRegionDiskAsyncPrimaryDiskOutputReference_Override(g GoogleComputeRegionDiskAsyncPrimaryDiskOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleComputeRegionDiskDiskEncryptionKeyOutputReference_Override ¶
func NewGoogleComputeRegionDiskDiskEncryptionKeyOutputReference_Override(g GoogleComputeRegionDiskDiskEncryptionKeyOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleComputeRegionDiskGuestOsFeaturesList_Override ¶
func NewGoogleComputeRegionDiskGuestOsFeaturesList_Override(g GoogleComputeRegionDiskGuestOsFeaturesList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGoogleComputeRegionDiskGuestOsFeaturesOutputReference_Override ¶
func NewGoogleComputeRegionDiskGuestOsFeaturesOutputReference_Override(g GoogleComputeRegionDiskGuestOsFeaturesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGoogleComputeRegionDiskSourceSnapshotEncryptionKeyOutputReference_Override ¶
func NewGoogleComputeRegionDiskSourceSnapshotEncryptionKeyOutputReference_Override(g GoogleComputeRegionDiskSourceSnapshotEncryptionKeyOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleComputeRegionDiskTimeoutsOutputReference_Override ¶
func NewGoogleComputeRegionDiskTimeoutsOutputReference_Override(g GoogleComputeRegionDiskTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleComputeRegionDisk_Override ¶
func NewGoogleComputeRegionDisk_Override(g GoogleComputeRegionDisk, scope constructs.Construct, id *string, config *GoogleComputeRegionDiskConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_compute_region_disk google_compute_region_disk} Resource.
Types ¶
type GoogleComputeRegionDisk ¶
type GoogleComputeRegionDisk interface {
cdktf.TerraformResource
AsyncPrimaryDisk() GoogleComputeRegionDiskAsyncPrimaryDiskOutputReference
AsyncPrimaryDiskInput() *GoogleComputeRegionDiskAsyncPrimaryDisk
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
CreationTimestamp() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
DiskEncryptionKey() GoogleComputeRegionDiskDiskEncryptionKeyOutputReference
DiskEncryptionKeyInput() *GoogleComputeRegionDiskDiskEncryptionKey
EffectiveLabels() cdktf.StringMap
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
GuestOsFeatures() GoogleComputeRegionDiskGuestOsFeaturesList
GuestOsFeaturesInput() interface{}
Id() *string
SetId(val *string)
IdInput() *string
Interface() *string
SetInterface(val *string)
InterfaceInput() *string
LabelFingerprint() *string
Labels() *map[string]*string
SetLabels(val *map[string]*string)
LabelsInput() *map[string]*string
LastAttachTimestamp() *string
LastDetachTimestamp() *string
Licenses() *[]*string
SetLicenses(val *[]*string)
LicensesInput() *[]*string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
PhysicalBlockSizeBytes() *float64
SetPhysicalBlockSizeBytes(val *float64)
PhysicalBlockSizeBytesInput() *float64
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Region() *string
SetRegion(val *string)
RegionInput() *string
ReplicaZones() *[]*string
SetReplicaZones(val *[]*string)
ReplicaZonesInput() *[]*string
SelfLink() *string
Size() *float64
SetSize(val *float64)
SizeInput() *float64
Snapshot() *string
SetSnapshot(val *string)
SnapshotInput() *string
SourceDisk() *string
SetSourceDisk(val *string)
SourceDiskId() *string
SourceDiskInput() *string
SourceSnapshotEncryptionKey() GoogleComputeRegionDiskSourceSnapshotEncryptionKeyOutputReference
SourceSnapshotEncryptionKeyInput() *GoogleComputeRegionDiskSourceSnapshotEncryptionKey
SourceSnapshotId() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
TerraformLabels() cdktf.StringMap
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GoogleComputeRegionDiskTimeoutsOutputReference
TimeoutsInput() interface{}
Type() *string
SetType(val *string)
TypeInput() *string
Users() *[]*string
// Adds a user defined moveTarget string to this resource to be later used in .moveTo(moveTarget) to resolve the location of the move.
// Experimental.
AddMoveTarget(moveTarget *string)
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
HasResourceMove() interface{}
// Experimental.
ImportFrom(id *string, provider cdktf.TerraformProvider)
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Move the resource corresponding to "id" to this resource.
//
// Note that the resource being moved from must be marked as moved using it's instance function.
// Experimental.
MoveFromId(id *string)
// Moves this resource to the target resource given by moveTarget.
// Experimental.
MoveTo(moveTarget *string, index interface{})
// Moves this resource to the resource corresponding to "id".
// Experimental.
MoveToId(id *string)
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutAsyncPrimaryDisk(value *GoogleComputeRegionDiskAsyncPrimaryDisk)
PutDiskEncryptionKey(value *GoogleComputeRegionDiskDiskEncryptionKey)
PutGuestOsFeatures(value interface{})
PutSourceSnapshotEncryptionKey(value *GoogleComputeRegionDiskSourceSnapshotEncryptionKey)
PutTimeouts(value *GoogleComputeRegionDiskTimeouts)
ResetAsyncPrimaryDisk()
ResetDescription()
ResetDiskEncryptionKey()
ResetGuestOsFeatures()
ResetId()
ResetInterface()
ResetLabels()
ResetLicenses()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetPhysicalBlockSizeBytes()
ResetProject()
ResetRegion()
ResetSize()
ResetSnapshot()
ResetSourceDisk()
ResetSourceSnapshotEncryptionKey()
ResetTimeouts()
ResetType()
SynthesizeAttributes() *map[string]interface{}
SynthesizeHclAttributes() *map[string]interface{}
// Experimental.
ToHclTerraform() interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_compute_region_disk google_compute_region_disk}.
func NewGoogleComputeRegionDisk ¶
func NewGoogleComputeRegionDisk(scope constructs.Construct, id *string, config *GoogleComputeRegionDiskConfig) GoogleComputeRegionDisk
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_compute_region_disk google_compute_region_disk} Resource.
type GoogleComputeRegionDiskAsyncPrimaryDisk ¶
type GoogleComputeRegionDiskAsyncPrimaryDisk struct {
// Primary disk for asynchronous disk replication.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_compute_region_disk#disk GoogleComputeRegionDisk#disk}
Disk *string `field:"required" json:"disk" yaml:"disk"`
}
type GoogleComputeRegionDiskAsyncPrimaryDiskOutputReference ¶
type GoogleComputeRegionDiskAsyncPrimaryDiskOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Disk() *string
SetDisk(val *string)
DiskInput() *string
// Experimental.
Fqn() *string
InternalValue() *GoogleComputeRegionDiskAsyncPrimaryDisk
SetInternalValue(val *GoogleComputeRegionDiskAsyncPrimaryDisk)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleComputeRegionDiskAsyncPrimaryDiskOutputReference ¶
func NewGoogleComputeRegionDiskAsyncPrimaryDiskOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleComputeRegionDiskAsyncPrimaryDiskOutputReference
type GoogleComputeRegionDiskConfig ¶
type GoogleComputeRegionDiskConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Name of the resource.
//
// Provided by the client when the resource is
// created. The name must be 1-63 characters long, and comply with
// RFC1035. Specifically, the name must be 1-63 characters long and match
// the regular expression '[a-z]([-a-z0-9]*[a-z0-9])?' which means the
// first character must be a lowercase letter, and all following
// characters must be a dash, lowercase letter, or digit, except the last
// character, which cannot be a dash.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_compute_region_disk#name GoogleComputeRegionDisk#name}
Name *string `field:"required" json:"name" yaml:"name"`
// URLs of the zones where the disk should be replicated to.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_compute_region_disk#replica_zones GoogleComputeRegionDisk#replica_zones}
ReplicaZones *[]*string `field:"required" json:"replicaZones" yaml:"replicaZones"`
// async_primary_disk block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_compute_region_disk#async_primary_disk GoogleComputeRegionDisk#async_primary_disk}
AsyncPrimaryDisk *GoogleComputeRegionDiskAsyncPrimaryDisk `field:"optional" json:"asyncPrimaryDisk" yaml:"asyncPrimaryDisk"`
// An optional description of this resource. Provide this property when you create the resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_compute_region_disk#description GoogleComputeRegionDisk#description}
Description *string `field:"optional" json:"description" yaml:"description"`
// disk_encryption_key block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_compute_region_disk#disk_encryption_key GoogleComputeRegionDisk#disk_encryption_key}
DiskEncryptionKey *GoogleComputeRegionDiskDiskEncryptionKey `field:"optional" json:"diskEncryptionKey" yaml:"diskEncryptionKey"`
// guest_os_features block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_compute_region_disk#guest_os_features GoogleComputeRegionDisk#guest_os_features}
GuestOsFeatures interface{} `field:"optional" json:"guestOsFeatures" yaml:"guestOsFeatures"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_compute_region_disk#id GoogleComputeRegionDisk#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Specifies the disk interface to use for attaching this disk, which is either SCSI or NVME.
//
// The default is SCSI.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_compute_region_disk#interface GoogleComputeRegionDisk#interface}
Interface *string `field:"optional" json:"interface" yaml:"interface"`
// Labels to apply to this disk. A list of key->value pairs.
//
// **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
// Please refer to the field 'effective_labels' for all of the labels present on the resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_compute_region_disk#labels GoogleComputeRegionDisk#labels}
Labels *map[string]*string `field:"optional" json:"labels" yaml:"labels"`
// Any applicable license URI.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_compute_region_disk#licenses GoogleComputeRegionDisk#licenses}
Licenses *[]*string `field:"optional" json:"licenses" yaml:"licenses"`
// Physical block size of the persistent disk, in bytes.
//
// If not present
// in a request, a default value is used. Currently supported sizes
// are 4096 and 16384, other sizes may be added in the future.
// If an unsupported value is requested, the error message will list
// the supported values for the caller's project.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_compute_region_disk#physical_block_size_bytes GoogleComputeRegionDisk#physical_block_size_bytes}
PhysicalBlockSizeBytes *float64 `field:"optional" json:"physicalBlockSizeBytes" yaml:"physicalBlockSizeBytes"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_compute_region_disk#project GoogleComputeRegionDisk#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// A reference to the region where the disk resides.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_compute_region_disk#region GoogleComputeRegionDisk#region}
Region *string `field:"optional" json:"region" yaml:"region"`
// Size of the persistent disk, specified in GB.
//
// You can specify this
// field when creating a persistent disk using the sourceImage or
// sourceSnapshot parameter, or specify it alone to create an empty
// persistent disk.
//
// If you specify this field along with sourceImage or sourceSnapshot,
// the value of sizeGb must not be less than the size of the sourceImage
// or the size of the snapshot.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_compute_region_disk#size GoogleComputeRegionDisk#size}
Size *float64 `field:"optional" json:"size" yaml:"size"`
// The source snapshot used to create this disk.
//
// You can provide this as
// a partial or full URL to the resource. For example, the following are
// valid values:
//
// * 'https://www.googleapis.com/compute/v1/projects/project/global/snapshots/snapshot'
// * 'projects/project/global/snapshots/snapshot'
// * 'global/snapshots/snapshot'
// * 'snapshot'
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_compute_region_disk#snapshot GoogleComputeRegionDisk#snapshot}
Snapshot *string `field:"optional" json:"snapshot" yaml:"snapshot"`
// The source disk used to create this disk.
//
// You can provide this as a partial or full URL to the resource.
// For example, the following are valid values:
//
// * https://www.googleapis.com/compute/v1/projects/{project}/zones/{zone}/disks/{disk}
// * https://www.googleapis.com/compute/v1/projects/{project}/regions/{region}/disks/{disk}
// * projects/{project}/zones/{zone}/disks/{disk}
// * projects/{project}/regions/{region}/disks/{disk}
// * zones/{zone}/disks/{disk}
// * regions/{region}/disks/{disk}
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_compute_region_disk#source_disk GoogleComputeRegionDisk#source_disk}
SourceDisk *string `field:"optional" json:"sourceDisk" yaml:"sourceDisk"`
// source_snapshot_encryption_key block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_compute_region_disk#source_snapshot_encryption_key GoogleComputeRegionDisk#source_snapshot_encryption_key}
SourceSnapshotEncryptionKey *GoogleComputeRegionDiskSourceSnapshotEncryptionKey `field:"optional" json:"sourceSnapshotEncryptionKey" yaml:"sourceSnapshotEncryptionKey"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_compute_region_disk#timeouts GoogleComputeRegionDisk#timeouts}
Timeouts *GoogleComputeRegionDiskTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
// URL of the disk type resource describing which disk type to use to create the disk.
//
// Provide this when creating the disk.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_compute_region_disk#type GoogleComputeRegionDisk#type}
Type *string `field:"optional" json:"type" yaml:"type"`
}
type GoogleComputeRegionDiskDiskEncryptionKey ¶
type GoogleComputeRegionDiskDiskEncryptionKey struct {
// The name of the encryption key that is stored in Google Cloud KMS.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_compute_region_disk#kms_key_name GoogleComputeRegionDisk#kms_key_name}
KmsKeyName *string `field:"optional" json:"kmsKeyName" yaml:"kmsKeyName"`
// Specifies a 256-bit customer-supplied encryption key, encoded in RFC 4648 base64 to either encrypt or decrypt this resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_compute_region_disk#raw_key GoogleComputeRegionDisk#raw_key}
RawKey *string `field:"optional" json:"rawKey" yaml:"rawKey"`
}
type GoogleComputeRegionDiskDiskEncryptionKeyOutputReference ¶
type GoogleComputeRegionDiskDiskEncryptionKeyOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleComputeRegionDiskDiskEncryptionKey
SetInternalValue(val *GoogleComputeRegionDiskDiskEncryptionKey)
KmsKeyName() *string
SetKmsKeyName(val *string)
KmsKeyNameInput() *string
RawKey() *string
SetRawKey(val *string)
RawKeyInput() *string
Sha256() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetKmsKeyName()
ResetRawKey()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleComputeRegionDiskDiskEncryptionKeyOutputReference ¶
func NewGoogleComputeRegionDiskDiskEncryptionKeyOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleComputeRegionDiskDiskEncryptionKeyOutputReference
type GoogleComputeRegionDiskGuestOsFeatures ¶
type GoogleComputeRegionDiskGuestOsFeatures struct {
// The type of supported feature.
//
// Read [Enabling guest operating system features](https://cloud.google.com/compute/docs/images/create-delete-deprecate-private-images#guest-os-features) to see a list of available options. Possible values: ["MULTI_IP_SUBNET", "SECURE_BOOT", "SEV_CAPABLE", "UEFI_COMPATIBLE", "VIRTIO_SCSI_MULTIQUEUE", "WINDOWS", "GVNIC", "SEV_LIVE_MIGRATABLE", "SEV_SNP_CAPABLE", "SUSPEND_RESUME_COMPATIBLE", "TDX_CAPABLE"]
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_compute_region_disk#type GoogleComputeRegionDisk#type}
Type *string `field:"required" json:"type" yaml:"type"`
}
type GoogleComputeRegionDiskGuestOsFeaturesList ¶
type GoogleComputeRegionDiskGuestOsFeaturesList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) GoogleComputeRegionDiskGuestOsFeaturesOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleComputeRegionDiskGuestOsFeaturesList ¶
func NewGoogleComputeRegionDiskGuestOsFeaturesList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GoogleComputeRegionDiskGuestOsFeaturesList
type GoogleComputeRegionDiskGuestOsFeaturesOutputReference ¶
type GoogleComputeRegionDiskGuestOsFeaturesOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
SetType(val *string)
TypeInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleComputeRegionDiskGuestOsFeaturesOutputReference ¶
func NewGoogleComputeRegionDiskGuestOsFeaturesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GoogleComputeRegionDiskGuestOsFeaturesOutputReference
type GoogleComputeRegionDiskSourceSnapshotEncryptionKey ¶
type GoogleComputeRegionDiskSourceSnapshotEncryptionKey struct {
// The name of the encryption key that is stored in Google Cloud KMS.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_compute_region_disk#kms_key_name GoogleComputeRegionDisk#kms_key_name}
KmsKeyName *string `field:"optional" json:"kmsKeyName" yaml:"kmsKeyName"`
// Specifies a 256-bit customer-supplied encryption key, encoded in RFC 4648 base64 to either encrypt or decrypt this resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_compute_region_disk#raw_key GoogleComputeRegionDisk#raw_key}
RawKey *string `field:"optional" json:"rawKey" yaml:"rawKey"`
}
type GoogleComputeRegionDiskSourceSnapshotEncryptionKeyOutputReference ¶
type GoogleComputeRegionDiskSourceSnapshotEncryptionKeyOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleComputeRegionDiskSourceSnapshotEncryptionKey
SetInternalValue(val *GoogleComputeRegionDiskSourceSnapshotEncryptionKey)
KmsKeyName() *string
SetKmsKeyName(val *string)
KmsKeyNameInput() *string
RawKey() *string
SetRawKey(val *string)
RawKeyInput() *string
Sha256() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetKmsKeyName()
ResetRawKey()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleComputeRegionDiskSourceSnapshotEncryptionKeyOutputReference ¶
func NewGoogleComputeRegionDiskSourceSnapshotEncryptionKeyOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleComputeRegionDiskSourceSnapshotEncryptionKeyOutputReference
type GoogleComputeRegionDiskTimeouts ¶
type GoogleComputeRegionDiskTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_compute_region_disk#create GoogleComputeRegionDisk#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_compute_region_disk#delete GoogleComputeRegionDisk#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_compute_region_disk#update GoogleComputeRegionDisk#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type GoogleComputeRegionDiskTimeoutsOutputReference ¶
type GoogleComputeRegionDiskTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleComputeRegionDiskTimeoutsOutputReference ¶
func NewGoogleComputeRegionDiskTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleComputeRegionDiskTimeoutsOutputReference
Source Files
¶
- GoogleComputeRegionDisk.go
- GoogleComputeRegionDiskAsyncPrimaryDisk.go
- GoogleComputeRegionDiskAsyncPrimaryDiskOutputReference.go
- GoogleComputeRegionDiskAsyncPrimaryDiskOutputReference__checks.go
- GoogleComputeRegionDiskConfig.go
- GoogleComputeRegionDiskDiskEncryptionKey.go
- GoogleComputeRegionDiskDiskEncryptionKeyOutputReference.go
- GoogleComputeRegionDiskDiskEncryptionKeyOutputReference__checks.go
- GoogleComputeRegionDiskGuestOsFeatures.go
- GoogleComputeRegionDiskGuestOsFeaturesList.go
- GoogleComputeRegionDiskGuestOsFeaturesList__checks.go
- GoogleComputeRegionDiskGuestOsFeaturesOutputReference.go
- GoogleComputeRegionDiskGuestOsFeaturesOutputReference__checks.go
- GoogleComputeRegionDiskSourceSnapshotEncryptionKey.go
- GoogleComputeRegionDiskSourceSnapshotEncryptionKeyOutputReference.go
- GoogleComputeRegionDiskSourceSnapshotEncryptionKeyOutputReference__checks.go
- GoogleComputeRegionDiskTimeouts.go
- GoogleComputeRegionDiskTimeoutsOutputReference.go
- GoogleComputeRegionDiskTimeoutsOutputReference__checks.go
- GoogleComputeRegionDisk__checks.go
- main.go