Documentation
¶
Index ¶
- func GoogleComputeRouter_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func GoogleComputeRouter_IsConstruct(x interface{}) *bool
- func GoogleComputeRouter_IsTerraformElement(x interface{}) *bool
- func GoogleComputeRouter_IsTerraformResource(x interface{}) *bool
- func GoogleComputeRouter_TfResourceType() *string
- func NewGoogleComputeRouterBgpAdvertisedIpRangesList_Override(g GoogleComputeRouterBgpAdvertisedIpRangesList, ...)
- func NewGoogleComputeRouterBgpAdvertisedIpRangesOutputReference_Override(g GoogleComputeRouterBgpAdvertisedIpRangesOutputReference, ...)
- func NewGoogleComputeRouterBgpOutputReference_Override(g GoogleComputeRouterBgpOutputReference, ...)
- func NewGoogleComputeRouterTimeoutsOutputReference_Override(g GoogleComputeRouterTimeoutsOutputReference, ...)
- func NewGoogleComputeRouter_Override(g GoogleComputeRouter, scope constructs.Construct, id *string, ...)
- type GoogleComputeRouter
- type GoogleComputeRouterBgp
- type GoogleComputeRouterBgpAdvertisedIpRanges
- type GoogleComputeRouterBgpAdvertisedIpRangesList
- type GoogleComputeRouterBgpAdvertisedIpRangesOutputReference
- type GoogleComputeRouterBgpOutputReference
- type GoogleComputeRouterConfig
- type GoogleComputeRouterTimeouts
- type GoogleComputeRouterTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleComputeRouter_GenerateConfigForImport ¶
func GoogleComputeRouter_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a GoogleComputeRouter resource upon running "cdktf plan <stack-name>".
func GoogleComputeRouter_IsConstruct ¶
func GoogleComputeRouter_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleComputeRouter_IsTerraformElement ¶
func GoogleComputeRouter_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleComputeRouter_IsTerraformResource ¶
func GoogleComputeRouter_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleComputeRouter_TfResourceType ¶
func GoogleComputeRouter_TfResourceType() *string
func NewGoogleComputeRouterBgpAdvertisedIpRangesList_Override ¶
func NewGoogleComputeRouterBgpAdvertisedIpRangesList_Override(g GoogleComputeRouterBgpAdvertisedIpRangesList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGoogleComputeRouterBgpAdvertisedIpRangesOutputReference_Override ¶
func NewGoogleComputeRouterBgpAdvertisedIpRangesOutputReference_Override(g GoogleComputeRouterBgpAdvertisedIpRangesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGoogleComputeRouterBgpOutputReference_Override ¶
func NewGoogleComputeRouterBgpOutputReference_Override(g GoogleComputeRouterBgpOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleComputeRouterTimeoutsOutputReference_Override ¶
func NewGoogleComputeRouterTimeoutsOutputReference_Override(g GoogleComputeRouterTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleComputeRouter_Override ¶
func NewGoogleComputeRouter_Override(g GoogleComputeRouter, scope constructs.Construct, id *string, config *GoogleComputeRouterConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_compute_router google_compute_router} Resource.
Types ¶
type GoogleComputeRouter ¶
type GoogleComputeRouter interface {
cdktf.TerraformResource
Bgp() GoogleComputeRouterBgpOutputReference
BgpInput() *GoogleComputeRouterBgp
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
CreationTimestamp() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
EncryptedInterconnectRouter() interface{}
SetEncryptedInterconnectRouter(val interface{})
EncryptedInterconnectRouterInput() interface{}
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
Network() *string
SetNetwork(val *string)
NetworkInput() *string
// The tree node.
Node() constructs.Node
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Region() *string
SetRegion(val *string)
RegionInput() *string
SelfLink() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GoogleComputeRouterTimeoutsOutputReference
TimeoutsInput() interface{}
// Adds a user defined moveTarget string to this resource to be later used in .moveTo(moveTarget) to resolve the location of the move.
// Experimental.
AddMoveTarget(moveTarget *string)
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
HasResourceMove() interface{}
// Experimental.
ImportFrom(id *string, provider cdktf.TerraformProvider)
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Move the resource corresponding to "id" to this resource.
//
// Note that the resource being moved from must be marked as moved using it's instance function.
// Experimental.
MoveFromId(id *string)
// Moves this resource to the target resource given by moveTarget.
// Experimental.
MoveTo(moveTarget *string, index interface{})
// Moves this resource to the resource corresponding to "id".
// Experimental.
MoveToId(id *string)
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutBgp(value *GoogleComputeRouterBgp)
PutTimeouts(value *GoogleComputeRouterTimeouts)
ResetBgp()
ResetDescription()
ResetEncryptedInterconnectRouter()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
ResetRegion()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
SynthesizeHclAttributes() *map[string]interface{}
// Experimental.
ToHclTerraform() interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_compute_router google_compute_router}.
func NewGoogleComputeRouter ¶
func NewGoogleComputeRouter(scope constructs.Construct, id *string, config *GoogleComputeRouterConfig) GoogleComputeRouter
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_compute_router google_compute_router} Resource.
type GoogleComputeRouterBgp ¶
type GoogleComputeRouterBgp struct {
// Local BGP Autonomous System Number (ASN).
//
// Must be an RFC6996
// private ASN, either 16-bit or 32-bit. The value will be fixed for
// this router resource. All VPN tunnels that link to this router
// will have the same local ASN.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_compute_router#asn GoogleComputeRouter#asn}
Asn *float64 `field:"required" json:"asn" yaml:"asn"`
// User-specified list of prefix groups to advertise in custom mode.
//
// This field can only be populated if advertiseMode is CUSTOM and
// is advertised to all peers of the router. These groups will be
// advertised in addition to any specified prefixes. Leave this field
// blank to advertise no custom groups.
//
// This enum field has the one valid value: ALL_SUBNETS
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_compute_router#advertised_groups GoogleComputeRouter#advertised_groups}
AdvertisedGroups *[]*string `field:"optional" json:"advertisedGroups" yaml:"advertisedGroups"`
// advertised_ip_ranges block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_compute_router#advertised_ip_ranges GoogleComputeRouter#advertised_ip_ranges}
AdvertisedIpRanges interface{} `field:"optional" json:"advertisedIpRanges" yaml:"advertisedIpRanges"`
// User-specified flag to indicate which mode to use for advertisement. Default value: "DEFAULT" Possible values: ["DEFAULT", "CUSTOM"].
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_compute_router#advertise_mode GoogleComputeRouter#advertise_mode}
AdvertiseMode *string `field:"optional" json:"advertiseMode" yaml:"advertiseMode"`
// Explicitly specifies a range of valid BGP Identifiers for this Router.
//
// It is provided as a link-local IPv4 range (from 169.254.0.0/16), of
// size at least /30, even if the BGP sessions are over IPv6. It must
// not overlap with any IPv4 BGP session ranges. Other vendors commonly
// call this router ID.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_compute_router#identifier_range GoogleComputeRouter#identifier_range}
IdentifierRange *string `field:"optional" json:"identifierRange" yaml:"identifierRange"`
// The interval in seconds between BGP keepalive messages that are sent to the peer.
//
// Hold time is three times the interval at which keepalive
// messages are sent, and the hold time is the maximum number of seconds
// allowed to elapse between successive keepalive messages that BGP
// receives from a peer.
//
// BGP will use the smaller of either the local hold time value or the
// peer's hold time value as the hold time for the BGP connection
// between the two peers. If set, this value must be between 20 and 60.
// The default is 20.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_compute_router#keepalive_interval GoogleComputeRouter#keepalive_interval}
KeepaliveInterval *float64 `field:"optional" json:"keepaliveInterval" yaml:"keepaliveInterval"`
}
type GoogleComputeRouterBgpAdvertisedIpRanges ¶
type GoogleComputeRouterBgpAdvertisedIpRanges struct {
// The IP range to advertise. The value must be a CIDR-formatted string.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_compute_router#range GoogleComputeRouter#range}
Range *string `field:"required" json:"range" yaml:"range"`
// User-specified description for the IP range.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_compute_router#description GoogleComputeRouter#description}
Description *string `field:"optional" json:"description" yaml:"description"`
}
type GoogleComputeRouterBgpAdvertisedIpRangesList ¶
type GoogleComputeRouterBgpAdvertisedIpRangesList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) GoogleComputeRouterBgpAdvertisedIpRangesOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleComputeRouterBgpAdvertisedIpRangesList ¶
func NewGoogleComputeRouterBgpAdvertisedIpRangesList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GoogleComputeRouterBgpAdvertisedIpRangesList
type GoogleComputeRouterBgpAdvertisedIpRangesOutputReference ¶
type GoogleComputeRouterBgpAdvertisedIpRangesOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Description() *string
SetDescription(val *string)
DescriptionInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Range() *string
SetRange(val *string)
RangeInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetDescription()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleComputeRouterBgpAdvertisedIpRangesOutputReference ¶
func NewGoogleComputeRouterBgpAdvertisedIpRangesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GoogleComputeRouterBgpAdvertisedIpRangesOutputReference
type GoogleComputeRouterBgpOutputReference ¶
type GoogleComputeRouterBgpOutputReference interface {
cdktf.ComplexObject
AdvertisedGroups() *[]*string
SetAdvertisedGroups(val *[]*string)
AdvertisedGroupsInput() *[]*string
AdvertisedIpRanges() GoogleComputeRouterBgpAdvertisedIpRangesList
AdvertisedIpRangesInput() interface{}
AdvertiseMode() *string
SetAdvertiseMode(val *string)
AdvertiseModeInput() *string
Asn() *float64
SetAsn(val *float64)
AsnInput() *float64
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
IdentifierRange() *string
SetIdentifierRange(val *string)
IdentifierRangeInput() *string
InternalValue() *GoogleComputeRouterBgp
SetInternalValue(val *GoogleComputeRouterBgp)
KeepaliveInterval() *float64
SetKeepaliveInterval(val *float64)
KeepaliveIntervalInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutAdvertisedIpRanges(value interface{})
ResetAdvertisedGroups()
ResetAdvertisedIpRanges()
ResetAdvertiseMode()
ResetIdentifierRange()
ResetKeepaliveInterval()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleComputeRouterBgpOutputReference ¶
func NewGoogleComputeRouterBgpOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleComputeRouterBgpOutputReference
type GoogleComputeRouterConfig ¶
type GoogleComputeRouterConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Name of the resource.
//
// The name must be 1-63 characters long, and
// comply with RFC1035. Specifically, the name must be 1-63 characters
// long and match the regular expression '[a-z]([-a-z0-9]*[a-z0-9])?'
// which means the first character must be a lowercase letter, and all
// following characters must be a dash, lowercase letter, or digit,
// except the last character, which cannot be a dash.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_compute_router#name GoogleComputeRouter#name}
Name *string `field:"required" json:"name" yaml:"name"`
// A reference to the network to which this router belongs.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_compute_router#network GoogleComputeRouter#network}
Network *string `field:"required" json:"network" yaml:"network"`
// bgp block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_compute_router#bgp GoogleComputeRouter#bgp}
Bgp *GoogleComputeRouterBgp `field:"optional" json:"bgp" yaml:"bgp"`
// An optional description of this resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_compute_router#description GoogleComputeRouter#description}
Description *string `field:"optional" json:"description" yaml:"description"`
// Indicates if a router is dedicated for use with encrypted VLAN attachments (interconnectAttachments).
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_compute_router#encrypted_interconnect_router GoogleComputeRouter#encrypted_interconnect_router}
EncryptedInterconnectRouter interface{} `field:"optional" json:"encryptedInterconnectRouter" yaml:"encryptedInterconnectRouter"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_compute_router#id GoogleComputeRouter#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_compute_router#project GoogleComputeRouter#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// Region where the router resides.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_compute_router#region GoogleComputeRouter#region}
Region *string `field:"optional" json:"region" yaml:"region"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_compute_router#timeouts GoogleComputeRouter#timeouts}
Timeouts *GoogleComputeRouterTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type GoogleComputeRouterTimeouts ¶
type GoogleComputeRouterTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_compute_router#create GoogleComputeRouter#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_compute_router#delete GoogleComputeRouter#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_compute_router#update GoogleComputeRouter#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type GoogleComputeRouterTimeoutsOutputReference ¶
type GoogleComputeRouterTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleComputeRouterTimeoutsOutputReference ¶
func NewGoogleComputeRouterTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleComputeRouterTimeoutsOutputReference
Source Files
¶
- GoogleComputeRouter.go
- GoogleComputeRouterBgp.go
- GoogleComputeRouterBgpAdvertisedIpRanges.go
- GoogleComputeRouterBgpAdvertisedIpRangesList.go
- GoogleComputeRouterBgpAdvertisedIpRangesList__checks.go
- GoogleComputeRouterBgpAdvertisedIpRangesOutputReference.go
- GoogleComputeRouterBgpAdvertisedIpRangesOutputReference__checks.go
- GoogleComputeRouterBgpOutputReference.go
- GoogleComputeRouterBgpOutputReference__checks.go
- GoogleComputeRouterConfig.go
- GoogleComputeRouterTimeouts.go
- GoogleComputeRouterTimeoutsOutputReference.go
- GoogleComputeRouterTimeoutsOutputReference__checks.go
- GoogleComputeRouter__checks.go
- main.go