Documentation
¶
Index ¶
- func GoogleIntegrationsClient_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func GoogleIntegrationsClient_IsConstruct(x interface{}) *bool
- func GoogleIntegrationsClient_IsTerraformElement(x interface{}) *bool
- func GoogleIntegrationsClient_IsTerraformResource(x interface{}) *bool
- func GoogleIntegrationsClient_TfResourceType() *string
- func NewGoogleIntegrationsClientCloudKmsConfigOutputReference_Override(g GoogleIntegrationsClientCloudKmsConfigOutputReference, ...)
- func NewGoogleIntegrationsClientTimeoutsOutputReference_Override(g GoogleIntegrationsClientTimeoutsOutputReference, ...)
- func NewGoogleIntegrationsClient_Override(g GoogleIntegrationsClient, scope constructs.Construct, id *string, ...)
- type GoogleIntegrationsClient
- type GoogleIntegrationsClientCloudKmsConfig
- type GoogleIntegrationsClientCloudKmsConfigOutputReference
- type GoogleIntegrationsClientConfig
- type GoogleIntegrationsClientTimeouts
- type GoogleIntegrationsClientTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleIntegrationsClient_GenerateConfigForImport ¶
func GoogleIntegrationsClient_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a GoogleIntegrationsClient resource upon running "cdktf plan <stack-name>".
func GoogleIntegrationsClient_IsConstruct ¶
func GoogleIntegrationsClient_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleIntegrationsClient_IsTerraformElement ¶
func GoogleIntegrationsClient_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleIntegrationsClient_IsTerraformResource ¶
func GoogleIntegrationsClient_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleIntegrationsClient_TfResourceType ¶
func GoogleIntegrationsClient_TfResourceType() *string
func NewGoogleIntegrationsClientCloudKmsConfigOutputReference_Override ¶
func NewGoogleIntegrationsClientCloudKmsConfigOutputReference_Override(g GoogleIntegrationsClientCloudKmsConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleIntegrationsClientTimeoutsOutputReference_Override ¶
func NewGoogleIntegrationsClientTimeoutsOutputReference_Override(g GoogleIntegrationsClientTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleIntegrationsClient_Override ¶
func NewGoogleIntegrationsClient_Override(g GoogleIntegrationsClient, scope constructs.Construct, id *string, config *GoogleIntegrationsClientConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_integrations_client google_integrations_client} Resource.
Types ¶
type GoogleIntegrationsClient ¶
type GoogleIntegrationsClient interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
CloudKmsConfig() GoogleIntegrationsClientCloudKmsConfigOutputReference
CloudKmsConfigInput() *GoogleIntegrationsClientCloudKmsConfig
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
CreateSampleIntegrations() interface{}
SetCreateSampleIntegrations(val interface{})
CreateSampleIntegrationsInput() interface{}
CreateSampleWorkflows() interface{}
SetCreateSampleWorkflows(val interface{})
CreateSampleWorkflowsInput() interface{}
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Location() *string
SetLocation(val *string)
LocationInput() *string
// The tree node.
Node() constructs.Node
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
ProvisionGmek() interface{}
SetProvisionGmek(val interface{})
ProvisionGmekInput() interface{}
// Experimental.
RawOverrides() interface{}
RunAsServiceAccount() *string
SetRunAsServiceAccount(val *string)
RunAsServiceAccountInput() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GoogleIntegrationsClientTimeoutsOutputReference
TimeoutsInput() interface{}
// Adds a user defined moveTarget string to this resource to be later used in .moveTo(moveTarget) to resolve the location of the move.
// Experimental.
AddMoveTarget(moveTarget *string)
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
HasResourceMove() interface{}
// Experimental.
ImportFrom(id *string, provider cdktf.TerraformProvider)
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Move the resource corresponding to "id" to this resource.
//
// Note that the resource being moved from must be marked as moved using it's instance function.
// Experimental.
MoveFromId(id *string)
// Moves this resource to the target resource given by moveTarget.
// Experimental.
MoveTo(moveTarget *string, index interface{})
// Moves this resource to the resource corresponding to "id".
// Experimental.
MoveToId(id *string)
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutCloudKmsConfig(value *GoogleIntegrationsClientCloudKmsConfig)
PutTimeouts(value *GoogleIntegrationsClientTimeouts)
ResetCloudKmsConfig()
ResetCreateSampleIntegrations()
ResetCreateSampleWorkflows()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
ResetProvisionGmek()
ResetRunAsServiceAccount()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
SynthesizeHclAttributes() *map[string]interface{}
// Experimental.
ToHclTerraform() interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_integrations_client google_integrations_client}.
func NewGoogleIntegrationsClient ¶
func NewGoogleIntegrationsClient(scope constructs.Construct, id *string, config *GoogleIntegrationsClientConfig) GoogleIntegrationsClient
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_integrations_client google_integrations_client} Resource.
type GoogleIntegrationsClientCloudKmsConfig ¶
type GoogleIntegrationsClientCloudKmsConfig struct {
// A Cloud KMS key is a named object containing one or more key versions, along with metadata for the key.
//
// A key exists on exactly one key ring tied to a
// specific location.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_integrations_client#key GoogleIntegrationsClient#key}
Key *string `field:"required" json:"key" yaml:"key"`
// Location name of the key ring, e.g. "us-west1".
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_integrations_client#kms_location GoogleIntegrationsClient#kms_location}
KmsLocation *string `field:"required" json:"kmsLocation" yaml:"kmsLocation"`
// A key ring organizes keys in a specific Google Cloud location and allows you to manage access control on groups of keys.
//
// A key ring's name does not need to be
// unique across a Google Cloud project, but must be unique within a given location.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_integrations_client#kms_ring GoogleIntegrationsClient#kms_ring}
KmsRing *string `field:"required" json:"kmsRing" yaml:"kmsRing"`
// Each version of a key contains key material used for encryption or signing.
//
// A key's version is represented by an integer, starting at 1. To decrypt data
// or verify a signature, you must use the same key version that was used to
// encrypt or sign the data.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_integrations_client#key_version GoogleIntegrationsClient#key_version}
KeyVersion *string `field:"optional" json:"keyVersion" yaml:"keyVersion"`
// The Google Cloud project id of the project where the kms key stored.
//
// If empty,
// the kms key is stored at the same project as customer's project and ecrypted
// with CMEK, otherwise, the kms key is stored in the tenant project and
// encrypted with GMEK.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_integrations_client#kms_project_id GoogleIntegrationsClient#kms_project_id}
KmsProjectId *string `field:"optional" json:"kmsProjectId" yaml:"kmsProjectId"`
}
type GoogleIntegrationsClientCloudKmsConfigOutputReference ¶
type GoogleIntegrationsClientCloudKmsConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleIntegrationsClientCloudKmsConfig
SetInternalValue(val *GoogleIntegrationsClientCloudKmsConfig)
Key() *string
SetKey(val *string)
KeyInput() *string
KeyVersion() *string
SetKeyVersion(val *string)
KeyVersionInput() *string
KmsLocation() *string
SetKmsLocation(val *string)
KmsLocationInput() *string
KmsProjectId() *string
SetKmsProjectId(val *string)
KmsProjectIdInput() *string
KmsRing() *string
SetKmsRing(val *string)
KmsRingInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetKeyVersion()
ResetKmsProjectId()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleIntegrationsClientCloudKmsConfigOutputReference ¶
func NewGoogleIntegrationsClientCloudKmsConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleIntegrationsClientCloudKmsConfigOutputReference
type GoogleIntegrationsClientConfig ¶
type GoogleIntegrationsClientConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Location in which client needs to be provisioned.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_integrations_client#location GoogleIntegrationsClient#location}
Location *string `field:"required" json:"location" yaml:"location"`
// cloud_kms_config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_integrations_client#cloud_kms_config GoogleIntegrationsClient#cloud_kms_config}
CloudKmsConfig *GoogleIntegrationsClientCloudKmsConfig `field:"optional" json:"cloudKmsConfig" yaml:"cloudKmsConfig"`
// Indicates if sample integrations should be created along with provisioning.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_integrations_client#create_sample_integrations GoogleIntegrationsClient#create_sample_integrations}
CreateSampleIntegrations interface{} `field:"optional" json:"createSampleIntegrations" yaml:"createSampleIntegrations"`
// Indicates if sample workflow should be created along with provisioning.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_integrations_client#create_sample_workflows GoogleIntegrationsClient#create_sample_workflows}
CreateSampleWorkflows interface{} `field:"optional" json:"createSampleWorkflows" yaml:"createSampleWorkflows"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_integrations_client#id GoogleIntegrationsClient#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_integrations_client#project GoogleIntegrationsClient#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// Indicates provision with GMEK or CMEK.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_integrations_client#provision_gmek GoogleIntegrationsClient#provision_gmek}
ProvisionGmek interface{} `field:"optional" json:"provisionGmek" yaml:"provisionGmek"`
// User input run-as service account, if empty, will bring up a new default service account.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_integrations_client#run_as_service_account GoogleIntegrationsClient#run_as_service_account}
RunAsServiceAccount *string `field:"optional" json:"runAsServiceAccount" yaml:"runAsServiceAccount"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_integrations_client#timeouts GoogleIntegrationsClient#timeouts}
Timeouts *GoogleIntegrationsClientTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type GoogleIntegrationsClientTimeouts ¶
type GoogleIntegrationsClientTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_integrations_client#create GoogleIntegrationsClient#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.39.1/docs/resources/google_integrations_client#delete GoogleIntegrationsClient#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
}
type GoogleIntegrationsClientTimeoutsOutputReference ¶
type GoogleIntegrationsClientTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleIntegrationsClientTimeoutsOutputReference ¶
func NewGoogleIntegrationsClientTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleIntegrationsClientTimeoutsOutputReference
Source Files
¶
- GoogleIntegrationsClient.go
- GoogleIntegrationsClientCloudKmsConfig.go
- GoogleIntegrationsClientCloudKmsConfigOutputReference.go
- GoogleIntegrationsClientCloudKmsConfigOutputReference__checks.go
- GoogleIntegrationsClientConfig.go
- GoogleIntegrationsClientTimeouts.go
- GoogleIntegrationsClientTimeoutsOutputReference.go
- GoogleIntegrationsClientTimeoutsOutputReference__checks.go
- GoogleIntegrationsClient__checks.go
- main.go