Documentation
¶
Index ¶
- func GoogleSecurityposturePostureDeployment_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func GoogleSecurityposturePostureDeployment_IsConstruct(x interface{}) *bool
- func GoogleSecurityposturePostureDeployment_IsTerraformElement(x interface{}) *bool
- func GoogleSecurityposturePostureDeployment_IsTerraformResource(x interface{}) *bool
- func GoogleSecurityposturePostureDeployment_TfResourceType() *string
- func NewGoogleSecurityposturePostureDeploymentTimeoutsOutputReference_Override(g GoogleSecurityposturePostureDeploymentTimeoutsOutputReference, ...)
- func NewGoogleSecurityposturePostureDeployment_Override(g GoogleSecurityposturePostureDeployment, scope constructs.Construct, ...)
- type GoogleSecurityposturePostureDeployment
- type GoogleSecurityposturePostureDeploymentConfig
- type GoogleSecurityposturePostureDeploymentTimeouts
- type GoogleSecurityposturePostureDeploymentTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleSecurityposturePostureDeployment_GenerateConfigForImport ¶
func GoogleSecurityposturePostureDeployment_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a GoogleSecurityposturePostureDeployment resource upon running "cdktf plan <stack-name>".
func GoogleSecurityposturePostureDeployment_IsConstruct ¶
func GoogleSecurityposturePostureDeployment_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleSecurityposturePostureDeployment_IsTerraformElement ¶
func GoogleSecurityposturePostureDeployment_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleSecurityposturePostureDeployment_IsTerraformResource ¶
func GoogleSecurityposturePostureDeployment_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleSecurityposturePostureDeployment_TfResourceType ¶
func GoogleSecurityposturePostureDeployment_TfResourceType() *string
func NewGoogleSecurityposturePostureDeploymentTimeoutsOutputReference_Override ¶
func NewGoogleSecurityposturePostureDeploymentTimeoutsOutputReference_Override(g GoogleSecurityposturePostureDeploymentTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleSecurityposturePostureDeployment_Override ¶
func NewGoogleSecurityposturePostureDeployment_Override(g GoogleSecurityposturePostureDeployment, scope constructs.Construct, id *string, config *GoogleSecurityposturePostureDeploymentConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_securityposture_posture_deployment google_securityposture_posture_deployment} Resource.
Types ¶
type GoogleSecurityposturePostureDeployment ¶
type GoogleSecurityposturePostureDeployment interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
CreateTime() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
DesiredPostureId() *string
DesiredPostureRevisionId() *string
Etag() *string
FailureMessage() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Location() *string
SetLocation(val *string)
LocationInput() *string
Name() *string
// The tree node.
Node() constructs.Node
Parent() *string
SetParent(val *string)
ParentInput() *string
PostureDeploymentId() *string
SetPostureDeploymentId(val *string)
PostureDeploymentIdInput() *string
PostureId() *string
SetPostureId(val *string)
PostureIdInput() *string
PostureRevisionId() *string
SetPostureRevisionId(val *string)
PostureRevisionIdInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Reconciling() cdktf.IResolvable
State() *string
TargetResource() *string
SetTargetResource(val *string)
TargetResourceInput() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GoogleSecurityposturePostureDeploymentTimeoutsOutputReference
TimeoutsInput() interface{}
UpdateTime() *string
// Adds a user defined moveTarget string to this resource to be later used in .moveTo(moveTarget) to resolve the location of the move.
// Experimental.
AddMoveTarget(moveTarget *string)
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
HasResourceMove() interface{}
// Experimental.
ImportFrom(id *string, provider cdktf.TerraformProvider)
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Move the resource corresponding to "id" to this resource.
//
// Note that the resource being moved from must be marked as moved using it's instance function.
// Experimental.
MoveFromId(id *string)
// Moves this resource to the target resource given by moveTarget.
// Experimental.
MoveTo(moveTarget *string, index interface{})
// Moves this resource to the resource corresponding to "id".
// Experimental.
MoveToId(id *string)
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutTimeouts(value *GoogleSecurityposturePostureDeploymentTimeouts)
ResetDescription()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
SynthesizeHclAttributes() *map[string]interface{}
// Experimental.
ToHclTerraform() interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_securityposture_posture_deployment google_securityposture_posture_deployment}.
func NewGoogleSecurityposturePostureDeployment ¶
func NewGoogleSecurityposturePostureDeployment(scope constructs.Construct, id *string, config *GoogleSecurityposturePostureDeploymentConfig) GoogleSecurityposturePostureDeployment
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_securityposture_posture_deployment google_securityposture_posture_deployment} Resource.
type GoogleSecurityposturePostureDeploymentConfig ¶
type GoogleSecurityposturePostureDeploymentConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// The location of the resource, eg. global'.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_securityposture_posture_deployment#location GoogleSecurityposturePostureDeployment#location}
Location *string `field:"required" json:"location" yaml:"location"`
// The parent of the resource, an organization. Format should be 'organizations/{organization_id}'.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_securityposture_posture_deployment#parent GoogleSecurityposturePostureDeployment#parent}
Parent *string `field:"required" json:"parent" yaml:"parent"`
// ID of the posture deployment.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_securityposture_posture_deployment#posture_deployment_id GoogleSecurityposturePostureDeployment#posture_deployment_id}
PostureDeploymentId *string `field:"required" json:"postureDeploymentId" yaml:"postureDeploymentId"`
// Relative name of the posture which needs to be deployed. It should be in the format: organizations/{organization_id}/locations/{location}/postures/{posture_id}.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_securityposture_posture_deployment#posture_id GoogleSecurityposturePostureDeployment#posture_id}
PostureId *string `field:"required" json:"postureId" yaml:"postureId"`
// Revision_id the posture which needs to be deployed.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_securityposture_posture_deployment#posture_revision_id GoogleSecurityposturePostureDeployment#posture_revision_id}
PostureRevisionId *string `field:"required" json:"postureRevisionId" yaml:"postureRevisionId"`
// The resource on which the posture should be deployed. This can be in one of the following formats: projects/{project_number}, folders/{folder_number}, organizations/{organization_id}.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_securityposture_posture_deployment#target_resource GoogleSecurityposturePostureDeployment#target_resource}
TargetResource *string `field:"required" json:"targetResource" yaml:"targetResource"`
// Description of the posture deployment.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_securityposture_posture_deployment#description GoogleSecurityposturePostureDeployment#description}
Description *string `field:"optional" json:"description" yaml:"description"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_securityposture_posture_deployment#id GoogleSecurityposturePostureDeployment#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_securityposture_posture_deployment#timeouts GoogleSecurityposturePostureDeployment#timeouts}
Timeouts *GoogleSecurityposturePostureDeploymentTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type GoogleSecurityposturePostureDeploymentTimeouts ¶
type GoogleSecurityposturePostureDeploymentTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_securityposture_posture_deployment#create GoogleSecurityposturePostureDeployment#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_securityposture_posture_deployment#delete GoogleSecurityposturePostureDeployment#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_securityposture_posture_deployment#update GoogleSecurityposturePostureDeployment#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type GoogleSecurityposturePostureDeploymentTimeoutsOutputReference ¶
type GoogleSecurityposturePostureDeploymentTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleSecurityposturePostureDeploymentTimeoutsOutputReference ¶
func NewGoogleSecurityposturePostureDeploymentTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleSecurityposturePostureDeploymentTimeoutsOutputReference
Source Files
¶
- GoogleSecurityposturePostureDeployment.go
- GoogleSecurityposturePostureDeploymentConfig.go
- GoogleSecurityposturePostureDeploymentTimeouts.go
- GoogleSecurityposturePostureDeploymentTimeoutsOutputReference.go
- GoogleSecurityposturePostureDeploymentTimeoutsOutputReference__checks.go
- GoogleSecurityposturePostureDeployment__checks.go
- main.go