Documentation
¶
Index ¶
- func GoogleSourcerepoRepository_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func GoogleSourcerepoRepository_IsConstruct(x interface{}) *bool
- func GoogleSourcerepoRepository_IsTerraformElement(x interface{}) *bool
- func GoogleSourcerepoRepository_IsTerraformResource(x interface{}) *bool
- func GoogleSourcerepoRepository_TfResourceType() *string
- func NewGoogleSourcerepoRepositoryPubsubConfigsList_Override(g GoogleSourcerepoRepositoryPubsubConfigsList, ...)
- func NewGoogleSourcerepoRepositoryPubsubConfigsOutputReference_Override(g GoogleSourcerepoRepositoryPubsubConfigsOutputReference, ...)
- func NewGoogleSourcerepoRepositoryTimeoutsOutputReference_Override(g GoogleSourcerepoRepositoryTimeoutsOutputReference, ...)
- func NewGoogleSourcerepoRepository_Override(g GoogleSourcerepoRepository, scope constructs.Construct, id *string, ...)
- type GoogleSourcerepoRepository
- type GoogleSourcerepoRepositoryConfig
- type GoogleSourcerepoRepositoryPubsubConfigs
- type GoogleSourcerepoRepositoryPubsubConfigsList
- type GoogleSourcerepoRepositoryPubsubConfigsOutputReference
- type GoogleSourcerepoRepositoryTimeouts
- type GoogleSourcerepoRepositoryTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleSourcerepoRepository_GenerateConfigForImport ¶
func GoogleSourcerepoRepository_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a GoogleSourcerepoRepository resource upon running "cdktf plan <stack-name>".
func GoogleSourcerepoRepository_IsConstruct ¶
func GoogleSourcerepoRepository_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleSourcerepoRepository_IsTerraformElement ¶
func GoogleSourcerepoRepository_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleSourcerepoRepository_IsTerraformResource ¶
func GoogleSourcerepoRepository_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleSourcerepoRepository_TfResourceType ¶
func GoogleSourcerepoRepository_TfResourceType() *string
func NewGoogleSourcerepoRepositoryPubsubConfigsList_Override ¶
func NewGoogleSourcerepoRepositoryPubsubConfigsList_Override(g GoogleSourcerepoRepositoryPubsubConfigsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGoogleSourcerepoRepositoryPubsubConfigsOutputReference_Override ¶
func NewGoogleSourcerepoRepositoryPubsubConfigsOutputReference_Override(g GoogleSourcerepoRepositoryPubsubConfigsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGoogleSourcerepoRepositoryTimeoutsOutputReference_Override ¶
func NewGoogleSourcerepoRepositoryTimeoutsOutputReference_Override(g GoogleSourcerepoRepositoryTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleSourcerepoRepository_Override ¶
func NewGoogleSourcerepoRepository_Override(g GoogleSourcerepoRepository, scope constructs.Construct, id *string, config *GoogleSourcerepoRepositoryConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_sourcerepo_repository google_sourcerepo_repository} Resource.
Types ¶
type GoogleSourcerepoRepository ¶
type GoogleSourcerepoRepository interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
PubsubConfigs() GoogleSourcerepoRepositoryPubsubConfigsList
PubsubConfigsInput() interface{}
// Experimental.
RawOverrides() interface{}
Size() *float64
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GoogleSourcerepoRepositoryTimeoutsOutputReference
TimeoutsInput() interface{}
Url() *string
// Adds a user defined moveTarget string to this resource to be later used in .moveTo(moveTarget) to resolve the location of the move.
// Experimental.
AddMoveTarget(moveTarget *string)
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
HasResourceMove() interface{}
// Experimental.
ImportFrom(id *string, provider cdktf.TerraformProvider)
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Move the resource corresponding to "id" to this resource.
//
// Note that the resource being moved from must be marked as moved using it's instance function.
// Experimental.
MoveFromId(id *string)
// Moves this resource to the target resource given by moveTarget.
// Experimental.
MoveTo(moveTarget *string, index interface{})
// Moves this resource to the resource corresponding to "id".
// Experimental.
MoveToId(id *string)
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutPubsubConfigs(value interface{})
PutTimeouts(value *GoogleSourcerepoRepositoryTimeouts)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
ResetPubsubConfigs()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
SynthesizeHclAttributes() *map[string]interface{}
// Experimental.
ToHclTerraform() interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_sourcerepo_repository google_sourcerepo_repository}.
func NewGoogleSourcerepoRepository ¶
func NewGoogleSourcerepoRepository(scope constructs.Construct, id *string, config *GoogleSourcerepoRepositoryConfig) GoogleSourcerepoRepository
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_sourcerepo_repository google_sourcerepo_repository} Resource.
type GoogleSourcerepoRepositoryConfig ¶
type GoogleSourcerepoRepositoryConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Resource name of the repository, of the form '{{repo}}'. The repo name may contain slashes. eg, 'name/with/slash'.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_sourcerepo_repository#name GoogleSourcerepoRepository#name}
Name *string `field:"required" json:"name" yaml:"name"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_sourcerepo_repository#id GoogleSourcerepoRepository#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_sourcerepo_repository#project GoogleSourcerepoRepository#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// pubsub_configs block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_sourcerepo_repository#pubsub_configs GoogleSourcerepoRepository#pubsub_configs}
PubsubConfigs interface{} `field:"optional" json:"pubsubConfigs" yaml:"pubsubConfigs"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_sourcerepo_repository#timeouts GoogleSourcerepoRepository#timeouts}
Timeouts *GoogleSourcerepoRepositoryTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type GoogleSourcerepoRepositoryPubsubConfigs ¶
type GoogleSourcerepoRepositoryPubsubConfigs struct {
// The format of the Cloud Pub/Sub messages.
//
// - PROTOBUF: The message payload is a serialized protocol buffer of SourceRepoEvent.
// - JSON: The message payload is a JSON string of SourceRepoEvent. Possible values: ["PROTOBUF", "JSON"]
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_sourcerepo_repository#message_format GoogleSourcerepoRepository#message_format}
MessageFormat *string `field:"required" json:"messageFormat" yaml:"messageFormat"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_sourcerepo_repository#topic GoogleSourcerepoRepository#topic}.
Topic *string `field:"required" json:"topic" yaml:"topic"`
// Email address of the service account used for publishing Cloud Pub/Sub messages.
//
// This service account needs to be in the same project as the PubsubConfig. When added,
// the caller needs to have iam.serviceAccounts.actAs permission on this service account.
// If unspecified, it defaults to the compute engine default service account.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_sourcerepo_repository#service_account_email GoogleSourcerepoRepository#service_account_email}
ServiceAccountEmail *string `field:"optional" json:"serviceAccountEmail" yaml:"serviceAccountEmail"`
}
type GoogleSourcerepoRepositoryPubsubConfigsList ¶
type GoogleSourcerepoRepositoryPubsubConfigsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) GoogleSourcerepoRepositoryPubsubConfigsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleSourcerepoRepositoryPubsubConfigsList ¶
func NewGoogleSourcerepoRepositoryPubsubConfigsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GoogleSourcerepoRepositoryPubsubConfigsList
type GoogleSourcerepoRepositoryPubsubConfigsOutputReference ¶
type GoogleSourcerepoRepositoryPubsubConfigsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
MessageFormat() *string
SetMessageFormat(val *string)
MessageFormatInput() *string
ServiceAccountEmail() *string
SetServiceAccountEmail(val *string)
ServiceAccountEmailInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Topic() *string
SetTopic(val *string)
TopicInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetServiceAccountEmail()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleSourcerepoRepositoryPubsubConfigsOutputReference ¶
func NewGoogleSourcerepoRepositoryPubsubConfigsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GoogleSourcerepoRepositoryPubsubConfigsOutputReference
type GoogleSourcerepoRepositoryTimeouts ¶
type GoogleSourcerepoRepositoryTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_sourcerepo_repository#create GoogleSourcerepoRepository#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_sourcerepo_repository#delete GoogleSourcerepoRepository#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/5.43.1/docs/resources/google_sourcerepo_repository#update GoogleSourcerepoRepository#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type GoogleSourcerepoRepositoryTimeoutsOutputReference ¶
type GoogleSourcerepoRepositoryTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleSourcerepoRepositoryTimeoutsOutputReference ¶
func NewGoogleSourcerepoRepositoryTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleSourcerepoRepositoryTimeoutsOutputReference
Source Files
¶
- GoogleSourcerepoRepository.go
- GoogleSourcerepoRepositoryConfig.go
- GoogleSourcerepoRepositoryPubsubConfigs.go
- GoogleSourcerepoRepositoryPubsubConfigsList.go
- GoogleSourcerepoRepositoryPubsubConfigsList__checks.go
- GoogleSourcerepoRepositoryPubsubConfigsOutputReference.go
- GoogleSourcerepoRepositoryPubsubConfigsOutputReference__checks.go
- GoogleSourcerepoRepositoryTimeouts.go
- GoogleSourcerepoRepositoryTimeoutsOutputReference.go
- GoogleSourcerepoRepositoryTimeoutsOutputReference__checks.go
- GoogleSourcerepoRepository__checks.go
- main.go