Documentation
¶
Index ¶
- func DataGoogleVmwareengineExternalAccessRule_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func DataGoogleVmwareengineExternalAccessRule_IsConstruct(x interface{}) *bool
- func DataGoogleVmwareengineExternalAccessRule_IsTerraformDataSource(x interface{}) *bool
- func DataGoogleVmwareengineExternalAccessRule_IsTerraformElement(x interface{}) *bool
- func DataGoogleVmwareengineExternalAccessRule_TfResourceType() *string
- func NewDataGoogleVmwareengineExternalAccessRuleDestinationIpRangesList_Override(d DataGoogleVmwareengineExternalAccessRuleDestinationIpRangesList, ...)
- func NewDataGoogleVmwareengineExternalAccessRuleDestinationIpRangesOutputReference_Override(d DataGoogleVmwareengineExternalAccessRuleDestinationIpRangesOutputReference, ...)
- func NewDataGoogleVmwareengineExternalAccessRuleSourceIpRangesList_Override(d DataGoogleVmwareengineExternalAccessRuleSourceIpRangesList, ...)
- func NewDataGoogleVmwareengineExternalAccessRuleSourceIpRangesOutputReference_Override(d DataGoogleVmwareengineExternalAccessRuleSourceIpRangesOutputReference, ...)
- func NewDataGoogleVmwareengineExternalAccessRule_Override(d DataGoogleVmwareengineExternalAccessRule, scope constructs.Construct, ...)
- type DataGoogleVmwareengineExternalAccessRule
- type DataGoogleVmwareengineExternalAccessRuleConfig
- type DataGoogleVmwareengineExternalAccessRuleDestinationIpRanges
- type DataGoogleVmwareengineExternalAccessRuleDestinationIpRangesList
- type DataGoogleVmwareengineExternalAccessRuleDestinationIpRangesOutputReference
- type DataGoogleVmwareengineExternalAccessRuleSourceIpRanges
- type DataGoogleVmwareengineExternalAccessRuleSourceIpRangesList
- type DataGoogleVmwareengineExternalAccessRuleSourceIpRangesOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DataGoogleVmwareengineExternalAccessRule_GenerateConfigForImport ¶
func DataGoogleVmwareengineExternalAccessRule_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a DataGoogleVmwareengineExternalAccessRule resource upon running "cdktf plan <stack-name>".
func DataGoogleVmwareengineExternalAccessRule_IsConstruct ¶
func DataGoogleVmwareengineExternalAccessRule_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func DataGoogleVmwareengineExternalAccessRule_IsTerraformDataSource ¶
func DataGoogleVmwareengineExternalAccessRule_IsTerraformDataSource(x interface{}) *bool
Experimental.
func DataGoogleVmwareengineExternalAccessRule_IsTerraformElement ¶
func DataGoogleVmwareengineExternalAccessRule_IsTerraformElement(x interface{}) *bool
Experimental.
func DataGoogleVmwareengineExternalAccessRule_TfResourceType ¶
func DataGoogleVmwareengineExternalAccessRule_TfResourceType() *string
func NewDataGoogleVmwareengineExternalAccessRuleDestinationIpRangesList_Override ¶
func NewDataGoogleVmwareengineExternalAccessRuleDestinationIpRangesList_Override(d DataGoogleVmwareengineExternalAccessRuleDestinationIpRangesList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataGoogleVmwareengineExternalAccessRuleDestinationIpRangesOutputReference_Override ¶
func NewDataGoogleVmwareengineExternalAccessRuleDestinationIpRangesOutputReference_Override(d DataGoogleVmwareengineExternalAccessRuleDestinationIpRangesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataGoogleVmwareengineExternalAccessRuleSourceIpRangesList_Override ¶
func NewDataGoogleVmwareengineExternalAccessRuleSourceIpRangesList_Override(d DataGoogleVmwareengineExternalAccessRuleSourceIpRangesList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewDataGoogleVmwareengineExternalAccessRuleSourceIpRangesOutputReference_Override ¶
func NewDataGoogleVmwareengineExternalAccessRuleSourceIpRangesOutputReference_Override(d DataGoogleVmwareengineExternalAccessRuleSourceIpRangesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewDataGoogleVmwareengineExternalAccessRule_Override ¶
func NewDataGoogleVmwareengineExternalAccessRule_Override(d DataGoogleVmwareengineExternalAccessRule, scope constructs.Construct, id *string, config *DataGoogleVmwareengineExternalAccessRuleConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/data-sources/google_vmwareengine_external_access_rule google_vmwareengine_external_access_rule} Data Source.
Types ¶
type DataGoogleVmwareengineExternalAccessRule ¶
type DataGoogleVmwareengineExternalAccessRule interface {
cdktf.TerraformDataSource
Action() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
CreateTime() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
DestinationIpRanges() DataGoogleVmwareengineExternalAccessRuleDestinationIpRangesList
DestinationPorts() *[]*string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
IpProtocol() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
Parent() *string
SetParent(val *string)
ParentInput() *string
Priority() *float64
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
RawOverrides() interface{}
SourceIpRanges() DataGoogleVmwareengineExternalAccessRuleSourceIpRangesList
SourcePorts() *[]*string
State() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Uid() *string
UpdateTime() *string
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
SynthesizeAttributes() *map[string]interface{}
SynthesizeHclAttributes() *map[string]interface{}
// Adds this resource to the terraform JSON output.
// Experimental.
ToHclTerraform() interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/data-sources/google_vmwareengine_external_access_rule google_vmwareengine_external_access_rule}.
func NewDataGoogleVmwareengineExternalAccessRule ¶
func NewDataGoogleVmwareengineExternalAccessRule(scope constructs.Construct, id *string, config *DataGoogleVmwareengineExternalAccessRuleConfig) DataGoogleVmwareengineExternalAccessRule
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/data-sources/google_vmwareengine_external_access_rule google_vmwareengine_external_access_rule} Data Source.
type DataGoogleVmwareengineExternalAccessRuleConfig ¶
type DataGoogleVmwareengineExternalAccessRuleConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// The ID of the external access rule.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/data-sources/google_vmwareengine_external_access_rule#name DataGoogleVmwareengineExternalAccessRule#name}
Name *string `field:"required" json:"name" yaml:"name"`
// The resource name of the network policy. Resource names are schemeless URIs that follow the conventions in https://cloud.google.com/apis/design/resource_names. For example: projects/my-project/locations/us-west1-a/networkPolicies/my-policy.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/data-sources/google_vmwareengine_external_access_rule#parent DataGoogleVmwareengineExternalAccessRule#parent}
Parent *string `field:"required" json:"parent" yaml:"parent"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/data-sources/google_vmwareengine_external_access_rule#id DataGoogleVmwareengineExternalAccessRule#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
}
type DataGoogleVmwareengineExternalAccessRuleDestinationIpRanges ¶
type DataGoogleVmwareengineExternalAccessRuleDestinationIpRanges struct {
}
type DataGoogleVmwareengineExternalAccessRuleDestinationIpRangesList ¶
type DataGoogleVmwareengineExternalAccessRuleDestinationIpRangesList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) DataGoogleVmwareengineExternalAccessRuleDestinationIpRangesOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleVmwareengineExternalAccessRuleDestinationIpRangesList ¶
func NewDataGoogleVmwareengineExternalAccessRuleDestinationIpRangesList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataGoogleVmwareengineExternalAccessRuleDestinationIpRangesList
type DataGoogleVmwareengineExternalAccessRuleDestinationIpRangesOutputReference ¶
type DataGoogleVmwareengineExternalAccessRuleDestinationIpRangesOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
ExternalAddress() *string
// Experimental.
Fqn() *string
InternalValue() *DataGoogleVmwareengineExternalAccessRuleDestinationIpRanges
SetInternalValue(val *DataGoogleVmwareengineExternalAccessRuleDestinationIpRanges)
IpAddressRange() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleVmwareengineExternalAccessRuleDestinationIpRangesOutputReference ¶
func NewDataGoogleVmwareengineExternalAccessRuleDestinationIpRangesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataGoogleVmwareengineExternalAccessRuleDestinationIpRangesOutputReference
type DataGoogleVmwareengineExternalAccessRuleSourceIpRanges ¶
type DataGoogleVmwareengineExternalAccessRuleSourceIpRanges struct {
}
type DataGoogleVmwareengineExternalAccessRuleSourceIpRangesList ¶
type DataGoogleVmwareengineExternalAccessRuleSourceIpRangesList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) DataGoogleVmwareengineExternalAccessRuleSourceIpRangesOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleVmwareengineExternalAccessRuleSourceIpRangesList ¶
func NewDataGoogleVmwareengineExternalAccessRuleSourceIpRangesList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) DataGoogleVmwareengineExternalAccessRuleSourceIpRangesList
type DataGoogleVmwareengineExternalAccessRuleSourceIpRangesOutputReference ¶
type DataGoogleVmwareengineExternalAccessRuleSourceIpRangesOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *DataGoogleVmwareengineExternalAccessRuleSourceIpRanges
SetInternalValue(val *DataGoogleVmwareengineExternalAccessRuleSourceIpRanges)
IpAddress() *string
IpAddressRange() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewDataGoogleVmwareengineExternalAccessRuleSourceIpRangesOutputReference ¶
func NewDataGoogleVmwareengineExternalAccessRuleSourceIpRangesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) DataGoogleVmwareengineExternalAccessRuleSourceIpRangesOutputReference
Source Files
¶
- DataGoogleVmwareengineExternalAccessRule.go
- DataGoogleVmwareengineExternalAccessRuleConfig.go
- DataGoogleVmwareengineExternalAccessRuleDestinationIpRanges.go
- DataGoogleVmwareengineExternalAccessRuleDestinationIpRangesList.go
- DataGoogleVmwareengineExternalAccessRuleDestinationIpRangesList__checks.go
- DataGoogleVmwareengineExternalAccessRuleDestinationIpRangesOutputReference.go
- DataGoogleVmwareengineExternalAccessRuleDestinationIpRangesOutputReference__checks.go
- DataGoogleVmwareengineExternalAccessRuleSourceIpRanges.go
- DataGoogleVmwareengineExternalAccessRuleSourceIpRangesList.go
- DataGoogleVmwareengineExternalAccessRuleSourceIpRangesList__checks.go
- DataGoogleVmwareengineExternalAccessRuleSourceIpRangesOutputReference.go
- DataGoogleVmwareengineExternalAccessRuleSourceIpRangesOutputReference__checks.go
- DataGoogleVmwareengineExternalAccessRule__checks.go
- main.go