Documentation
¶
Index ¶
- func GoogleApigeeSharedflow_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func GoogleApigeeSharedflow_IsConstruct(x interface{}) *bool
- func GoogleApigeeSharedflow_IsTerraformElement(x interface{}) *bool
- func GoogleApigeeSharedflow_IsTerraformResource(x interface{}) *bool
- func GoogleApigeeSharedflow_TfResourceType() *string
- func NewGoogleApigeeSharedflowMetaDataList_Override(g GoogleApigeeSharedflowMetaDataList, ...)
- func NewGoogleApigeeSharedflowMetaDataOutputReference_Override(g GoogleApigeeSharedflowMetaDataOutputReference, ...)
- func NewGoogleApigeeSharedflowTimeoutsOutputReference_Override(g GoogleApigeeSharedflowTimeoutsOutputReference, ...)
- func NewGoogleApigeeSharedflow_Override(g GoogleApigeeSharedflow, scope constructs.Construct, id *string, ...)
- type GoogleApigeeSharedflow
- type GoogleApigeeSharedflowConfig
- type GoogleApigeeSharedflowMetaData
- type GoogleApigeeSharedflowMetaDataList
- type GoogleApigeeSharedflowMetaDataOutputReference
- type GoogleApigeeSharedflowTimeouts
- type GoogleApigeeSharedflowTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleApigeeSharedflow_GenerateConfigForImport ¶
func GoogleApigeeSharedflow_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a GoogleApigeeSharedflow resource upon running "cdktf plan <stack-name>".
func GoogleApigeeSharedflow_IsConstruct ¶
func GoogleApigeeSharedflow_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleApigeeSharedflow_IsTerraformElement ¶
func GoogleApigeeSharedflow_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleApigeeSharedflow_IsTerraformResource ¶
func GoogleApigeeSharedflow_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleApigeeSharedflow_TfResourceType ¶
func GoogleApigeeSharedflow_TfResourceType() *string
func NewGoogleApigeeSharedflowMetaDataList_Override ¶
func NewGoogleApigeeSharedflowMetaDataList_Override(g GoogleApigeeSharedflowMetaDataList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGoogleApigeeSharedflowMetaDataOutputReference_Override ¶
func NewGoogleApigeeSharedflowMetaDataOutputReference_Override(g GoogleApigeeSharedflowMetaDataOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGoogleApigeeSharedflowTimeoutsOutputReference_Override ¶
func NewGoogleApigeeSharedflowTimeoutsOutputReference_Override(g GoogleApigeeSharedflowTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleApigeeSharedflow_Override ¶
func NewGoogleApigeeSharedflow_Override(g GoogleApigeeSharedflow, scope constructs.Construct, id *string, config *GoogleApigeeSharedflowConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_apigee_sharedflow google_apigee_sharedflow} Resource.
Types ¶
type GoogleApigeeSharedflow ¶
type GoogleApigeeSharedflow interface {
cdktf.TerraformResource
// Experimental.
Connection() interface{}
SetConnection(val interface{})
ConstructNodeMetadata() *map[string]interface{}
Count() interface{}
SetCount(val interface{})
DependsOn() *[]*string
// Experimental.
ForEach() cdktf.ITerraformIterator
SetForEach(val cdktf.ITerraformIterator)
Fqn() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
// The tree node.
Provider() cdktf.TerraformProvider
SetProvider(val cdktf.TerraformProvider)
Provisioners() *[]interface{}
SetProvisioners(val *[]interface{})
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
TerraformMetaArguments() *map[string]interface{}
// Experimental.
// Experimental.
AddMoveTarget(moveTarget *string)
AddOverride(path *string, value interface{})
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
GetListAttribute(terraformAttribute *string) *[]*string
GetNumberAttribute(terraformAttribute *string) *float64
GetNumberListAttribute(terraformAttribute *string) *[]*float64
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
GetStringAttribute(terraformAttribute *string) *string
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
HasResourceMove() interface{}
ImportFrom(id *string, provider cdktf.TerraformProvider)
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
//
// Note that the resource being moved from must be marked as moved using it's instance function.
// Experimental.
MoveFromId(id *string)
// Experimental.
MoveTo(moveTarget *string, index interface{})
// Experimental.
MoveToId(id *string)
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ToHclTerraform() interface{}
ToMetadata() interface{}
ToString() *string
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_apigee_sharedflow google_apigee_sharedflow}.
func NewGoogleApigeeSharedflow ¶
func NewGoogleApigeeSharedflow(scope constructs.Construct, id *string, config *GoogleApigeeSharedflowConfig) GoogleApigeeSharedflow
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_apigee_sharedflow google_apigee_sharedflow} Resource.
type GoogleApigeeSharedflowConfig ¶
type GoogleApigeeSharedflowConfig struct {
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
Count interface{} `field:"optional" json:"count" yaml:"count"`
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_apigee_sharedflow#config_bundle GoogleApigeeSharedflow#config_bundle}
ConfigBundle *string `field:"required" json:"configBundle" yaml:"configBundle"`
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_apigee_sharedflow#name GoogleApigeeSharedflow#name}
Name *string `field:"required" json:"name" yaml:"name"`
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_apigee_sharedflow#org_id GoogleApigeeSharedflow#org_id}
OrgId *string `field:"required" json:"orgId" yaml:"orgId"`
//
// A change in hash will trigger an update.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_apigee_sharedflow#detect_md5hash GoogleApigeeSharedflow#detect_md5hash}
DetectMd5Hash *string `field:"optional" json:"detectMd5Hash" yaml:"detectMd5Hash"`
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_apigee_sharedflow#timeouts GoogleApigeeSharedflow#timeouts}
Timeouts *GoogleApigeeSharedflowTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type GoogleApigeeSharedflowMetaData ¶
type GoogleApigeeSharedflowMetaData struct {
}
type GoogleApigeeSharedflowMetaDataList ¶
type GoogleApigeeSharedflowMetaDataList interface {
cdktf.ComplexList
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Fqn() *string
// The attribute on the parent resource this class is referencing.
// The parent resource.
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleApigeeSharedflowMetaDataList ¶
func NewGoogleApigeeSharedflowMetaDataList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GoogleApigeeSharedflowMetaDataList
type GoogleApigeeSharedflowMetaDataOutputReference ¶
type GoogleApigeeSharedflowMetaDataOutputReference interface {
cdktf.ComplexObject
// Experimental.
ComplexObjectIndex() interface{}
SetComplexObjectIndex(val interface{})
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
ComputeFqn() *string
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
GetListAttribute(terraformAttribute *string) *[]*string
GetNumberAttribute(terraformAttribute *string) *float64
GetNumberListAttribute(terraformAttribute *string) *[]*float64
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
GetStringAttribute(terraformAttribute *string) *string
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
InterpolationAsList() cdktf.IResolvable
InterpolationForAttribute(property *string) cdktf.IResolvable
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleApigeeSharedflowMetaDataOutputReference ¶
func NewGoogleApigeeSharedflowMetaDataOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GoogleApigeeSharedflowMetaDataOutputReference
type GoogleApigeeSharedflowTimeoutsOutputReference ¶
type GoogleApigeeSharedflowTimeoutsOutputReference interface {
cdktf.ComplexObject
// Experimental.
ComplexObjectIndex() interface{}
SetComplexObjectIndex(val interface{})
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
// Experimental.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
ComputeFqn() *string
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
GetListAttribute(terraformAttribute *string) *[]*string
GetNumberAttribute(terraformAttribute *string) *float64
GetNumberListAttribute(terraformAttribute *string) *[]*float64
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
GetStringAttribute(terraformAttribute *string) *string
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
InterpolationAsList() cdktf.IResolvable
// Experimental.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleApigeeSharedflowTimeoutsOutputReference ¶
func NewGoogleApigeeSharedflowTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleApigeeSharedflowTimeoutsOutputReference
Source Files
¶
- GoogleApigeeSharedflow.go
- GoogleApigeeSharedflowConfig.go
- GoogleApigeeSharedflowMetaData.go
- GoogleApigeeSharedflowMetaDataList.go
- GoogleApigeeSharedflowMetaDataList__checks.go
- GoogleApigeeSharedflowMetaDataOutputReference.go
- GoogleApigeeSharedflowMetaDataOutputReference__checks.go
- GoogleApigeeSharedflowTimeouts.go
- GoogleApigeeSharedflowTimeoutsOutputReference.go
- GoogleApigeeSharedflowTimeoutsOutputReference__checks.go
- GoogleApigeeSharedflow__checks.go
- main.go