Documentation
¶
Index ¶
- func GoogleBigqueryDataTransferConfig_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func GoogleBigqueryDataTransferConfig_IsConstruct(x interface{}) *bool
- func GoogleBigqueryDataTransferConfig_IsTerraformElement(x interface{}) *bool
- func GoogleBigqueryDataTransferConfig_IsTerraformResource(x interface{}) *bool
- func GoogleBigqueryDataTransferConfig_TfResourceType() *string
- func NewGoogleBigqueryDataTransferConfigEmailPreferencesOutputReference_Override(g GoogleBigqueryDataTransferConfigEmailPreferencesOutputReference, ...)
- func NewGoogleBigqueryDataTransferConfigEncryptionConfigurationOutputReference_Override(g GoogleBigqueryDataTransferConfigEncryptionConfigurationOutputReference, ...)
- func NewGoogleBigqueryDataTransferConfigScheduleOptionsOutputReference_Override(g GoogleBigqueryDataTransferConfigScheduleOptionsOutputReference, ...)
- func NewGoogleBigqueryDataTransferConfigSensitiveParamsOutputReference_Override(g GoogleBigqueryDataTransferConfigSensitiveParamsOutputReference, ...)
- func NewGoogleBigqueryDataTransferConfigTimeoutsOutputReference_Override(g GoogleBigqueryDataTransferConfigTimeoutsOutputReference, ...)
- func NewGoogleBigqueryDataTransferConfig_Override(g GoogleBigqueryDataTransferConfig, scope constructs.Construct, id *string, ...)
- type GoogleBigqueryDataTransferConfig
- type GoogleBigqueryDataTransferConfigConfig
- type GoogleBigqueryDataTransferConfigEmailPreferences
- type GoogleBigqueryDataTransferConfigEmailPreferencesOutputReference
- type GoogleBigqueryDataTransferConfigEncryptionConfiguration
- type GoogleBigqueryDataTransferConfigEncryptionConfigurationOutputReference
- type GoogleBigqueryDataTransferConfigScheduleOptions
- type GoogleBigqueryDataTransferConfigScheduleOptionsOutputReference
- type GoogleBigqueryDataTransferConfigSensitiveParams
- type GoogleBigqueryDataTransferConfigSensitiveParamsOutputReference
- type GoogleBigqueryDataTransferConfigTimeouts
- type GoogleBigqueryDataTransferConfigTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleBigqueryDataTransferConfig_GenerateConfigForImport ¶
func GoogleBigqueryDataTransferConfig_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a GoogleBigqueryDataTransferConfig resource upon running "cdktf plan <stack-name>".
func GoogleBigqueryDataTransferConfig_IsConstruct ¶
func GoogleBigqueryDataTransferConfig_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleBigqueryDataTransferConfig_IsTerraformElement ¶
func GoogleBigqueryDataTransferConfig_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleBigqueryDataTransferConfig_IsTerraformResource ¶
func GoogleBigqueryDataTransferConfig_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleBigqueryDataTransferConfig_TfResourceType ¶
func GoogleBigqueryDataTransferConfig_TfResourceType() *string
func NewGoogleBigqueryDataTransferConfigEmailPreferencesOutputReference_Override ¶
func NewGoogleBigqueryDataTransferConfigEmailPreferencesOutputReference_Override(g GoogleBigqueryDataTransferConfigEmailPreferencesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleBigqueryDataTransferConfigEncryptionConfigurationOutputReference_Override ¶
func NewGoogleBigqueryDataTransferConfigEncryptionConfigurationOutputReference_Override(g GoogleBigqueryDataTransferConfigEncryptionConfigurationOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleBigqueryDataTransferConfigScheduleOptionsOutputReference_Override ¶
func NewGoogleBigqueryDataTransferConfigScheduleOptionsOutputReference_Override(g GoogleBigqueryDataTransferConfigScheduleOptionsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleBigqueryDataTransferConfigSensitiveParamsOutputReference_Override ¶
func NewGoogleBigqueryDataTransferConfigSensitiveParamsOutputReference_Override(g GoogleBigqueryDataTransferConfigSensitiveParamsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleBigqueryDataTransferConfigTimeoutsOutputReference_Override ¶
func NewGoogleBigqueryDataTransferConfigTimeoutsOutputReference_Override(g GoogleBigqueryDataTransferConfigTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleBigqueryDataTransferConfig_Override ¶
func NewGoogleBigqueryDataTransferConfig_Override(g GoogleBigqueryDataTransferConfig, scope constructs.Construct, id *string, config *GoogleBigqueryDataTransferConfigConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_bigquery_data_transfer_config google_bigquery_data_transfer_config} Resource.
Types ¶
type GoogleBigqueryDataTransferConfig ¶
type GoogleBigqueryDataTransferConfig interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
DataRefreshWindowDays() *float64
SetDataRefreshWindowDays(val *float64)
DataRefreshWindowDaysInput() *float64
DataSourceId() *string
SetDataSourceId(val *string)
DataSourceIdInput() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DestinationDatasetId() *string
SetDestinationDatasetId(val *string)
DestinationDatasetIdInput() *string
Disabled() interface{}
SetDisabled(val interface{})
DisabledInput() interface{}
DisplayName() *string
SetDisplayName(val *string)
DisplayNameInput() *string
EmailPreferences() GoogleBigqueryDataTransferConfigEmailPreferencesOutputReference
EmailPreferencesInput() *GoogleBigqueryDataTransferConfigEmailPreferences
EncryptionConfiguration() GoogleBigqueryDataTransferConfigEncryptionConfigurationOutputReference
EncryptionConfigurationInput() *GoogleBigqueryDataTransferConfigEncryptionConfiguration
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Location() *string
SetLocation(val *string)
LocationInput() *string
Name() *string
// The tree node.
Node() constructs.Node
NotificationPubsubTopic() *string
SetNotificationPubsubTopic(val *string)
NotificationPubsubTopicInput() *string
Params() *map[string]*string
SetParams(val *map[string]*string)
ParamsInput() *map[string]*string
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Schedule() *string
SetSchedule(val *string)
ScheduleInput() *string
ScheduleOptions() GoogleBigqueryDataTransferConfigScheduleOptionsOutputReference
ScheduleOptionsInput() *GoogleBigqueryDataTransferConfigScheduleOptions
SensitiveParams() GoogleBigqueryDataTransferConfigSensitiveParamsOutputReference
SensitiveParamsInput() *GoogleBigqueryDataTransferConfigSensitiveParams
ServiceAccountName() *string
SetServiceAccountName(val *string)
ServiceAccountNameInput() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GoogleBigqueryDataTransferConfigTimeoutsOutputReference
TimeoutsInput() interface{}
// Adds a user defined moveTarget string to this resource to be later used in .moveTo(moveTarget) to resolve the location of the move.
// Experimental.
AddMoveTarget(moveTarget *string)
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
HasResourceMove() interface{}
// Experimental.
ImportFrom(id *string, provider cdktf.TerraformProvider)
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Move the resource corresponding to "id" to this resource.
//
// Note that the resource being moved from must be marked as moved using it's instance function.
// Experimental.
MoveFromId(id *string)
// Moves this resource to the target resource given by moveTarget.
// Experimental.
MoveTo(moveTarget *string, index interface{})
// Moves this resource to the resource corresponding to "id".
// Experimental.
MoveToId(id *string)
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutEmailPreferences(value *GoogleBigqueryDataTransferConfigEmailPreferences)
PutEncryptionConfiguration(value *GoogleBigqueryDataTransferConfigEncryptionConfiguration)
PutScheduleOptions(value *GoogleBigqueryDataTransferConfigScheduleOptions)
PutSensitiveParams(value *GoogleBigqueryDataTransferConfigSensitiveParams)
PutTimeouts(value *GoogleBigqueryDataTransferConfigTimeouts)
ResetDataRefreshWindowDays()
ResetDestinationDatasetId()
ResetDisabled()
ResetEmailPreferences()
ResetEncryptionConfiguration()
ResetId()
ResetLocation()
ResetNotificationPubsubTopic()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
ResetSchedule()
ResetScheduleOptions()
ResetSensitiveParams()
ResetServiceAccountName()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
SynthesizeHclAttributes() *map[string]interface{}
// Experimental.
ToHclTerraform() interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_bigquery_data_transfer_config google_bigquery_data_transfer_config}.
func NewGoogleBigqueryDataTransferConfig ¶
func NewGoogleBigqueryDataTransferConfig(scope constructs.Construct, id *string, config *GoogleBigqueryDataTransferConfigConfig) GoogleBigqueryDataTransferConfig
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_bigquery_data_transfer_config google_bigquery_data_transfer_config} Resource.
type GoogleBigqueryDataTransferConfigConfig ¶
type GoogleBigqueryDataTransferConfigConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// The data source id. Cannot be changed once the transfer config is created.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_bigquery_data_transfer_config#data_source_id GoogleBigqueryDataTransferConfig#data_source_id}
DataSourceId *string `field:"required" json:"dataSourceId" yaml:"dataSourceId"`
// The user specified display name for the transfer config.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_bigquery_data_transfer_config#display_name GoogleBigqueryDataTransferConfig#display_name}
DisplayName *string `field:"required" json:"displayName" yaml:"displayName"`
// Parameters specific to each data source.
//
// For more information see the bq tab in the 'Setting up a data transfer'
// section for each data source. For example the parameters for Cloud Storage transfers are listed here:
// https://cloud.google.com/bigquery-transfer/docs/cloud-storage-transfer#bq
//
// **NOTE** : If you are attempting to update a parameter that cannot be updated (due to api limitations) [please force recreation of the resource](https://www.terraform.io/cli/state/taint#forcing-re-creation-of-resources).
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_bigquery_data_transfer_config#params GoogleBigqueryDataTransferConfig#params}
Params *map[string]*string `field:"required" json:"params" yaml:"params"`
// The number of days to look back to automatically refresh the data.
//
// For example, if dataRefreshWindowDays = 10, then every day BigQuery
// reingests data for [today-10, today-1], rather than ingesting data for
// just [today-1]. Only valid if the data source supports the feature.
// Set the value to 0 to use the default value.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_bigquery_data_transfer_config#data_refresh_window_days GoogleBigqueryDataTransferConfig#data_refresh_window_days}
DataRefreshWindowDays *float64 `field:"optional" json:"dataRefreshWindowDays" yaml:"dataRefreshWindowDays"`
// The BigQuery target dataset id.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_bigquery_data_transfer_config#destination_dataset_id GoogleBigqueryDataTransferConfig#destination_dataset_id}
DestinationDatasetId *string `field:"optional" json:"destinationDatasetId" yaml:"destinationDatasetId"`
// When set to true, no runs are scheduled for a given transfer.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_bigquery_data_transfer_config#disabled GoogleBigqueryDataTransferConfig#disabled}
Disabled interface{} `field:"optional" json:"disabled" yaml:"disabled"`
// email_preferences block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_bigquery_data_transfer_config#email_preferences GoogleBigqueryDataTransferConfig#email_preferences}
EmailPreferences *GoogleBigqueryDataTransferConfigEmailPreferences `field:"optional" json:"emailPreferences" yaml:"emailPreferences"`
// encryption_configuration block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_bigquery_data_transfer_config#encryption_configuration GoogleBigqueryDataTransferConfig#encryption_configuration}
EncryptionConfiguration *GoogleBigqueryDataTransferConfigEncryptionConfiguration `field:"optional" json:"encryptionConfiguration" yaml:"encryptionConfiguration"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_bigquery_data_transfer_config#id GoogleBigqueryDataTransferConfig#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// The geographic location where the transfer config should reside. Examples: US, EU, asia-northeast1. The default value is US.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_bigquery_data_transfer_config#location GoogleBigqueryDataTransferConfig#location}
Location *string `field:"optional" json:"location" yaml:"location"`
// Pub/Sub topic where notifications will be sent after transfer runs associated with this transfer config finish.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_bigquery_data_transfer_config#notification_pubsub_topic GoogleBigqueryDataTransferConfig#notification_pubsub_topic}
NotificationPubsubTopic *string `field:"optional" json:"notificationPubsubTopic" yaml:"notificationPubsubTopic"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_bigquery_data_transfer_config#project GoogleBigqueryDataTransferConfig#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// Data transfer schedule.
//
// If the data source does not support a custom
// schedule, this should be empty. If it is empty, the default value for
// the data source will be used. The specified times are in UTC. Examples
// of valid format: 1st,3rd monday of month 15:30, every wed,fri of jan,
// jun 13:15, and first sunday of quarter 00:00. See more explanation
// about the format here:
// https://cloud.google.com/appengine/docs/flexible/python/scheduling-jobs-with-cron-yaml#the_schedule_format
// NOTE: The minimum interval time between recurring transfers depends
// on the data source; refer to the documentation for your data source.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_bigquery_data_transfer_config#schedule GoogleBigqueryDataTransferConfig#schedule}
Schedule *string `field:"optional" json:"schedule" yaml:"schedule"`
// schedule_options block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_bigquery_data_transfer_config#schedule_options GoogleBigqueryDataTransferConfig#schedule_options}
ScheduleOptions *GoogleBigqueryDataTransferConfigScheduleOptions `field:"optional" json:"scheduleOptions" yaml:"scheduleOptions"`
// sensitive_params block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_bigquery_data_transfer_config#sensitive_params GoogleBigqueryDataTransferConfig#sensitive_params}
SensitiveParams *GoogleBigqueryDataTransferConfigSensitiveParams `field:"optional" json:"sensitiveParams" yaml:"sensitiveParams"`
// Service account email.
//
// If this field is set, transfer config will
// be created with this service account credentials. It requires that
// requesting user calling this API has permissions to act as this service account.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_bigquery_data_transfer_config#service_account_name GoogleBigqueryDataTransferConfig#service_account_name}
ServiceAccountName *string `field:"optional" json:"serviceAccountName" yaml:"serviceAccountName"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_bigquery_data_transfer_config#timeouts GoogleBigqueryDataTransferConfig#timeouts}
Timeouts *GoogleBigqueryDataTransferConfigTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type GoogleBigqueryDataTransferConfigEmailPreferences ¶
type GoogleBigqueryDataTransferConfigEmailPreferences struct {
// If true, email notifications will be sent on transfer run failures.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_bigquery_data_transfer_config#enable_failure_email GoogleBigqueryDataTransferConfig#enable_failure_email}
EnableFailureEmail interface{} `field:"required" json:"enableFailureEmail" yaml:"enableFailureEmail"`
}
type GoogleBigqueryDataTransferConfigEmailPreferencesOutputReference ¶
type GoogleBigqueryDataTransferConfigEmailPreferencesOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
EnableFailureEmail() interface{}
SetEnableFailureEmail(val interface{})
EnableFailureEmailInput() interface{}
// Experimental.
Fqn() *string
InternalValue() *GoogleBigqueryDataTransferConfigEmailPreferences
SetInternalValue(val *GoogleBigqueryDataTransferConfigEmailPreferences)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleBigqueryDataTransferConfigEmailPreferencesOutputReference ¶
func NewGoogleBigqueryDataTransferConfigEmailPreferencesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleBigqueryDataTransferConfigEmailPreferencesOutputReference
type GoogleBigqueryDataTransferConfigEncryptionConfiguration ¶
type GoogleBigqueryDataTransferConfigEncryptionConfiguration struct {
// The name of the KMS key used for encrypting BigQuery data.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_bigquery_data_transfer_config#kms_key_name GoogleBigqueryDataTransferConfig#kms_key_name}
KmsKeyName *string `field:"required" json:"kmsKeyName" yaml:"kmsKeyName"`
}
type GoogleBigqueryDataTransferConfigEncryptionConfigurationOutputReference ¶
type GoogleBigqueryDataTransferConfigEncryptionConfigurationOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleBigqueryDataTransferConfigEncryptionConfiguration
SetInternalValue(val *GoogleBigqueryDataTransferConfigEncryptionConfiguration)
KmsKeyName() *string
SetKmsKeyName(val *string)
KmsKeyNameInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleBigqueryDataTransferConfigEncryptionConfigurationOutputReference ¶
func NewGoogleBigqueryDataTransferConfigEncryptionConfigurationOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleBigqueryDataTransferConfigEncryptionConfigurationOutputReference
type GoogleBigqueryDataTransferConfigScheduleOptions ¶
type GoogleBigqueryDataTransferConfigScheduleOptions struct {
// If true, automatic scheduling of data transfer runs for this configuration will be disabled.
//
// The runs can be started on ad-hoc
// basis using transferConfigs.startManualRuns API. When automatic
// scheduling is disabled, the TransferConfig.schedule field will
// be ignored.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_bigquery_data_transfer_config#disable_auto_scheduling GoogleBigqueryDataTransferConfig#disable_auto_scheduling}
DisableAutoScheduling interface{} `field:"optional" json:"disableAutoScheduling" yaml:"disableAutoScheduling"`
// Defines time to stop scheduling transfer runs.
//
// A transfer run cannot be
// scheduled at or after the end time. The end time can be changed at any
// moment. The time when a data transfer can be triggered manually is not
// limited by this option.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_bigquery_data_transfer_config#end_time GoogleBigqueryDataTransferConfig#end_time}
EndTime *string `field:"optional" json:"endTime" yaml:"endTime"`
// Specifies time to start scheduling transfer runs.
//
// The first run will be
// scheduled at or after the start time according to a recurrence pattern
// defined in the schedule string. The start time can be changed at any
// moment. The time when a data transfer can be triggered manually is not
// limited by this option.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_bigquery_data_transfer_config#start_time GoogleBigqueryDataTransferConfig#start_time}
StartTime *string `field:"optional" json:"startTime" yaml:"startTime"`
}
type GoogleBigqueryDataTransferConfigScheduleOptionsOutputReference ¶
type GoogleBigqueryDataTransferConfigScheduleOptionsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DisableAutoScheduling() interface{}
SetDisableAutoScheduling(val interface{})
DisableAutoSchedulingInput() interface{}
EndTime() *string
SetEndTime(val *string)
EndTimeInput() *string
// Experimental.
Fqn() *string
InternalValue() *GoogleBigqueryDataTransferConfigScheduleOptions
SetInternalValue(val *GoogleBigqueryDataTransferConfigScheduleOptions)
StartTime() *string
SetStartTime(val *string)
StartTimeInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetDisableAutoScheduling()
ResetEndTime()
ResetStartTime()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleBigqueryDataTransferConfigScheduleOptionsOutputReference ¶
func NewGoogleBigqueryDataTransferConfigScheduleOptionsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleBigqueryDataTransferConfigScheduleOptionsOutputReference
type GoogleBigqueryDataTransferConfigSensitiveParams ¶
type GoogleBigqueryDataTransferConfigSensitiveParams struct {
// The Secret Access Key of the AWS account transferring data from.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_bigquery_data_transfer_config#secret_access_key GoogleBigqueryDataTransferConfig#secret_access_key}
SecretAccessKey *string `field:"optional" json:"secretAccessKey" yaml:"secretAccessKey"`
// The Secret Access Key of the AWS account transferring data from.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_bigquery_data_transfer_config#secret_access_key_wo GoogleBigqueryDataTransferConfig#secret_access_key_wo}
SecretAccessKeyWo *string `field:"optional" json:"secretAccessKeyWo" yaml:"secretAccessKeyWo"`
// The version of the sensitive params - used to trigger updates of the write-only params.
//
// For more info see [updating write-only attributes](/docs/providers/google/guides/using_write_only_attributes.html#updating-write-only-attributes)
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_bigquery_data_transfer_config#secret_access_key_wo_version GoogleBigqueryDataTransferConfig#secret_access_key_wo_version}
SecretAccessKeyWoVersion *float64 `field:"optional" json:"secretAccessKeyWoVersion" yaml:"secretAccessKeyWoVersion"`
}
type GoogleBigqueryDataTransferConfigSensitiveParamsOutputReference ¶
type GoogleBigqueryDataTransferConfigSensitiveParamsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleBigqueryDataTransferConfigSensitiveParams
SetInternalValue(val *GoogleBigqueryDataTransferConfigSensitiveParams)
SecretAccessKey() *string
SetSecretAccessKey(val *string)
SecretAccessKeyInput() *string
SecretAccessKeyWo() *string
SetSecretAccessKeyWo(val *string)
SecretAccessKeyWoInput() *string
SecretAccessKeyWoVersion() *float64
SetSecretAccessKeyWoVersion(val *float64)
SecretAccessKeyWoVersionInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetSecretAccessKey()
ResetSecretAccessKeyWo()
ResetSecretAccessKeyWoVersion()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleBigqueryDataTransferConfigSensitiveParamsOutputReference ¶
func NewGoogleBigqueryDataTransferConfigSensitiveParamsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleBigqueryDataTransferConfigSensitiveParamsOutputReference
type GoogleBigqueryDataTransferConfigTimeouts ¶
type GoogleBigqueryDataTransferConfigTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_bigquery_data_transfer_config#create GoogleBigqueryDataTransferConfig#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_bigquery_data_transfer_config#delete GoogleBigqueryDataTransferConfig#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_bigquery_data_transfer_config#update GoogleBigqueryDataTransferConfig#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type GoogleBigqueryDataTransferConfigTimeoutsOutputReference ¶
type GoogleBigqueryDataTransferConfigTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleBigqueryDataTransferConfigTimeoutsOutputReference ¶
func NewGoogleBigqueryDataTransferConfigTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleBigqueryDataTransferConfigTimeoutsOutputReference
Source Files
¶
- GoogleBigqueryDataTransferConfig.go
- GoogleBigqueryDataTransferConfigConfig.go
- GoogleBigqueryDataTransferConfigEmailPreferences.go
- GoogleBigqueryDataTransferConfigEmailPreferencesOutputReference.go
- GoogleBigqueryDataTransferConfigEmailPreferencesOutputReference__checks.go
- GoogleBigqueryDataTransferConfigEncryptionConfiguration.go
- GoogleBigqueryDataTransferConfigEncryptionConfigurationOutputReference.go
- GoogleBigqueryDataTransferConfigEncryptionConfigurationOutputReference__checks.go
- GoogleBigqueryDataTransferConfigScheduleOptions.go
- GoogleBigqueryDataTransferConfigScheduleOptionsOutputReference.go
- GoogleBigqueryDataTransferConfigScheduleOptionsOutputReference__checks.go
- GoogleBigqueryDataTransferConfigSensitiveParams.go
- GoogleBigqueryDataTransferConfigSensitiveParamsOutputReference.go
- GoogleBigqueryDataTransferConfigSensitiveParamsOutputReference__checks.go
- GoogleBigqueryDataTransferConfigTimeouts.go
- GoogleBigqueryDataTransferConfigTimeoutsOutputReference.go
- GoogleBigqueryDataTransferConfigTimeoutsOutputReference__checks.go
- GoogleBigqueryDataTransferConfig__checks.go
- main.go