Documentation
¶
Index ¶
- func GoogleCloudRunDomainMapping_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func GoogleCloudRunDomainMapping_IsConstruct(x interface{}) *bool
- func GoogleCloudRunDomainMapping_IsTerraformElement(x interface{}) *bool
- func GoogleCloudRunDomainMapping_IsTerraformResource(x interface{}) *bool
- func GoogleCloudRunDomainMapping_TfResourceType() *string
- func NewGoogleCloudRunDomainMappingMetadataOutputReference_Override(g GoogleCloudRunDomainMappingMetadataOutputReference, ...)
- func NewGoogleCloudRunDomainMappingSpecOutputReference_Override(g GoogleCloudRunDomainMappingSpecOutputReference, ...)
- func NewGoogleCloudRunDomainMappingStatusConditionsList_Override(g GoogleCloudRunDomainMappingStatusConditionsList, ...)
- func NewGoogleCloudRunDomainMappingStatusConditionsOutputReference_Override(g GoogleCloudRunDomainMappingStatusConditionsOutputReference, ...)
- func NewGoogleCloudRunDomainMappingStatusList_Override(g GoogleCloudRunDomainMappingStatusList, ...)
- func NewGoogleCloudRunDomainMappingStatusOutputReference_Override(g GoogleCloudRunDomainMappingStatusOutputReference, ...)
- func NewGoogleCloudRunDomainMappingStatusResourceRecordsList_Override(g GoogleCloudRunDomainMappingStatusResourceRecordsList, ...)
- func NewGoogleCloudRunDomainMappingStatusResourceRecordsOutputReference_Override(g GoogleCloudRunDomainMappingStatusResourceRecordsOutputReference, ...)
- func NewGoogleCloudRunDomainMappingTimeoutsOutputReference_Override(g GoogleCloudRunDomainMappingTimeoutsOutputReference, ...)
- func NewGoogleCloudRunDomainMapping_Override(g GoogleCloudRunDomainMapping, scope constructs.Construct, id *string, ...)
- type GoogleCloudRunDomainMapping
- type GoogleCloudRunDomainMappingConfig
- type GoogleCloudRunDomainMappingMetadata
- type GoogleCloudRunDomainMappingMetadataOutputReference
- type GoogleCloudRunDomainMappingSpec
- type GoogleCloudRunDomainMappingSpecOutputReference
- type GoogleCloudRunDomainMappingStatus
- type GoogleCloudRunDomainMappingStatusConditions
- type GoogleCloudRunDomainMappingStatusConditionsList
- type GoogleCloudRunDomainMappingStatusConditionsOutputReference
- type GoogleCloudRunDomainMappingStatusList
- type GoogleCloudRunDomainMappingStatusOutputReference
- type GoogleCloudRunDomainMappingStatusResourceRecords
- type GoogleCloudRunDomainMappingStatusResourceRecordsList
- type GoogleCloudRunDomainMappingStatusResourceRecordsOutputReference
- type GoogleCloudRunDomainMappingTimeouts
- type GoogleCloudRunDomainMappingTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleCloudRunDomainMapping_GenerateConfigForImport ¶
func GoogleCloudRunDomainMapping_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a GoogleCloudRunDomainMapping resource upon running "cdktf plan <stack-name>".
func GoogleCloudRunDomainMapping_IsConstruct ¶
func GoogleCloudRunDomainMapping_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleCloudRunDomainMapping_IsTerraformElement ¶
func GoogleCloudRunDomainMapping_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleCloudRunDomainMapping_IsTerraformResource ¶
func GoogleCloudRunDomainMapping_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleCloudRunDomainMapping_TfResourceType ¶
func GoogleCloudRunDomainMapping_TfResourceType() *string
func NewGoogleCloudRunDomainMappingMetadataOutputReference_Override ¶
func NewGoogleCloudRunDomainMappingMetadataOutputReference_Override(g GoogleCloudRunDomainMappingMetadataOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleCloudRunDomainMappingSpecOutputReference_Override ¶
func NewGoogleCloudRunDomainMappingSpecOutputReference_Override(g GoogleCloudRunDomainMappingSpecOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleCloudRunDomainMappingStatusConditionsList_Override ¶
func NewGoogleCloudRunDomainMappingStatusConditionsList_Override(g GoogleCloudRunDomainMappingStatusConditionsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGoogleCloudRunDomainMappingStatusConditionsOutputReference_Override ¶
func NewGoogleCloudRunDomainMappingStatusConditionsOutputReference_Override(g GoogleCloudRunDomainMappingStatusConditionsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGoogleCloudRunDomainMappingStatusList_Override ¶
func NewGoogleCloudRunDomainMappingStatusList_Override(g GoogleCloudRunDomainMappingStatusList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGoogleCloudRunDomainMappingStatusOutputReference_Override ¶
func NewGoogleCloudRunDomainMappingStatusOutputReference_Override(g GoogleCloudRunDomainMappingStatusOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGoogleCloudRunDomainMappingStatusResourceRecordsList_Override ¶
func NewGoogleCloudRunDomainMappingStatusResourceRecordsList_Override(g GoogleCloudRunDomainMappingStatusResourceRecordsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGoogleCloudRunDomainMappingStatusResourceRecordsOutputReference_Override ¶
func NewGoogleCloudRunDomainMappingStatusResourceRecordsOutputReference_Override(g GoogleCloudRunDomainMappingStatusResourceRecordsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGoogleCloudRunDomainMappingTimeoutsOutputReference_Override ¶
func NewGoogleCloudRunDomainMappingTimeoutsOutputReference_Override(g GoogleCloudRunDomainMappingTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleCloudRunDomainMapping_Override ¶
func NewGoogleCloudRunDomainMapping_Override(g GoogleCloudRunDomainMapping, scope constructs.Construct, id *string, config *GoogleCloudRunDomainMappingConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_cloud_run_domain_mapping google_cloud_run_domain_mapping} Resource.
Types ¶
type GoogleCloudRunDomainMapping ¶
type GoogleCloudRunDomainMapping interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Location() *string
SetLocation(val *string)
LocationInput() *string
Metadata() GoogleCloudRunDomainMappingMetadataOutputReference
MetadataInput() *GoogleCloudRunDomainMappingMetadata
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Spec() GoogleCloudRunDomainMappingSpecOutputReference
SpecInput() *GoogleCloudRunDomainMappingSpec
Status() GoogleCloudRunDomainMappingStatusList
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GoogleCloudRunDomainMappingTimeoutsOutputReference
TimeoutsInput() interface{}
// Adds a user defined moveTarget string to this resource to be later used in .moveTo(moveTarget) to resolve the location of the move.
// Experimental.
AddMoveTarget(moveTarget *string)
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
HasResourceMove() interface{}
// Experimental.
ImportFrom(id *string, provider cdktf.TerraformProvider)
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Move the resource corresponding to "id" to this resource.
//
// Note that the resource being moved from must be marked as moved using it's instance function.
// Experimental.
MoveFromId(id *string)
// Moves this resource to the target resource given by moveTarget.
// Experimental.
MoveTo(moveTarget *string, index interface{})
// Moves this resource to the resource corresponding to "id".
// Experimental.
MoveToId(id *string)
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutMetadata(value *GoogleCloudRunDomainMappingMetadata)
PutSpec(value *GoogleCloudRunDomainMappingSpec)
PutTimeouts(value *GoogleCloudRunDomainMappingTimeouts)
ResetId()
ResetMetadata()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
SynthesizeHclAttributes() *map[string]interface{}
// Experimental.
ToHclTerraform() interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_cloud_run_domain_mapping google_cloud_run_domain_mapping}.
func NewGoogleCloudRunDomainMapping ¶
func NewGoogleCloudRunDomainMapping(scope constructs.Construct, id *string, config *GoogleCloudRunDomainMappingConfig) GoogleCloudRunDomainMapping
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_cloud_run_domain_mapping google_cloud_run_domain_mapping} Resource.
type GoogleCloudRunDomainMappingConfig ¶
type GoogleCloudRunDomainMappingConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// The location of the cloud run instance. eg us-central1.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_cloud_run_domain_mapping#location GoogleCloudRunDomainMapping#location}
Location *string `field:"required" json:"location" yaml:"location"`
// Name should be a [verified](https://support.google.com/webmasters/answer/9008080) domain.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_cloud_run_domain_mapping#name GoogleCloudRunDomainMapping#name}
Name *string `field:"required" json:"name" yaml:"name"`
// spec block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_cloud_run_domain_mapping#spec GoogleCloudRunDomainMapping#spec}
Spec *GoogleCloudRunDomainMappingSpec `field:"required" json:"spec" yaml:"spec"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_cloud_run_domain_mapping#id GoogleCloudRunDomainMapping#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// metadata block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_cloud_run_domain_mapping#metadata GoogleCloudRunDomainMapping#metadata}
Metadata *GoogleCloudRunDomainMappingMetadata `field:"optional" json:"metadata" yaml:"metadata"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_cloud_run_domain_mapping#project GoogleCloudRunDomainMapping#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_cloud_run_domain_mapping#timeouts GoogleCloudRunDomainMapping#timeouts}
Timeouts *GoogleCloudRunDomainMappingTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type GoogleCloudRunDomainMappingMetadata ¶
type GoogleCloudRunDomainMappingMetadata struct {
// In Cloud Run the namespace must be equal to either the project ID or project number.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_cloud_run_domain_mapping#namespace GoogleCloudRunDomainMapping#namespace}
Namespace *string `field:"required" json:"namespace" yaml:"namespace"`
// Annotations is a key value map stored with a resource that may be set by external tools to store and retrieve arbitrary metadata.
//
// More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/annotations
//
// **Note**: The Cloud Run API may add additional annotations that were not provided in your config.
// If terraform plan shows a diff where a server-side annotation is added, you can add it to your config
// or apply the lifecycle.ignore_changes rule to the metadata.0.annotations field.
//
// **Note**: This field is non-authoritative, and will only manage the annotations present in your configuration.
// Please refer to the field 'effective_annotations' for all of the annotations present on the resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_cloud_run_domain_mapping#annotations GoogleCloudRunDomainMapping#annotations}
Annotations *map[string]*string `field:"optional" json:"annotations" yaml:"annotations"`
// Map of string keys and values that can be used to organize and categorize (scope and select) objects.
//
// May match selectors of replication controllers
// and routes.
// More info: https://kubernetes.io/docs/concepts/overview/working-with-objects/labels
//
// **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
// Please refer to the field 'effective_labels' for all of the labels present on the resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_cloud_run_domain_mapping#labels GoogleCloudRunDomainMapping#labels}
Labels *map[string]*string `field:"optional" json:"labels" yaml:"labels"`
}
type GoogleCloudRunDomainMappingMetadataOutputReference ¶
type GoogleCloudRunDomainMappingMetadataOutputReference interface {
cdktf.ComplexObject
Annotations() *map[string]*string
SetAnnotations(val *map[string]*string)
AnnotationsInput() *map[string]*string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
EffectiveAnnotations() cdktf.StringMap
EffectiveLabels() cdktf.StringMap
// Experimental.
Fqn() *string
Generation() *float64
InternalValue() *GoogleCloudRunDomainMappingMetadata
SetInternalValue(val *GoogleCloudRunDomainMappingMetadata)
Labels() *map[string]*string
SetLabels(val *map[string]*string)
LabelsInput() *map[string]*string
Namespace() *string
SetNamespace(val *string)
NamespaceInput() *string
ResourceVersion() *string
SelfLink() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
TerraformLabels() cdktf.StringMap
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Uid() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetAnnotations()
ResetLabels()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleCloudRunDomainMappingMetadataOutputReference ¶
func NewGoogleCloudRunDomainMappingMetadataOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleCloudRunDomainMappingMetadataOutputReference
type GoogleCloudRunDomainMappingSpec ¶
type GoogleCloudRunDomainMappingSpec struct {
// The name of the Cloud Run Service that this DomainMapping applies to. The route must exist.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_cloud_run_domain_mapping#route_name GoogleCloudRunDomainMapping#route_name}
RouteName *string `field:"required" json:"routeName" yaml:"routeName"`
// The mode of the certificate. Default value: "AUTOMATIC" Possible values: ["NONE", "AUTOMATIC"].
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_cloud_run_domain_mapping#certificate_mode GoogleCloudRunDomainMapping#certificate_mode}
CertificateMode *string `field:"optional" json:"certificateMode" yaml:"certificateMode"`
// If set, the mapping will override any mapping set before this spec was set.
//
// It is recommended that the user leaves this empty to receive an error
// warning about a potential conflict and only set it once the respective UI
// has given such a warning.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_cloud_run_domain_mapping#force_override GoogleCloudRunDomainMapping#force_override}
ForceOverride interface{} `field:"optional" json:"forceOverride" yaml:"forceOverride"`
}
type GoogleCloudRunDomainMappingSpecOutputReference ¶
type GoogleCloudRunDomainMappingSpecOutputReference interface {
cdktf.ComplexObject
CertificateMode() *string
SetCertificateMode(val *string)
CertificateModeInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
ForceOverride() interface{}
SetForceOverride(val interface{})
ForceOverrideInput() interface{}
// Experimental.
Fqn() *string
InternalValue() *GoogleCloudRunDomainMappingSpec
SetInternalValue(val *GoogleCloudRunDomainMappingSpec)
RouteName() *string
SetRouteName(val *string)
RouteNameInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCertificateMode()
ResetForceOverride()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleCloudRunDomainMappingSpecOutputReference ¶
func NewGoogleCloudRunDomainMappingSpecOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleCloudRunDomainMappingSpecOutputReference
type GoogleCloudRunDomainMappingStatus ¶
type GoogleCloudRunDomainMappingStatus struct {
}
type GoogleCloudRunDomainMappingStatusConditions ¶
type GoogleCloudRunDomainMappingStatusConditions struct {
}
type GoogleCloudRunDomainMappingStatusConditionsList ¶
type GoogleCloudRunDomainMappingStatusConditionsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) GoogleCloudRunDomainMappingStatusConditionsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleCloudRunDomainMappingStatusConditionsList ¶
func NewGoogleCloudRunDomainMappingStatusConditionsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GoogleCloudRunDomainMappingStatusConditionsList
type GoogleCloudRunDomainMappingStatusConditionsOutputReference ¶
type GoogleCloudRunDomainMappingStatusConditionsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleCloudRunDomainMappingStatusConditions
SetInternalValue(val *GoogleCloudRunDomainMappingStatusConditions)
Message() *string
Reason() *string
Status() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleCloudRunDomainMappingStatusConditionsOutputReference ¶
func NewGoogleCloudRunDomainMappingStatusConditionsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GoogleCloudRunDomainMappingStatusConditionsOutputReference
type GoogleCloudRunDomainMappingStatusList ¶
type GoogleCloudRunDomainMappingStatusList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) GoogleCloudRunDomainMappingStatusOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleCloudRunDomainMappingStatusList ¶
func NewGoogleCloudRunDomainMappingStatusList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GoogleCloudRunDomainMappingStatusList
type GoogleCloudRunDomainMappingStatusOutputReference ¶
type GoogleCloudRunDomainMappingStatusOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Conditions() GoogleCloudRunDomainMappingStatusConditionsList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleCloudRunDomainMappingStatus
SetInternalValue(val *GoogleCloudRunDomainMappingStatus)
MappedRouteName() *string
ObservedGeneration() *float64
ResourceRecords() GoogleCloudRunDomainMappingStatusResourceRecordsList
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleCloudRunDomainMappingStatusOutputReference ¶
func NewGoogleCloudRunDomainMappingStatusOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GoogleCloudRunDomainMappingStatusOutputReference
type GoogleCloudRunDomainMappingStatusResourceRecords ¶
type GoogleCloudRunDomainMappingStatusResourceRecords struct {
}
type GoogleCloudRunDomainMappingStatusResourceRecordsList ¶
type GoogleCloudRunDomainMappingStatusResourceRecordsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) GoogleCloudRunDomainMappingStatusResourceRecordsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleCloudRunDomainMappingStatusResourceRecordsList ¶
func NewGoogleCloudRunDomainMappingStatusResourceRecordsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GoogleCloudRunDomainMappingStatusResourceRecordsList
type GoogleCloudRunDomainMappingStatusResourceRecordsOutputReference ¶
type GoogleCloudRunDomainMappingStatusResourceRecordsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleCloudRunDomainMappingStatusResourceRecords
SetInternalValue(val *GoogleCloudRunDomainMappingStatusResourceRecords)
Name() *string
Rrdata() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleCloudRunDomainMappingStatusResourceRecordsOutputReference ¶
func NewGoogleCloudRunDomainMappingStatusResourceRecordsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GoogleCloudRunDomainMappingStatusResourceRecordsOutputReference
type GoogleCloudRunDomainMappingTimeouts ¶
type GoogleCloudRunDomainMappingTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_cloud_run_domain_mapping#create GoogleCloudRunDomainMapping#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_cloud_run_domain_mapping#delete GoogleCloudRunDomainMapping#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
}
type GoogleCloudRunDomainMappingTimeoutsOutputReference ¶
type GoogleCloudRunDomainMappingTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleCloudRunDomainMappingTimeoutsOutputReference ¶
func NewGoogleCloudRunDomainMappingTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleCloudRunDomainMappingTimeoutsOutputReference
Source Files
¶
- GoogleCloudRunDomainMapping.go
- GoogleCloudRunDomainMappingConfig.go
- GoogleCloudRunDomainMappingMetadata.go
- GoogleCloudRunDomainMappingMetadataOutputReference.go
- GoogleCloudRunDomainMappingMetadataOutputReference__checks.go
- GoogleCloudRunDomainMappingSpec.go
- GoogleCloudRunDomainMappingSpecOutputReference.go
- GoogleCloudRunDomainMappingSpecOutputReference__checks.go
- GoogleCloudRunDomainMappingStatus.go
- GoogleCloudRunDomainMappingStatusConditions.go
- GoogleCloudRunDomainMappingStatusConditionsList.go
- GoogleCloudRunDomainMappingStatusConditionsList__checks.go
- GoogleCloudRunDomainMappingStatusConditionsOutputReference.go
- GoogleCloudRunDomainMappingStatusConditionsOutputReference__checks.go
- GoogleCloudRunDomainMappingStatusList.go
- GoogleCloudRunDomainMappingStatusList__checks.go
- GoogleCloudRunDomainMappingStatusOutputReference.go
- GoogleCloudRunDomainMappingStatusOutputReference__checks.go
- GoogleCloudRunDomainMappingStatusResourceRecords.go
- GoogleCloudRunDomainMappingStatusResourceRecordsList.go
- GoogleCloudRunDomainMappingStatusResourceRecordsList__checks.go
- GoogleCloudRunDomainMappingStatusResourceRecordsOutputReference.go
- GoogleCloudRunDomainMappingStatusResourceRecordsOutputReference__checks.go
- GoogleCloudRunDomainMappingTimeouts.go
- GoogleCloudRunDomainMappingTimeoutsOutputReference.go
- GoogleCloudRunDomainMappingTimeoutsOutputReference__checks.go
- GoogleCloudRunDomainMapping__checks.go
- main.go