Documentation
¶
Index ¶
- func GoogleComputeNetworkFirewallPolicyRule_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func GoogleComputeNetworkFirewallPolicyRule_IsConstruct(x interface{}) *bool
- func GoogleComputeNetworkFirewallPolicyRule_IsTerraformElement(x interface{}) *bool
- func GoogleComputeNetworkFirewallPolicyRule_IsTerraformResource(x interface{}) *bool
- func GoogleComputeNetworkFirewallPolicyRule_TfResourceType() *string
- func NewGoogleComputeNetworkFirewallPolicyRuleMatchLayer4ConfigsList_Override(g GoogleComputeNetworkFirewallPolicyRuleMatchLayer4ConfigsList, ...)
- func NewGoogleComputeNetworkFirewallPolicyRuleMatchLayer4ConfigsOutputReference_Override(g GoogleComputeNetworkFirewallPolicyRuleMatchLayer4ConfigsOutputReference, ...)
- func NewGoogleComputeNetworkFirewallPolicyRuleMatchOutputReference_Override(g GoogleComputeNetworkFirewallPolicyRuleMatchOutputReference, ...)
- func NewGoogleComputeNetworkFirewallPolicyRuleMatchSrcSecureTagsList_Override(g GoogleComputeNetworkFirewallPolicyRuleMatchSrcSecureTagsList, ...)
- func NewGoogleComputeNetworkFirewallPolicyRuleMatchSrcSecureTagsOutputReference_Override(g GoogleComputeNetworkFirewallPolicyRuleMatchSrcSecureTagsOutputReference, ...)
- func NewGoogleComputeNetworkFirewallPolicyRuleTargetSecureTagsList_Override(g GoogleComputeNetworkFirewallPolicyRuleTargetSecureTagsList, ...)
- func NewGoogleComputeNetworkFirewallPolicyRuleTargetSecureTagsOutputReference_Override(g GoogleComputeNetworkFirewallPolicyRuleTargetSecureTagsOutputReference, ...)
- func NewGoogleComputeNetworkFirewallPolicyRuleTimeoutsOutputReference_Override(g GoogleComputeNetworkFirewallPolicyRuleTimeoutsOutputReference, ...)
- func NewGoogleComputeNetworkFirewallPolicyRule_Override(g GoogleComputeNetworkFirewallPolicyRule, scope constructs.Construct, ...)
- type GoogleComputeNetworkFirewallPolicyRule
- type GoogleComputeNetworkFirewallPolicyRuleConfig
- type GoogleComputeNetworkFirewallPolicyRuleMatch
- type GoogleComputeNetworkFirewallPolicyRuleMatchLayer4Configs
- type GoogleComputeNetworkFirewallPolicyRuleMatchLayer4ConfigsList
- type GoogleComputeNetworkFirewallPolicyRuleMatchLayer4ConfigsOutputReference
- type GoogleComputeNetworkFirewallPolicyRuleMatchOutputReference
- type GoogleComputeNetworkFirewallPolicyRuleMatchSrcSecureTags
- type GoogleComputeNetworkFirewallPolicyRuleMatchSrcSecureTagsList
- type GoogleComputeNetworkFirewallPolicyRuleMatchSrcSecureTagsOutputReference
- type GoogleComputeNetworkFirewallPolicyRuleTargetSecureTags
- type GoogleComputeNetworkFirewallPolicyRuleTargetSecureTagsList
- type GoogleComputeNetworkFirewallPolicyRuleTargetSecureTagsOutputReference
- type GoogleComputeNetworkFirewallPolicyRuleTimeouts
- type GoogleComputeNetworkFirewallPolicyRuleTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleComputeNetworkFirewallPolicyRule_GenerateConfigForImport ¶
func GoogleComputeNetworkFirewallPolicyRule_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a GoogleComputeNetworkFirewallPolicyRule resource upon running "cdktf plan <stack-name>".
func GoogleComputeNetworkFirewallPolicyRule_IsConstruct ¶
func GoogleComputeNetworkFirewallPolicyRule_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleComputeNetworkFirewallPolicyRule_IsTerraformElement ¶
func GoogleComputeNetworkFirewallPolicyRule_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleComputeNetworkFirewallPolicyRule_IsTerraformResource ¶
func GoogleComputeNetworkFirewallPolicyRule_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleComputeNetworkFirewallPolicyRule_TfResourceType ¶
func GoogleComputeNetworkFirewallPolicyRule_TfResourceType() *string
func NewGoogleComputeNetworkFirewallPolicyRuleMatchLayer4ConfigsList_Override ¶
func NewGoogleComputeNetworkFirewallPolicyRuleMatchLayer4ConfigsList_Override(g GoogleComputeNetworkFirewallPolicyRuleMatchLayer4ConfigsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGoogleComputeNetworkFirewallPolicyRuleMatchLayer4ConfigsOutputReference_Override ¶
func NewGoogleComputeNetworkFirewallPolicyRuleMatchLayer4ConfigsOutputReference_Override(g GoogleComputeNetworkFirewallPolicyRuleMatchLayer4ConfigsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGoogleComputeNetworkFirewallPolicyRuleMatchOutputReference_Override ¶
func NewGoogleComputeNetworkFirewallPolicyRuleMatchOutputReference_Override(g GoogleComputeNetworkFirewallPolicyRuleMatchOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleComputeNetworkFirewallPolicyRuleMatchSrcSecureTagsList_Override ¶
func NewGoogleComputeNetworkFirewallPolicyRuleMatchSrcSecureTagsList_Override(g GoogleComputeNetworkFirewallPolicyRuleMatchSrcSecureTagsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGoogleComputeNetworkFirewallPolicyRuleMatchSrcSecureTagsOutputReference_Override ¶
func NewGoogleComputeNetworkFirewallPolicyRuleMatchSrcSecureTagsOutputReference_Override(g GoogleComputeNetworkFirewallPolicyRuleMatchSrcSecureTagsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGoogleComputeNetworkFirewallPolicyRuleTargetSecureTagsList_Override ¶
func NewGoogleComputeNetworkFirewallPolicyRuleTargetSecureTagsList_Override(g GoogleComputeNetworkFirewallPolicyRuleTargetSecureTagsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGoogleComputeNetworkFirewallPolicyRuleTargetSecureTagsOutputReference_Override ¶
func NewGoogleComputeNetworkFirewallPolicyRuleTargetSecureTagsOutputReference_Override(g GoogleComputeNetworkFirewallPolicyRuleTargetSecureTagsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGoogleComputeNetworkFirewallPolicyRuleTimeoutsOutputReference_Override ¶
func NewGoogleComputeNetworkFirewallPolicyRuleTimeoutsOutputReference_Override(g GoogleComputeNetworkFirewallPolicyRuleTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleComputeNetworkFirewallPolicyRule_Override ¶
func NewGoogleComputeNetworkFirewallPolicyRule_Override(g GoogleComputeNetworkFirewallPolicyRule, scope constructs.Construct, id *string, config *GoogleComputeNetworkFirewallPolicyRuleConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_compute_network_firewall_policy_rule google_compute_network_firewall_policy_rule} Resource.
Types ¶
type GoogleComputeNetworkFirewallPolicyRule ¶
type GoogleComputeNetworkFirewallPolicyRule interface {
cdktf.TerraformResource
Action() *string
SetAction(val *string)
ActionInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
CreationTimestamp() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
Direction() *string
SetDirection(val *string)
DirectionInput() *string
Disabled() interface{}
SetDisabled(val interface{})
DisabledInput() interface{}
EnableLogging() interface{}
SetEnableLogging(val interface{})
EnableLoggingInput() interface{}
FirewallPolicy() *string
SetFirewallPolicy(val *string)
FirewallPolicyInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
Kind() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Match() GoogleComputeNetworkFirewallPolicyRuleMatchOutputReference
MatchInput() *GoogleComputeNetworkFirewallPolicyRuleMatch
// The tree node.
Node() constructs.Node
Priority() *float64
SetPriority(val *float64)
PriorityInput() *float64
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
RuleName() *string
SetRuleName(val *string)
RuleNameInput() *string
RuleTupleCount() *float64
SecurityProfileGroup() *string
SetSecurityProfileGroup(val *string)
SecurityProfileGroupInput() *string
TargetSecureTags() GoogleComputeNetworkFirewallPolicyRuleTargetSecureTagsList
TargetSecureTagsInput() interface{}
TargetServiceAccounts() *[]*string
SetTargetServiceAccounts(val *[]*string)
TargetServiceAccountsInput() *[]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GoogleComputeNetworkFirewallPolicyRuleTimeoutsOutputReference
TimeoutsInput() interface{}
TlsInspect() interface{}
SetTlsInspect(val interface{})
TlsInspectInput() interface{}
// Adds a user defined moveTarget string to this resource to be later used in .moveTo(moveTarget) to resolve the location of the move.
// Experimental.
AddMoveTarget(moveTarget *string)
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
HasResourceMove() interface{}
// Experimental.
ImportFrom(id *string, provider cdktf.TerraformProvider)
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Move the resource corresponding to "id" to this resource.
//
// Note that the resource being moved from must be marked as moved using it's instance function.
// Experimental.
MoveFromId(id *string)
// Moves this resource to the target resource given by moveTarget.
// Experimental.
MoveTo(moveTarget *string, index interface{})
// Moves this resource to the resource corresponding to "id".
// Experimental.
MoveToId(id *string)
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutMatch(value *GoogleComputeNetworkFirewallPolicyRuleMatch)
PutTargetSecureTags(value interface{})
PutTimeouts(value *GoogleComputeNetworkFirewallPolicyRuleTimeouts)
ResetDescription()
ResetDisabled()
ResetEnableLogging()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
ResetRuleName()
ResetSecurityProfileGroup()
ResetTargetSecureTags()
ResetTargetServiceAccounts()
ResetTimeouts()
ResetTlsInspect()
SynthesizeAttributes() *map[string]interface{}
SynthesizeHclAttributes() *map[string]interface{}
// Experimental.
ToHclTerraform() interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_compute_network_firewall_policy_rule google_compute_network_firewall_policy_rule}.
func NewGoogleComputeNetworkFirewallPolicyRule ¶
func NewGoogleComputeNetworkFirewallPolicyRule(scope constructs.Construct, id *string, config *GoogleComputeNetworkFirewallPolicyRuleConfig) GoogleComputeNetworkFirewallPolicyRule
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_compute_network_firewall_policy_rule google_compute_network_firewall_policy_rule} Resource.
type GoogleComputeNetworkFirewallPolicyRuleConfig ¶
type GoogleComputeNetworkFirewallPolicyRuleConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// The Action to perform when the client connection triggers the rule. Valid actions are "allow", "deny", "goto_next" and "apply_security_profile_group".
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_compute_network_firewall_policy_rule#action GoogleComputeNetworkFirewallPolicyRule#action}
Action *string `field:"required" json:"action" yaml:"action"`
// The direction in which this rule applies. Possible values: ["INGRESS", "EGRESS"].
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_compute_network_firewall_policy_rule#direction GoogleComputeNetworkFirewallPolicyRule#direction}
Direction *string `field:"required" json:"direction" yaml:"direction"`
// The firewall policy of the resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_compute_network_firewall_policy_rule#firewall_policy GoogleComputeNetworkFirewallPolicyRule#firewall_policy}
FirewallPolicy *string `field:"required" json:"firewallPolicy" yaml:"firewallPolicy"`
// match block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_compute_network_firewall_policy_rule#match GoogleComputeNetworkFirewallPolicyRule#match}
Match *GoogleComputeNetworkFirewallPolicyRuleMatch `field:"required" json:"match" yaml:"match"`
// An integer indicating the priority of a rule in the list.
//
// The priority must be a positive value between 0 and 2147483647.
// Rules are evaluated from highest to lowest priority where 0 is the highest priority and 2147483647 is the lowest prority.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_compute_network_firewall_policy_rule#priority GoogleComputeNetworkFirewallPolicyRule#priority}
Priority *float64 `field:"required" json:"priority" yaml:"priority"`
// An optional description for this resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_compute_network_firewall_policy_rule#description GoogleComputeNetworkFirewallPolicyRule#description}
Description *string `field:"optional" json:"description" yaml:"description"`
// Denotes whether the firewall policy rule is disabled.
//
// When set to true, the firewall policy rule is not enforced and traffic behaves as if it did not exist.
// If this is unspecified, the firewall policy rule will be enabled.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_compute_network_firewall_policy_rule#disabled GoogleComputeNetworkFirewallPolicyRule#disabled}
Disabled interface{} `field:"optional" json:"disabled" yaml:"disabled"`
// Denotes whether to enable logging for a particular rule.
//
// If logging is enabled, logs will be exported to the configured export destination in Stackdriver.
// Logs may be exported to BigQuery or Pub/Sub.
// Note: you cannot enable logging on "goto_next" rules.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_compute_network_firewall_policy_rule#enable_logging GoogleComputeNetworkFirewallPolicyRule#enable_logging}
EnableLogging interface{} `field:"optional" json:"enableLogging" yaml:"enableLogging"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_compute_network_firewall_policy_rule#id GoogleComputeNetworkFirewallPolicyRule#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_compute_network_firewall_policy_rule#project GoogleComputeNetworkFirewallPolicyRule#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// An optional name for the rule. This field is not a unique identifier and can be updated.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_compute_network_firewall_policy_rule#rule_name GoogleComputeNetworkFirewallPolicyRule#rule_name}
RuleName *string `field:"optional" json:"ruleName" yaml:"ruleName"`
// A fully-qualified URL of a SecurityProfile resource instance.
//
// Example: https://networksecurity.googleapis.com/v1/projects/{project}/locations/{location}/securityProfileGroups/my-security-profile-group
// Must be specified if action = 'apply_security_profile_group' and cannot be specified for other actions.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_compute_network_firewall_policy_rule#security_profile_group GoogleComputeNetworkFirewallPolicyRule#security_profile_group}
SecurityProfileGroup *string `field:"optional" json:"securityProfileGroup" yaml:"securityProfileGroup"`
// target_secure_tags block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_compute_network_firewall_policy_rule#target_secure_tags GoogleComputeNetworkFirewallPolicyRule#target_secure_tags}
TargetSecureTags interface{} `field:"optional" json:"targetSecureTags" yaml:"targetSecureTags"`
// A list of service accounts indicating the sets of instances that are applied with this rule.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_compute_network_firewall_policy_rule#target_service_accounts GoogleComputeNetworkFirewallPolicyRule#target_service_accounts}
TargetServiceAccounts *[]*string `field:"optional" json:"targetServiceAccounts" yaml:"targetServiceAccounts"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_compute_network_firewall_policy_rule#timeouts GoogleComputeNetworkFirewallPolicyRule#timeouts}
Timeouts *GoogleComputeNetworkFirewallPolicyRuleTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
// Boolean flag indicating if the traffic should be TLS decrypted.
//
// Can be set only if action = 'apply_security_profile_group' and cannot be set for other actions.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_compute_network_firewall_policy_rule#tls_inspect GoogleComputeNetworkFirewallPolicyRule#tls_inspect}
TlsInspect interface{} `field:"optional" json:"tlsInspect" yaml:"tlsInspect"`
}
type GoogleComputeNetworkFirewallPolicyRuleMatch ¶
type GoogleComputeNetworkFirewallPolicyRuleMatch struct {
// layer4_configs block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_compute_network_firewall_policy_rule#layer4_configs GoogleComputeNetworkFirewallPolicyRule#layer4_configs}
Layer4Configs interface{} `field:"required" json:"layer4Configs" yaml:"layer4Configs"`
// Address groups which should be matched against the traffic destination. Maximum number of destination address groups is 10.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_compute_network_firewall_policy_rule#dest_address_groups GoogleComputeNetworkFirewallPolicyRule#dest_address_groups}
DestAddressGroups *[]*string `field:"optional" json:"destAddressGroups" yaml:"destAddressGroups"`
// Fully Qualified Domain Name (FQDN) which should be matched against traffic destination.
//
// Maximum number of destination fqdn allowed is 100.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_compute_network_firewall_policy_rule#dest_fqdns GoogleComputeNetworkFirewallPolicyRule#dest_fqdns}
DestFqdns *[]*string `field:"optional" json:"destFqdns" yaml:"destFqdns"`
// CIDR IP address range. Maximum number of destination CIDR IP ranges allowed is 5000.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_compute_network_firewall_policy_rule#dest_ip_ranges GoogleComputeNetworkFirewallPolicyRule#dest_ip_ranges}
DestIpRanges *[]*string `field:"optional" json:"destIpRanges" yaml:"destIpRanges"`
// Network scope of the traffic destination. Possible values: ["INTERNET", "INTRA_VPC", "NON_INTERNET", "VPC_NETWORKS"].
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_compute_network_firewall_policy_rule#dest_network_scope GoogleComputeNetworkFirewallPolicyRule#dest_network_scope}
DestNetworkScope *string `field:"optional" json:"destNetworkScope" yaml:"destNetworkScope"`
// Region codes whose IP addresses will be used to match for destination of traffic.
//
// Should be specified as 2 letter country code defined as per ISO 3166 alpha-2 country codes. ex."US" Maximum number of dest region codes allowed is 5000.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_compute_network_firewall_policy_rule#dest_region_codes GoogleComputeNetworkFirewallPolicyRule#dest_region_codes}
DestRegionCodes *[]*string `field:"optional" json:"destRegionCodes" yaml:"destRegionCodes"`
// Names of Network Threat Intelligence lists. The IPs in these lists will be matched against traffic destination.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_compute_network_firewall_policy_rule#dest_threat_intelligences GoogleComputeNetworkFirewallPolicyRule#dest_threat_intelligences}
DestThreatIntelligences *[]*string `field:"optional" json:"destThreatIntelligences" yaml:"destThreatIntelligences"`
// Address groups which should be matched against the traffic source. Maximum number of source address groups is 10.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_compute_network_firewall_policy_rule#src_address_groups GoogleComputeNetworkFirewallPolicyRule#src_address_groups}
SrcAddressGroups *[]*string `field:"optional" json:"srcAddressGroups" yaml:"srcAddressGroups"`
// Fully Qualified Domain Name (FQDN) which should be matched against traffic source.
//
// Maximum number of source fqdn allowed is 100.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_compute_network_firewall_policy_rule#src_fqdns GoogleComputeNetworkFirewallPolicyRule#src_fqdns}
SrcFqdns *[]*string `field:"optional" json:"srcFqdns" yaml:"srcFqdns"`
// CIDR IP address range. Maximum number of source CIDR IP ranges allowed is 5000.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_compute_network_firewall_policy_rule#src_ip_ranges GoogleComputeNetworkFirewallPolicyRule#src_ip_ranges}
SrcIpRanges *[]*string `field:"optional" json:"srcIpRanges" yaml:"srcIpRanges"`
// Networks of the traffic source. It can be either a full or partial url.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_compute_network_firewall_policy_rule#src_networks GoogleComputeNetworkFirewallPolicyRule#src_networks}
SrcNetworks *[]*string `field:"optional" json:"srcNetworks" yaml:"srcNetworks"`
// Network scope of the traffic source. Possible values: ["INTERNET", "INTRA_VPC", "NON_INTERNET", "VPC_NETWORKS"].
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_compute_network_firewall_policy_rule#src_network_scope GoogleComputeNetworkFirewallPolicyRule#src_network_scope}
SrcNetworkScope *string `field:"optional" json:"srcNetworkScope" yaml:"srcNetworkScope"`
// Region codes whose IP addresses will be used to match for source of traffic.
//
// Should be specified as 2 letter country code defined as per ISO 3166 alpha-2 country codes. ex."US" Maximum number of source region codes allowed is 5000.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_compute_network_firewall_policy_rule#src_region_codes GoogleComputeNetworkFirewallPolicyRule#src_region_codes}
SrcRegionCodes *[]*string `field:"optional" json:"srcRegionCodes" yaml:"srcRegionCodes"`
// src_secure_tags block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_compute_network_firewall_policy_rule#src_secure_tags GoogleComputeNetworkFirewallPolicyRule#src_secure_tags}
SrcSecureTags interface{} `field:"optional" json:"srcSecureTags" yaml:"srcSecureTags"`
// Names of Network Threat Intelligence lists. The IPs in these lists will be matched against traffic source.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_compute_network_firewall_policy_rule#src_threat_intelligences GoogleComputeNetworkFirewallPolicyRule#src_threat_intelligences}
SrcThreatIntelligences *[]*string `field:"optional" json:"srcThreatIntelligences" yaml:"srcThreatIntelligences"`
}
type GoogleComputeNetworkFirewallPolicyRuleMatchLayer4Configs ¶
type GoogleComputeNetworkFirewallPolicyRuleMatchLayer4Configs struct {
// The IP protocol to which this rule applies.
//
// The protocol type is required when creating a firewall rule.
// This value can either be one of the following well known protocol strings (tcp, udp, icmp, esp, ah, ipip, sctp), or the IP protocol number.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_compute_network_firewall_policy_rule#ip_protocol GoogleComputeNetworkFirewallPolicyRule#ip_protocol}
IpProtocol *string `field:"required" json:"ipProtocol" yaml:"ipProtocol"`
// An optional list of ports to which this rule applies.
//
// This field is only applicable for UDP or TCP protocol. Each entry must be either an integer or a range. If not specified, this rule applies to connections through any port.
// Example inputs include: ["22"], ["80","443"], and ["12345-12349"].
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_compute_network_firewall_policy_rule#ports GoogleComputeNetworkFirewallPolicyRule#ports}
Ports *[]*string `field:"optional" json:"ports" yaml:"ports"`
}
type GoogleComputeNetworkFirewallPolicyRuleMatchLayer4ConfigsList ¶
type GoogleComputeNetworkFirewallPolicyRuleMatchLayer4ConfigsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) GoogleComputeNetworkFirewallPolicyRuleMatchLayer4ConfigsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleComputeNetworkFirewallPolicyRuleMatchLayer4ConfigsList ¶
func NewGoogleComputeNetworkFirewallPolicyRuleMatchLayer4ConfigsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GoogleComputeNetworkFirewallPolicyRuleMatchLayer4ConfigsList
type GoogleComputeNetworkFirewallPolicyRuleMatchLayer4ConfigsOutputReference ¶
type GoogleComputeNetworkFirewallPolicyRuleMatchLayer4ConfigsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
IpProtocol() *string
SetIpProtocol(val *string)
IpProtocolInput() *string
Ports() *[]*string
SetPorts(val *[]*string)
PortsInput() *[]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetPorts()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleComputeNetworkFirewallPolicyRuleMatchLayer4ConfigsOutputReference ¶
func NewGoogleComputeNetworkFirewallPolicyRuleMatchLayer4ConfigsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GoogleComputeNetworkFirewallPolicyRuleMatchLayer4ConfigsOutputReference
type GoogleComputeNetworkFirewallPolicyRuleMatchOutputReference ¶
type GoogleComputeNetworkFirewallPolicyRuleMatchOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DestAddressGroups() *[]*string
SetDestAddressGroups(val *[]*string)
DestAddressGroupsInput() *[]*string
DestFqdns() *[]*string
SetDestFqdns(val *[]*string)
DestFqdnsInput() *[]*string
DestIpRanges() *[]*string
SetDestIpRanges(val *[]*string)
DestIpRangesInput() *[]*string
DestNetworkScope() *string
SetDestNetworkScope(val *string)
DestNetworkScopeInput() *string
DestRegionCodes() *[]*string
SetDestRegionCodes(val *[]*string)
DestRegionCodesInput() *[]*string
DestThreatIntelligences() *[]*string
SetDestThreatIntelligences(val *[]*string)
DestThreatIntelligencesInput() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleComputeNetworkFirewallPolicyRuleMatch
SetInternalValue(val *GoogleComputeNetworkFirewallPolicyRuleMatch)
Layer4Configs() GoogleComputeNetworkFirewallPolicyRuleMatchLayer4ConfigsList
Layer4ConfigsInput() interface{}
SrcAddressGroups() *[]*string
SetSrcAddressGroups(val *[]*string)
SrcAddressGroupsInput() *[]*string
SrcFqdns() *[]*string
SetSrcFqdns(val *[]*string)
SrcFqdnsInput() *[]*string
SrcIpRanges() *[]*string
SetSrcIpRanges(val *[]*string)
SrcIpRangesInput() *[]*string
SrcNetworks() *[]*string
SetSrcNetworks(val *[]*string)
SrcNetworkScope() *string
SetSrcNetworkScope(val *string)
SrcNetworkScopeInput() *string
SrcNetworksInput() *[]*string
SrcRegionCodes() *[]*string
SetSrcRegionCodes(val *[]*string)
SrcRegionCodesInput() *[]*string
SrcSecureTags() GoogleComputeNetworkFirewallPolicyRuleMatchSrcSecureTagsList
SrcSecureTagsInput() interface{}
SrcThreatIntelligences() *[]*string
SetSrcThreatIntelligences(val *[]*string)
SrcThreatIntelligencesInput() *[]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutLayer4Configs(value interface{})
PutSrcSecureTags(value interface{})
ResetDestAddressGroups()
ResetDestFqdns()
ResetDestIpRanges()
ResetDestNetworkScope()
ResetDestRegionCodes()
ResetDestThreatIntelligences()
ResetSrcAddressGroups()
ResetSrcFqdns()
ResetSrcIpRanges()
ResetSrcNetworks()
ResetSrcNetworkScope()
ResetSrcRegionCodes()
ResetSrcSecureTags()
ResetSrcThreatIntelligences()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleComputeNetworkFirewallPolicyRuleMatchOutputReference ¶
func NewGoogleComputeNetworkFirewallPolicyRuleMatchOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleComputeNetworkFirewallPolicyRuleMatchOutputReference
type GoogleComputeNetworkFirewallPolicyRuleMatchSrcSecureTags ¶
type GoogleComputeNetworkFirewallPolicyRuleMatchSrcSecureTags struct {
// Name of the secure tag, created with TagManager's TagValue API.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_compute_network_firewall_policy_rule#name GoogleComputeNetworkFirewallPolicyRule#name}
Name *string `field:"optional" json:"name" yaml:"name"`
}
type GoogleComputeNetworkFirewallPolicyRuleMatchSrcSecureTagsList ¶
type GoogleComputeNetworkFirewallPolicyRuleMatchSrcSecureTagsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) GoogleComputeNetworkFirewallPolicyRuleMatchSrcSecureTagsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleComputeNetworkFirewallPolicyRuleMatchSrcSecureTagsList ¶
func NewGoogleComputeNetworkFirewallPolicyRuleMatchSrcSecureTagsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GoogleComputeNetworkFirewallPolicyRuleMatchSrcSecureTagsList
type GoogleComputeNetworkFirewallPolicyRuleMatchSrcSecureTagsOutputReference ¶
type GoogleComputeNetworkFirewallPolicyRuleMatchSrcSecureTagsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Name() *string
SetName(val *string)
NameInput() *string
State() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetName()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleComputeNetworkFirewallPolicyRuleMatchSrcSecureTagsOutputReference ¶
func NewGoogleComputeNetworkFirewallPolicyRuleMatchSrcSecureTagsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GoogleComputeNetworkFirewallPolicyRuleMatchSrcSecureTagsOutputReference
type GoogleComputeNetworkFirewallPolicyRuleTargetSecureTags ¶
type GoogleComputeNetworkFirewallPolicyRuleTargetSecureTags struct {
// Name of the secure tag, created with TagManager's TagValue API.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_compute_network_firewall_policy_rule#name GoogleComputeNetworkFirewallPolicyRule#name}
Name *string `field:"optional" json:"name" yaml:"name"`
}
type GoogleComputeNetworkFirewallPolicyRuleTargetSecureTagsList ¶
type GoogleComputeNetworkFirewallPolicyRuleTargetSecureTagsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) GoogleComputeNetworkFirewallPolicyRuleTargetSecureTagsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleComputeNetworkFirewallPolicyRuleTargetSecureTagsList ¶
func NewGoogleComputeNetworkFirewallPolicyRuleTargetSecureTagsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GoogleComputeNetworkFirewallPolicyRuleTargetSecureTagsList
type GoogleComputeNetworkFirewallPolicyRuleTargetSecureTagsOutputReference ¶
type GoogleComputeNetworkFirewallPolicyRuleTargetSecureTagsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Name() *string
SetName(val *string)
NameInput() *string
State() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetName()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleComputeNetworkFirewallPolicyRuleTargetSecureTagsOutputReference ¶
func NewGoogleComputeNetworkFirewallPolicyRuleTargetSecureTagsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GoogleComputeNetworkFirewallPolicyRuleTargetSecureTagsOutputReference
type GoogleComputeNetworkFirewallPolicyRuleTimeouts ¶
type GoogleComputeNetworkFirewallPolicyRuleTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_compute_network_firewall_policy_rule#create GoogleComputeNetworkFirewallPolicyRule#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_compute_network_firewall_policy_rule#delete GoogleComputeNetworkFirewallPolicyRule#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_compute_network_firewall_policy_rule#update GoogleComputeNetworkFirewallPolicyRule#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type GoogleComputeNetworkFirewallPolicyRuleTimeoutsOutputReference ¶
type GoogleComputeNetworkFirewallPolicyRuleTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleComputeNetworkFirewallPolicyRuleTimeoutsOutputReference ¶
func NewGoogleComputeNetworkFirewallPolicyRuleTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleComputeNetworkFirewallPolicyRuleTimeoutsOutputReference
Source Files
¶
- GoogleComputeNetworkFirewallPolicyRule.go
- GoogleComputeNetworkFirewallPolicyRuleConfig.go
- GoogleComputeNetworkFirewallPolicyRuleMatch.go
- GoogleComputeNetworkFirewallPolicyRuleMatchLayer4Configs.go
- GoogleComputeNetworkFirewallPolicyRuleMatchLayer4ConfigsList.go
- GoogleComputeNetworkFirewallPolicyRuleMatchLayer4ConfigsList__checks.go
- GoogleComputeNetworkFirewallPolicyRuleMatchLayer4ConfigsOutputReference.go
- GoogleComputeNetworkFirewallPolicyRuleMatchLayer4ConfigsOutputReference__checks.go
- GoogleComputeNetworkFirewallPolicyRuleMatchOutputReference.go
- GoogleComputeNetworkFirewallPolicyRuleMatchOutputReference__checks.go
- GoogleComputeNetworkFirewallPolicyRuleMatchSrcSecureTags.go
- GoogleComputeNetworkFirewallPolicyRuleMatchSrcSecureTagsList.go
- GoogleComputeNetworkFirewallPolicyRuleMatchSrcSecureTagsList__checks.go
- GoogleComputeNetworkFirewallPolicyRuleMatchSrcSecureTagsOutputReference.go
- GoogleComputeNetworkFirewallPolicyRuleMatchSrcSecureTagsOutputReference__checks.go
- GoogleComputeNetworkFirewallPolicyRuleTargetSecureTags.go
- GoogleComputeNetworkFirewallPolicyRuleTargetSecureTagsList.go
- GoogleComputeNetworkFirewallPolicyRuleTargetSecureTagsList__checks.go
- GoogleComputeNetworkFirewallPolicyRuleTargetSecureTagsOutputReference.go
- GoogleComputeNetworkFirewallPolicyRuleTargetSecureTagsOutputReference__checks.go
- GoogleComputeNetworkFirewallPolicyRuleTimeouts.go
- GoogleComputeNetworkFirewallPolicyRuleTimeoutsOutputReference.go
- GoogleComputeNetworkFirewallPolicyRuleTimeoutsOutputReference__checks.go
- GoogleComputeNetworkFirewallPolicyRule__checks.go
- main.go