Documentation
¶
Index ¶
- func GoogleComputeServiceAttachment_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func GoogleComputeServiceAttachment_IsConstruct(x interface{}) *bool
- func GoogleComputeServiceAttachment_IsTerraformElement(x interface{}) *bool
- func GoogleComputeServiceAttachment_IsTerraformResource(x interface{}) *bool
- func GoogleComputeServiceAttachment_TfResourceType() *string
- func NewGoogleComputeServiceAttachmentConnectedEndpointsList_Override(g GoogleComputeServiceAttachmentConnectedEndpointsList, ...)
- func NewGoogleComputeServiceAttachmentConnectedEndpointsOutputReference_Override(g GoogleComputeServiceAttachmentConnectedEndpointsOutputReference, ...)
- func NewGoogleComputeServiceAttachmentConsumerAcceptListsList_Override(g GoogleComputeServiceAttachmentConsumerAcceptListsList, ...)
- func NewGoogleComputeServiceAttachmentConsumerAcceptListsOutputReference_Override(g GoogleComputeServiceAttachmentConsumerAcceptListsOutputReference, ...)
- func NewGoogleComputeServiceAttachmentTimeoutsOutputReference_Override(g GoogleComputeServiceAttachmentTimeoutsOutputReference, ...)
- func NewGoogleComputeServiceAttachment_Override(g GoogleComputeServiceAttachment, scope constructs.Construct, id *string, ...)
- type GoogleComputeServiceAttachment
- type GoogleComputeServiceAttachmentConfig
- type GoogleComputeServiceAttachmentConnectedEndpoints
- type GoogleComputeServiceAttachmentConnectedEndpointsList
- type GoogleComputeServiceAttachmentConnectedEndpointsOutputReference
- type GoogleComputeServiceAttachmentConsumerAcceptLists
- type GoogleComputeServiceAttachmentConsumerAcceptListsList
- type GoogleComputeServiceAttachmentConsumerAcceptListsOutputReference
- type GoogleComputeServiceAttachmentTimeouts
- type GoogleComputeServiceAttachmentTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleComputeServiceAttachment_GenerateConfigForImport ¶
func GoogleComputeServiceAttachment_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a GoogleComputeServiceAttachment resource upon running "cdktf plan <stack-name>".
func GoogleComputeServiceAttachment_IsConstruct ¶
func GoogleComputeServiceAttachment_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleComputeServiceAttachment_IsTerraformElement ¶
func GoogleComputeServiceAttachment_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleComputeServiceAttachment_IsTerraformResource ¶
func GoogleComputeServiceAttachment_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleComputeServiceAttachment_TfResourceType ¶
func GoogleComputeServiceAttachment_TfResourceType() *string
func NewGoogleComputeServiceAttachmentConnectedEndpointsList_Override ¶
func NewGoogleComputeServiceAttachmentConnectedEndpointsList_Override(g GoogleComputeServiceAttachmentConnectedEndpointsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGoogleComputeServiceAttachmentConnectedEndpointsOutputReference_Override ¶
func NewGoogleComputeServiceAttachmentConnectedEndpointsOutputReference_Override(g GoogleComputeServiceAttachmentConnectedEndpointsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGoogleComputeServiceAttachmentConsumerAcceptListsList_Override ¶
func NewGoogleComputeServiceAttachmentConsumerAcceptListsList_Override(g GoogleComputeServiceAttachmentConsumerAcceptListsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGoogleComputeServiceAttachmentConsumerAcceptListsOutputReference_Override ¶
func NewGoogleComputeServiceAttachmentConsumerAcceptListsOutputReference_Override(g GoogleComputeServiceAttachmentConsumerAcceptListsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGoogleComputeServiceAttachmentTimeoutsOutputReference_Override ¶
func NewGoogleComputeServiceAttachmentTimeoutsOutputReference_Override(g GoogleComputeServiceAttachmentTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleComputeServiceAttachment_Override ¶
func NewGoogleComputeServiceAttachment_Override(g GoogleComputeServiceAttachment, scope constructs.Construct, id *string, config *GoogleComputeServiceAttachmentConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_compute_service_attachment google_compute_service_attachment} Resource.
Types ¶
type GoogleComputeServiceAttachment ¶
type GoogleComputeServiceAttachment interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
ConnectedEndpoints() GoogleComputeServiceAttachmentConnectedEndpointsList
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
ConnectionPreference() *string
SetConnectionPreference(val *string)
ConnectionPreferenceInput() *string
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
ConsumerAcceptLists() GoogleComputeServiceAttachmentConsumerAcceptListsList
ConsumerAcceptListsInput() interface{}
ConsumerRejectLists() *[]*string
SetConsumerRejectLists(val *[]*string)
ConsumerRejectListsInput() *[]*string
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
DomainNames() *[]*string
SetDomainNames(val *[]*string)
DomainNamesInput() *[]*string
EnableProxyProtocol() interface{}
SetEnableProxyProtocol(val interface{})
EnableProxyProtocolInput() interface{}
Fingerprint() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
NatSubnets() *[]*string
SetNatSubnets(val *[]*string)
NatSubnetsInput() *[]*string
// The tree node.
Node() constructs.Node
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
ReconcileConnections() interface{}
SetReconcileConnections(val interface{})
ReconcileConnectionsInput() interface{}
Region() *string
SetRegion(val *string)
RegionInput() *string
SelfLink() *string
TargetService() *string
SetTargetService(val *string)
TargetServiceInput() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GoogleComputeServiceAttachmentTimeoutsOutputReference
TimeoutsInput() interface{}
// Adds a user defined moveTarget string to this resource to be later used in .moveTo(moveTarget) to resolve the location of the move.
// Experimental.
AddMoveTarget(moveTarget *string)
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
HasResourceMove() interface{}
// Experimental.
ImportFrom(id *string, provider cdktf.TerraformProvider)
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Move the resource corresponding to "id" to this resource.
//
// Note that the resource being moved from must be marked as moved using it's instance function.
// Experimental.
MoveFromId(id *string)
// Moves this resource to the target resource given by moveTarget.
// Experimental.
MoveTo(moveTarget *string, index interface{})
// Moves this resource to the resource corresponding to "id".
// Experimental.
MoveToId(id *string)
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutConsumerAcceptLists(value interface{})
PutTimeouts(value *GoogleComputeServiceAttachmentTimeouts)
ResetConsumerAcceptLists()
ResetConsumerRejectLists()
ResetDescription()
ResetDomainNames()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
ResetReconcileConnections()
ResetRegion()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
SynthesizeHclAttributes() *map[string]interface{}
// Experimental.
ToHclTerraform() interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_compute_service_attachment google_compute_service_attachment}.
func NewGoogleComputeServiceAttachment ¶
func NewGoogleComputeServiceAttachment(scope constructs.Construct, id *string, config *GoogleComputeServiceAttachmentConfig) GoogleComputeServiceAttachment
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_compute_service_attachment google_compute_service_attachment} Resource.
type GoogleComputeServiceAttachmentConfig ¶
type GoogleComputeServiceAttachmentConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// The connection preference to use for this service attachment. Valid values include "ACCEPT_AUTOMATIC", "ACCEPT_MANUAL".
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_compute_service_attachment#connection_preference GoogleComputeServiceAttachment#connection_preference}
ConnectionPreference *string `field:"required" json:"connectionPreference" yaml:"connectionPreference"`
// If true, enable the proxy protocol which is for supplying client TCP/IP address data in TCP connections that traverse proxies on their way to destination servers.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_compute_service_attachment#enable_proxy_protocol GoogleComputeServiceAttachment#enable_proxy_protocol}
EnableProxyProtocol interface{} `field:"required" json:"enableProxyProtocol" yaml:"enableProxyProtocol"`
// Name of the resource.
//
// The name must be 1-63 characters long, and
// comply with RFC1035. Specifically, the name must be 1-63 characters
// long and match the regular expression '[a-z]([-a-z0-9]*[a-z0-9])?'
// which means the first character must be a lowercase letter, and all
// following characters must be a dash, lowercase letter, or digit,
// except the last character, which cannot be a dash.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_compute_service_attachment#name GoogleComputeServiceAttachment#name}
Name *string `field:"required" json:"name" yaml:"name"`
// An array of subnets that is provided for NAT in this service attachment.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_compute_service_attachment#nat_subnets GoogleComputeServiceAttachment#nat_subnets}
NatSubnets *[]*string `field:"required" json:"natSubnets" yaml:"natSubnets"`
// The URL of a service serving the endpoint identified by this service attachment.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_compute_service_attachment#target_service GoogleComputeServiceAttachment#target_service}
TargetService *string `field:"required" json:"targetService" yaml:"targetService"`
// consumer_accept_lists block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_compute_service_attachment#consumer_accept_lists GoogleComputeServiceAttachment#consumer_accept_lists}
ConsumerAcceptLists interface{} `field:"optional" json:"consumerAcceptLists" yaml:"consumerAcceptLists"`
// An array of projects that are not allowed to connect to this service attachment.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_compute_service_attachment#consumer_reject_lists GoogleComputeServiceAttachment#consumer_reject_lists}
ConsumerRejectLists *[]*string `field:"optional" json:"consumerRejectLists" yaml:"consumerRejectLists"`
// An optional description of this resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_compute_service_attachment#description GoogleComputeServiceAttachment#description}
Description *string `field:"optional" json:"description" yaml:"description"`
// If specified, the domain name will be used during the integration between the PSC connected endpoints and the Cloud DNS.
//
// For example, this is a
// valid domain name: "p.mycompany.com.". Current max number of domain names
// supported is 1.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_compute_service_attachment#domain_names GoogleComputeServiceAttachment#domain_names}
DomainNames *[]*string `field:"optional" json:"domainNames" yaml:"domainNames"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_compute_service_attachment#id GoogleComputeServiceAttachment#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_compute_service_attachment#project GoogleComputeServiceAttachment#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// This flag determines whether a consumer accept/reject list change can reconcile the statuses of existing ACCEPTED or REJECTED PSC endpoints.
//
// If false, connection policy update will only affect existing PENDING PSC endpoints. Existing ACCEPTED/REJECTED endpoints will remain untouched regardless how the connection policy is modified .
// If true, update will affect both PENDING and ACCEPTED/REJECTED PSC endpoints. For example, an ACCEPTED PSC endpoint will be moved to REJECTED if its project is added to the reject list.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_compute_service_attachment#reconcile_connections GoogleComputeServiceAttachment#reconcile_connections}
ReconcileConnections interface{} `field:"optional" json:"reconcileConnections" yaml:"reconcileConnections"`
// URL of the region where the resource resides.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_compute_service_attachment#region GoogleComputeServiceAttachment#region}
Region *string `field:"optional" json:"region" yaml:"region"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_compute_service_attachment#timeouts GoogleComputeServiceAttachment#timeouts}
Timeouts *GoogleComputeServiceAttachmentTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type GoogleComputeServiceAttachmentConnectedEndpoints ¶
type GoogleComputeServiceAttachmentConnectedEndpoints struct {
}
type GoogleComputeServiceAttachmentConnectedEndpointsList ¶
type GoogleComputeServiceAttachmentConnectedEndpointsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) GoogleComputeServiceAttachmentConnectedEndpointsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleComputeServiceAttachmentConnectedEndpointsList ¶
func NewGoogleComputeServiceAttachmentConnectedEndpointsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GoogleComputeServiceAttachmentConnectedEndpointsList
type GoogleComputeServiceAttachmentConnectedEndpointsOutputReference ¶
type GoogleComputeServiceAttachmentConnectedEndpointsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Endpoint() *string
// Experimental.
Fqn() *string
InternalValue() *GoogleComputeServiceAttachmentConnectedEndpoints
SetInternalValue(val *GoogleComputeServiceAttachmentConnectedEndpoints)
Status() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleComputeServiceAttachmentConnectedEndpointsOutputReference ¶
func NewGoogleComputeServiceAttachmentConnectedEndpointsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GoogleComputeServiceAttachmentConnectedEndpointsOutputReference
type GoogleComputeServiceAttachmentConsumerAcceptLists ¶
type GoogleComputeServiceAttachmentConsumerAcceptLists struct {
// The number of consumer forwarding rules the consumer project can create.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_compute_service_attachment#connection_limit GoogleComputeServiceAttachment#connection_limit}
ConnectionLimit *float64 `field:"required" json:"connectionLimit" yaml:"connectionLimit"`
// The network that is allowed to connect to this service attachment. Only one of project_id_or_num and network_url may be set.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_compute_service_attachment#network_url GoogleComputeServiceAttachment#network_url}
NetworkUrl *string `field:"optional" json:"networkUrl" yaml:"networkUrl"`
// A project that is allowed to connect to this service attachment. Only one of project_id_or_num and network_url may be set.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_compute_service_attachment#project_id_or_num GoogleComputeServiceAttachment#project_id_or_num}
ProjectIdOrNum *string `field:"optional" json:"projectIdOrNum" yaml:"projectIdOrNum"`
}
type GoogleComputeServiceAttachmentConsumerAcceptListsList ¶
type GoogleComputeServiceAttachmentConsumerAcceptListsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) GoogleComputeServiceAttachmentConsumerAcceptListsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleComputeServiceAttachmentConsumerAcceptListsList ¶
func NewGoogleComputeServiceAttachmentConsumerAcceptListsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GoogleComputeServiceAttachmentConsumerAcceptListsList
type GoogleComputeServiceAttachmentConsumerAcceptListsOutputReference ¶
type GoogleComputeServiceAttachmentConsumerAcceptListsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
ConnectionLimit() *float64
SetConnectionLimit(val *float64)
ConnectionLimitInput() *float64
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
NetworkUrl() *string
SetNetworkUrl(val *string)
NetworkUrlInput() *string
ProjectIdOrNum() *string
SetProjectIdOrNum(val *string)
ProjectIdOrNumInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetNetworkUrl()
ResetProjectIdOrNum()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleComputeServiceAttachmentConsumerAcceptListsOutputReference ¶
func NewGoogleComputeServiceAttachmentConsumerAcceptListsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GoogleComputeServiceAttachmentConsumerAcceptListsOutputReference
type GoogleComputeServiceAttachmentTimeouts ¶
type GoogleComputeServiceAttachmentTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_compute_service_attachment#create GoogleComputeServiceAttachment#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_compute_service_attachment#delete GoogleComputeServiceAttachment#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_compute_service_attachment#update GoogleComputeServiceAttachment#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type GoogleComputeServiceAttachmentTimeoutsOutputReference ¶
type GoogleComputeServiceAttachmentTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleComputeServiceAttachmentTimeoutsOutputReference ¶
func NewGoogleComputeServiceAttachmentTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleComputeServiceAttachmentTimeoutsOutputReference
Source Files
¶
- GoogleComputeServiceAttachment.go
- GoogleComputeServiceAttachmentConfig.go
- GoogleComputeServiceAttachmentConnectedEndpoints.go
- GoogleComputeServiceAttachmentConnectedEndpointsList.go
- GoogleComputeServiceAttachmentConnectedEndpointsList__checks.go
- GoogleComputeServiceAttachmentConnectedEndpointsOutputReference.go
- GoogleComputeServiceAttachmentConnectedEndpointsOutputReference__checks.go
- GoogleComputeServiceAttachmentConsumerAcceptLists.go
- GoogleComputeServiceAttachmentConsumerAcceptListsList.go
- GoogleComputeServiceAttachmentConsumerAcceptListsList__checks.go
- GoogleComputeServiceAttachmentConsumerAcceptListsOutputReference.go
- GoogleComputeServiceAttachmentConsumerAcceptListsOutputReference__checks.go
- GoogleComputeServiceAttachmentTimeouts.go
- GoogleComputeServiceAttachmentTimeoutsOutputReference.go
- GoogleComputeServiceAttachmentTimeoutsOutputReference__checks.go
- GoogleComputeServiceAttachment__checks.go
- main.go