Documentation
¶
Index ¶
- func GoogleDataCatalogTag_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func GoogleDataCatalogTag_IsConstruct(x interface{}) *bool
- func GoogleDataCatalogTag_IsTerraformElement(x interface{}) *bool
- func GoogleDataCatalogTag_IsTerraformResource(x interface{}) *bool
- func GoogleDataCatalogTag_TfResourceType() *string
- func NewGoogleDataCatalogTagFieldsList_Override(g GoogleDataCatalogTagFieldsList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewGoogleDataCatalogTagFieldsOutputReference_Override(g GoogleDataCatalogTagFieldsOutputReference, ...)
- func NewGoogleDataCatalogTagTimeoutsOutputReference_Override(g GoogleDataCatalogTagTimeoutsOutputReference, ...)
- func NewGoogleDataCatalogTag_Override(g GoogleDataCatalogTag, scope constructs.Construct, id *string, ...)
- type GoogleDataCatalogTag
- type GoogleDataCatalogTagConfig
- type GoogleDataCatalogTagFields
- type GoogleDataCatalogTagFieldsList
- type GoogleDataCatalogTagFieldsOutputReference
- type GoogleDataCatalogTagTimeouts
- type GoogleDataCatalogTagTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleDataCatalogTag_GenerateConfigForImport ¶
func GoogleDataCatalogTag_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a GoogleDataCatalogTag resource upon running "cdktf plan <stack-name>".
func GoogleDataCatalogTag_IsConstruct ¶
func GoogleDataCatalogTag_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleDataCatalogTag_IsTerraformElement ¶
func GoogleDataCatalogTag_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleDataCatalogTag_IsTerraformResource ¶
func GoogleDataCatalogTag_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleDataCatalogTag_TfResourceType ¶
func GoogleDataCatalogTag_TfResourceType() *string
func NewGoogleDataCatalogTagFieldsList_Override ¶
func NewGoogleDataCatalogTagFieldsList_Override(g GoogleDataCatalogTagFieldsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGoogleDataCatalogTagFieldsOutputReference_Override ¶
func NewGoogleDataCatalogTagFieldsOutputReference_Override(g GoogleDataCatalogTagFieldsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGoogleDataCatalogTagTimeoutsOutputReference_Override ¶
func NewGoogleDataCatalogTagTimeoutsOutputReference_Override(g GoogleDataCatalogTagTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleDataCatalogTag_Override ¶
func NewGoogleDataCatalogTag_Override(g GoogleDataCatalogTag, scope constructs.Construct, id *string, config *GoogleDataCatalogTagConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_data_catalog_tag google_data_catalog_tag} Resource.
Types ¶
type GoogleDataCatalogTag ¶
type GoogleDataCatalogTag interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
Column() *string
SetColumn(val *string)
ColumnInput() *string
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Fields() GoogleDataCatalogTagFieldsList
FieldsInput() interface{}
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
// The tree node.
Node() constructs.Node
Parent() *string
SetParent(val *string)
ParentInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Template() *string
SetTemplate(val *string)
TemplateDisplayname() *string
TemplateInput() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GoogleDataCatalogTagTimeoutsOutputReference
TimeoutsInput() interface{}
// Adds a user defined moveTarget string to this resource to be later used in .moveTo(moveTarget) to resolve the location of the move.
// Experimental.
AddMoveTarget(moveTarget *string)
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
HasResourceMove() interface{}
// Experimental.
ImportFrom(id *string, provider cdktf.TerraformProvider)
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Move the resource corresponding to "id" to this resource.
//
// Note that the resource being moved from must be marked as moved using it's instance function.
// Experimental.
MoveFromId(id *string)
// Moves this resource to the target resource given by moveTarget.
// Experimental.
MoveTo(moveTarget *string, index interface{})
// Moves this resource to the resource corresponding to "id".
// Experimental.
MoveToId(id *string)
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutFields(value interface{})
PutTimeouts(value *GoogleDataCatalogTagTimeouts)
ResetColumn()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetParent()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
SynthesizeHclAttributes() *map[string]interface{}
// Experimental.
ToHclTerraform() interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_data_catalog_tag google_data_catalog_tag}.
func NewGoogleDataCatalogTag ¶
func NewGoogleDataCatalogTag(scope constructs.Construct, id *string, config *GoogleDataCatalogTagConfig) GoogleDataCatalogTag
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_data_catalog_tag google_data_catalog_tag} Resource.
type GoogleDataCatalogTagConfig ¶
type GoogleDataCatalogTagConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// fields block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_data_catalog_tag#fields GoogleDataCatalogTag#fields}
Fields interface{} `field:"required" json:"fields" yaml:"fields"`
// The resource name of the tag template that this tag uses. Example: projects/{project_id}/locations/{location}/tagTemplates/{tagTemplateId} This field cannot be modified after creation.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_data_catalog_tag#template GoogleDataCatalogTag#template}
Template *string `field:"required" json:"template" yaml:"template"`
// Resources like Entry can have schemas associated with them.
//
// This scope allows users to attach tags to an
// individual column based on that schema.
//
// For attaching a tag to a nested column, use '.' to separate the column names. Example:
// 'outer_column.inner_column'
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_data_catalog_tag#column GoogleDataCatalogTag#column}
Column *string `field:"optional" json:"column" yaml:"column"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_data_catalog_tag#id GoogleDataCatalogTag#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// The name of the parent this tag is attached to.
//
// This can be the name of an entry or an entry group. If an entry group, the tag will be attached to
// all entries in that group.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_data_catalog_tag#parent GoogleDataCatalogTag#parent}
Parent *string `field:"optional" json:"parent" yaml:"parent"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_data_catalog_tag#timeouts GoogleDataCatalogTag#timeouts}
Timeouts *GoogleDataCatalogTagTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type GoogleDataCatalogTagFields ¶
type GoogleDataCatalogTagFields struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_data_catalog_tag#field_name GoogleDataCatalogTag#field_name}.
FieldName *string `field:"required" json:"fieldName" yaml:"fieldName"`
// Holds the value for a tag field with boolean type.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_data_catalog_tag#bool_value GoogleDataCatalogTag#bool_value}
BoolValue interface{} `field:"optional" json:"boolValue" yaml:"boolValue"`
// Holds the value for a tag field with double type.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_data_catalog_tag#double_value GoogleDataCatalogTag#double_value}
DoubleValue *float64 `field:"optional" json:"doubleValue" yaml:"doubleValue"`
// The display name of the enum value.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_data_catalog_tag#enum_value GoogleDataCatalogTag#enum_value}
EnumValue *string `field:"optional" json:"enumValue" yaml:"enumValue"`
// Holds the value for a tag field with string type.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_data_catalog_tag#string_value GoogleDataCatalogTag#string_value}
StringValue *string `field:"optional" json:"stringValue" yaml:"stringValue"`
// Holds the value for a tag field with timestamp type.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_data_catalog_tag#timestamp_value GoogleDataCatalogTag#timestamp_value}
TimestampValue *string `field:"optional" json:"timestampValue" yaml:"timestampValue"`
}
type GoogleDataCatalogTagFieldsList ¶
type GoogleDataCatalogTagFieldsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) GoogleDataCatalogTagFieldsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleDataCatalogTagFieldsList ¶
func NewGoogleDataCatalogTagFieldsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GoogleDataCatalogTagFieldsList
type GoogleDataCatalogTagFieldsOutputReference ¶
type GoogleDataCatalogTagFieldsOutputReference interface {
cdktf.ComplexObject
BoolValue() interface{}
SetBoolValue(val interface{})
BoolValueInput() interface{}
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DisplayName() *string
DoubleValue() *float64
SetDoubleValue(val *float64)
DoubleValueInput() *float64
EnumValue() *string
SetEnumValue(val *string)
EnumValueInput() *string
FieldName() *string
SetFieldName(val *string)
FieldNameInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Order() *float64
StringValue() *string
SetStringValue(val *string)
StringValueInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
TimestampValue() *string
SetTimestampValue(val *string)
TimestampValueInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetBoolValue()
ResetDoubleValue()
ResetEnumValue()
ResetStringValue()
ResetTimestampValue()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleDataCatalogTagFieldsOutputReference ¶
func NewGoogleDataCatalogTagFieldsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GoogleDataCatalogTagFieldsOutputReference
type GoogleDataCatalogTagTimeouts ¶
type GoogleDataCatalogTagTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_data_catalog_tag#create GoogleDataCatalogTag#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_data_catalog_tag#delete GoogleDataCatalogTag#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_data_catalog_tag#update GoogleDataCatalogTag#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type GoogleDataCatalogTagTimeoutsOutputReference ¶
type GoogleDataCatalogTagTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleDataCatalogTagTimeoutsOutputReference ¶
func NewGoogleDataCatalogTagTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleDataCatalogTagTimeoutsOutputReference
Source Files
¶
- GoogleDataCatalogTag.go
- GoogleDataCatalogTagConfig.go
- GoogleDataCatalogTagFields.go
- GoogleDataCatalogTagFieldsList.go
- GoogleDataCatalogTagFieldsList__checks.go
- GoogleDataCatalogTagFieldsOutputReference.go
- GoogleDataCatalogTagFieldsOutputReference__checks.go
- GoogleDataCatalogTagTimeouts.go
- GoogleDataCatalogTagTimeoutsOutputReference.go
- GoogleDataCatalogTagTimeoutsOutputReference__checks.go
- GoogleDataCatalogTag__checks.go
- main.go