Documentation
¶
Index ¶
- func GoogleDataformRepositoryWorkflowConfig_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func GoogleDataformRepositoryWorkflowConfig_IsConstruct(x interface{}) *bool
- func GoogleDataformRepositoryWorkflowConfig_IsTerraformElement(x interface{}) *bool
- func GoogleDataformRepositoryWorkflowConfig_IsTerraformResource(x interface{}) *bool
- func GoogleDataformRepositoryWorkflowConfig_TfResourceType() *string
- func NewGoogleDataformRepositoryWorkflowConfigInvocationConfigIncludedTargetsList_Override(g GoogleDataformRepositoryWorkflowConfigInvocationConfigIncludedTargetsList, ...)
- func NewGoogleDataformRepositoryWorkflowConfigInvocationConfigIncludedTargetsOutputReference_Override(...)
- func NewGoogleDataformRepositoryWorkflowConfigInvocationConfigOutputReference_Override(g GoogleDataformRepositoryWorkflowConfigInvocationConfigOutputReference, ...)
- func NewGoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecordsErrorStatusList_Override(...)
- func NewGoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecordsErrorStatusOutputReference_Override(...)
- func NewGoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecordsList_Override(g GoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecordsList, ...)
- func NewGoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecordsOutputReference_Override(...)
- func NewGoogleDataformRepositoryWorkflowConfigTimeoutsOutputReference_Override(g GoogleDataformRepositoryWorkflowConfigTimeoutsOutputReference, ...)
- func NewGoogleDataformRepositoryWorkflowConfig_Override(g GoogleDataformRepositoryWorkflowConfig, scope constructs.Construct, ...)
- type GoogleDataformRepositoryWorkflowConfig
- type GoogleDataformRepositoryWorkflowConfigConfig
- type GoogleDataformRepositoryWorkflowConfigInvocationConfig
- type GoogleDataformRepositoryWorkflowConfigInvocationConfigIncludedTargets
- type GoogleDataformRepositoryWorkflowConfigInvocationConfigIncludedTargetsList
- type GoogleDataformRepositoryWorkflowConfigInvocationConfigIncludedTargetsOutputReference
- type GoogleDataformRepositoryWorkflowConfigInvocationConfigOutputReference
- type GoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecords
- type GoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecordsErrorStatus
- type GoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecordsErrorStatusList
- type GoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecordsErrorStatusOutputReference
- type GoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecordsList
- type GoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecordsOutputReference
- type GoogleDataformRepositoryWorkflowConfigTimeouts
- type GoogleDataformRepositoryWorkflowConfigTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleDataformRepositoryWorkflowConfig_GenerateConfigForImport ¶
func GoogleDataformRepositoryWorkflowConfig_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a GoogleDataformRepositoryWorkflowConfig resource upon running "cdktf plan <stack-name>".
func GoogleDataformRepositoryWorkflowConfig_IsConstruct ¶
func GoogleDataformRepositoryWorkflowConfig_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleDataformRepositoryWorkflowConfig_IsTerraformElement ¶
func GoogleDataformRepositoryWorkflowConfig_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleDataformRepositoryWorkflowConfig_IsTerraformResource ¶
func GoogleDataformRepositoryWorkflowConfig_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleDataformRepositoryWorkflowConfig_TfResourceType ¶
func GoogleDataformRepositoryWorkflowConfig_TfResourceType() *string
func NewGoogleDataformRepositoryWorkflowConfigInvocationConfigIncludedTargetsList_Override ¶
func NewGoogleDataformRepositoryWorkflowConfigInvocationConfigIncludedTargetsList_Override(g GoogleDataformRepositoryWorkflowConfigInvocationConfigIncludedTargetsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGoogleDataformRepositoryWorkflowConfigInvocationConfigIncludedTargetsOutputReference_Override ¶
func NewGoogleDataformRepositoryWorkflowConfigInvocationConfigIncludedTargetsOutputReference_Override(g GoogleDataformRepositoryWorkflowConfigInvocationConfigIncludedTargetsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGoogleDataformRepositoryWorkflowConfigInvocationConfigOutputReference_Override ¶
func NewGoogleDataformRepositoryWorkflowConfigInvocationConfigOutputReference_Override(g GoogleDataformRepositoryWorkflowConfigInvocationConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecordsErrorStatusList_Override ¶
func NewGoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecordsErrorStatusList_Override(g GoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecordsErrorStatusList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecordsErrorStatusOutputReference_Override ¶
func NewGoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecordsErrorStatusOutputReference_Override(g GoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecordsErrorStatusOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecordsList_Override ¶
func NewGoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecordsList_Override(g GoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecordsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecordsOutputReference_Override ¶
func NewGoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecordsOutputReference_Override(g GoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecordsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGoogleDataformRepositoryWorkflowConfigTimeoutsOutputReference_Override ¶
func NewGoogleDataformRepositoryWorkflowConfigTimeoutsOutputReference_Override(g GoogleDataformRepositoryWorkflowConfigTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleDataformRepositoryWorkflowConfig_Override ¶
func NewGoogleDataformRepositoryWorkflowConfig_Override(g GoogleDataformRepositoryWorkflowConfig, scope constructs.Construct, id *string, config *GoogleDataformRepositoryWorkflowConfigConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_dataform_repository_workflow_config google_dataform_repository_workflow_config} Resource.
Types ¶
type GoogleDataformRepositoryWorkflowConfig ¶
type GoogleDataformRepositoryWorkflowConfig interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
CronSchedule() *string
SetCronSchedule(val *string)
CronScheduleInput() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
InvocationConfig() GoogleDataformRepositoryWorkflowConfigInvocationConfigOutputReference
InvocationConfigInput() *GoogleDataformRepositoryWorkflowConfigInvocationConfig
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
RecentScheduledExecutionRecords() GoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecordsList
Region() *string
SetRegion(val *string)
RegionInput() *string
ReleaseConfig() *string
SetReleaseConfig(val *string)
ReleaseConfigInput() *string
Repository() *string
SetRepository(val *string)
RepositoryInput() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GoogleDataformRepositoryWorkflowConfigTimeoutsOutputReference
TimeoutsInput() interface{}
TimeZone() *string
SetTimeZone(val *string)
TimeZoneInput() *string
// Adds a user defined moveTarget string to this resource to be later used in .moveTo(moveTarget) to resolve the location of the move.
// Experimental.
AddMoveTarget(moveTarget *string)
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
HasResourceMove() interface{}
// Experimental.
ImportFrom(id *string, provider cdktf.TerraformProvider)
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Move the resource corresponding to "id" to this resource.
//
// Note that the resource being moved from must be marked as moved using it's instance function.
// Experimental.
MoveFromId(id *string)
// Moves this resource to the target resource given by moveTarget.
// Experimental.
MoveTo(moveTarget *string, index interface{})
// Moves this resource to the resource corresponding to "id".
// Experimental.
MoveToId(id *string)
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutInvocationConfig(value *GoogleDataformRepositoryWorkflowConfigInvocationConfig)
PutTimeouts(value *GoogleDataformRepositoryWorkflowConfigTimeouts)
ResetCronSchedule()
ResetId()
ResetInvocationConfig()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
ResetRegion()
ResetRepository()
ResetTimeouts()
ResetTimeZone()
SynthesizeAttributes() *map[string]interface{}
SynthesizeHclAttributes() *map[string]interface{}
// Experimental.
ToHclTerraform() interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_dataform_repository_workflow_config google_dataform_repository_workflow_config}.
func NewGoogleDataformRepositoryWorkflowConfig ¶
func NewGoogleDataformRepositoryWorkflowConfig(scope constructs.Construct, id *string, config *GoogleDataformRepositoryWorkflowConfigConfig) GoogleDataformRepositoryWorkflowConfig
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_dataform_repository_workflow_config google_dataform_repository_workflow_config} Resource.
type GoogleDataformRepositoryWorkflowConfigConfig ¶
type GoogleDataformRepositoryWorkflowConfigConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// The workflow's name.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_dataform_repository_workflow_config#name GoogleDataformRepositoryWorkflowConfig#name}
Name *string `field:"required" json:"name" yaml:"name"`
// The name of the release config whose releaseCompilationResult should be executed.
//
// Must be in the format projects/* /locations/* /repositories/* /releaseConfigs/*.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_dataform_repository_workflow_config#release_config GoogleDataformRepositoryWorkflowConfig#release_config}
//
// Note: The above comment contained a comment block ending sequence (* followed by /). We have introduced a space between to prevent syntax errors. Please ignore the space.
ReleaseConfig *string `field:"required" json:"releaseConfig" yaml:"releaseConfig"`
// Optional. Optional schedule (in cron format) for automatic creation of compilation results.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_dataform_repository_workflow_config#cron_schedule GoogleDataformRepositoryWorkflowConfig#cron_schedule}
CronSchedule *string `field:"optional" json:"cronSchedule" yaml:"cronSchedule"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_dataform_repository_workflow_config#id GoogleDataformRepositoryWorkflowConfig#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// invocation_config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_dataform_repository_workflow_config#invocation_config GoogleDataformRepositoryWorkflowConfig#invocation_config}
InvocationConfig *GoogleDataformRepositoryWorkflowConfigInvocationConfig `field:"optional" json:"invocationConfig" yaml:"invocationConfig"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_dataform_repository_workflow_config#project GoogleDataformRepositoryWorkflowConfig#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// A reference to the region.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_dataform_repository_workflow_config#region GoogleDataformRepositoryWorkflowConfig#region}
Region *string `field:"optional" json:"region" yaml:"region"`
// A reference to the Dataform repository.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_dataform_repository_workflow_config#repository GoogleDataformRepositoryWorkflowConfig#repository}
Repository *string `field:"optional" json:"repository" yaml:"repository"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_dataform_repository_workflow_config#timeouts GoogleDataformRepositoryWorkflowConfig#timeouts}
Timeouts *GoogleDataformRepositoryWorkflowConfigTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
// Optional.
//
// Specifies the time zone to be used when interpreting cronSchedule. Must be a time zone name from the time zone database (https://en.wikipedia.org/wiki/List_of_tz_database_time_zones). If left unspecified, the default is UTC.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_dataform_repository_workflow_config#time_zone GoogleDataformRepositoryWorkflowConfig#time_zone}
TimeZone *string `field:"optional" json:"timeZone" yaml:"timeZone"`
}
type GoogleDataformRepositoryWorkflowConfigInvocationConfig ¶
type GoogleDataformRepositoryWorkflowConfigInvocationConfig struct {
// Optional. When set to true, any incremental tables will be fully refreshed.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_dataform_repository_workflow_config#fully_refresh_incremental_tables_enabled GoogleDataformRepositoryWorkflowConfig#fully_refresh_incremental_tables_enabled}
FullyRefreshIncrementalTablesEnabled interface{} `field:"optional" json:"fullyRefreshIncrementalTablesEnabled" yaml:"fullyRefreshIncrementalTablesEnabled"`
// Optional. The set of tags to include.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_dataform_repository_workflow_config#included_tags GoogleDataformRepositoryWorkflowConfig#included_tags}
IncludedTags *[]*string `field:"optional" json:"includedTags" yaml:"includedTags"`
// included_targets block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_dataform_repository_workflow_config#included_targets GoogleDataformRepositoryWorkflowConfig#included_targets}
IncludedTargets interface{} `field:"optional" json:"includedTargets" yaml:"includedTargets"`
// Optional. The service account to run workflow invocations under.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_dataform_repository_workflow_config#service_account GoogleDataformRepositoryWorkflowConfig#service_account}
ServiceAccount *string `field:"optional" json:"serviceAccount" yaml:"serviceAccount"`
// Optional. When set to true, transitive dependencies of included actions will be executed.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_dataform_repository_workflow_config#transitive_dependencies_included GoogleDataformRepositoryWorkflowConfig#transitive_dependencies_included}
TransitiveDependenciesIncluded interface{} `field:"optional" json:"transitiveDependenciesIncluded" yaml:"transitiveDependenciesIncluded"`
// Optional. When set to true, transitive dependents of included actions will be executed.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_dataform_repository_workflow_config#transitive_dependents_included GoogleDataformRepositoryWorkflowConfig#transitive_dependents_included}
TransitiveDependentsIncluded interface{} `field:"optional" json:"transitiveDependentsIncluded" yaml:"transitiveDependentsIncluded"`
}
type GoogleDataformRepositoryWorkflowConfigInvocationConfigIncludedTargets ¶
type GoogleDataformRepositoryWorkflowConfigInvocationConfigIncludedTargets struct {
// The action's database (Google Cloud project ID).
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_dataform_repository_workflow_config#database GoogleDataformRepositoryWorkflowConfig#database}
Database *string `field:"optional" json:"database" yaml:"database"`
// The action's name, within database and schema.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_dataform_repository_workflow_config#name GoogleDataformRepositoryWorkflowConfig#name}
Name *string `field:"optional" json:"name" yaml:"name"`
// The action's schema (BigQuery dataset ID), within database.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_dataform_repository_workflow_config#schema GoogleDataformRepositoryWorkflowConfig#schema}
Schema *string `field:"optional" json:"schema" yaml:"schema"`
}
type GoogleDataformRepositoryWorkflowConfigInvocationConfigIncludedTargetsList ¶
type GoogleDataformRepositoryWorkflowConfigInvocationConfigIncludedTargetsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) GoogleDataformRepositoryWorkflowConfigInvocationConfigIncludedTargetsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleDataformRepositoryWorkflowConfigInvocationConfigIncludedTargetsList ¶
func NewGoogleDataformRepositoryWorkflowConfigInvocationConfigIncludedTargetsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GoogleDataformRepositoryWorkflowConfigInvocationConfigIncludedTargetsList
type GoogleDataformRepositoryWorkflowConfigInvocationConfigIncludedTargetsOutputReference ¶
type GoogleDataformRepositoryWorkflowConfigInvocationConfigIncludedTargetsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Database() *string
SetDatabase(val *string)
DatabaseInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Name() *string
SetName(val *string)
NameInput() *string
Schema() *string
SetSchema(val *string)
SchemaInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetDatabase()
ResetName()
ResetSchema()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleDataformRepositoryWorkflowConfigInvocationConfigIncludedTargetsOutputReference ¶
func NewGoogleDataformRepositoryWorkflowConfigInvocationConfigIncludedTargetsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GoogleDataformRepositoryWorkflowConfigInvocationConfigIncludedTargetsOutputReference
type GoogleDataformRepositoryWorkflowConfigInvocationConfigOutputReference ¶
type GoogleDataformRepositoryWorkflowConfigInvocationConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
FullyRefreshIncrementalTablesEnabled() interface{}
SetFullyRefreshIncrementalTablesEnabled(val interface{})
FullyRefreshIncrementalTablesEnabledInput() interface{}
IncludedTags() *[]*string
SetIncludedTags(val *[]*string)
IncludedTagsInput() *[]*string
IncludedTargets() GoogleDataformRepositoryWorkflowConfigInvocationConfigIncludedTargetsList
IncludedTargetsInput() interface{}
InternalValue() *GoogleDataformRepositoryWorkflowConfigInvocationConfig
SetInternalValue(val *GoogleDataformRepositoryWorkflowConfigInvocationConfig)
ServiceAccount() *string
SetServiceAccount(val *string)
ServiceAccountInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
TransitiveDependenciesIncluded() interface{}
SetTransitiveDependenciesIncluded(val interface{})
TransitiveDependenciesIncludedInput() interface{}
TransitiveDependentsIncluded() interface{}
SetTransitiveDependentsIncluded(val interface{})
TransitiveDependentsIncludedInput() interface{}
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutIncludedTargets(value interface{})
ResetFullyRefreshIncrementalTablesEnabled()
ResetIncludedTags()
ResetIncludedTargets()
ResetServiceAccount()
ResetTransitiveDependenciesIncluded()
ResetTransitiveDependentsIncluded()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleDataformRepositoryWorkflowConfigInvocationConfigOutputReference ¶
func NewGoogleDataformRepositoryWorkflowConfigInvocationConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleDataformRepositoryWorkflowConfigInvocationConfigOutputReference
type GoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecords ¶
type GoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecords struct {
}
type GoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecordsErrorStatus ¶
type GoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecordsErrorStatus struct {
}
type GoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecordsErrorStatusList ¶
type GoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecordsErrorStatusList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) GoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecordsErrorStatusOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecordsErrorStatusList ¶
func NewGoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecordsErrorStatusList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecordsErrorStatusList
type GoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecordsErrorStatusOutputReference ¶
type GoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecordsErrorStatusOutputReference interface {
cdktf.ComplexObject
Code() *float64
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecordsErrorStatus
SetInternalValue(val *GoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecordsErrorStatus)
Message() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecordsErrorStatusOutputReference ¶
func NewGoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecordsErrorStatusOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecordsErrorStatusOutputReference
type GoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecordsList ¶
type GoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecordsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) GoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecordsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecordsList ¶
func NewGoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecordsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecordsList
type GoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecordsOutputReference ¶
type GoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecordsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
ErrorStatus() GoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecordsErrorStatusList
ExecutionTime() *string
// Experimental.
Fqn() *string
InternalValue() *GoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecords
SetInternalValue(val *GoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecords)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
WorkflowInvocation() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecordsOutputReference ¶
func NewGoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecordsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecordsOutputReference
type GoogleDataformRepositoryWorkflowConfigTimeouts ¶
type GoogleDataformRepositoryWorkflowConfigTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_dataform_repository_workflow_config#create GoogleDataformRepositoryWorkflowConfig#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_dataform_repository_workflow_config#delete GoogleDataformRepositoryWorkflowConfig#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_dataform_repository_workflow_config#update GoogleDataformRepositoryWorkflowConfig#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type GoogleDataformRepositoryWorkflowConfigTimeoutsOutputReference ¶
type GoogleDataformRepositoryWorkflowConfigTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleDataformRepositoryWorkflowConfigTimeoutsOutputReference ¶
func NewGoogleDataformRepositoryWorkflowConfigTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleDataformRepositoryWorkflowConfigTimeoutsOutputReference
Source Files
¶
- GoogleDataformRepositoryWorkflowConfig.go
- GoogleDataformRepositoryWorkflowConfigConfig.go
- GoogleDataformRepositoryWorkflowConfigInvocationConfig.go
- GoogleDataformRepositoryWorkflowConfigInvocationConfigIncludedTargets.go
- GoogleDataformRepositoryWorkflowConfigInvocationConfigIncludedTargetsList.go
- GoogleDataformRepositoryWorkflowConfigInvocationConfigIncludedTargetsList__checks.go
- GoogleDataformRepositoryWorkflowConfigInvocationConfigIncludedTargetsOutputReference.go
- GoogleDataformRepositoryWorkflowConfigInvocationConfigIncludedTargetsOutputReference__checks.go
- GoogleDataformRepositoryWorkflowConfigInvocationConfigOutputReference.go
- GoogleDataformRepositoryWorkflowConfigInvocationConfigOutputReference__checks.go
- GoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecords.go
- GoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecordsErrorStatus.go
- GoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecordsErrorStatusList.go
- GoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecordsErrorStatusList__checks.go
- GoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecordsErrorStatusOutputReference.go
- GoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecordsErrorStatusOutputReference__checks.go
- GoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecordsList.go
- GoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecordsList__checks.go
- GoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecordsOutputReference.go
- GoogleDataformRepositoryWorkflowConfigRecentScheduledExecutionRecordsOutputReference__checks.go
- GoogleDataformRepositoryWorkflowConfigTimeouts.go
- GoogleDataformRepositoryWorkflowConfigTimeoutsOutputReference.go
- GoogleDataformRepositoryWorkflowConfigTimeoutsOutputReference__checks.go
- GoogleDataformRepositoryWorkflowConfig__checks.go
- main.go