Documentation
¶
Index ¶
- func GoogleDiscoveryEngineChatEngine_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func GoogleDiscoveryEngineChatEngine_IsConstruct(x interface{}) *bool
- func GoogleDiscoveryEngineChatEngine_IsTerraformElement(x interface{}) *bool
- func GoogleDiscoveryEngineChatEngine_IsTerraformResource(x interface{}) *bool
- func GoogleDiscoveryEngineChatEngine_TfResourceType() *string
- func NewGoogleDiscoveryEngineChatEngineChatEngineConfigAgentCreationConfigOutputReference_Override(...)
- func NewGoogleDiscoveryEngineChatEngineChatEngineConfigOutputReference_Override(g GoogleDiscoveryEngineChatEngineChatEngineConfigOutputReference, ...)
- func NewGoogleDiscoveryEngineChatEngineChatEngineMetadataList_Override(g GoogleDiscoveryEngineChatEngineChatEngineMetadataList, ...)
- func NewGoogleDiscoveryEngineChatEngineChatEngineMetadataOutputReference_Override(g GoogleDiscoveryEngineChatEngineChatEngineMetadataOutputReference, ...)
- func NewGoogleDiscoveryEngineChatEngineCommonConfigOutputReference_Override(g GoogleDiscoveryEngineChatEngineCommonConfigOutputReference, ...)
- func NewGoogleDiscoveryEngineChatEngineTimeoutsOutputReference_Override(g GoogleDiscoveryEngineChatEngineTimeoutsOutputReference, ...)
- func NewGoogleDiscoveryEngineChatEngine_Override(g GoogleDiscoveryEngineChatEngine, scope constructs.Construct, id *string, ...)
- type GoogleDiscoveryEngineChatEngine
- type GoogleDiscoveryEngineChatEngineChatEngineConfig
- type GoogleDiscoveryEngineChatEngineChatEngineConfigAgentCreationConfig
- type GoogleDiscoveryEngineChatEngineChatEngineConfigAgentCreationConfigOutputReference
- type GoogleDiscoveryEngineChatEngineChatEngineConfigOutputReference
- type GoogleDiscoveryEngineChatEngineChatEngineMetadata
- type GoogleDiscoveryEngineChatEngineChatEngineMetadataList
- type GoogleDiscoveryEngineChatEngineChatEngineMetadataOutputReference
- type GoogleDiscoveryEngineChatEngineCommonConfig
- type GoogleDiscoveryEngineChatEngineCommonConfigOutputReference
- type GoogleDiscoveryEngineChatEngineConfig
- type GoogleDiscoveryEngineChatEngineTimeouts
- type GoogleDiscoveryEngineChatEngineTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleDiscoveryEngineChatEngine_GenerateConfigForImport ¶
func GoogleDiscoveryEngineChatEngine_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a GoogleDiscoveryEngineChatEngine resource upon running "cdktf plan <stack-name>".
func GoogleDiscoveryEngineChatEngine_IsConstruct ¶
func GoogleDiscoveryEngineChatEngine_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleDiscoveryEngineChatEngine_IsTerraformElement ¶
func GoogleDiscoveryEngineChatEngine_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleDiscoveryEngineChatEngine_IsTerraformResource ¶
func GoogleDiscoveryEngineChatEngine_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleDiscoveryEngineChatEngine_TfResourceType ¶
func GoogleDiscoveryEngineChatEngine_TfResourceType() *string
func NewGoogleDiscoveryEngineChatEngineChatEngineConfigAgentCreationConfigOutputReference_Override ¶
func NewGoogleDiscoveryEngineChatEngineChatEngineConfigAgentCreationConfigOutputReference_Override(g GoogleDiscoveryEngineChatEngineChatEngineConfigAgentCreationConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleDiscoveryEngineChatEngineChatEngineConfigOutputReference_Override ¶
func NewGoogleDiscoveryEngineChatEngineChatEngineConfigOutputReference_Override(g GoogleDiscoveryEngineChatEngineChatEngineConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleDiscoveryEngineChatEngineChatEngineMetadataList_Override ¶
func NewGoogleDiscoveryEngineChatEngineChatEngineMetadataList_Override(g GoogleDiscoveryEngineChatEngineChatEngineMetadataList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGoogleDiscoveryEngineChatEngineChatEngineMetadataOutputReference_Override ¶
func NewGoogleDiscoveryEngineChatEngineChatEngineMetadataOutputReference_Override(g GoogleDiscoveryEngineChatEngineChatEngineMetadataOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGoogleDiscoveryEngineChatEngineCommonConfigOutputReference_Override ¶
func NewGoogleDiscoveryEngineChatEngineCommonConfigOutputReference_Override(g GoogleDiscoveryEngineChatEngineCommonConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleDiscoveryEngineChatEngineTimeoutsOutputReference_Override ¶
func NewGoogleDiscoveryEngineChatEngineTimeoutsOutputReference_Override(g GoogleDiscoveryEngineChatEngineTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleDiscoveryEngineChatEngine_Override ¶
func NewGoogleDiscoveryEngineChatEngine_Override(g GoogleDiscoveryEngineChatEngine, scope constructs.Construct, id *string, config *GoogleDiscoveryEngineChatEngineConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_discovery_engine_chat_engine google_discovery_engine_chat_engine} Resource.
Types ¶
type GoogleDiscoveryEngineChatEngine ¶
type GoogleDiscoveryEngineChatEngine interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
ChatEngineConfig() GoogleDiscoveryEngineChatEngineChatEngineConfigOutputReference
ChatEngineConfigInput() *GoogleDiscoveryEngineChatEngineChatEngineConfig
ChatEngineMetadata() GoogleDiscoveryEngineChatEngineChatEngineMetadataList
CollectionId() *string
SetCollectionId(val *string)
CollectionIdInput() *string
CommonConfig() GoogleDiscoveryEngineChatEngineCommonConfigOutputReference
CommonConfigInput() *GoogleDiscoveryEngineChatEngineCommonConfig
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
CreateTime() *string
DataStoreIds() *[]*string
SetDataStoreIds(val *[]*string)
DataStoreIdsInput() *[]*string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DisplayName() *string
SetDisplayName(val *string)
DisplayNameInput() *string
EngineId() *string
SetEngineId(val *string)
EngineIdInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
IndustryVertical() *string
SetIndustryVertical(val *string)
IndustryVerticalInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Location() *string
SetLocation(val *string)
LocationInput() *string
Name() *string
// The tree node.
Node() constructs.Node
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GoogleDiscoveryEngineChatEngineTimeoutsOutputReference
TimeoutsInput() interface{}
UpdateTime() *string
// Adds a user defined moveTarget string to this resource to be later used in .moveTo(moveTarget) to resolve the location of the move.
// Experimental.
AddMoveTarget(moveTarget *string)
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
HasResourceMove() interface{}
// Experimental.
ImportFrom(id *string, provider cdktf.TerraformProvider)
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Move the resource corresponding to "id" to this resource.
//
// Note that the resource being moved from must be marked as moved using it's instance function.
// Experimental.
MoveFromId(id *string)
// Moves this resource to the target resource given by moveTarget.
// Experimental.
MoveTo(moveTarget *string, index interface{})
// Moves this resource to the resource corresponding to "id".
// Experimental.
MoveToId(id *string)
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutChatEngineConfig(value *GoogleDiscoveryEngineChatEngineChatEngineConfig)
PutCommonConfig(value *GoogleDiscoveryEngineChatEngineCommonConfig)
PutTimeouts(value *GoogleDiscoveryEngineChatEngineTimeouts)
ResetCommonConfig()
ResetId()
ResetIndustryVertical()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
SynthesizeHclAttributes() *map[string]interface{}
// Experimental.
ToHclTerraform() interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_discovery_engine_chat_engine google_discovery_engine_chat_engine}.
func NewGoogleDiscoveryEngineChatEngine ¶
func NewGoogleDiscoveryEngineChatEngine(scope constructs.Construct, id *string, config *GoogleDiscoveryEngineChatEngineConfig) GoogleDiscoveryEngineChatEngine
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_discovery_engine_chat_engine google_discovery_engine_chat_engine} Resource.
type GoogleDiscoveryEngineChatEngineChatEngineConfig ¶
type GoogleDiscoveryEngineChatEngineChatEngineConfig struct {
// agent_creation_config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_discovery_engine_chat_engine#agent_creation_config GoogleDiscoveryEngineChatEngine#agent_creation_config}
AgentCreationConfig *GoogleDiscoveryEngineChatEngineChatEngineConfigAgentCreationConfig `field:"optional" json:"agentCreationConfig" yaml:"agentCreationConfig"`
// If the flag set to true, we allow the agent and engine are in different locations, otherwise the agent and engine are required to be in the same location.
//
// The flag is set to false by default.
// Note that the 'allow_cross_region' are one-time consumed by and passed
// to EngineService.CreateEngine. It means they cannot be retrieved using
// EngineService.GetEngine or EngineService.ListEngines API after engine
// creation.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_discovery_engine_chat_engine#allow_cross_region GoogleDiscoveryEngineChatEngine#allow_cross_region}
AllowCrossRegion interface{} `field:"optional" json:"allowCrossRegion" yaml:"allowCrossRegion"`
// The resource name of an existing Dialogflow agent to link to this Chat Engine.
//
// Format: 'projects/<Project_ID>/locations/<Location_ID>/agents/<Agent_ID>'.
// Exactly one of 'agent_creation_config' or 'dialogflow_agent_to_link' must be set.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_discovery_engine_chat_engine#dialogflow_agent_to_link GoogleDiscoveryEngineChatEngine#dialogflow_agent_to_link}
DialogflowAgentToLink *string `field:"optional" json:"dialogflowAgentToLink" yaml:"dialogflowAgentToLink"`
}
type GoogleDiscoveryEngineChatEngineChatEngineConfigAgentCreationConfig ¶
type GoogleDiscoveryEngineChatEngineChatEngineConfigAgentCreationConfig struct {
// The default language of the agent as a language tag.
//
// See [Language Support](https://cloud.google.com/dialogflow/docs/reference/language) for a list of the currently supported language codes.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_discovery_engine_chat_engine#default_language_code GoogleDiscoveryEngineChatEngine#default_language_code}
DefaultLanguageCode *string `field:"required" json:"defaultLanguageCode" yaml:"defaultLanguageCode"`
// The time zone of the agent from the [time zone database](https://www.iana.org/time-zones), e.g., America/New_York, Europe/Paris.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_discovery_engine_chat_engine#time_zone GoogleDiscoveryEngineChatEngine#time_zone}
TimeZone *string `field:"required" json:"timeZone" yaml:"timeZone"`
// Name of the company, organization or other entity that the agent represents.
//
// Used for knowledge connector LLM prompt and for knowledge search.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_discovery_engine_chat_engine#business GoogleDiscoveryEngineChatEngine#business}
Business *string `field:"optional" json:"business" yaml:"business"`
// Agent location for Agent creation, currently supported values: global/us/eu, it needs to be the same region as the Chat Engine.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_discovery_engine_chat_engine#location GoogleDiscoveryEngineChatEngine#location}
Location *string `field:"optional" json:"location" yaml:"location"`
}
type GoogleDiscoveryEngineChatEngineChatEngineConfigAgentCreationConfigOutputReference ¶
type GoogleDiscoveryEngineChatEngineChatEngineConfigAgentCreationConfigOutputReference interface {
cdktf.ComplexObject
Business() *string
SetBusiness(val *string)
BusinessInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DefaultLanguageCode() *string
SetDefaultLanguageCode(val *string)
DefaultLanguageCodeInput() *string
// Experimental.
Fqn() *string
InternalValue() *GoogleDiscoveryEngineChatEngineChatEngineConfigAgentCreationConfig
SetInternalValue(val *GoogleDiscoveryEngineChatEngineChatEngineConfigAgentCreationConfig)
Location() *string
SetLocation(val *string)
LocationInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
TimeZone() *string
SetTimeZone(val *string)
TimeZoneInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetBusiness()
ResetLocation()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleDiscoveryEngineChatEngineChatEngineConfigAgentCreationConfigOutputReference ¶
func NewGoogleDiscoveryEngineChatEngineChatEngineConfigAgentCreationConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleDiscoveryEngineChatEngineChatEngineConfigAgentCreationConfigOutputReference
type GoogleDiscoveryEngineChatEngineChatEngineConfigOutputReference ¶
type GoogleDiscoveryEngineChatEngineChatEngineConfigOutputReference interface {
cdktf.ComplexObject
AgentCreationConfig() GoogleDiscoveryEngineChatEngineChatEngineConfigAgentCreationConfigOutputReference
AgentCreationConfigInput() *GoogleDiscoveryEngineChatEngineChatEngineConfigAgentCreationConfig
AllowCrossRegion() interface{}
SetAllowCrossRegion(val interface{})
AllowCrossRegionInput() interface{}
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DialogflowAgentToLink() *string
SetDialogflowAgentToLink(val *string)
DialogflowAgentToLinkInput() *string
// Experimental.
Fqn() *string
InternalValue() *GoogleDiscoveryEngineChatEngineChatEngineConfig
SetInternalValue(val *GoogleDiscoveryEngineChatEngineChatEngineConfig)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutAgentCreationConfig(value *GoogleDiscoveryEngineChatEngineChatEngineConfigAgentCreationConfig)
ResetAgentCreationConfig()
ResetAllowCrossRegion()
ResetDialogflowAgentToLink()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleDiscoveryEngineChatEngineChatEngineConfigOutputReference ¶
func NewGoogleDiscoveryEngineChatEngineChatEngineConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleDiscoveryEngineChatEngineChatEngineConfigOutputReference
type GoogleDiscoveryEngineChatEngineChatEngineMetadata ¶
type GoogleDiscoveryEngineChatEngineChatEngineMetadata struct {
}
type GoogleDiscoveryEngineChatEngineChatEngineMetadataList ¶
type GoogleDiscoveryEngineChatEngineChatEngineMetadataList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) GoogleDiscoveryEngineChatEngineChatEngineMetadataOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleDiscoveryEngineChatEngineChatEngineMetadataList ¶
func NewGoogleDiscoveryEngineChatEngineChatEngineMetadataList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GoogleDiscoveryEngineChatEngineChatEngineMetadataList
type GoogleDiscoveryEngineChatEngineChatEngineMetadataOutputReference ¶
type GoogleDiscoveryEngineChatEngineChatEngineMetadataOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
DialogflowAgent() *string
// Experimental.
Fqn() *string
InternalValue() *GoogleDiscoveryEngineChatEngineChatEngineMetadata
SetInternalValue(val *GoogleDiscoveryEngineChatEngineChatEngineMetadata)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleDiscoveryEngineChatEngineChatEngineMetadataOutputReference ¶
func NewGoogleDiscoveryEngineChatEngineChatEngineMetadataOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GoogleDiscoveryEngineChatEngineChatEngineMetadataOutputReference
type GoogleDiscoveryEngineChatEngineCommonConfig ¶
type GoogleDiscoveryEngineChatEngineCommonConfig struct {
// The name of the company, business or entity that is associated with the engine.
//
// Setting this may help improve LLM related features.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_discovery_engine_chat_engine#company_name GoogleDiscoveryEngineChatEngine#company_name}
CompanyName *string `field:"optional" json:"companyName" yaml:"companyName"`
}
type GoogleDiscoveryEngineChatEngineCommonConfigOutputReference ¶
type GoogleDiscoveryEngineChatEngineCommonConfigOutputReference interface {
cdktf.ComplexObject
CompanyName() *string
SetCompanyName(val *string)
CompanyNameInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleDiscoveryEngineChatEngineCommonConfig
SetInternalValue(val *GoogleDiscoveryEngineChatEngineCommonConfig)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCompanyName()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleDiscoveryEngineChatEngineCommonConfigOutputReference ¶
func NewGoogleDiscoveryEngineChatEngineCommonConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleDiscoveryEngineChatEngineCommonConfigOutputReference
type GoogleDiscoveryEngineChatEngineConfig ¶
type GoogleDiscoveryEngineChatEngineConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// chat_engine_config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_discovery_engine_chat_engine#chat_engine_config GoogleDiscoveryEngineChatEngine#chat_engine_config}
ChatEngineConfig *GoogleDiscoveryEngineChatEngineChatEngineConfig `field:"required" json:"chatEngineConfig" yaml:"chatEngineConfig"`
// The collection ID.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_discovery_engine_chat_engine#collection_id GoogleDiscoveryEngineChatEngine#collection_id}
CollectionId *string `field:"required" json:"collectionId" yaml:"collectionId"`
// The data stores associated with this engine.
//
// Multiple DataStores in the same Collection can be associated here. All listed DataStores must be 'SOLUTION_TYPE_CHAT'.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_discovery_engine_chat_engine#data_store_ids GoogleDiscoveryEngineChatEngine#data_store_ids}
DataStoreIds *[]*string `field:"required" json:"dataStoreIds" yaml:"dataStoreIds"`
// The display name of the engine. Should be human readable. UTF-8 encoded string with limit of 1024 characters.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_discovery_engine_chat_engine#display_name GoogleDiscoveryEngineChatEngine#display_name}
DisplayName *string `field:"required" json:"displayName" yaml:"displayName"`
// The ID to use for chat engine.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_discovery_engine_chat_engine#engine_id GoogleDiscoveryEngineChatEngine#engine_id}
EngineId *string `field:"required" json:"engineId" yaml:"engineId"`
// Location.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_discovery_engine_chat_engine#location GoogleDiscoveryEngineChatEngine#location}
Location *string `field:"required" json:"location" yaml:"location"`
// common_config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_discovery_engine_chat_engine#common_config GoogleDiscoveryEngineChatEngine#common_config}
CommonConfig *GoogleDiscoveryEngineChatEngineCommonConfig `field:"optional" json:"commonConfig" yaml:"commonConfig"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_discovery_engine_chat_engine#id GoogleDiscoveryEngineChatEngine#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// The industry vertical that the chat engine registers.
//
// Vertical on Engine has to match vertical of the DataStore linked to the engine. Default value: "GENERIC" Possible values: ["GENERIC"]
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_discovery_engine_chat_engine#industry_vertical GoogleDiscoveryEngineChatEngine#industry_vertical}
IndustryVertical *string `field:"optional" json:"industryVertical" yaml:"industryVertical"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_discovery_engine_chat_engine#project GoogleDiscoveryEngineChatEngine#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_discovery_engine_chat_engine#timeouts GoogleDiscoveryEngineChatEngine#timeouts}
Timeouts *GoogleDiscoveryEngineChatEngineTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type GoogleDiscoveryEngineChatEngineTimeouts ¶
type GoogleDiscoveryEngineChatEngineTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_discovery_engine_chat_engine#create GoogleDiscoveryEngineChatEngine#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_discovery_engine_chat_engine#delete GoogleDiscoveryEngineChatEngine#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_discovery_engine_chat_engine#update GoogleDiscoveryEngineChatEngine#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type GoogleDiscoveryEngineChatEngineTimeoutsOutputReference ¶
type GoogleDiscoveryEngineChatEngineTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleDiscoveryEngineChatEngineTimeoutsOutputReference ¶
func NewGoogleDiscoveryEngineChatEngineTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleDiscoveryEngineChatEngineTimeoutsOutputReference
Source Files
¶
- GoogleDiscoveryEngineChatEngine.go
- GoogleDiscoveryEngineChatEngineChatEngineConfig.go
- GoogleDiscoveryEngineChatEngineChatEngineConfigAgentCreationConfig.go
- GoogleDiscoveryEngineChatEngineChatEngineConfigAgentCreationConfigOutputReference.go
- GoogleDiscoveryEngineChatEngineChatEngineConfigAgentCreationConfigOutputReference__checks.go
- GoogleDiscoveryEngineChatEngineChatEngineConfigOutputReference.go
- GoogleDiscoveryEngineChatEngineChatEngineConfigOutputReference__checks.go
- GoogleDiscoveryEngineChatEngineChatEngineMetadata.go
- GoogleDiscoveryEngineChatEngineChatEngineMetadataList.go
- GoogleDiscoveryEngineChatEngineChatEngineMetadataList__checks.go
- GoogleDiscoveryEngineChatEngineChatEngineMetadataOutputReference.go
- GoogleDiscoveryEngineChatEngineChatEngineMetadataOutputReference__checks.go
- GoogleDiscoveryEngineChatEngineCommonConfig.go
- GoogleDiscoveryEngineChatEngineCommonConfigOutputReference.go
- GoogleDiscoveryEngineChatEngineCommonConfigOutputReference__checks.go
- GoogleDiscoveryEngineChatEngineConfig.go
- GoogleDiscoveryEngineChatEngineTimeouts.go
- GoogleDiscoveryEngineChatEngineTimeoutsOutputReference.go
- GoogleDiscoveryEngineChatEngineTimeoutsOutputReference__checks.go
- GoogleDiscoveryEngineChatEngine__checks.go
- main.go