Documentation
¶
Index ¶
- func GoogleGkeonpremBareMetalNodePool_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func GoogleGkeonpremBareMetalNodePool_IsConstruct(x interface{}) *bool
- func GoogleGkeonpremBareMetalNodePool_IsTerraformElement(x interface{}) *bool
- func GoogleGkeonpremBareMetalNodePool_IsTerraformResource(x interface{}) *bool
- func GoogleGkeonpremBareMetalNodePool_TfResourceType() *string
- func NewGoogleGkeonpremBareMetalNodePoolNodePoolConfigNodeConfigsList_Override(g GoogleGkeonpremBareMetalNodePoolNodePoolConfigNodeConfigsList, ...)
- func NewGoogleGkeonpremBareMetalNodePoolNodePoolConfigNodeConfigsOutputReference_Override(g GoogleGkeonpremBareMetalNodePoolNodePoolConfigNodeConfigsOutputReference, ...)
- func NewGoogleGkeonpremBareMetalNodePoolNodePoolConfigOutputReference_Override(g GoogleGkeonpremBareMetalNodePoolNodePoolConfigOutputReference, ...)
- func NewGoogleGkeonpremBareMetalNodePoolNodePoolConfigTaintsList_Override(g GoogleGkeonpremBareMetalNodePoolNodePoolConfigTaintsList, ...)
- func NewGoogleGkeonpremBareMetalNodePoolNodePoolConfigTaintsOutputReference_Override(g GoogleGkeonpremBareMetalNodePoolNodePoolConfigTaintsOutputReference, ...)
- func NewGoogleGkeonpremBareMetalNodePoolStatusConditionsList_Override(g GoogleGkeonpremBareMetalNodePoolStatusConditionsList, ...)
- func NewGoogleGkeonpremBareMetalNodePoolStatusConditionsOutputReference_Override(g GoogleGkeonpremBareMetalNodePoolStatusConditionsOutputReference, ...)
- func NewGoogleGkeonpremBareMetalNodePoolStatusList_Override(g GoogleGkeonpremBareMetalNodePoolStatusList, ...)
- func NewGoogleGkeonpremBareMetalNodePoolStatusOutputReference_Override(g GoogleGkeonpremBareMetalNodePoolStatusOutputReference, ...)
- func NewGoogleGkeonpremBareMetalNodePoolTimeoutsOutputReference_Override(g GoogleGkeonpremBareMetalNodePoolTimeoutsOutputReference, ...)
- func NewGoogleGkeonpremBareMetalNodePool_Override(g GoogleGkeonpremBareMetalNodePool, scope constructs.Construct, id *string, ...)
- type GoogleGkeonpremBareMetalNodePool
- type GoogleGkeonpremBareMetalNodePoolConfig
- type GoogleGkeonpremBareMetalNodePoolNodePoolConfig
- type GoogleGkeonpremBareMetalNodePoolNodePoolConfigNodeConfigs
- type GoogleGkeonpremBareMetalNodePoolNodePoolConfigNodeConfigsList
- type GoogleGkeonpremBareMetalNodePoolNodePoolConfigNodeConfigsOutputReference
- type GoogleGkeonpremBareMetalNodePoolNodePoolConfigOutputReference
- type GoogleGkeonpremBareMetalNodePoolNodePoolConfigTaints
- type GoogleGkeonpremBareMetalNodePoolNodePoolConfigTaintsList
- type GoogleGkeonpremBareMetalNodePoolNodePoolConfigTaintsOutputReference
- type GoogleGkeonpremBareMetalNodePoolStatus
- type GoogleGkeonpremBareMetalNodePoolStatusConditions
- type GoogleGkeonpremBareMetalNodePoolStatusConditionsList
- type GoogleGkeonpremBareMetalNodePoolStatusConditionsOutputReference
- type GoogleGkeonpremBareMetalNodePoolStatusList
- type GoogleGkeonpremBareMetalNodePoolStatusOutputReference
- type GoogleGkeonpremBareMetalNodePoolTimeouts
- type GoogleGkeonpremBareMetalNodePoolTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleGkeonpremBareMetalNodePool_GenerateConfigForImport ¶
func GoogleGkeonpremBareMetalNodePool_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a GoogleGkeonpremBareMetalNodePool resource upon running "cdktf plan <stack-name>".
func GoogleGkeonpremBareMetalNodePool_IsConstruct ¶
func GoogleGkeonpremBareMetalNodePool_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleGkeonpremBareMetalNodePool_IsTerraformElement ¶
func GoogleGkeonpremBareMetalNodePool_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleGkeonpremBareMetalNodePool_IsTerraformResource ¶
func GoogleGkeonpremBareMetalNodePool_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleGkeonpremBareMetalNodePool_TfResourceType ¶
func GoogleGkeonpremBareMetalNodePool_TfResourceType() *string
func NewGoogleGkeonpremBareMetalNodePoolNodePoolConfigNodeConfigsList_Override ¶
func NewGoogleGkeonpremBareMetalNodePoolNodePoolConfigNodeConfigsList_Override(g GoogleGkeonpremBareMetalNodePoolNodePoolConfigNodeConfigsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGoogleGkeonpremBareMetalNodePoolNodePoolConfigNodeConfigsOutputReference_Override ¶
func NewGoogleGkeonpremBareMetalNodePoolNodePoolConfigNodeConfigsOutputReference_Override(g GoogleGkeonpremBareMetalNodePoolNodePoolConfigNodeConfigsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGoogleGkeonpremBareMetalNodePoolNodePoolConfigOutputReference_Override ¶
func NewGoogleGkeonpremBareMetalNodePoolNodePoolConfigOutputReference_Override(g GoogleGkeonpremBareMetalNodePoolNodePoolConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleGkeonpremBareMetalNodePoolNodePoolConfigTaintsList_Override ¶
func NewGoogleGkeonpremBareMetalNodePoolNodePoolConfigTaintsList_Override(g GoogleGkeonpremBareMetalNodePoolNodePoolConfigTaintsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGoogleGkeonpremBareMetalNodePoolNodePoolConfigTaintsOutputReference_Override ¶
func NewGoogleGkeonpremBareMetalNodePoolNodePoolConfigTaintsOutputReference_Override(g GoogleGkeonpremBareMetalNodePoolNodePoolConfigTaintsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGoogleGkeonpremBareMetalNodePoolStatusConditionsList_Override ¶
func NewGoogleGkeonpremBareMetalNodePoolStatusConditionsList_Override(g GoogleGkeonpremBareMetalNodePoolStatusConditionsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGoogleGkeonpremBareMetalNodePoolStatusConditionsOutputReference_Override ¶
func NewGoogleGkeonpremBareMetalNodePoolStatusConditionsOutputReference_Override(g GoogleGkeonpremBareMetalNodePoolStatusConditionsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGoogleGkeonpremBareMetalNodePoolStatusList_Override ¶
func NewGoogleGkeonpremBareMetalNodePoolStatusList_Override(g GoogleGkeonpremBareMetalNodePoolStatusList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGoogleGkeonpremBareMetalNodePoolStatusOutputReference_Override ¶
func NewGoogleGkeonpremBareMetalNodePoolStatusOutputReference_Override(g GoogleGkeonpremBareMetalNodePoolStatusOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGoogleGkeonpremBareMetalNodePoolTimeoutsOutputReference_Override ¶
func NewGoogleGkeonpremBareMetalNodePoolTimeoutsOutputReference_Override(g GoogleGkeonpremBareMetalNodePoolTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleGkeonpremBareMetalNodePool_Override ¶
func NewGoogleGkeonpremBareMetalNodePool_Override(g GoogleGkeonpremBareMetalNodePool, scope constructs.Construct, id *string, config *GoogleGkeonpremBareMetalNodePoolConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_gkeonprem_bare_metal_node_pool google_gkeonprem_bare_metal_node_pool} Resource.
Types ¶
type GoogleGkeonpremBareMetalNodePool ¶
type GoogleGkeonpremBareMetalNodePool interface {
cdktf.TerraformResource
Annotations() *map[string]*string
SetAnnotations(val *map[string]*string)
AnnotationsInput() *map[string]*string
BareMetalCluster() *string
SetBareMetalCluster(val *string)
BareMetalClusterInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
CreateTime() *string
DeleteTime() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DisplayName() *string
SetDisplayName(val *string)
DisplayNameInput() *string
EffectiveAnnotations() cdktf.StringMap
Etag() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Location() *string
SetLocation(val *string)
LocationInput() *string
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
NodePoolConfig() GoogleGkeonpremBareMetalNodePoolNodePoolConfigOutputReference
NodePoolConfigInput() *GoogleGkeonpremBareMetalNodePoolNodePoolConfig
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Reconciling() cdktf.IResolvable
State() *string
Status() GoogleGkeonpremBareMetalNodePoolStatusList
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GoogleGkeonpremBareMetalNodePoolTimeoutsOutputReference
TimeoutsInput() interface{}
Uid() *string
UpdateTime() *string
// Adds a user defined moveTarget string to this resource to be later used in .moveTo(moveTarget) to resolve the location of the move.
// Experimental.
AddMoveTarget(moveTarget *string)
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
HasResourceMove() interface{}
// Experimental.
ImportFrom(id *string, provider cdktf.TerraformProvider)
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Move the resource corresponding to "id" to this resource.
//
// Note that the resource being moved from must be marked as moved using it's instance function.
// Experimental.
MoveFromId(id *string)
// Moves this resource to the target resource given by moveTarget.
// Experimental.
MoveTo(moveTarget *string, index interface{})
// Moves this resource to the resource corresponding to "id".
// Experimental.
MoveToId(id *string)
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutNodePoolConfig(value *GoogleGkeonpremBareMetalNodePoolNodePoolConfig)
PutTimeouts(value *GoogleGkeonpremBareMetalNodePoolTimeouts)
ResetAnnotations()
ResetDisplayName()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
SynthesizeHclAttributes() *map[string]interface{}
// Experimental.
ToHclTerraform() interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_gkeonprem_bare_metal_node_pool google_gkeonprem_bare_metal_node_pool}.
func NewGoogleGkeonpremBareMetalNodePool ¶
func NewGoogleGkeonpremBareMetalNodePool(scope constructs.Construct, id *string, config *GoogleGkeonpremBareMetalNodePoolConfig) GoogleGkeonpremBareMetalNodePool
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_gkeonprem_bare_metal_node_pool google_gkeonprem_bare_metal_node_pool} Resource.
type GoogleGkeonpremBareMetalNodePoolConfig ¶
type GoogleGkeonpremBareMetalNodePoolConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// The cluster this node pool belongs to.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_gkeonprem_bare_metal_node_pool#bare_metal_cluster GoogleGkeonpremBareMetalNodePool#bare_metal_cluster}
BareMetalCluster *string `field:"required" json:"bareMetalCluster" yaml:"bareMetalCluster"`
// The location of the resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_gkeonprem_bare_metal_node_pool#location GoogleGkeonpremBareMetalNodePool#location}
Location *string `field:"required" json:"location" yaml:"location"`
// The bare metal node pool name.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_gkeonprem_bare_metal_node_pool#name GoogleGkeonpremBareMetalNodePool#name}
Name *string `field:"required" json:"name" yaml:"name"`
// node_pool_config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_gkeonprem_bare_metal_node_pool#node_pool_config GoogleGkeonpremBareMetalNodePool#node_pool_config}
NodePoolConfig *GoogleGkeonpremBareMetalNodePoolNodePoolConfig `field:"required" json:"nodePoolConfig" yaml:"nodePoolConfig"`
// Annotations on the Bare Metal Node Pool.
//
// This field has the same restrictions as Kubernetes annotations.
// The total size of all keys and values combined is limited to 256k.
// Key can have 2 segments: prefix (optional) and name (required),
// separated by a slash (/).
// Prefix must be a DNS subdomain.
// Name must be 63 characters or less, begin and end with alphanumerics,
// with dashes (-), underscores (_), dots (.), and alphanumerics between.
//
//
// **Note**: This field is non-authoritative, and will only manage the annotations present in your configuration.
// Please refer to the field 'effective_annotations' for all of the annotations present on the resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_gkeonprem_bare_metal_node_pool#annotations GoogleGkeonpremBareMetalNodePool#annotations}
Annotations *map[string]*string `field:"optional" json:"annotations" yaml:"annotations"`
// The display name for the Bare Metal Node Pool.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_gkeonprem_bare_metal_node_pool#display_name GoogleGkeonpremBareMetalNodePool#display_name}
DisplayName *string `field:"optional" json:"displayName" yaml:"displayName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_gkeonprem_bare_metal_node_pool#id GoogleGkeonpremBareMetalNodePool#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_gkeonprem_bare_metal_node_pool#project GoogleGkeonpremBareMetalNodePool#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_gkeonprem_bare_metal_node_pool#timeouts GoogleGkeonpremBareMetalNodePool#timeouts}
Timeouts *GoogleGkeonpremBareMetalNodePoolTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type GoogleGkeonpremBareMetalNodePoolNodePoolConfig ¶
type GoogleGkeonpremBareMetalNodePoolNodePoolConfig struct {
// node_configs block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_gkeonprem_bare_metal_node_pool#node_configs GoogleGkeonpremBareMetalNodePool#node_configs}
NodeConfigs interface{} `field:"required" json:"nodeConfigs" yaml:"nodeConfigs"`
// The map of Kubernetes labels (key/value pairs) to be applied to each node.
//
// These will added in addition to any default label(s)
// that Kubernetes may apply to the node. In case of conflict in
// label keys, the applied set may differ depending on the Kubernetes
// version -- it's best to assume the behavior is undefined and
// conflicts should be avoided. For more information, including usage
// and the valid values, see:
// - http://kubernetes.io/v1.1/docs/user-guide/labels.html
// An object containing a list of "key": value pairs.
// For example: { "name": "wrench", "mass": "1.3kg", "count": "3" }.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_gkeonprem_bare_metal_node_pool#labels GoogleGkeonpremBareMetalNodePool#labels}
Labels *map[string]*string `field:"optional" json:"labels" yaml:"labels"`
// Specifies the nodes operating system (default: LINUX).
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_gkeonprem_bare_metal_node_pool#operating_system GoogleGkeonpremBareMetalNodePool#operating_system}
OperatingSystem *string `field:"optional" json:"operatingSystem" yaml:"operatingSystem"`
// taints block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_gkeonprem_bare_metal_node_pool#taints GoogleGkeonpremBareMetalNodePool#taints}
Taints interface{} `field:"optional" json:"taints" yaml:"taints"`
}
type GoogleGkeonpremBareMetalNodePoolNodePoolConfigNodeConfigs ¶
type GoogleGkeonpremBareMetalNodePoolNodePoolConfigNodeConfigs struct {
// The map of Kubernetes labels (key/value pairs) to be applied to each node.
//
// These will added in addition to any default label(s)
// that Kubernetes may apply to the node. In case of conflict in
// label keys, the applied set may differ depending on the Kubernetes
// version -- it's best to assume the behavior is undefined and
// conflicts should be avoided. For more information, including usage
// and the valid values, see:
// - http://kubernetes.io/v1.1/docs/user-guide/labels.html
// An object containing a list of "key": value pairs.
// For example: { "name": "wrench", "mass": "1.3kg", "count": "3" }.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_gkeonprem_bare_metal_node_pool#labels GoogleGkeonpremBareMetalNodePool#labels}
Labels *map[string]*string `field:"optional" json:"labels" yaml:"labels"`
// The default IPv4 address for SSH access and Kubernetes node. Example: 192.168.0.1.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_gkeonprem_bare_metal_node_pool#node_ip GoogleGkeonpremBareMetalNodePool#node_ip}
NodeIp *string `field:"optional" json:"nodeIp" yaml:"nodeIp"`
}
type GoogleGkeonpremBareMetalNodePoolNodePoolConfigNodeConfigsList ¶
type GoogleGkeonpremBareMetalNodePoolNodePoolConfigNodeConfigsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) GoogleGkeonpremBareMetalNodePoolNodePoolConfigNodeConfigsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleGkeonpremBareMetalNodePoolNodePoolConfigNodeConfigsList ¶
func NewGoogleGkeonpremBareMetalNodePoolNodePoolConfigNodeConfigsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GoogleGkeonpremBareMetalNodePoolNodePoolConfigNodeConfigsList
type GoogleGkeonpremBareMetalNodePoolNodePoolConfigNodeConfigsOutputReference ¶
type GoogleGkeonpremBareMetalNodePoolNodePoolConfigNodeConfigsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Labels() *map[string]*string
SetLabels(val *map[string]*string)
LabelsInput() *map[string]*string
NodeIp() *string
SetNodeIp(val *string)
NodeIpInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetLabels()
ResetNodeIp()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleGkeonpremBareMetalNodePoolNodePoolConfigNodeConfigsOutputReference ¶
func NewGoogleGkeonpremBareMetalNodePoolNodePoolConfigNodeConfigsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GoogleGkeonpremBareMetalNodePoolNodePoolConfigNodeConfigsOutputReference
type GoogleGkeonpremBareMetalNodePoolNodePoolConfigOutputReference ¶
type GoogleGkeonpremBareMetalNodePoolNodePoolConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleGkeonpremBareMetalNodePoolNodePoolConfig
SetInternalValue(val *GoogleGkeonpremBareMetalNodePoolNodePoolConfig)
Labels() *map[string]*string
SetLabels(val *map[string]*string)
LabelsInput() *map[string]*string
NodeConfigs() GoogleGkeonpremBareMetalNodePoolNodePoolConfigNodeConfigsList
NodeConfigsInput() interface{}
OperatingSystem() *string
SetOperatingSystem(val *string)
OperatingSystemInput() *string
Taints() GoogleGkeonpremBareMetalNodePoolNodePoolConfigTaintsList
TaintsInput() interface{}
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutNodeConfigs(value interface{})
PutTaints(value interface{})
ResetLabels()
ResetOperatingSystem()
ResetTaints()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleGkeonpremBareMetalNodePoolNodePoolConfigOutputReference ¶
func NewGoogleGkeonpremBareMetalNodePoolNodePoolConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleGkeonpremBareMetalNodePoolNodePoolConfigOutputReference
type GoogleGkeonpremBareMetalNodePoolNodePoolConfigTaints ¶
type GoogleGkeonpremBareMetalNodePoolNodePoolConfigTaints struct {
// Specifies the nodes operating system (default: LINUX). Possible values: ["EFFECT_UNSPECIFIED", "PREFER_NO_SCHEDULE", "NO_EXECUTE"].
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_gkeonprem_bare_metal_node_pool#effect GoogleGkeonpremBareMetalNodePool#effect}
Effect *string `field:"optional" json:"effect" yaml:"effect"`
// Key associated with the effect.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_gkeonprem_bare_metal_node_pool#key GoogleGkeonpremBareMetalNodePool#key}
Key *string `field:"optional" json:"key" yaml:"key"`
// Value associated with the effect.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_gkeonprem_bare_metal_node_pool#value GoogleGkeonpremBareMetalNodePool#value}
Value *string `field:"optional" json:"value" yaml:"value"`
}
type GoogleGkeonpremBareMetalNodePoolNodePoolConfigTaintsList ¶
type GoogleGkeonpremBareMetalNodePoolNodePoolConfigTaintsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) GoogleGkeonpremBareMetalNodePoolNodePoolConfigTaintsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleGkeonpremBareMetalNodePoolNodePoolConfigTaintsList ¶
func NewGoogleGkeonpremBareMetalNodePoolNodePoolConfigTaintsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GoogleGkeonpremBareMetalNodePoolNodePoolConfigTaintsList
type GoogleGkeonpremBareMetalNodePoolNodePoolConfigTaintsOutputReference ¶
type GoogleGkeonpremBareMetalNodePoolNodePoolConfigTaintsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Effect() *string
SetEffect(val *string)
EffectInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Key() *string
SetKey(val *string)
KeyInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Value() *string
SetValue(val *string)
ValueInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetEffect()
ResetKey()
ResetValue()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleGkeonpremBareMetalNodePoolNodePoolConfigTaintsOutputReference ¶
func NewGoogleGkeonpremBareMetalNodePoolNodePoolConfigTaintsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GoogleGkeonpremBareMetalNodePoolNodePoolConfigTaintsOutputReference
type GoogleGkeonpremBareMetalNodePoolStatus ¶
type GoogleGkeonpremBareMetalNodePoolStatus struct {
}
type GoogleGkeonpremBareMetalNodePoolStatusConditions ¶
type GoogleGkeonpremBareMetalNodePoolStatusConditions struct {
}
type GoogleGkeonpremBareMetalNodePoolStatusConditionsList ¶
type GoogleGkeonpremBareMetalNodePoolStatusConditionsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) GoogleGkeonpremBareMetalNodePoolStatusConditionsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleGkeonpremBareMetalNodePoolStatusConditionsList ¶
func NewGoogleGkeonpremBareMetalNodePoolStatusConditionsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GoogleGkeonpremBareMetalNodePoolStatusConditionsList
type GoogleGkeonpremBareMetalNodePoolStatusConditionsOutputReference ¶
type GoogleGkeonpremBareMetalNodePoolStatusConditionsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleGkeonpremBareMetalNodePoolStatusConditions
SetInternalValue(val *GoogleGkeonpremBareMetalNodePoolStatusConditions)
LastTransitionTime() *string
Message() *string
Reason() *string
State() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleGkeonpremBareMetalNodePoolStatusConditionsOutputReference ¶
func NewGoogleGkeonpremBareMetalNodePoolStatusConditionsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GoogleGkeonpremBareMetalNodePoolStatusConditionsOutputReference
type GoogleGkeonpremBareMetalNodePoolStatusList ¶
type GoogleGkeonpremBareMetalNodePoolStatusList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) GoogleGkeonpremBareMetalNodePoolStatusOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleGkeonpremBareMetalNodePoolStatusList ¶
func NewGoogleGkeonpremBareMetalNodePoolStatusList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GoogleGkeonpremBareMetalNodePoolStatusList
type GoogleGkeonpremBareMetalNodePoolStatusOutputReference ¶
type GoogleGkeonpremBareMetalNodePoolStatusOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Conditions() GoogleGkeonpremBareMetalNodePoolStatusConditionsList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
ErrorMessage() *string
// Experimental.
Fqn() *string
InternalValue() *GoogleGkeonpremBareMetalNodePoolStatus
SetInternalValue(val *GoogleGkeonpremBareMetalNodePoolStatus)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleGkeonpremBareMetalNodePoolStatusOutputReference ¶
func NewGoogleGkeonpremBareMetalNodePoolStatusOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GoogleGkeonpremBareMetalNodePoolStatusOutputReference
type GoogleGkeonpremBareMetalNodePoolTimeouts ¶
type GoogleGkeonpremBareMetalNodePoolTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_gkeonprem_bare_metal_node_pool#create GoogleGkeonpremBareMetalNodePool#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_gkeonprem_bare_metal_node_pool#delete GoogleGkeonpremBareMetalNodePool#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_gkeonprem_bare_metal_node_pool#update GoogleGkeonpremBareMetalNodePool#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type GoogleGkeonpremBareMetalNodePoolTimeoutsOutputReference ¶
type GoogleGkeonpremBareMetalNodePoolTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleGkeonpremBareMetalNodePoolTimeoutsOutputReference ¶
func NewGoogleGkeonpremBareMetalNodePoolTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleGkeonpremBareMetalNodePoolTimeoutsOutputReference
Source Files
¶
- GoogleGkeonpremBareMetalNodePool.go
- GoogleGkeonpremBareMetalNodePoolConfig.go
- GoogleGkeonpremBareMetalNodePoolNodePoolConfig.go
- GoogleGkeonpremBareMetalNodePoolNodePoolConfigNodeConfigs.go
- GoogleGkeonpremBareMetalNodePoolNodePoolConfigNodeConfigsList.go
- GoogleGkeonpremBareMetalNodePoolNodePoolConfigNodeConfigsList__checks.go
- GoogleGkeonpremBareMetalNodePoolNodePoolConfigNodeConfigsOutputReference.go
- GoogleGkeonpremBareMetalNodePoolNodePoolConfigNodeConfigsOutputReference__checks.go
- GoogleGkeonpremBareMetalNodePoolNodePoolConfigOutputReference.go
- GoogleGkeonpremBareMetalNodePoolNodePoolConfigOutputReference__checks.go
- GoogleGkeonpremBareMetalNodePoolNodePoolConfigTaints.go
- GoogleGkeonpremBareMetalNodePoolNodePoolConfigTaintsList.go
- GoogleGkeonpremBareMetalNodePoolNodePoolConfigTaintsList__checks.go
- GoogleGkeonpremBareMetalNodePoolNodePoolConfigTaintsOutputReference.go
- GoogleGkeonpremBareMetalNodePoolNodePoolConfigTaintsOutputReference__checks.go
- GoogleGkeonpremBareMetalNodePoolStatus.go
- GoogleGkeonpremBareMetalNodePoolStatusConditions.go
- GoogleGkeonpremBareMetalNodePoolStatusConditionsList.go
- GoogleGkeonpremBareMetalNodePoolStatusConditionsList__checks.go
- GoogleGkeonpremBareMetalNodePoolStatusConditionsOutputReference.go
- GoogleGkeonpremBareMetalNodePoolStatusConditionsOutputReference__checks.go
- GoogleGkeonpremBareMetalNodePoolStatusList.go
- GoogleGkeonpremBareMetalNodePoolStatusList__checks.go
- GoogleGkeonpremBareMetalNodePoolStatusOutputReference.go
- GoogleGkeonpremBareMetalNodePoolStatusOutputReference__checks.go
- GoogleGkeonpremBareMetalNodePoolTimeouts.go
- GoogleGkeonpremBareMetalNodePoolTimeoutsOutputReference.go
- GoogleGkeonpremBareMetalNodePoolTimeoutsOutputReference__checks.go
- GoogleGkeonpremBareMetalNodePool__checks.go
- main.go