Documentation
¶
Index ¶
- func GoogleIntegrationConnectorsManagedZone_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func GoogleIntegrationConnectorsManagedZone_IsConstruct(x interface{}) *bool
- func GoogleIntegrationConnectorsManagedZone_IsTerraformElement(x interface{}) *bool
- func GoogleIntegrationConnectorsManagedZone_IsTerraformResource(x interface{}) *bool
- func GoogleIntegrationConnectorsManagedZone_TfResourceType() *string
- func NewGoogleIntegrationConnectorsManagedZoneTimeoutsOutputReference_Override(g GoogleIntegrationConnectorsManagedZoneTimeoutsOutputReference, ...)
- func NewGoogleIntegrationConnectorsManagedZone_Override(g GoogleIntegrationConnectorsManagedZone, scope constructs.Construct, ...)
- type GoogleIntegrationConnectorsManagedZone
- type GoogleIntegrationConnectorsManagedZoneConfig
- type GoogleIntegrationConnectorsManagedZoneTimeouts
- type GoogleIntegrationConnectorsManagedZoneTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleIntegrationConnectorsManagedZone_GenerateConfigForImport ¶
func GoogleIntegrationConnectorsManagedZone_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a GoogleIntegrationConnectorsManagedZone resource upon running "cdktf plan <stack-name>".
func GoogleIntegrationConnectorsManagedZone_IsConstruct ¶
func GoogleIntegrationConnectorsManagedZone_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleIntegrationConnectorsManagedZone_IsTerraformElement ¶
func GoogleIntegrationConnectorsManagedZone_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleIntegrationConnectorsManagedZone_IsTerraformResource ¶
func GoogleIntegrationConnectorsManagedZone_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleIntegrationConnectorsManagedZone_TfResourceType ¶
func GoogleIntegrationConnectorsManagedZone_TfResourceType() *string
func NewGoogleIntegrationConnectorsManagedZoneTimeoutsOutputReference_Override ¶
func NewGoogleIntegrationConnectorsManagedZoneTimeoutsOutputReference_Override(g GoogleIntegrationConnectorsManagedZoneTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleIntegrationConnectorsManagedZone_Override ¶
func NewGoogleIntegrationConnectorsManagedZone_Override(g GoogleIntegrationConnectorsManagedZone, scope constructs.Construct, id *string, config *GoogleIntegrationConnectorsManagedZoneConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_integration_connectors_managed_zone google_integration_connectors_managed_zone} Resource.
Types ¶
type GoogleIntegrationConnectorsManagedZone ¶
type GoogleIntegrationConnectorsManagedZone interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
CreateTime() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
Dns() *string
SetDns(val *string)
DnsInput() *string
EffectiveLabels() cdktf.StringMap
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
Labels() *map[string]*string
SetLabels(val *map[string]*string)
LabelsInput() *map[string]*string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
TargetProject() *string
SetTargetProject(val *string)
TargetProjectInput() *string
TargetVpc() *string
SetTargetVpc(val *string)
TargetVpcInput() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
TerraformLabels() cdktf.StringMap
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GoogleIntegrationConnectorsManagedZoneTimeoutsOutputReference
TimeoutsInput() interface{}
UpdateTime() *string
// Adds a user defined moveTarget string to this resource to be later used in .moveTo(moveTarget) to resolve the location of the move.
// Experimental.
AddMoveTarget(moveTarget *string)
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
HasResourceMove() interface{}
// Experimental.
ImportFrom(id *string, provider cdktf.TerraformProvider)
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Move the resource corresponding to "id" to this resource.
//
// Note that the resource being moved from must be marked as moved using it's instance function.
// Experimental.
MoveFromId(id *string)
// Moves this resource to the target resource given by moveTarget.
// Experimental.
MoveTo(moveTarget *string, index interface{})
// Moves this resource to the resource corresponding to "id".
// Experimental.
MoveToId(id *string)
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutTimeouts(value *GoogleIntegrationConnectorsManagedZoneTimeouts)
ResetDescription()
ResetId()
ResetLabels()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
SynthesizeHclAttributes() *map[string]interface{}
// Experimental.
ToHclTerraform() interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_integration_connectors_managed_zone google_integration_connectors_managed_zone}.
func NewGoogleIntegrationConnectorsManagedZone ¶
func NewGoogleIntegrationConnectorsManagedZone(scope constructs.Construct, id *string, config *GoogleIntegrationConnectorsManagedZoneConfig) GoogleIntegrationConnectorsManagedZone
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_integration_connectors_managed_zone google_integration_connectors_managed_zone} Resource.
type GoogleIntegrationConnectorsManagedZoneConfig ¶
type GoogleIntegrationConnectorsManagedZoneConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// DNS Name of the resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_integration_connectors_managed_zone#dns GoogleIntegrationConnectorsManagedZone#dns}
Dns *string `field:"required" json:"dns" yaml:"dns"`
// Name of Managed Zone needs to be created.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_integration_connectors_managed_zone#name GoogleIntegrationConnectorsManagedZone#name}
Name *string `field:"required" json:"name" yaml:"name"`
// The name of the Target Project.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_integration_connectors_managed_zone#target_project GoogleIntegrationConnectorsManagedZone#target_project}
TargetProject *string `field:"required" json:"targetProject" yaml:"targetProject"`
// The name of the Target Project VPC Network.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_integration_connectors_managed_zone#target_vpc GoogleIntegrationConnectorsManagedZone#target_vpc}
TargetVpc *string `field:"required" json:"targetVpc" yaml:"targetVpc"`
// Description of the resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_integration_connectors_managed_zone#description GoogleIntegrationConnectorsManagedZone#description}
Description *string `field:"optional" json:"description" yaml:"description"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_integration_connectors_managed_zone#id GoogleIntegrationConnectorsManagedZone#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Resource labels to represent user provided metadata.
//
// **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
// Please refer to the field 'effective_labels' for all of the labels present on the resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_integration_connectors_managed_zone#labels GoogleIntegrationConnectorsManagedZone#labels}
Labels *map[string]*string `field:"optional" json:"labels" yaml:"labels"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_integration_connectors_managed_zone#project GoogleIntegrationConnectorsManagedZone#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_integration_connectors_managed_zone#timeouts GoogleIntegrationConnectorsManagedZone#timeouts}
Timeouts *GoogleIntegrationConnectorsManagedZoneTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type GoogleIntegrationConnectorsManagedZoneTimeouts ¶
type GoogleIntegrationConnectorsManagedZoneTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_integration_connectors_managed_zone#create GoogleIntegrationConnectorsManagedZone#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_integration_connectors_managed_zone#delete GoogleIntegrationConnectorsManagedZone#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_integration_connectors_managed_zone#update GoogleIntegrationConnectorsManagedZone#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type GoogleIntegrationConnectorsManagedZoneTimeoutsOutputReference ¶
type GoogleIntegrationConnectorsManagedZoneTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleIntegrationConnectorsManagedZoneTimeoutsOutputReference ¶
func NewGoogleIntegrationConnectorsManagedZoneTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleIntegrationConnectorsManagedZoneTimeoutsOutputReference
Source Files
¶
- GoogleIntegrationConnectorsManagedZone.go
- GoogleIntegrationConnectorsManagedZoneConfig.go
- GoogleIntegrationConnectorsManagedZoneTimeouts.go
- GoogleIntegrationConnectorsManagedZoneTimeoutsOutputReference.go
- GoogleIntegrationConnectorsManagedZoneTimeoutsOutputReference__checks.go
- GoogleIntegrationConnectorsManagedZone__checks.go
- main.go