Documentation
¶
Index ¶
- func GoogleKmsCryptoKey_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func GoogleKmsCryptoKey_IsConstruct(x interface{}) *bool
- func GoogleKmsCryptoKey_IsTerraformElement(x interface{}) *bool
- func GoogleKmsCryptoKey_IsTerraformResource(x interface{}) *bool
- func GoogleKmsCryptoKey_TfResourceType() *string
- func NewGoogleKmsCryptoKeyKeyAccessJustificationsPolicyOutputReference_Override(g GoogleKmsCryptoKeyKeyAccessJustificationsPolicyOutputReference, ...)
- func NewGoogleKmsCryptoKeyPrimaryList_Override(g GoogleKmsCryptoKeyPrimaryList, terraformResource cdktf.IInterpolatingParent, ...)
- func NewGoogleKmsCryptoKeyPrimaryOutputReference_Override(g GoogleKmsCryptoKeyPrimaryOutputReference, ...)
- func NewGoogleKmsCryptoKeyTimeoutsOutputReference_Override(g GoogleKmsCryptoKeyTimeoutsOutputReference, ...)
- func NewGoogleKmsCryptoKeyVersionTemplateOutputReference_Override(g GoogleKmsCryptoKeyVersionTemplateOutputReference, ...)
- func NewGoogleKmsCryptoKey_Override(g GoogleKmsCryptoKey, scope constructs.Construct, id *string, ...)
- type GoogleKmsCryptoKey
- type GoogleKmsCryptoKeyConfig
- type GoogleKmsCryptoKeyKeyAccessJustificationsPolicy
- type GoogleKmsCryptoKeyKeyAccessJustificationsPolicyOutputReference
- type GoogleKmsCryptoKeyPrimary
- type GoogleKmsCryptoKeyPrimaryList
- type GoogleKmsCryptoKeyPrimaryOutputReference
- type GoogleKmsCryptoKeyTimeouts
- type GoogleKmsCryptoKeyTimeoutsOutputReference
- type GoogleKmsCryptoKeyVersionTemplate
- type GoogleKmsCryptoKeyVersionTemplateOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleKmsCryptoKey_GenerateConfigForImport ¶
func GoogleKmsCryptoKey_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a GoogleKmsCryptoKey resource upon running "cdktf plan <stack-name>".
func GoogleKmsCryptoKey_IsConstruct ¶
func GoogleKmsCryptoKey_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleKmsCryptoKey_IsTerraformElement ¶
func GoogleKmsCryptoKey_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleKmsCryptoKey_IsTerraformResource ¶
func GoogleKmsCryptoKey_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleKmsCryptoKey_TfResourceType ¶
func GoogleKmsCryptoKey_TfResourceType() *string
func NewGoogleKmsCryptoKeyKeyAccessJustificationsPolicyOutputReference_Override ¶
func NewGoogleKmsCryptoKeyKeyAccessJustificationsPolicyOutputReference_Override(g GoogleKmsCryptoKeyKeyAccessJustificationsPolicyOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleKmsCryptoKeyPrimaryList_Override ¶
func NewGoogleKmsCryptoKeyPrimaryList_Override(g GoogleKmsCryptoKeyPrimaryList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGoogleKmsCryptoKeyPrimaryOutputReference_Override ¶
func NewGoogleKmsCryptoKeyPrimaryOutputReference_Override(g GoogleKmsCryptoKeyPrimaryOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGoogleKmsCryptoKeyTimeoutsOutputReference_Override ¶
func NewGoogleKmsCryptoKeyTimeoutsOutputReference_Override(g GoogleKmsCryptoKeyTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleKmsCryptoKeyVersionTemplateOutputReference_Override ¶
func NewGoogleKmsCryptoKeyVersionTemplateOutputReference_Override(g GoogleKmsCryptoKeyVersionTemplateOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleKmsCryptoKey_Override ¶
func NewGoogleKmsCryptoKey_Override(g GoogleKmsCryptoKey, scope constructs.Construct, id *string, config *GoogleKmsCryptoKeyConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_kms_crypto_key google_kms_crypto_key} Resource.
Types ¶
type GoogleKmsCryptoKey ¶
type GoogleKmsCryptoKey interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
CryptoKeyBackend() *string
SetCryptoKeyBackend(val *string)
CryptoKeyBackendInput() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DestroyScheduledDuration() *string
SetDestroyScheduledDuration(val *string)
DestroyScheduledDurationInput() *string
EffectiveLabels() cdktf.StringMap
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
ImportOnly() interface{}
SetImportOnly(val interface{})
ImportOnlyInput() interface{}
KeyAccessJustificationsPolicy() GoogleKmsCryptoKeyKeyAccessJustificationsPolicyOutputReference
KeyAccessJustificationsPolicyInput() *GoogleKmsCryptoKeyKeyAccessJustificationsPolicy
KeyRing() *string
SetKeyRing(val *string)
KeyRingInput() *string
Labels() *map[string]*string
SetLabels(val *map[string]*string)
LabelsInput() *map[string]*string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
Primary() GoogleKmsCryptoKeyPrimaryList
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
Purpose() *string
SetPurpose(val *string)
PurposeInput() *string
// Experimental.
RawOverrides() interface{}
RotationPeriod() *string
SetRotationPeriod(val *string)
RotationPeriodInput() *string
SkipInitialVersionCreation() interface{}
SetSkipInitialVersionCreation(val interface{})
SkipInitialVersionCreationInput() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
TerraformLabels() cdktf.StringMap
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GoogleKmsCryptoKeyTimeoutsOutputReference
TimeoutsInput() interface{}
VersionTemplate() GoogleKmsCryptoKeyVersionTemplateOutputReference
VersionTemplateInput() *GoogleKmsCryptoKeyVersionTemplate
// Adds a user defined moveTarget string to this resource to be later used in .moveTo(moveTarget) to resolve the location of the move.
// Experimental.
AddMoveTarget(moveTarget *string)
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
HasResourceMove() interface{}
// Experimental.
ImportFrom(id *string, provider cdktf.TerraformProvider)
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Move the resource corresponding to "id" to this resource.
//
// Note that the resource being moved from must be marked as moved using it's instance function.
// Experimental.
MoveFromId(id *string)
// Moves this resource to the target resource given by moveTarget.
// Experimental.
MoveTo(moveTarget *string, index interface{})
// Moves this resource to the resource corresponding to "id".
// Experimental.
MoveToId(id *string)
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutKeyAccessJustificationsPolicy(value *GoogleKmsCryptoKeyKeyAccessJustificationsPolicy)
PutTimeouts(value *GoogleKmsCryptoKeyTimeouts)
PutVersionTemplate(value *GoogleKmsCryptoKeyVersionTemplate)
ResetCryptoKeyBackend()
ResetDestroyScheduledDuration()
ResetId()
ResetImportOnly()
ResetKeyAccessJustificationsPolicy()
ResetLabels()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetPurpose()
ResetRotationPeriod()
ResetSkipInitialVersionCreation()
ResetTimeouts()
ResetVersionTemplate()
SynthesizeAttributes() *map[string]interface{}
SynthesizeHclAttributes() *map[string]interface{}
// Experimental.
ToHclTerraform() interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_kms_crypto_key google_kms_crypto_key}.
func NewGoogleKmsCryptoKey ¶
func NewGoogleKmsCryptoKey(scope constructs.Construct, id *string, config *GoogleKmsCryptoKeyConfig) GoogleKmsCryptoKey
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_kms_crypto_key google_kms_crypto_key} Resource.
type GoogleKmsCryptoKeyConfig ¶
type GoogleKmsCryptoKeyConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// The KeyRing that this key belongs to. Format: ”projects/{{project}}/locations/{{location}}/keyRings/{{keyRing}}”.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_kms_crypto_key#key_ring GoogleKmsCryptoKey#key_ring}
KeyRing *string `field:"required" json:"keyRing" yaml:"keyRing"`
// The resource name for the CryptoKey.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_kms_crypto_key#name GoogleKmsCryptoKey#name}
Name *string `field:"required" json:"name" yaml:"name"`
// The resource name of the backend environment associated with all CryptoKeyVersions within this CryptoKey.
//
// The resource name is in the format "projects/* /locations/* /ekmConnections/*" and only applies to "EXTERNAL_VPC" keys.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_kms_crypto_key#crypto_key_backend GoogleKmsCryptoKey#crypto_key_backend}
//
// Note: The above comment contained a comment block ending sequence (* followed by /). We have introduced a space between to prevent syntax errors. Please ignore the space.
CryptoKeyBackend *string `field:"optional" json:"cryptoKeyBackend" yaml:"cryptoKeyBackend"`
// The period of time that versions of this key spend in the DESTROY_SCHEDULED state before transitioning to DESTROYED.
//
// If not specified at creation time, the default duration is 30 days.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_kms_crypto_key#destroy_scheduled_duration GoogleKmsCryptoKey#destroy_scheduled_duration}
DestroyScheduledDuration *string `field:"optional" json:"destroyScheduledDuration" yaml:"destroyScheduledDuration"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_kms_crypto_key#id GoogleKmsCryptoKey#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Whether this key may contain imported versions only.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_kms_crypto_key#import_only GoogleKmsCryptoKey#import_only}
ImportOnly interface{} `field:"optional" json:"importOnly" yaml:"importOnly"`
// key_access_justifications_policy block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_kms_crypto_key#key_access_justifications_policy GoogleKmsCryptoKey#key_access_justifications_policy}
KeyAccessJustificationsPolicy *GoogleKmsCryptoKeyKeyAccessJustificationsPolicy `field:"optional" json:"keyAccessJustificationsPolicy" yaml:"keyAccessJustificationsPolicy"`
// Labels with user-defined metadata to apply to this resource.
//
// **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
// Please refer to the field 'effective_labels' for all of the labels present on the resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_kms_crypto_key#labels GoogleKmsCryptoKey#labels}
Labels *map[string]*string `field:"optional" json:"labels" yaml:"labels"`
// The immutable purpose of this CryptoKey. See the [purpose reference](https://cloud.google.com/kms/docs/reference/rest/v1/projects.locations.keyRings.cryptoKeys#CryptoKeyPurpose) for possible inputs. Default value is "ENCRYPT_DECRYPT".
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_kms_crypto_key#purpose GoogleKmsCryptoKey#purpose}
Purpose *string `field:"optional" json:"purpose" yaml:"purpose"`
// Every time this period passes, generate a new CryptoKeyVersion and set it as the primary.
//
// The first rotation will take place after the specified period. The rotation period has
// the format of a decimal number with up to 9 fractional digits, followed by the
// letter 's' (seconds). It must be greater than a day (ie, 86400).
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_kms_crypto_key#rotation_period GoogleKmsCryptoKey#rotation_period}
RotationPeriod *string `field:"optional" json:"rotationPeriod" yaml:"rotationPeriod"`
// If set to true, the request will create a CryptoKey without any CryptoKeyVersions.
//
// You must use the 'google_kms_crypto_key_version' resource to create a new CryptoKeyVersion
// or 'google_kms_key_ring_import_job' resource to import the CryptoKeyVersion.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_kms_crypto_key#skip_initial_version_creation GoogleKmsCryptoKey#skip_initial_version_creation}
SkipInitialVersionCreation interface{} `field:"optional" json:"skipInitialVersionCreation" yaml:"skipInitialVersionCreation"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_kms_crypto_key#timeouts GoogleKmsCryptoKey#timeouts}
Timeouts *GoogleKmsCryptoKeyTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
// version_template block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_kms_crypto_key#version_template GoogleKmsCryptoKey#version_template}
VersionTemplate *GoogleKmsCryptoKeyVersionTemplate `field:"optional" json:"versionTemplate" yaml:"versionTemplate"`
}
type GoogleKmsCryptoKeyKeyAccessJustificationsPolicy ¶
type GoogleKmsCryptoKeyKeyAccessJustificationsPolicy struct {
// The list of allowed reasons for access to this CryptoKey.
//
// Zero allowed
// access reasons means all encrypt, decrypt, and sign operations for
// this CryptoKey will fail.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_kms_crypto_key#allowed_access_reasons GoogleKmsCryptoKey#allowed_access_reasons}
AllowedAccessReasons *[]*string `field:"optional" json:"allowedAccessReasons" yaml:"allowedAccessReasons"`
}
type GoogleKmsCryptoKeyKeyAccessJustificationsPolicyOutputReference ¶
type GoogleKmsCryptoKeyKeyAccessJustificationsPolicyOutputReference interface {
cdktf.ComplexObject
AllowedAccessReasons() *[]*string
SetAllowedAccessReasons(val *[]*string)
AllowedAccessReasonsInput() *[]*string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleKmsCryptoKeyKeyAccessJustificationsPolicy
SetInternalValue(val *GoogleKmsCryptoKeyKeyAccessJustificationsPolicy)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetAllowedAccessReasons()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleKmsCryptoKeyKeyAccessJustificationsPolicyOutputReference ¶
func NewGoogleKmsCryptoKeyKeyAccessJustificationsPolicyOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleKmsCryptoKeyKeyAccessJustificationsPolicyOutputReference
type GoogleKmsCryptoKeyPrimary ¶
type GoogleKmsCryptoKeyPrimary struct {
}
type GoogleKmsCryptoKeyPrimaryList ¶
type GoogleKmsCryptoKeyPrimaryList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) GoogleKmsCryptoKeyPrimaryOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleKmsCryptoKeyPrimaryList ¶
func NewGoogleKmsCryptoKeyPrimaryList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GoogleKmsCryptoKeyPrimaryList
type GoogleKmsCryptoKeyPrimaryOutputReference ¶
type GoogleKmsCryptoKeyPrimaryOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleKmsCryptoKeyPrimary
SetInternalValue(val *GoogleKmsCryptoKeyPrimary)
Name() *string
State() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleKmsCryptoKeyPrimaryOutputReference ¶
func NewGoogleKmsCryptoKeyPrimaryOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GoogleKmsCryptoKeyPrimaryOutputReference
type GoogleKmsCryptoKeyTimeouts ¶
type GoogleKmsCryptoKeyTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_kms_crypto_key#create GoogleKmsCryptoKey#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_kms_crypto_key#delete GoogleKmsCryptoKey#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_kms_crypto_key#update GoogleKmsCryptoKey#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type GoogleKmsCryptoKeyTimeoutsOutputReference ¶
type GoogleKmsCryptoKeyTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleKmsCryptoKeyTimeoutsOutputReference ¶
func NewGoogleKmsCryptoKeyTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleKmsCryptoKeyTimeoutsOutputReference
type GoogleKmsCryptoKeyVersionTemplate ¶
type GoogleKmsCryptoKeyVersionTemplate struct {
// The algorithm to use when creating a version based on this template. See the [algorithm reference](https://cloud.google.com/kms/docs/reference/rest/v1/CryptoKeyVersionAlgorithm) for possible inputs.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_kms_crypto_key#algorithm GoogleKmsCryptoKey#algorithm}
Algorithm *string `field:"required" json:"algorithm" yaml:"algorithm"`
// The protection level to use when creating a version based on this template.
//
// Possible values include "SOFTWARE", "HSM", "EXTERNAL", "EXTERNAL_VPC". Defaults to "SOFTWARE".
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_kms_crypto_key#protection_level GoogleKmsCryptoKey#protection_level}
ProtectionLevel *string `field:"optional" json:"protectionLevel" yaml:"protectionLevel"`
}
type GoogleKmsCryptoKeyVersionTemplateOutputReference ¶
type GoogleKmsCryptoKeyVersionTemplateOutputReference interface {
cdktf.ComplexObject
Algorithm() *string
SetAlgorithm(val *string)
AlgorithmInput() *string
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleKmsCryptoKeyVersionTemplate
SetInternalValue(val *GoogleKmsCryptoKeyVersionTemplate)
ProtectionLevel() *string
SetProtectionLevel(val *string)
ProtectionLevelInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetProtectionLevel()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleKmsCryptoKeyVersionTemplateOutputReference ¶
func NewGoogleKmsCryptoKeyVersionTemplateOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleKmsCryptoKeyVersionTemplateOutputReference
Source Files
¶
- GoogleKmsCryptoKey.go
- GoogleKmsCryptoKeyConfig.go
- GoogleKmsCryptoKeyKeyAccessJustificationsPolicy.go
- GoogleKmsCryptoKeyKeyAccessJustificationsPolicyOutputReference.go
- GoogleKmsCryptoKeyKeyAccessJustificationsPolicyOutputReference__checks.go
- GoogleKmsCryptoKeyPrimary.go
- GoogleKmsCryptoKeyPrimaryList.go
- GoogleKmsCryptoKeyPrimaryList__checks.go
- GoogleKmsCryptoKeyPrimaryOutputReference.go
- GoogleKmsCryptoKeyPrimaryOutputReference__checks.go
- GoogleKmsCryptoKeyTimeouts.go
- GoogleKmsCryptoKeyTimeoutsOutputReference.go
- GoogleKmsCryptoKeyTimeoutsOutputReference__checks.go
- GoogleKmsCryptoKeyVersionTemplate.go
- GoogleKmsCryptoKeyVersionTemplateOutputReference.go
- GoogleKmsCryptoKeyVersionTemplateOutputReference__checks.go
- GoogleKmsCryptoKey__checks.go
- main.go