Documentation
¶
Index ¶
- func GoogleLoggingProjectSink_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func GoogleLoggingProjectSink_IsConstruct(x interface{}) *bool
- func GoogleLoggingProjectSink_IsTerraformElement(x interface{}) *bool
- func GoogleLoggingProjectSink_IsTerraformResource(x interface{}) *bool
- func GoogleLoggingProjectSink_TfResourceType() *string
- func NewGoogleLoggingProjectSinkBigqueryOptionsOutputReference_Override(g GoogleLoggingProjectSinkBigqueryOptionsOutputReference, ...)
- func NewGoogleLoggingProjectSinkExclusionsList_Override(g GoogleLoggingProjectSinkExclusionsList, ...)
- func NewGoogleLoggingProjectSinkExclusionsOutputReference_Override(g GoogleLoggingProjectSinkExclusionsOutputReference, ...)
- func NewGoogleLoggingProjectSink_Override(g GoogleLoggingProjectSink, scope constructs.Construct, id *string, ...)
- type GoogleLoggingProjectSink
- type GoogleLoggingProjectSinkBigqueryOptions
- type GoogleLoggingProjectSinkBigqueryOptionsOutputReference
- type GoogleLoggingProjectSinkConfig
- type GoogleLoggingProjectSinkExclusions
- type GoogleLoggingProjectSinkExclusionsList
- type GoogleLoggingProjectSinkExclusionsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleLoggingProjectSink_GenerateConfigForImport ¶
func GoogleLoggingProjectSink_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a GoogleLoggingProjectSink resource upon running "cdktf plan <stack-name>".
func GoogleLoggingProjectSink_IsConstruct ¶
func GoogleLoggingProjectSink_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleLoggingProjectSink_IsTerraformElement ¶
func GoogleLoggingProjectSink_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleLoggingProjectSink_IsTerraformResource ¶
func GoogleLoggingProjectSink_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleLoggingProjectSink_TfResourceType ¶
func GoogleLoggingProjectSink_TfResourceType() *string
func NewGoogleLoggingProjectSinkBigqueryOptionsOutputReference_Override ¶
func NewGoogleLoggingProjectSinkBigqueryOptionsOutputReference_Override(g GoogleLoggingProjectSinkBigqueryOptionsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleLoggingProjectSinkExclusionsList_Override ¶
func NewGoogleLoggingProjectSinkExclusionsList_Override(g GoogleLoggingProjectSinkExclusionsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGoogleLoggingProjectSinkExclusionsOutputReference_Override ¶
func NewGoogleLoggingProjectSinkExclusionsOutputReference_Override(g GoogleLoggingProjectSinkExclusionsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGoogleLoggingProjectSink_Override ¶
func NewGoogleLoggingProjectSink_Override(g GoogleLoggingProjectSink, scope constructs.Construct, id *string, config *GoogleLoggingProjectSinkConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_logging_project_sink google_logging_project_sink} Resource.
Types ¶
type GoogleLoggingProjectSink ¶
type GoogleLoggingProjectSink interface {
cdktf.TerraformResource
BigqueryOptions() GoogleLoggingProjectSinkBigqueryOptionsOutputReference
BigqueryOptionsInput() *GoogleLoggingProjectSinkBigqueryOptions
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
CustomWriterIdentity() *string
SetCustomWriterIdentity(val *string)
CustomWriterIdentityInput() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
Destination() *string
SetDestination(val *string)
DestinationInput() *string
Disabled() interface{}
SetDisabled(val interface{})
DisabledInput() interface{}
Exclusions() GoogleLoggingProjectSinkExclusionsList
ExclusionsInput() interface{}
Filter() *string
SetFilter(val *string)
FilterInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
UniqueWriterIdentity() interface{}
SetUniqueWriterIdentity(val interface{})
UniqueWriterIdentityInput() interface{}
WriterIdentity() *string
// Adds a user defined moveTarget string to this resource to be later used in .moveTo(moveTarget) to resolve the location of the move.
// Experimental.
AddMoveTarget(moveTarget *string)
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
HasResourceMove() interface{}
// Experimental.
ImportFrom(id *string, provider cdktf.TerraformProvider)
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Move the resource corresponding to "id" to this resource.
//
// Note that the resource being moved from must be marked as moved using it's instance function.
// Experimental.
MoveFromId(id *string)
// Moves this resource to the target resource given by moveTarget.
// Experimental.
MoveTo(moveTarget *string, index interface{})
// Moves this resource to the resource corresponding to "id".
// Experimental.
MoveToId(id *string)
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutBigqueryOptions(value *GoogleLoggingProjectSinkBigqueryOptions)
PutExclusions(value interface{})
ResetBigqueryOptions()
ResetCustomWriterIdentity()
ResetDescription()
ResetDisabled()
ResetExclusions()
ResetFilter()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
ResetUniqueWriterIdentity()
SynthesizeAttributes() *map[string]interface{}
SynthesizeHclAttributes() *map[string]interface{}
// Experimental.
ToHclTerraform() interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_logging_project_sink google_logging_project_sink}.
func NewGoogleLoggingProjectSink ¶
func NewGoogleLoggingProjectSink(scope constructs.Construct, id *string, config *GoogleLoggingProjectSinkConfig) GoogleLoggingProjectSink
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_logging_project_sink google_logging_project_sink} Resource.
type GoogleLoggingProjectSinkBigqueryOptions ¶
type GoogleLoggingProjectSinkBigqueryOptions struct {
// Whether to use BigQuery's partition tables.
//
// By default, Logging creates dated tables based on the log entries' timestamps, e.g. syslog_20170523. With partitioned tables the date suffix is no longer present and special query syntax has to be used instead. In both cases, tables are sharded based on UTC timezone.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_logging_project_sink#use_partitioned_tables GoogleLoggingProjectSink#use_partitioned_tables}
UsePartitionedTables interface{} `field:"required" json:"usePartitionedTables" yaml:"usePartitionedTables"`
}
type GoogleLoggingProjectSinkBigqueryOptionsOutputReference ¶
type GoogleLoggingProjectSinkBigqueryOptionsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleLoggingProjectSinkBigqueryOptions
SetInternalValue(val *GoogleLoggingProjectSinkBigqueryOptions)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
UsePartitionedTables() interface{}
SetUsePartitionedTables(val interface{})
UsePartitionedTablesInput() interface{}
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleLoggingProjectSinkBigqueryOptionsOutputReference ¶
func NewGoogleLoggingProjectSinkBigqueryOptionsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleLoggingProjectSinkBigqueryOptionsOutputReference
type GoogleLoggingProjectSinkConfig ¶
type GoogleLoggingProjectSinkConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// The destination of the sink (or, in other words, where logs are written to).
//
// Can be a Cloud Storage bucket, a PubSub topic, or a BigQuery dataset. Examples: "storage.googleapis.com/[GCS_BUCKET]" "bigquery.googleapis.com/projects/[PROJECT_ID]/datasets/[DATASET]" "pubsub.googleapis.com/projects/[PROJECT_ID]/topics/[TOPIC_ID]" The writer associated with the sink must have access to write to the above resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_logging_project_sink#destination GoogleLoggingProjectSink#destination}
Destination *string `field:"required" json:"destination" yaml:"destination"`
// The name of the logging sink.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_logging_project_sink#name GoogleLoggingProjectSink#name}
Name *string `field:"required" json:"name" yaml:"name"`
// bigquery_options block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_logging_project_sink#bigquery_options GoogleLoggingProjectSink#bigquery_options}
BigqueryOptions *GoogleLoggingProjectSinkBigqueryOptions `field:"optional" json:"bigqueryOptions" yaml:"bigqueryOptions"`
// A service account provided by the caller that will be used to write the log entries.
//
// The format must be serviceAccount:some@email. This field can only be specified if you are routing logs to a destination outside this sink's project. If not specified, a Logging service account will automatically be generated.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_logging_project_sink#custom_writer_identity GoogleLoggingProjectSink#custom_writer_identity}
CustomWriterIdentity *string `field:"optional" json:"customWriterIdentity" yaml:"customWriterIdentity"`
// A description of this sink. The maximum length of the description is 8000 characters.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_logging_project_sink#description GoogleLoggingProjectSink#description}
Description *string `field:"optional" json:"description" yaml:"description"`
// If set to True, then this sink is disabled and it does not export any log entries.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_logging_project_sink#disabled GoogleLoggingProjectSink#disabled}
Disabled interface{} `field:"optional" json:"disabled" yaml:"disabled"`
// exclusions block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_logging_project_sink#exclusions GoogleLoggingProjectSink#exclusions}
Exclusions interface{} `field:"optional" json:"exclusions" yaml:"exclusions"`
// The filter to apply when exporting logs. Only log entries that match the filter are exported.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_logging_project_sink#filter GoogleLoggingProjectSink#filter}
Filter *string `field:"optional" json:"filter" yaml:"filter"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_logging_project_sink#id GoogleLoggingProjectSink#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// The ID of the project to create the sink in.
//
// If omitted, the project associated with the provider is used.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_logging_project_sink#project GoogleLoggingProjectSink#project}
Project *string `field:"optional" json:"project" yaml:"project"`
// Whether or not to create a unique identity associated with this sink.
//
// If false (the legacy behavior), then the writer_identity used is serviceAccount:cloud-logs@system.gserviceaccount.com. If true (default), then a unique service account is created and used for this sink. If you wish to publish logs across projects, you must set unique_writer_identity to true.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_logging_project_sink#unique_writer_identity GoogleLoggingProjectSink#unique_writer_identity}
UniqueWriterIdentity interface{} `field:"optional" json:"uniqueWriterIdentity" yaml:"uniqueWriterIdentity"`
}
type GoogleLoggingProjectSinkExclusions ¶
type GoogleLoggingProjectSinkExclusions struct {
// An advanced logs filter that matches the log entries to be excluded.
//
// By using the sample function, you can exclude less than 100% of the matching log entries
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_logging_project_sink#filter GoogleLoggingProjectSink#filter}
Filter *string `field:"required" json:"filter" yaml:"filter"`
// A client-assigned identifier, such as "load-balancer-exclusion".
//
// Identifiers are limited to 100 characters and can include only letters, digits, underscores, hyphens, and periods. First character has to be alphanumeric.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_logging_project_sink#name GoogleLoggingProjectSink#name}
Name *string `field:"required" json:"name" yaml:"name"`
// A description of this exclusion.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_logging_project_sink#description GoogleLoggingProjectSink#description}
Description *string `field:"optional" json:"description" yaml:"description"`
// If set to True, then this exclusion is disabled and it does not exclude any log entries.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_logging_project_sink#disabled GoogleLoggingProjectSink#disabled}
Disabled interface{} `field:"optional" json:"disabled" yaml:"disabled"`
}
type GoogleLoggingProjectSinkExclusionsList ¶
type GoogleLoggingProjectSinkExclusionsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) GoogleLoggingProjectSinkExclusionsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleLoggingProjectSinkExclusionsList ¶
func NewGoogleLoggingProjectSinkExclusionsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GoogleLoggingProjectSinkExclusionsList
type GoogleLoggingProjectSinkExclusionsOutputReference ¶
type GoogleLoggingProjectSinkExclusionsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Description() *string
SetDescription(val *string)
DescriptionInput() *string
Disabled() interface{}
SetDisabled(val interface{})
DisabledInput() interface{}
Filter() *string
SetFilter(val *string)
FilterInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Name() *string
SetName(val *string)
NameInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetDescription()
ResetDisabled()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleLoggingProjectSinkExclusionsOutputReference ¶
func NewGoogleLoggingProjectSinkExclusionsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GoogleLoggingProjectSinkExclusionsOutputReference
Source Files
¶
- GoogleLoggingProjectSink.go
- GoogleLoggingProjectSinkBigqueryOptions.go
- GoogleLoggingProjectSinkBigqueryOptionsOutputReference.go
- GoogleLoggingProjectSinkBigqueryOptionsOutputReference__checks.go
- GoogleLoggingProjectSinkConfig.go
- GoogleLoggingProjectSinkExclusions.go
- GoogleLoggingProjectSinkExclusionsList.go
- GoogleLoggingProjectSinkExclusionsList__checks.go
- GoogleLoggingProjectSinkExclusionsOutputReference.go
- GoogleLoggingProjectSinkExclusionsOutputReference__checks.go
- GoogleLoggingProjectSink__checks.go
- main.go