Documentation
¶
Index ¶
- func GoogleMemcacheInstance_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func GoogleMemcacheInstance_IsConstruct(x interface{}) *bool
- func GoogleMemcacheInstance_IsTerraformElement(x interface{}) *bool
- func GoogleMemcacheInstance_IsTerraformResource(x interface{}) *bool
- func GoogleMemcacheInstance_TfResourceType() *string
- func NewGoogleMemcacheInstanceMaintenancePolicyOutputReference_Override(g GoogleMemcacheInstanceMaintenancePolicyOutputReference, ...)
- func NewGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowList_Override(g GoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowList, ...)
- func NewGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowOutputReference_Override(...)
- func NewGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeOutputReference_Override(...)
- func NewGoogleMemcacheInstanceMaintenanceScheduleList_Override(g GoogleMemcacheInstanceMaintenanceScheduleList, ...)
- func NewGoogleMemcacheInstanceMaintenanceScheduleOutputReference_Override(g GoogleMemcacheInstanceMaintenanceScheduleOutputReference, ...)
- func NewGoogleMemcacheInstanceMemcacheNodesList_Override(g GoogleMemcacheInstanceMemcacheNodesList, ...)
- func NewGoogleMemcacheInstanceMemcacheNodesOutputReference_Override(g GoogleMemcacheInstanceMemcacheNodesOutputReference, ...)
- func NewGoogleMemcacheInstanceMemcacheParametersOutputReference_Override(g GoogleMemcacheInstanceMemcacheParametersOutputReference, ...)
- func NewGoogleMemcacheInstanceNodeConfigOutputReference_Override(g GoogleMemcacheInstanceNodeConfigOutputReference, ...)
- func NewGoogleMemcacheInstanceTimeoutsOutputReference_Override(g GoogleMemcacheInstanceTimeoutsOutputReference, ...)
- func NewGoogleMemcacheInstance_Override(g GoogleMemcacheInstance, scope constructs.Construct, id *string, ...)
- type GoogleMemcacheInstance
- type GoogleMemcacheInstanceConfig
- type GoogleMemcacheInstanceMaintenancePolicy
- type GoogleMemcacheInstanceMaintenancePolicyOutputReference
- type GoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindow
- type GoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowList
- type GoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowOutputReference
- type GoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTime
- type GoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeOutputReference
- type GoogleMemcacheInstanceMaintenanceSchedule
- type GoogleMemcacheInstanceMaintenanceScheduleList
- type GoogleMemcacheInstanceMaintenanceScheduleOutputReference
- type GoogleMemcacheInstanceMemcacheNodes
- type GoogleMemcacheInstanceMemcacheNodesList
- type GoogleMemcacheInstanceMemcacheNodesOutputReference
- type GoogleMemcacheInstanceMemcacheParameters
- type GoogleMemcacheInstanceMemcacheParametersOutputReference
- type GoogleMemcacheInstanceNodeConfig
- type GoogleMemcacheInstanceNodeConfigOutputReference
- type GoogleMemcacheInstanceTimeouts
- type GoogleMemcacheInstanceTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleMemcacheInstance_GenerateConfigForImport ¶
func GoogleMemcacheInstance_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a GoogleMemcacheInstance resource upon running "cdktf plan <stack-name>".
func GoogleMemcacheInstance_IsConstruct ¶
func GoogleMemcacheInstance_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleMemcacheInstance_IsTerraformElement ¶
func GoogleMemcacheInstance_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleMemcacheInstance_IsTerraformResource ¶
func GoogleMemcacheInstance_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleMemcacheInstance_TfResourceType ¶
func GoogleMemcacheInstance_TfResourceType() *string
func NewGoogleMemcacheInstanceMaintenancePolicyOutputReference_Override ¶
func NewGoogleMemcacheInstanceMaintenancePolicyOutputReference_Override(g GoogleMemcacheInstanceMaintenancePolicyOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowList_Override ¶
func NewGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowList_Override(g GoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowOutputReference_Override ¶
func NewGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowOutputReference_Override(g GoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeOutputReference_Override ¶
func NewGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeOutputReference_Override(g GoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleMemcacheInstanceMaintenanceScheduleList_Override ¶
func NewGoogleMemcacheInstanceMaintenanceScheduleList_Override(g GoogleMemcacheInstanceMaintenanceScheduleList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGoogleMemcacheInstanceMaintenanceScheduleOutputReference_Override ¶
func NewGoogleMemcacheInstanceMaintenanceScheduleOutputReference_Override(g GoogleMemcacheInstanceMaintenanceScheduleOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGoogleMemcacheInstanceMemcacheNodesList_Override ¶
func NewGoogleMemcacheInstanceMemcacheNodesList_Override(g GoogleMemcacheInstanceMemcacheNodesList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGoogleMemcacheInstanceMemcacheNodesOutputReference_Override ¶
func NewGoogleMemcacheInstanceMemcacheNodesOutputReference_Override(g GoogleMemcacheInstanceMemcacheNodesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGoogleMemcacheInstanceMemcacheParametersOutputReference_Override ¶
func NewGoogleMemcacheInstanceMemcacheParametersOutputReference_Override(g GoogleMemcacheInstanceMemcacheParametersOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleMemcacheInstanceNodeConfigOutputReference_Override ¶
func NewGoogleMemcacheInstanceNodeConfigOutputReference_Override(g GoogleMemcacheInstanceNodeConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleMemcacheInstanceTimeoutsOutputReference_Override ¶
func NewGoogleMemcacheInstanceTimeoutsOutputReference_Override(g GoogleMemcacheInstanceTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleMemcacheInstance_Override ¶
func NewGoogleMemcacheInstance_Override(g GoogleMemcacheInstance, scope constructs.Construct, id *string, config *GoogleMemcacheInstanceConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_memcache_instance google_memcache_instance} Resource.
Types ¶
type GoogleMemcacheInstance ¶
type GoogleMemcacheInstance interface {
cdktf.TerraformResource
AuthorizedNetwork() *string
SetAuthorizedNetwork(val *string)
AuthorizedNetworkInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
CreateTime() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DiscoveryEndpoint() *string
DisplayName() *string
SetDisplayName(val *string)
DisplayNameInput() *string
EffectiveLabels() cdktf.StringMap
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
Labels() *map[string]*string
SetLabels(val *map[string]*string)
LabelsInput() *map[string]*string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
MaintenancePolicy() GoogleMemcacheInstanceMaintenancePolicyOutputReference
MaintenancePolicyInput() *GoogleMemcacheInstanceMaintenancePolicy
MaintenanceSchedule() GoogleMemcacheInstanceMaintenanceScheduleList
MemcacheFullVersion() *string
MemcacheNodes() GoogleMemcacheInstanceMemcacheNodesList
MemcacheParameters() GoogleMemcacheInstanceMemcacheParametersOutputReference
MemcacheParametersInput() *GoogleMemcacheInstanceMemcacheParameters
MemcacheVersion() *string
SetMemcacheVersion(val *string)
MemcacheVersionInput() *string
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
NodeConfig() GoogleMemcacheInstanceNodeConfigOutputReference
NodeConfigInput() *GoogleMemcacheInstanceNodeConfig
NodeCount() *float64
SetNodeCount(val *float64)
NodeCountInput() *float64
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Region() *string
SetRegion(val *string)
RegionInput() *string
ReservedIpRangeId() *[]*string
SetReservedIpRangeId(val *[]*string)
ReservedIpRangeIdInput() *[]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
TerraformLabels() cdktf.StringMap
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GoogleMemcacheInstanceTimeoutsOutputReference
TimeoutsInput() interface{}
Zones() *[]*string
SetZones(val *[]*string)
ZonesInput() *[]*string
// Adds a user defined moveTarget string to this resource to be later used in .moveTo(moveTarget) to resolve the location of the move.
// Experimental.
AddMoveTarget(moveTarget *string)
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
HasResourceMove() interface{}
// Experimental.
ImportFrom(id *string, provider cdktf.TerraformProvider)
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Move the resource corresponding to "id" to this resource.
//
// Note that the resource being moved from must be marked as moved using it's instance function.
// Experimental.
MoveFromId(id *string)
// Moves this resource to the target resource given by moveTarget.
// Experimental.
MoveTo(moveTarget *string, index interface{})
// Moves this resource to the resource corresponding to "id".
// Experimental.
MoveToId(id *string)
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutMaintenancePolicy(value *GoogleMemcacheInstanceMaintenancePolicy)
PutMemcacheParameters(value *GoogleMemcacheInstanceMemcacheParameters)
PutNodeConfig(value *GoogleMemcacheInstanceNodeConfig)
PutTimeouts(value *GoogleMemcacheInstanceTimeouts)
ResetAuthorizedNetwork()
ResetDisplayName()
ResetId()
ResetLabels()
ResetMaintenancePolicy()
ResetMemcacheParameters()
ResetMemcacheVersion()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
ResetRegion()
ResetReservedIpRangeId()
ResetTimeouts()
ResetZones()
SynthesizeAttributes() *map[string]interface{}
SynthesizeHclAttributes() *map[string]interface{}
// Experimental.
ToHclTerraform() interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_memcache_instance google_memcache_instance}.
func NewGoogleMemcacheInstance ¶
func NewGoogleMemcacheInstance(scope constructs.Construct, id *string, config *GoogleMemcacheInstanceConfig) GoogleMemcacheInstance
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_memcache_instance google_memcache_instance} Resource.
type GoogleMemcacheInstanceConfig ¶
type GoogleMemcacheInstanceConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// The resource name of the instance.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_memcache_instance#name GoogleMemcacheInstance#name}
Name *string `field:"required" json:"name" yaml:"name"`
// node_config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_memcache_instance#node_config GoogleMemcacheInstance#node_config}
NodeConfig *GoogleMemcacheInstanceNodeConfig `field:"required" json:"nodeConfig" yaml:"nodeConfig"`
// Number of nodes in the memcache instance.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_memcache_instance#node_count GoogleMemcacheInstance#node_count}
NodeCount *float64 `field:"required" json:"nodeCount" yaml:"nodeCount"`
// The full name of the GCE network to connect the instance to. If not provided, 'default' will be used.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_memcache_instance#authorized_network GoogleMemcacheInstance#authorized_network}
AuthorizedNetwork *string `field:"optional" json:"authorizedNetwork" yaml:"authorizedNetwork"`
// A user-visible name for the instance.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_memcache_instance#display_name GoogleMemcacheInstance#display_name}
DisplayName *string `field:"optional" json:"displayName" yaml:"displayName"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_memcache_instance#id GoogleMemcacheInstance#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Resource labels to represent user-provided metadata.
//
// **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
// Please refer to the field 'effective_labels' for all of the labels present on the resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_memcache_instance#labels GoogleMemcacheInstance#labels}
Labels *map[string]*string `field:"optional" json:"labels" yaml:"labels"`
// maintenance_policy block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_memcache_instance#maintenance_policy GoogleMemcacheInstance#maintenance_policy}
MaintenancePolicy *GoogleMemcacheInstanceMaintenancePolicy `field:"optional" json:"maintenancePolicy" yaml:"maintenancePolicy"`
// memcache_parameters block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_memcache_instance#memcache_parameters GoogleMemcacheInstance#memcache_parameters}
MemcacheParameters *GoogleMemcacheInstanceMemcacheParameters `field:"optional" json:"memcacheParameters" yaml:"memcacheParameters"`
// The major version of Memcached software.
//
// If not provided, latest supported version will be used.
// Currently the latest supported major version is MEMCACHE_1_5. The minor version will be automatically
// determined by our system based on the latest supported minor version. Default value: "MEMCACHE_1_5" Possible values: ["MEMCACHE_1_5", "MEMCACHE_1_6_15"]
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_memcache_instance#memcache_version GoogleMemcacheInstance#memcache_version}
MemcacheVersion *string `field:"optional" json:"memcacheVersion" yaml:"memcacheVersion"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_memcache_instance#project GoogleMemcacheInstance#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// The region of the Memcache instance. If it is not provided, the provider region is used.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_memcache_instance#region GoogleMemcacheInstance#region}
Region *string `field:"optional" json:"region" yaml:"region"`
// Contains the name of allocated IP address ranges associated with the private service access connection for example, "test-default" associated with IP range 10.0.0.0/29.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_memcache_instance#reserved_ip_range_id GoogleMemcacheInstance#reserved_ip_range_id}
ReservedIpRangeId *[]*string `field:"optional" json:"reservedIpRangeId" yaml:"reservedIpRangeId"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_memcache_instance#timeouts GoogleMemcacheInstance#timeouts}
Timeouts *GoogleMemcacheInstanceTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
// Zones where memcache nodes should be provisioned. If not provided, all zones will be used.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_memcache_instance#zones GoogleMemcacheInstance#zones}
Zones *[]*string `field:"optional" json:"zones" yaml:"zones"`
}
type GoogleMemcacheInstanceMaintenancePolicy ¶
type GoogleMemcacheInstanceMaintenancePolicy struct {
// weekly_maintenance_window block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_memcache_instance#weekly_maintenance_window GoogleMemcacheInstance#weekly_maintenance_window}
WeeklyMaintenanceWindow interface{} `field:"required" json:"weeklyMaintenanceWindow" yaml:"weeklyMaintenanceWindow"`
// Optional. Description of what this policy is for. Create/Update methods return INVALID_ARGUMENT if the length is greater than 512.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_memcache_instance#description GoogleMemcacheInstance#description}
Description *string `field:"optional" json:"description" yaml:"description"`
}
type GoogleMemcacheInstanceMaintenancePolicyOutputReference ¶
type GoogleMemcacheInstanceMaintenancePolicyOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
CreateTime() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Description() *string
SetDescription(val *string)
DescriptionInput() *string
// Experimental.
Fqn() *string
InternalValue() *GoogleMemcacheInstanceMaintenancePolicy
SetInternalValue(val *GoogleMemcacheInstanceMaintenancePolicy)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
UpdateTime() *string
WeeklyMaintenanceWindow() GoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowList
WeeklyMaintenanceWindowInput() interface{}
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutWeeklyMaintenanceWindow(value interface{})
ResetDescription()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleMemcacheInstanceMaintenancePolicyOutputReference ¶
func NewGoogleMemcacheInstanceMaintenancePolicyOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleMemcacheInstanceMaintenancePolicyOutputReference
type GoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindow ¶
type GoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindow struct {
// Required.
//
// The day of week that maintenance updates occur.
// - DAY_OF_WEEK_UNSPECIFIED: The day of the week is unspecified.
// - MONDAY: Monday
// - TUESDAY: Tuesday
// - WEDNESDAY: Wednesday
// - THURSDAY: Thursday
// - FRIDAY: Friday
// - SATURDAY: Saturday
// - SUNDAY: Sunday Possible values: ["DAY_OF_WEEK_UNSPECIFIED", "MONDAY", "TUESDAY", "WEDNESDAY", "THURSDAY", "FRIDAY", "SATURDAY", "SUNDAY"]
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_memcache_instance#day GoogleMemcacheInstance#day}
Day *string `field:"required" json:"day" yaml:"day"`
// Required.
//
// The length of the maintenance window, ranging from 3 hours to 8 hours.
// A duration in seconds with up to nine fractional digits,
// terminated by 's'. Example: "3.5s".
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_memcache_instance#duration GoogleMemcacheInstance#duration}
Duration *string `field:"required" json:"duration" yaml:"duration"`
// start_time block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_memcache_instance#start_time GoogleMemcacheInstance#start_time}
StartTime *GoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTime `field:"required" json:"startTime" yaml:"startTime"`
}
type GoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowList ¶
type GoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) GoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowList ¶
func NewGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowList
type GoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowOutputReference ¶
type GoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Day() *string
SetDay(val *string)
DayInput() *string
Duration() *string
SetDuration(val *string)
DurationInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
StartTime() GoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeOutputReference
StartTimeInput() *GoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTime
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutStartTime(value *GoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTime)
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowOutputReference ¶
func NewGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowOutputReference
type GoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTime ¶
type GoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTime struct {
// Hours of day in 24 hour format.
//
// Should be from 0 to 23.
// An API may choose to allow the value "24:00:00" for scenarios like business closing time.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_memcache_instance#hours GoogleMemcacheInstance#hours}
Hours *float64 `field:"optional" json:"hours" yaml:"hours"`
// Minutes of hour of day. Must be from 0 to 59.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_memcache_instance#minutes GoogleMemcacheInstance#minutes}
Minutes *float64 `field:"optional" json:"minutes" yaml:"minutes"`
// Fractions of seconds in nanoseconds. Must be from 0 to 999,999,999.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_memcache_instance#nanos GoogleMemcacheInstance#nanos}
Nanos *float64 `field:"optional" json:"nanos" yaml:"nanos"`
// Seconds of minutes of the time.
//
// Must normally be from 0 to 59.
// An API may allow the value 60 if it allows leap-seconds.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_memcache_instance#seconds GoogleMemcacheInstance#seconds}
Seconds *float64 `field:"optional" json:"seconds" yaml:"seconds"`
}
type GoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeOutputReference ¶
type GoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Hours() *float64
SetHours(val *float64)
HoursInput() *float64
InternalValue() *GoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTime
SetInternalValue(val *GoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTime)
Minutes() *float64
SetMinutes(val *float64)
MinutesInput() *float64
Nanos() *float64
SetNanos(val *float64)
NanosInput() *float64
Seconds() *float64
SetSeconds(val *float64)
SecondsInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetHours()
ResetMinutes()
ResetNanos()
ResetSeconds()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeOutputReference ¶
func NewGoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeOutputReference
type GoogleMemcacheInstanceMaintenanceSchedule ¶
type GoogleMemcacheInstanceMaintenanceSchedule struct {
}
type GoogleMemcacheInstanceMaintenanceScheduleList ¶
type GoogleMemcacheInstanceMaintenanceScheduleList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) GoogleMemcacheInstanceMaintenanceScheduleOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleMemcacheInstanceMaintenanceScheduleList ¶
func NewGoogleMemcacheInstanceMaintenanceScheduleList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GoogleMemcacheInstanceMaintenanceScheduleList
type GoogleMemcacheInstanceMaintenanceScheduleOutputReference ¶
type GoogleMemcacheInstanceMaintenanceScheduleOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
EndTime() *string
// Experimental.
Fqn() *string
InternalValue() *GoogleMemcacheInstanceMaintenanceSchedule
SetInternalValue(val *GoogleMemcacheInstanceMaintenanceSchedule)
ScheduleDeadlineTime() *string
StartTime() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleMemcacheInstanceMaintenanceScheduleOutputReference ¶
func NewGoogleMemcacheInstanceMaintenanceScheduleOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GoogleMemcacheInstanceMaintenanceScheduleOutputReference
type GoogleMemcacheInstanceMemcacheNodes ¶
type GoogleMemcacheInstanceMemcacheNodes struct {
}
type GoogleMemcacheInstanceMemcacheNodesList ¶
type GoogleMemcacheInstanceMemcacheNodesList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) GoogleMemcacheInstanceMemcacheNodesOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleMemcacheInstanceMemcacheNodesList ¶
func NewGoogleMemcacheInstanceMemcacheNodesList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GoogleMemcacheInstanceMemcacheNodesList
type GoogleMemcacheInstanceMemcacheNodesOutputReference ¶
type GoogleMemcacheInstanceMemcacheNodesOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Host() *string
InternalValue() *GoogleMemcacheInstanceMemcacheNodes
SetInternalValue(val *GoogleMemcacheInstanceMemcacheNodes)
NodeId() *string
Port() *float64
State() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Zone() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleMemcacheInstanceMemcacheNodesOutputReference ¶
func NewGoogleMemcacheInstanceMemcacheNodesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GoogleMemcacheInstanceMemcacheNodesOutputReference
type GoogleMemcacheInstanceMemcacheParameters ¶
type GoogleMemcacheInstanceMemcacheParameters struct {
// User-defined set of parameters to use in the memcache process.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_memcache_instance#params GoogleMemcacheInstance#params}
Params *map[string]*string `field:"optional" json:"params" yaml:"params"`
}
type GoogleMemcacheInstanceMemcacheParametersOutputReference ¶
type GoogleMemcacheInstanceMemcacheParametersOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Id() *string
InternalValue() *GoogleMemcacheInstanceMemcacheParameters
SetInternalValue(val *GoogleMemcacheInstanceMemcacheParameters)
Params() *map[string]*string
SetParams(val *map[string]*string)
ParamsInput() *map[string]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetParams()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleMemcacheInstanceMemcacheParametersOutputReference ¶
func NewGoogleMemcacheInstanceMemcacheParametersOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleMemcacheInstanceMemcacheParametersOutputReference
type GoogleMemcacheInstanceNodeConfig ¶
type GoogleMemcacheInstanceNodeConfig struct {
// Number of CPUs per node.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_memcache_instance#cpu_count GoogleMemcacheInstance#cpu_count}
CpuCount *float64 `field:"required" json:"cpuCount" yaml:"cpuCount"`
// Memory size in Mebibytes for each memcache node.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_memcache_instance#memory_size_mb GoogleMemcacheInstance#memory_size_mb}
MemorySizeMb *float64 `field:"required" json:"memorySizeMb" yaml:"memorySizeMb"`
}
type GoogleMemcacheInstanceNodeConfigOutputReference ¶
type GoogleMemcacheInstanceNodeConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
CpuCount() *float64
SetCpuCount(val *float64)
CpuCountInput() *float64
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleMemcacheInstanceNodeConfig
SetInternalValue(val *GoogleMemcacheInstanceNodeConfig)
MemorySizeMb() *float64
SetMemorySizeMb(val *float64)
MemorySizeMbInput() *float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleMemcacheInstanceNodeConfigOutputReference ¶
func NewGoogleMemcacheInstanceNodeConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleMemcacheInstanceNodeConfigOutputReference
type GoogleMemcacheInstanceTimeouts ¶
type GoogleMemcacheInstanceTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_memcache_instance#create GoogleMemcacheInstance#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_memcache_instance#delete GoogleMemcacheInstance#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_memcache_instance#update GoogleMemcacheInstance#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type GoogleMemcacheInstanceTimeoutsOutputReference ¶
type GoogleMemcacheInstanceTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleMemcacheInstanceTimeoutsOutputReference ¶
func NewGoogleMemcacheInstanceTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleMemcacheInstanceTimeoutsOutputReference
Source Files
¶
- GoogleMemcacheInstance.go
- GoogleMemcacheInstanceConfig.go
- GoogleMemcacheInstanceMaintenancePolicy.go
- GoogleMemcacheInstanceMaintenancePolicyOutputReference.go
- GoogleMemcacheInstanceMaintenancePolicyOutputReference__checks.go
- GoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindow.go
- GoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowList.go
- GoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowList__checks.go
- GoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowOutputReference.go
- GoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowOutputReference__checks.go
- GoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTime.go
- GoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeOutputReference.go
- GoogleMemcacheInstanceMaintenancePolicyWeeklyMaintenanceWindowStartTimeOutputReference__checks.go
- GoogleMemcacheInstanceMaintenanceSchedule.go
- GoogleMemcacheInstanceMaintenanceScheduleList.go
- GoogleMemcacheInstanceMaintenanceScheduleList__checks.go
- GoogleMemcacheInstanceMaintenanceScheduleOutputReference.go
- GoogleMemcacheInstanceMaintenanceScheduleOutputReference__checks.go
- GoogleMemcacheInstanceMemcacheNodes.go
- GoogleMemcacheInstanceMemcacheNodesList.go
- GoogleMemcacheInstanceMemcacheNodesList__checks.go
- GoogleMemcacheInstanceMemcacheNodesOutputReference.go
- GoogleMemcacheInstanceMemcacheNodesOutputReference__checks.go
- GoogleMemcacheInstanceMemcacheParameters.go
- GoogleMemcacheInstanceMemcacheParametersOutputReference.go
- GoogleMemcacheInstanceMemcacheParametersOutputReference__checks.go
- GoogleMemcacheInstanceNodeConfig.go
- GoogleMemcacheInstanceNodeConfigOutputReference.go
- GoogleMemcacheInstanceNodeConfigOutputReference__checks.go
- GoogleMemcacheInstanceTimeouts.go
- GoogleMemcacheInstanceTimeoutsOutputReference.go
- GoogleMemcacheInstanceTimeoutsOutputReference__checks.go
- GoogleMemcacheInstance__checks.go
- main.go