Documentation
¶
Index ¶
- func GoogleNetappStoragePool_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func GoogleNetappStoragePool_IsConstruct(x interface{}) *bool
- func GoogleNetappStoragePool_IsTerraformElement(x interface{}) *bool
- func GoogleNetappStoragePool_IsTerraformResource(x interface{}) *bool
- func GoogleNetappStoragePool_TfResourceType() *string
- func NewGoogleNetappStoragePoolTimeoutsOutputReference_Override(g GoogleNetappStoragePoolTimeoutsOutputReference, ...)
- func NewGoogleNetappStoragePool_Override(g GoogleNetappStoragePool, scope constructs.Construct, id *string, ...)
- type GoogleNetappStoragePool
- type GoogleNetappStoragePoolConfig
- type GoogleNetappStoragePoolTimeouts
- type GoogleNetappStoragePoolTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleNetappStoragePool_GenerateConfigForImport ¶
func GoogleNetappStoragePool_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a GoogleNetappStoragePool resource upon running "cdktf plan <stack-name>".
func GoogleNetappStoragePool_IsConstruct ¶
func GoogleNetappStoragePool_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleNetappStoragePool_IsTerraformElement ¶
func GoogleNetappStoragePool_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleNetappStoragePool_IsTerraformResource ¶
func GoogleNetappStoragePool_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleNetappStoragePool_TfResourceType ¶
func GoogleNetappStoragePool_TfResourceType() *string
func NewGoogleNetappStoragePoolTimeoutsOutputReference_Override ¶
func NewGoogleNetappStoragePoolTimeoutsOutputReference_Override(g GoogleNetappStoragePoolTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleNetappStoragePool_Override ¶
func NewGoogleNetappStoragePool_Override(g GoogleNetappStoragePool, scope constructs.Construct, id *string, config *GoogleNetappStoragePoolConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_netapp_storage_pool google_netapp_storage_pool} Resource.
Types ¶
type GoogleNetappStoragePool ¶
type GoogleNetappStoragePool interface {
cdktf.TerraformResource
ActiveDirectory() *string
SetActiveDirectory(val *string)
ActiveDirectoryInput() *string
AllowAutoTiering() interface{}
SetAllowAutoTiering(val interface{})
AllowAutoTieringInput() interface{}
CapacityGib() *string
SetCapacityGib(val *string)
CapacityGibInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
CustomPerformanceEnabled() interface{}
SetCustomPerformanceEnabled(val interface{})
CustomPerformanceEnabledInput() interface{}
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
EffectiveLabels() cdktf.StringMap
EncryptionType() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
KmsConfig() *string
SetKmsConfig(val *string)
KmsConfigInput() *string
Labels() *map[string]*string
SetLabels(val *map[string]*string)
LabelsInput() *map[string]*string
LdapEnabled() interface{}
SetLdapEnabled(val interface{})
LdapEnabledInput() interface{}
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Location() *string
SetLocation(val *string)
LocationInput() *string
Name() *string
SetName(val *string)
NameInput() *string
Network() *string
SetNetwork(val *string)
NetworkInput() *string
// The tree node.
Node() constructs.Node
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
ReplicaZone() *string
SetReplicaZone(val *string)
ReplicaZoneInput() *string
ServiceLevel() *string
SetServiceLevel(val *string)
ServiceLevelInput() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
TerraformLabels() cdktf.StringMap
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GoogleNetappStoragePoolTimeoutsOutputReference
TimeoutsInput() interface{}
TotalIops() *string
SetTotalIops(val *string)
TotalIopsInput() *string
TotalThroughputMibps() *string
SetTotalThroughputMibps(val *string)
TotalThroughputMibpsInput() *string
VolumeCapacityGib() *string
VolumeCount() *float64
Zone() *string
SetZone(val *string)
ZoneInput() *string
// Adds a user defined moveTarget string to this resource to be later used in .moveTo(moveTarget) to resolve the location of the move.
// Experimental.
AddMoveTarget(moveTarget *string)
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
HasResourceMove() interface{}
// Experimental.
ImportFrom(id *string, provider cdktf.TerraformProvider)
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Move the resource corresponding to "id" to this resource.
//
// Note that the resource being moved from must be marked as moved using it's instance function.
// Experimental.
MoveFromId(id *string)
// Moves this resource to the target resource given by moveTarget.
// Experimental.
MoveTo(moveTarget *string, index interface{})
// Moves this resource to the resource corresponding to "id".
// Experimental.
MoveToId(id *string)
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutTimeouts(value *GoogleNetappStoragePoolTimeouts)
ResetActiveDirectory()
ResetAllowAutoTiering()
ResetCustomPerformanceEnabled()
ResetDescription()
ResetId()
ResetKmsConfig()
ResetLabels()
ResetLdapEnabled()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
ResetReplicaZone()
ResetTimeouts()
ResetTotalIops()
ResetTotalThroughputMibps()
ResetZone()
SynthesizeAttributes() *map[string]interface{}
SynthesizeHclAttributes() *map[string]interface{}
// Experimental.
ToHclTerraform() interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_netapp_storage_pool google_netapp_storage_pool}.
func NewGoogleNetappStoragePool ¶
func NewGoogleNetappStoragePool(scope constructs.Construct, id *string, config *GoogleNetappStoragePoolConfig) GoogleNetappStoragePool
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_netapp_storage_pool google_netapp_storage_pool} Resource.
type GoogleNetappStoragePoolConfig ¶
type GoogleNetappStoragePoolConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// Capacity of the storage pool (in GiB).
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_netapp_storage_pool#capacity_gib GoogleNetappStoragePool#capacity_gib}
CapacityGib *string `field:"required" json:"capacityGib" yaml:"capacityGib"`
// Name of the location. For zonal Flex pools specify a zone name, in all other cases a region name.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_netapp_storage_pool#location GoogleNetappStoragePool#location}
Location *string `field:"required" json:"location" yaml:"location"`
// The resource name of the storage pool. Needs to be unique per location/region.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_netapp_storage_pool#name GoogleNetappStoragePool#name}
Name *string `field:"required" json:"name" yaml:"name"`
// VPC network name with format: 'projects/{{project}}/global/networks/{{network}}'.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_netapp_storage_pool#network GoogleNetappStoragePool#network}
Network *string `field:"required" json:"network" yaml:"network"`
// Service level of the storage pool. Possible values: ["PREMIUM", "EXTREME", "STANDARD", "FLEX"].
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_netapp_storage_pool#service_level GoogleNetappStoragePool#service_level}
ServiceLevel *string `field:"required" json:"serviceLevel" yaml:"serviceLevel"`
// Specifies the Active Directory policy to be used.
//
// Format: 'projects/{{project}}/locations/{{location}}/activeDirectories/{{name}}'.
// The policy needs to be in the same location as the storage pool.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_netapp_storage_pool#active_directory GoogleNetappStoragePool#active_directory}
ActiveDirectory *string `field:"optional" json:"activeDirectory" yaml:"activeDirectory"`
// Optional.
//
// True if the storage pool supports Auto Tiering enabled volumes. Default is false.
// Auto-tiering can be enabled after storage pool creation but it can't be disabled once enabled.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_netapp_storage_pool#allow_auto_tiering GoogleNetappStoragePool#allow_auto_tiering}
AllowAutoTiering interface{} `field:"optional" json:"allowAutoTiering" yaml:"allowAutoTiering"`
// Optional. True if using Independent Scaling of capacity and performance (Hyperdisk). Default is false.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_netapp_storage_pool#custom_performance_enabled GoogleNetappStoragePool#custom_performance_enabled}
CustomPerformanceEnabled interface{} `field:"optional" json:"customPerformanceEnabled" yaml:"customPerformanceEnabled"`
// An optional description of this resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_netapp_storage_pool#description GoogleNetappStoragePool#description}
Description *string `field:"optional" json:"description" yaml:"description"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_netapp_storage_pool#id GoogleNetappStoragePool#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Specifies the CMEK policy to be used for volume encryption.
//
// Format: 'projects/{{project}}/locations/{{location}}/kmsConfigs/{{name}}'.
// The policy needs to be in the same location as the storage pool.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_netapp_storage_pool#kms_config GoogleNetappStoragePool#kms_config}
KmsConfig *string `field:"optional" json:"kmsConfig" yaml:"kmsConfig"`
// Labels as key value pairs. Example: '{ "owner": "Bob", "department": "finance", "purpose": "testing" }'.
//
// **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
// Please refer to the field 'effective_labels' for all of the labels present on the resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_netapp_storage_pool#labels GoogleNetappStoragePool#labels}
Labels *map[string]*string `field:"optional" json:"labels" yaml:"labels"`
// When enabled, the volumes uses Active Directory as LDAP name service for UID/GID lookups.
//
// Required to enable extended group support for NFSv3,
// using security identifiers for NFSv4.1 or principal names for kerberized NFSv4.1.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_netapp_storage_pool#ldap_enabled GoogleNetappStoragePool#ldap_enabled}
LdapEnabled interface{} `field:"optional" json:"ldapEnabled" yaml:"ldapEnabled"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_netapp_storage_pool#project GoogleNetappStoragePool#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// Specifies the replica zone for regional Flex pools. 'zone' and 'replica_zone' values can be swapped to initiate a [zone switch](https://cloud.google.com/netapp/volumes/docs/configure-and-use/storage-pools/edit-or-delete-storage-pool#switch_active_and_replica_zones).
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_netapp_storage_pool#replica_zone GoogleNetappStoragePool#replica_zone}
ReplicaZone *string `field:"optional" json:"replicaZone" yaml:"replicaZone"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_netapp_storage_pool#timeouts GoogleNetappStoragePool#timeouts}
Timeouts *GoogleNetappStoragePoolTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
// Optional. Custom Performance Total IOPS of the pool If not provided, it will be calculated based on the totalThroughputMibps.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_netapp_storage_pool#total_iops GoogleNetappStoragePool#total_iops}
TotalIops *string `field:"optional" json:"totalIops" yaml:"totalIops"`
// Optional. Custom Performance Total Throughput of the pool (in MiB/s).
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_netapp_storage_pool#total_throughput_mibps GoogleNetappStoragePool#total_throughput_mibps}
TotalThroughputMibps *string `field:"optional" json:"totalThroughputMibps" yaml:"totalThroughputMibps"`
// Specifies the active zone for regional Flex pools.
//
// 'zone' and 'replica_zone' values can be swapped to initiate a
// [zone switch](https://cloud.google.com/netapp/volumes/docs/configure-and-use/storage-pools/edit-or-delete-storage-pool#switch_active_and_replica_zones).
// If you want to create a zonal Flex pool, specify a zone name for 'location' and omit 'zone'.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_netapp_storage_pool#zone GoogleNetappStoragePool#zone}
Zone *string `field:"optional" json:"zone" yaml:"zone"`
}
type GoogleNetappStoragePoolTimeouts ¶
type GoogleNetappStoragePoolTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_netapp_storage_pool#create GoogleNetappStoragePool#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_netapp_storage_pool#delete GoogleNetappStoragePool#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_netapp_storage_pool#update GoogleNetappStoragePool#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type GoogleNetappStoragePoolTimeoutsOutputReference ¶
type GoogleNetappStoragePoolTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleNetappStoragePoolTimeoutsOutputReference ¶
func NewGoogleNetappStoragePoolTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleNetappStoragePoolTimeoutsOutputReference