Documentation
¶
Index ¶
- func GoogleNetworkSecurityAuthorizationPolicy_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func GoogleNetworkSecurityAuthorizationPolicy_IsConstruct(x interface{}) *bool
- func GoogleNetworkSecurityAuthorizationPolicy_IsTerraformElement(x interface{}) *bool
- func GoogleNetworkSecurityAuthorizationPolicy_IsTerraformResource(x interface{}) *bool
- func GoogleNetworkSecurityAuthorizationPolicy_TfResourceType() *string
- func NewGoogleNetworkSecurityAuthorizationPolicyRulesDestinationsHttpHeaderMatchOutputReference_Override(...)
- func NewGoogleNetworkSecurityAuthorizationPolicyRulesDestinationsList_Override(g GoogleNetworkSecurityAuthorizationPolicyRulesDestinationsList, ...)
- func NewGoogleNetworkSecurityAuthorizationPolicyRulesDestinationsOutputReference_Override(g GoogleNetworkSecurityAuthorizationPolicyRulesDestinationsOutputReference, ...)
- func NewGoogleNetworkSecurityAuthorizationPolicyRulesList_Override(g GoogleNetworkSecurityAuthorizationPolicyRulesList, ...)
- func NewGoogleNetworkSecurityAuthorizationPolicyRulesOutputReference_Override(g GoogleNetworkSecurityAuthorizationPolicyRulesOutputReference, ...)
- func NewGoogleNetworkSecurityAuthorizationPolicyRulesSourcesList_Override(g GoogleNetworkSecurityAuthorizationPolicyRulesSourcesList, ...)
- func NewGoogleNetworkSecurityAuthorizationPolicyRulesSourcesOutputReference_Override(g GoogleNetworkSecurityAuthorizationPolicyRulesSourcesOutputReference, ...)
- func NewGoogleNetworkSecurityAuthorizationPolicyTimeoutsOutputReference_Override(g GoogleNetworkSecurityAuthorizationPolicyTimeoutsOutputReference, ...)
- func NewGoogleNetworkSecurityAuthorizationPolicy_Override(g GoogleNetworkSecurityAuthorizationPolicy, scope constructs.Construct, ...)
- type GoogleNetworkSecurityAuthorizationPolicy
- type GoogleNetworkSecurityAuthorizationPolicyConfig
- type GoogleNetworkSecurityAuthorizationPolicyRules
- type GoogleNetworkSecurityAuthorizationPolicyRulesDestinations
- type GoogleNetworkSecurityAuthorizationPolicyRulesDestinationsHttpHeaderMatch
- type GoogleNetworkSecurityAuthorizationPolicyRulesDestinationsHttpHeaderMatchOutputReference
- type GoogleNetworkSecurityAuthorizationPolicyRulesDestinationsList
- type GoogleNetworkSecurityAuthorizationPolicyRulesDestinationsOutputReference
- type GoogleNetworkSecurityAuthorizationPolicyRulesList
- type GoogleNetworkSecurityAuthorizationPolicyRulesOutputReference
- type GoogleNetworkSecurityAuthorizationPolicyRulesSources
- type GoogleNetworkSecurityAuthorizationPolicyRulesSourcesList
- type GoogleNetworkSecurityAuthorizationPolicyRulesSourcesOutputReference
- type GoogleNetworkSecurityAuthorizationPolicyTimeouts
- type GoogleNetworkSecurityAuthorizationPolicyTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleNetworkSecurityAuthorizationPolicy_GenerateConfigForImport ¶
func GoogleNetworkSecurityAuthorizationPolicy_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a GoogleNetworkSecurityAuthorizationPolicy resource upon running "cdktf plan <stack-name>".
func GoogleNetworkSecurityAuthorizationPolicy_IsConstruct ¶
func GoogleNetworkSecurityAuthorizationPolicy_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleNetworkSecurityAuthorizationPolicy_IsTerraformElement ¶
func GoogleNetworkSecurityAuthorizationPolicy_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleNetworkSecurityAuthorizationPolicy_IsTerraformResource ¶
func GoogleNetworkSecurityAuthorizationPolicy_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleNetworkSecurityAuthorizationPolicy_TfResourceType ¶
func GoogleNetworkSecurityAuthorizationPolicy_TfResourceType() *string
func NewGoogleNetworkSecurityAuthorizationPolicyRulesDestinationsHttpHeaderMatchOutputReference_Override ¶
func NewGoogleNetworkSecurityAuthorizationPolicyRulesDestinationsHttpHeaderMatchOutputReference_Override(g GoogleNetworkSecurityAuthorizationPolicyRulesDestinationsHttpHeaderMatchOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleNetworkSecurityAuthorizationPolicyRulesDestinationsList_Override ¶
func NewGoogleNetworkSecurityAuthorizationPolicyRulesDestinationsList_Override(g GoogleNetworkSecurityAuthorizationPolicyRulesDestinationsList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGoogleNetworkSecurityAuthorizationPolicyRulesDestinationsOutputReference_Override ¶
func NewGoogleNetworkSecurityAuthorizationPolicyRulesDestinationsOutputReference_Override(g GoogleNetworkSecurityAuthorizationPolicyRulesDestinationsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGoogleNetworkSecurityAuthorizationPolicyRulesList_Override ¶
func NewGoogleNetworkSecurityAuthorizationPolicyRulesList_Override(g GoogleNetworkSecurityAuthorizationPolicyRulesList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGoogleNetworkSecurityAuthorizationPolicyRulesOutputReference_Override ¶
func NewGoogleNetworkSecurityAuthorizationPolicyRulesOutputReference_Override(g GoogleNetworkSecurityAuthorizationPolicyRulesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGoogleNetworkSecurityAuthorizationPolicyRulesSourcesList_Override ¶
func NewGoogleNetworkSecurityAuthorizationPolicyRulesSourcesList_Override(g GoogleNetworkSecurityAuthorizationPolicyRulesSourcesList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGoogleNetworkSecurityAuthorizationPolicyRulesSourcesOutputReference_Override ¶
func NewGoogleNetworkSecurityAuthorizationPolicyRulesSourcesOutputReference_Override(g GoogleNetworkSecurityAuthorizationPolicyRulesSourcesOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGoogleNetworkSecurityAuthorizationPolicyTimeoutsOutputReference_Override ¶
func NewGoogleNetworkSecurityAuthorizationPolicyTimeoutsOutputReference_Override(g GoogleNetworkSecurityAuthorizationPolicyTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleNetworkSecurityAuthorizationPolicy_Override ¶
func NewGoogleNetworkSecurityAuthorizationPolicy_Override(g GoogleNetworkSecurityAuthorizationPolicy, scope constructs.Construct, id *string, config *GoogleNetworkSecurityAuthorizationPolicyConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_network_security_authorization_policy google_network_security_authorization_policy} Resource.
Types ¶
type GoogleNetworkSecurityAuthorizationPolicy ¶
type GoogleNetworkSecurityAuthorizationPolicy interface {
cdktf.TerraformResource
Action() *string
SetAction(val *string)
ActionInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
CreateTime() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
EffectiveLabels() cdktf.StringMap
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
Labels() *map[string]*string
SetLabels(val *map[string]*string)
LabelsInput() *map[string]*string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Location() *string
SetLocation(val *string)
LocationInput() *string
Name() *string
SetName(val *string)
NameInput() *string
// The tree node.
Node() constructs.Node
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
Rules() GoogleNetworkSecurityAuthorizationPolicyRulesList
RulesInput() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
TerraformLabels() cdktf.StringMap
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GoogleNetworkSecurityAuthorizationPolicyTimeoutsOutputReference
TimeoutsInput() interface{}
UpdateTime() *string
// Adds a user defined moveTarget string to this resource to be later used in .moveTo(moveTarget) to resolve the location of the move.
// Experimental.
AddMoveTarget(moveTarget *string)
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
HasResourceMove() interface{}
// Experimental.
ImportFrom(id *string, provider cdktf.TerraformProvider)
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Move the resource corresponding to "id" to this resource.
//
// Note that the resource being moved from must be marked as moved using it's instance function.
// Experimental.
MoveFromId(id *string)
// Moves this resource to the target resource given by moveTarget.
// Experimental.
MoveTo(moveTarget *string, index interface{})
// Moves this resource to the resource corresponding to "id".
// Experimental.
MoveToId(id *string)
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutRules(value interface{})
PutTimeouts(value *GoogleNetworkSecurityAuthorizationPolicyTimeouts)
ResetDescription()
ResetId()
ResetLabels()
ResetLocation()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
ResetRules()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
SynthesizeHclAttributes() *map[string]interface{}
// Experimental.
ToHclTerraform() interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_network_security_authorization_policy google_network_security_authorization_policy}.
func NewGoogleNetworkSecurityAuthorizationPolicy ¶
func NewGoogleNetworkSecurityAuthorizationPolicy(scope constructs.Construct, id *string, config *GoogleNetworkSecurityAuthorizationPolicyConfig) GoogleNetworkSecurityAuthorizationPolicy
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_network_security_authorization_policy google_network_security_authorization_policy} Resource.
type GoogleNetworkSecurityAuthorizationPolicyConfig ¶
type GoogleNetworkSecurityAuthorizationPolicyConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// The action to take when a rule match is found.
//
// Possible values are "ALLOW" or "DENY". Possible values: ["ALLOW", "DENY"]
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_network_security_authorization_policy#action GoogleNetworkSecurityAuthorizationPolicy#action}
Action *string `field:"required" json:"action" yaml:"action"`
// Name of the AuthorizationPolicy resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_network_security_authorization_policy#name GoogleNetworkSecurityAuthorizationPolicy#name}
Name *string `field:"required" json:"name" yaml:"name"`
// A free-text description of the resource. Max length 1024 characters.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_network_security_authorization_policy#description GoogleNetworkSecurityAuthorizationPolicy#description}
Description *string `field:"optional" json:"description" yaml:"description"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_network_security_authorization_policy#id GoogleNetworkSecurityAuthorizationPolicy#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Set of label tags associated with the AuthorizationPolicy resource.
//
// **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
// Please refer to the field 'effective_labels' for all of the labels present on the resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_network_security_authorization_policy#labels GoogleNetworkSecurityAuthorizationPolicy#labels}
Labels *map[string]*string `field:"optional" json:"labels" yaml:"labels"`
// The location of the authorization policy. The default value is 'global'.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_network_security_authorization_policy#location GoogleNetworkSecurityAuthorizationPolicy#location}
Location *string `field:"optional" json:"location" yaml:"location"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_network_security_authorization_policy#project GoogleNetworkSecurityAuthorizationPolicy#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// rules block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_network_security_authorization_policy#rules GoogleNetworkSecurityAuthorizationPolicy#rules}
Rules interface{} `field:"optional" json:"rules" yaml:"rules"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_network_security_authorization_policy#timeouts GoogleNetworkSecurityAuthorizationPolicy#timeouts}
Timeouts *GoogleNetworkSecurityAuthorizationPolicyTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type GoogleNetworkSecurityAuthorizationPolicyRules ¶
type GoogleNetworkSecurityAuthorizationPolicyRules struct {
// destinations block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_network_security_authorization_policy#destinations GoogleNetworkSecurityAuthorizationPolicy#destinations}
Destinations interface{} `field:"optional" json:"destinations" yaml:"destinations"`
// sources block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_network_security_authorization_policy#sources GoogleNetworkSecurityAuthorizationPolicy#sources}
Sources interface{} `field:"optional" json:"sources" yaml:"sources"`
}
type GoogleNetworkSecurityAuthorizationPolicyRulesDestinations ¶
type GoogleNetworkSecurityAuthorizationPolicyRulesDestinations struct {
// List of host names to match.
//
// Matched against the ":authority" header in http requests. At least one host should match. Each host can be an exact match, or a prefix match (example "mydomain.*") or a suffix match (example "*.myorg.com") or a presence (any) match "*".
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_network_security_authorization_policy#hosts GoogleNetworkSecurityAuthorizationPolicy#hosts}
Hosts *[]*string `field:"required" json:"hosts" yaml:"hosts"`
// A list of HTTP methods to match.
//
// At least one method should match. Should not be set for gRPC services.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_network_security_authorization_policy#methods GoogleNetworkSecurityAuthorizationPolicy#methods}
Methods *[]*string `field:"required" json:"methods" yaml:"methods"`
// List of destination ports to match. At least one port should match.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_network_security_authorization_policy#ports GoogleNetworkSecurityAuthorizationPolicy#ports}
Ports *[]*float64 `field:"required" json:"ports" yaml:"ports"`
// http_header_match block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_network_security_authorization_policy#http_header_match GoogleNetworkSecurityAuthorizationPolicy#http_header_match}
HttpHeaderMatch *GoogleNetworkSecurityAuthorizationPolicyRulesDestinationsHttpHeaderMatch `field:"optional" json:"httpHeaderMatch" yaml:"httpHeaderMatch"`
}
type GoogleNetworkSecurityAuthorizationPolicyRulesDestinationsHttpHeaderMatch ¶
type GoogleNetworkSecurityAuthorizationPolicyRulesDestinationsHttpHeaderMatch struct {
// The name of the HTTP header to match.
//
// For matching against the HTTP request's authority, use a headerMatch with the header name ":authority". For matching a request's method, use the headerName ":method".
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_network_security_authorization_policy#header_name GoogleNetworkSecurityAuthorizationPolicy#header_name}
HeaderName *string `field:"required" json:"headerName" yaml:"headerName"`
// The value of the header must match the regular expression specified in regexMatch.
//
// For regular expression grammar, please see: en.cppreference.com/w/cpp/regex/ecmascript For matching against a port specified in the HTTP request, use a headerMatch with headerName set to Host and a regular expression that satisfies the RFC2616 Host header's port specifier.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_network_security_authorization_policy#regex_match GoogleNetworkSecurityAuthorizationPolicy#regex_match}
RegexMatch *string `field:"required" json:"regexMatch" yaml:"regexMatch"`
}
type GoogleNetworkSecurityAuthorizationPolicyRulesDestinationsHttpHeaderMatchOutputReference ¶
type GoogleNetworkSecurityAuthorizationPolicyRulesDestinationsHttpHeaderMatchOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
HeaderName() *string
SetHeaderName(val *string)
HeaderNameInput() *string
InternalValue() *GoogleNetworkSecurityAuthorizationPolicyRulesDestinationsHttpHeaderMatch
SetInternalValue(val *GoogleNetworkSecurityAuthorizationPolicyRulesDestinationsHttpHeaderMatch)
RegexMatch() *string
SetRegexMatch(val *string)
RegexMatchInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleNetworkSecurityAuthorizationPolicyRulesDestinationsHttpHeaderMatchOutputReference ¶
func NewGoogleNetworkSecurityAuthorizationPolicyRulesDestinationsHttpHeaderMatchOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleNetworkSecurityAuthorizationPolicyRulesDestinationsHttpHeaderMatchOutputReference
type GoogleNetworkSecurityAuthorizationPolicyRulesDestinationsList ¶
type GoogleNetworkSecurityAuthorizationPolicyRulesDestinationsList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) GoogleNetworkSecurityAuthorizationPolicyRulesDestinationsOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleNetworkSecurityAuthorizationPolicyRulesDestinationsList ¶
func NewGoogleNetworkSecurityAuthorizationPolicyRulesDestinationsList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GoogleNetworkSecurityAuthorizationPolicyRulesDestinationsList
type GoogleNetworkSecurityAuthorizationPolicyRulesDestinationsOutputReference ¶
type GoogleNetworkSecurityAuthorizationPolicyRulesDestinationsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
Hosts() *[]*string
SetHosts(val *[]*string)
HostsInput() *[]*string
HttpHeaderMatch() GoogleNetworkSecurityAuthorizationPolicyRulesDestinationsHttpHeaderMatchOutputReference
HttpHeaderMatchInput() *GoogleNetworkSecurityAuthorizationPolicyRulesDestinationsHttpHeaderMatch
InternalValue() interface{}
SetInternalValue(val interface{})
Methods() *[]*string
SetMethods(val *[]*string)
MethodsInput() *[]*string
Ports() *[]*float64
SetPorts(val *[]*float64)
PortsInput() *[]*float64
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutHttpHeaderMatch(value *GoogleNetworkSecurityAuthorizationPolicyRulesDestinationsHttpHeaderMatch)
ResetHttpHeaderMatch()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleNetworkSecurityAuthorizationPolicyRulesDestinationsOutputReference ¶
func NewGoogleNetworkSecurityAuthorizationPolicyRulesDestinationsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GoogleNetworkSecurityAuthorizationPolicyRulesDestinationsOutputReference
type GoogleNetworkSecurityAuthorizationPolicyRulesList ¶
type GoogleNetworkSecurityAuthorizationPolicyRulesList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) GoogleNetworkSecurityAuthorizationPolicyRulesOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleNetworkSecurityAuthorizationPolicyRulesList ¶
func NewGoogleNetworkSecurityAuthorizationPolicyRulesList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GoogleNetworkSecurityAuthorizationPolicyRulesList
type GoogleNetworkSecurityAuthorizationPolicyRulesOutputReference ¶
type GoogleNetworkSecurityAuthorizationPolicyRulesOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Destinations() GoogleNetworkSecurityAuthorizationPolicyRulesDestinationsList
DestinationsInput() interface{}
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
Sources() GoogleNetworkSecurityAuthorizationPolicyRulesSourcesList
SourcesInput() interface{}
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutDestinations(value interface{})
PutSources(value interface{})
ResetDestinations()
ResetSources()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleNetworkSecurityAuthorizationPolicyRulesOutputReference ¶
func NewGoogleNetworkSecurityAuthorizationPolicyRulesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GoogleNetworkSecurityAuthorizationPolicyRulesOutputReference
type GoogleNetworkSecurityAuthorizationPolicyRulesSources ¶
type GoogleNetworkSecurityAuthorizationPolicyRulesSources struct {
// List of CIDR ranges to match based on source IP address.
//
// At least one IP block should match. Single IP (e.g., "1.2.3.4") and CIDR (e.g., "1.2.3.0/24") are supported. Authorization based on source IP alone should be avoided.
// The IP addresses of any load balancers or proxies should be considered untrusted.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_network_security_authorization_policy#ip_blocks GoogleNetworkSecurityAuthorizationPolicy#ip_blocks}
IpBlocks *[]*string `field:"optional" json:"ipBlocks" yaml:"ipBlocks"`
// List of peer identities to match for authorization.
//
// At least one principal should match. Each peer can be an exact match, or a prefix match (example, "namespace/*") or a suffix match (example, "* /service-account") or a presence match "*".
// Authorization based on the principal name without certificate validation (configured by ServerTlsPolicy resource) is considered insecure.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_network_security_authorization_policy#principals GoogleNetworkSecurityAuthorizationPolicy#principals}
//
// Note: The above comment contained a comment block ending sequence (* followed by /). We have introduced a space between to prevent syntax errors. Please ignore the space.
Principals *[]*string `field:"optional" json:"principals" yaml:"principals"`
}
type GoogleNetworkSecurityAuthorizationPolicyRulesSourcesList ¶
type GoogleNetworkSecurityAuthorizationPolicyRulesSourcesList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Creating an iterator for this complex list.
//
// The list will be converted into a map with the mapKeyAttributeName as the key.
// Experimental.
AllWithMapKey(mapKeyAttributeName *string) cdktf.DynamicListTerraformIterator
// Experimental.
ComputeFqn() *string
Get(index *float64) GoogleNetworkSecurityAuthorizationPolicyRulesSourcesOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleNetworkSecurityAuthorizationPolicyRulesSourcesList ¶
func NewGoogleNetworkSecurityAuthorizationPolicyRulesSourcesList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GoogleNetworkSecurityAuthorizationPolicyRulesSourcesList
type GoogleNetworkSecurityAuthorizationPolicyRulesSourcesOutputReference ¶
type GoogleNetworkSecurityAuthorizationPolicyRulesSourcesOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
IpBlocks() *[]*string
SetIpBlocks(val *[]*string)
IpBlocksInput() *[]*string
Principals() *[]*string
SetPrincipals(val *[]*string)
PrincipalsInput() *[]*string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetIpBlocks()
ResetPrincipals()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleNetworkSecurityAuthorizationPolicyRulesSourcesOutputReference ¶
func NewGoogleNetworkSecurityAuthorizationPolicyRulesSourcesOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GoogleNetworkSecurityAuthorizationPolicyRulesSourcesOutputReference
type GoogleNetworkSecurityAuthorizationPolicyTimeouts ¶
type GoogleNetworkSecurityAuthorizationPolicyTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_network_security_authorization_policy#create GoogleNetworkSecurityAuthorizationPolicy#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_network_security_authorization_policy#delete GoogleNetworkSecurityAuthorizationPolicy#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_network_security_authorization_policy#update GoogleNetworkSecurityAuthorizationPolicy#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type GoogleNetworkSecurityAuthorizationPolicyTimeoutsOutputReference ¶
type GoogleNetworkSecurityAuthorizationPolicyTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleNetworkSecurityAuthorizationPolicyTimeoutsOutputReference ¶
func NewGoogleNetworkSecurityAuthorizationPolicyTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleNetworkSecurityAuthorizationPolicyTimeoutsOutputReference
Source Files
¶
- GoogleNetworkSecurityAuthorizationPolicy.go
- GoogleNetworkSecurityAuthorizationPolicyConfig.go
- GoogleNetworkSecurityAuthorizationPolicyRules.go
- GoogleNetworkSecurityAuthorizationPolicyRulesDestinations.go
- GoogleNetworkSecurityAuthorizationPolicyRulesDestinationsHttpHeaderMatch.go
- GoogleNetworkSecurityAuthorizationPolicyRulesDestinationsHttpHeaderMatchOutputReference.go
- GoogleNetworkSecurityAuthorizationPolicyRulesDestinationsHttpHeaderMatchOutputReference__checks.go
- GoogleNetworkSecurityAuthorizationPolicyRulesDestinationsList.go
- GoogleNetworkSecurityAuthorizationPolicyRulesDestinationsList__checks.go
- GoogleNetworkSecurityAuthorizationPolicyRulesDestinationsOutputReference.go
- GoogleNetworkSecurityAuthorizationPolicyRulesDestinationsOutputReference__checks.go
- GoogleNetworkSecurityAuthorizationPolicyRulesList.go
- GoogleNetworkSecurityAuthorizationPolicyRulesList__checks.go
- GoogleNetworkSecurityAuthorizationPolicyRulesOutputReference.go
- GoogleNetworkSecurityAuthorizationPolicyRulesOutputReference__checks.go
- GoogleNetworkSecurityAuthorizationPolicyRulesSources.go
- GoogleNetworkSecurityAuthorizationPolicyRulesSourcesList.go
- GoogleNetworkSecurityAuthorizationPolicyRulesSourcesList__checks.go
- GoogleNetworkSecurityAuthorizationPolicyRulesSourcesOutputReference.go
- GoogleNetworkSecurityAuthorizationPolicyRulesSourcesOutputReference__checks.go
- GoogleNetworkSecurityAuthorizationPolicyTimeouts.go
- GoogleNetworkSecurityAuthorizationPolicyTimeoutsOutputReference.go
- GoogleNetworkSecurityAuthorizationPolicyTimeoutsOutputReference__checks.go
- GoogleNetworkSecurityAuthorizationPolicy__checks.go
- main.go