Documentation
¶
Index ¶
- func GoogleNotebooksInstance_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func GoogleNotebooksInstance_IsConstruct(x interface{}) *bool
- func GoogleNotebooksInstance_IsTerraformElement(x interface{}) *bool
- func GoogleNotebooksInstance_IsTerraformResource(x interface{}) *bool
- func GoogleNotebooksInstance_TfResourceType() *string
- func NewGoogleNotebooksInstanceAcceleratorConfigOutputReference_Override(g GoogleNotebooksInstanceAcceleratorConfigOutputReference, ...)
- func NewGoogleNotebooksInstanceContainerImageOutputReference_Override(g GoogleNotebooksInstanceContainerImageOutputReference, ...)
- func NewGoogleNotebooksInstanceReservationAffinityOutputReference_Override(g GoogleNotebooksInstanceReservationAffinityOutputReference, ...)
- func NewGoogleNotebooksInstanceShieldedInstanceConfigOutputReference_Override(g GoogleNotebooksInstanceShieldedInstanceConfigOutputReference, ...)
- func NewGoogleNotebooksInstanceTimeoutsOutputReference_Override(g GoogleNotebooksInstanceTimeoutsOutputReference, ...)
- func NewGoogleNotebooksInstanceVmImageOutputReference_Override(g GoogleNotebooksInstanceVmImageOutputReference, ...)
- func NewGoogleNotebooksInstance_Override(g GoogleNotebooksInstance, scope constructs.Construct, id *string, ...)
- type GoogleNotebooksInstance
- type GoogleNotebooksInstanceAcceleratorConfig
- type GoogleNotebooksInstanceAcceleratorConfigOutputReference
- type GoogleNotebooksInstanceConfig
- type GoogleNotebooksInstanceContainerImage
- type GoogleNotebooksInstanceContainerImageOutputReference
- type GoogleNotebooksInstanceReservationAffinity
- type GoogleNotebooksInstanceReservationAffinityOutputReference
- type GoogleNotebooksInstanceShieldedInstanceConfig
- type GoogleNotebooksInstanceShieldedInstanceConfigOutputReference
- type GoogleNotebooksInstanceTimeouts
- type GoogleNotebooksInstanceTimeoutsOutputReference
- type GoogleNotebooksInstanceVmImage
- type GoogleNotebooksInstanceVmImageOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleNotebooksInstance_GenerateConfigForImport ¶
func GoogleNotebooksInstance_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a GoogleNotebooksInstance resource upon running "cdktf plan <stack-name>".
func GoogleNotebooksInstance_IsConstruct ¶
func GoogleNotebooksInstance_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleNotebooksInstance_IsTerraformElement ¶
func GoogleNotebooksInstance_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleNotebooksInstance_IsTerraformResource ¶
func GoogleNotebooksInstance_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleNotebooksInstance_TfResourceType ¶
func GoogleNotebooksInstance_TfResourceType() *string
func NewGoogleNotebooksInstanceAcceleratorConfigOutputReference_Override ¶
func NewGoogleNotebooksInstanceAcceleratorConfigOutputReference_Override(g GoogleNotebooksInstanceAcceleratorConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleNotebooksInstanceContainerImageOutputReference_Override ¶
func NewGoogleNotebooksInstanceContainerImageOutputReference_Override(g GoogleNotebooksInstanceContainerImageOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleNotebooksInstanceReservationAffinityOutputReference_Override ¶
func NewGoogleNotebooksInstanceReservationAffinityOutputReference_Override(g GoogleNotebooksInstanceReservationAffinityOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleNotebooksInstanceShieldedInstanceConfigOutputReference_Override ¶
func NewGoogleNotebooksInstanceShieldedInstanceConfigOutputReference_Override(g GoogleNotebooksInstanceShieldedInstanceConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleNotebooksInstanceTimeoutsOutputReference_Override ¶
func NewGoogleNotebooksInstanceTimeoutsOutputReference_Override(g GoogleNotebooksInstanceTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleNotebooksInstanceVmImageOutputReference_Override ¶
func NewGoogleNotebooksInstanceVmImageOutputReference_Override(g GoogleNotebooksInstanceVmImageOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleNotebooksInstance_Override ¶
func NewGoogleNotebooksInstance_Override(g GoogleNotebooksInstance, scope constructs.Construct, id *string, config *GoogleNotebooksInstanceConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_notebooks_instance google_notebooks_instance} Resource.
Types ¶
type GoogleNotebooksInstance ¶
type GoogleNotebooksInstance interface {
cdktf.TerraformResource
AcceleratorConfig() GoogleNotebooksInstanceAcceleratorConfigOutputReference
AcceleratorConfigInput() *GoogleNotebooksInstanceAcceleratorConfig
BootDiskSizeGb() *float64
SetBootDiskSizeGb(val *float64)
BootDiskSizeGbInput() *float64
BootDiskType() *string
SetBootDiskType(val *string)
BootDiskTypeInput() *string
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
ContainerImage() GoogleNotebooksInstanceContainerImageOutputReference
ContainerImageInput() *GoogleNotebooksInstanceContainerImage
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
CreateTime() *string
SetCreateTime(val *string)
CreateTimeInput() *string
CustomGpuDriverPath() *string
SetCustomGpuDriverPath(val *string)
CustomGpuDriverPathInput() *string
DataDiskSizeGb() *float64
SetDataDiskSizeGb(val *float64)
DataDiskSizeGbInput() *float64
DataDiskType() *string
SetDataDiskType(val *string)
DataDiskTypeInput() *string
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
DesiredState() *string
SetDesiredState(val *string)
DesiredStateInput() *string
DiskEncryption() *string
SetDiskEncryption(val *string)
DiskEncryptionInput() *string
EffectiveLabels() cdktf.StringMap
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
InstallGpuDriver() interface{}
SetInstallGpuDriver(val interface{})
InstallGpuDriverInput() interface{}
InstanceOwners() *[]*string
SetInstanceOwners(val *[]*string)
InstanceOwnersInput() *[]*string
KmsKey() *string
SetKmsKey(val *string)
KmsKeyInput() *string
Labels() *map[string]*string
SetLabels(val *map[string]*string)
LabelsInput() *map[string]*string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Location() *string
SetLocation(val *string)
LocationInput() *string
MachineType() *string
SetMachineType(val *string)
MachineTypeInput() *string
Metadata() *map[string]*string
SetMetadata(val *map[string]*string)
MetadataInput() *map[string]*string
Name() *string
SetName(val *string)
NameInput() *string
Network() *string
SetNetwork(val *string)
NetworkInput() *string
NicType() *string
SetNicType(val *string)
NicTypeInput() *string
// The tree node.
Node() constructs.Node
NoProxyAccess() interface{}
SetNoProxyAccess(val interface{})
NoProxyAccessInput() interface{}
NoPublicIp() interface{}
SetNoPublicIp(val interface{})
NoPublicIpInput() interface{}
NoRemoveDataDisk() interface{}
SetNoRemoveDataDisk(val interface{})
NoRemoveDataDiskInput() interface{}
PostStartupScript() *string
SetPostStartupScript(val *string)
PostStartupScriptInput() *string
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
ProxyUri() *string
// Experimental.
RawOverrides() interface{}
ReservationAffinity() GoogleNotebooksInstanceReservationAffinityOutputReference
ReservationAffinityInput() *GoogleNotebooksInstanceReservationAffinity
ServiceAccount() *string
SetServiceAccount(val *string)
ServiceAccountInput() *string
ServiceAccountScopes() *[]*string
SetServiceAccountScopes(val *[]*string)
ServiceAccountScopesInput() *[]*string
ShieldedInstanceConfig() GoogleNotebooksInstanceShieldedInstanceConfigOutputReference
ShieldedInstanceConfigInput() *GoogleNotebooksInstanceShieldedInstanceConfig
State() *string
Subnet() *string
SetSubnet(val *string)
SubnetInput() *string
Tags() *[]*string
SetTags(val *[]*string)
TagsInput() *[]*string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
TerraformLabels() cdktf.StringMap
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GoogleNotebooksInstanceTimeoutsOutputReference
TimeoutsInput() interface{}
UpdateTime() *string
SetUpdateTime(val *string)
UpdateTimeInput() *string
VmImage() GoogleNotebooksInstanceVmImageOutputReference
VmImageInput() *GoogleNotebooksInstanceVmImage
// Adds a user defined moveTarget string to this resource to be later used in .moveTo(moveTarget) to resolve the location of the move.
// Experimental.
AddMoveTarget(moveTarget *string)
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
HasResourceMove() interface{}
// Experimental.
ImportFrom(id *string, provider cdktf.TerraformProvider)
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Move the resource corresponding to "id" to this resource.
//
// Note that the resource being moved from must be marked as moved using it's instance function.
// Experimental.
MoveFromId(id *string)
// Moves this resource to the target resource given by moveTarget.
// Experimental.
MoveTo(moveTarget *string, index interface{})
// Moves this resource to the resource corresponding to "id".
// Experimental.
MoveToId(id *string)
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutAcceleratorConfig(value *GoogleNotebooksInstanceAcceleratorConfig)
PutContainerImage(value *GoogleNotebooksInstanceContainerImage)
PutReservationAffinity(value *GoogleNotebooksInstanceReservationAffinity)
PutShieldedInstanceConfig(value *GoogleNotebooksInstanceShieldedInstanceConfig)
PutTimeouts(value *GoogleNotebooksInstanceTimeouts)
PutVmImage(value *GoogleNotebooksInstanceVmImage)
ResetAcceleratorConfig()
ResetBootDiskSizeGb()
ResetBootDiskType()
ResetContainerImage()
ResetCreateTime()
ResetCustomGpuDriverPath()
ResetDataDiskSizeGb()
ResetDataDiskType()
ResetDesiredState()
ResetDiskEncryption()
ResetId()
ResetInstallGpuDriver()
ResetInstanceOwners()
ResetKmsKey()
ResetLabels()
ResetMetadata()
ResetNetwork()
ResetNicType()
ResetNoProxyAccess()
ResetNoPublicIp()
ResetNoRemoveDataDisk()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetPostStartupScript()
ResetProject()
ResetReservationAffinity()
ResetServiceAccount()
ResetServiceAccountScopes()
ResetShieldedInstanceConfig()
ResetSubnet()
ResetTags()
ResetTimeouts()
ResetUpdateTime()
ResetVmImage()
SynthesizeAttributes() *map[string]interface{}
SynthesizeHclAttributes() *map[string]interface{}
// Experimental.
ToHclTerraform() interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_notebooks_instance google_notebooks_instance}.
func NewGoogleNotebooksInstance ¶
func NewGoogleNotebooksInstance(scope constructs.Construct, id *string, config *GoogleNotebooksInstanceConfig) GoogleNotebooksInstance
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_notebooks_instance google_notebooks_instance} Resource.
type GoogleNotebooksInstanceAcceleratorConfig ¶
type GoogleNotebooksInstanceAcceleratorConfig struct {
// Count of cores of this accelerator.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_notebooks_instance#core_count GoogleNotebooksInstance#core_count}
CoreCount *float64 `field:"required" json:"coreCount" yaml:"coreCount"`
// Type of this accelerator. Possible values: ["ACCELERATOR_TYPE_UNSPECIFIED", "NVIDIA_TESLA_K80", "NVIDIA_TESLA_P100", "NVIDIA_TESLA_V100", "NVIDIA_TESLA_P4", "NVIDIA_TESLA_T4", "NVIDIA_TESLA_T4_VWS", "NVIDIA_TESLA_P100_VWS", "NVIDIA_TESLA_P4_VWS", "NVIDIA_TESLA_A100", "TPU_V2", "TPU_V3"].
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_notebooks_instance#type GoogleNotebooksInstance#type}
Type *string `field:"required" json:"type" yaml:"type"`
}
type GoogleNotebooksInstanceAcceleratorConfigOutputReference ¶
type GoogleNotebooksInstanceAcceleratorConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
CoreCount() *float64
SetCoreCount(val *float64)
CoreCountInput() *float64
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleNotebooksInstanceAcceleratorConfig
SetInternalValue(val *GoogleNotebooksInstanceAcceleratorConfig)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Type() *string
SetType(val *string)
TypeInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleNotebooksInstanceAcceleratorConfigOutputReference ¶
func NewGoogleNotebooksInstanceAcceleratorConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleNotebooksInstanceAcceleratorConfigOutputReference
type GoogleNotebooksInstanceConfig ¶
type GoogleNotebooksInstanceConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// A reference to the zone where the machine resides.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_notebooks_instance#location GoogleNotebooksInstance#location}
Location *string `field:"required" json:"location" yaml:"location"`
// A reference to a machine type which defines VM kind.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_notebooks_instance#machine_type GoogleNotebooksInstance#machine_type}
MachineType *string `field:"required" json:"machineType" yaml:"machineType"`
// The name specified for the Notebook instance.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_notebooks_instance#name GoogleNotebooksInstance#name}
Name *string `field:"required" json:"name" yaml:"name"`
// accelerator_config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_notebooks_instance#accelerator_config GoogleNotebooksInstance#accelerator_config}
AcceleratorConfig *GoogleNotebooksInstanceAcceleratorConfig `field:"optional" json:"acceleratorConfig" yaml:"acceleratorConfig"`
// The size of the boot disk in GB attached to this instance, up to a maximum of 64000 GB (64 TB).
//
// The minimum recommended value is 100 GB.
// If not specified, this defaults to 100.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_notebooks_instance#boot_disk_size_gb GoogleNotebooksInstance#boot_disk_size_gb}
BootDiskSizeGb *float64 `field:"optional" json:"bootDiskSizeGb" yaml:"bootDiskSizeGb"`
// Possible disk types for notebook instances. Possible values: ["DISK_TYPE_UNSPECIFIED", "PD_STANDARD", "PD_SSD", "PD_BALANCED", "PD_EXTREME"].
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_notebooks_instance#boot_disk_type GoogleNotebooksInstance#boot_disk_type}
BootDiskType *string `field:"optional" json:"bootDiskType" yaml:"bootDiskType"`
// container_image block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_notebooks_instance#container_image GoogleNotebooksInstance#container_image}
ContainerImage *GoogleNotebooksInstanceContainerImage `field:"optional" json:"containerImage" yaml:"containerImage"`
// Instance creation time.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_notebooks_instance#create_time GoogleNotebooksInstance#create_time}
CreateTime *string `field:"optional" json:"createTime" yaml:"createTime"`
// Specify a custom Cloud Storage path where the GPU driver is stored.
//
// If not specified, we'll automatically choose from official GPU drivers.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_notebooks_instance#custom_gpu_driver_path GoogleNotebooksInstance#custom_gpu_driver_path}
CustomGpuDriverPath *string `field:"optional" json:"customGpuDriverPath" yaml:"customGpuDriverPath"`
// The size of the data disk in GB attached to this instance, up to a maximum of 64000 GB (64 TB).
//
// You can choose the size of the data disk based on how big your notebooks and data are.
// If not specified, this defaults to 100.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_notebooks_instance#data_disk_size_gb GoogleNotebooksInstance#data_disk_size_gb}
DataDiskSizeGb *float64 `field:"optional" json:"dataDiskSizeGb" yaml:"dataDiskSizeGb"`
// Possible disk types for notebook instances. Possible values: ["DISK_TYPE_UNSPECIFIED", "PD_STANDARD", "PD_SSD", "PD_BALANCED", "PD_EXTREME"].
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_notebooks_instance#data_disk_type GoogleNotebooksInstance#data_disk_type}
DataDiskType *string `field:"optional" json:"dataDiskType" yaml:"dataDiskType"`
// Desired state of the Notebook Instance.
//
// Set this field to 'ACTIVE' to start the Instance, and 'STOPPED' to stop the Instance.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_notebooks_instance#desired_state GoogleNotebooksInstance#desired_state}
DesiredState *string `field:"optional" json:"desiredState" yaml:"desiredState"`
// Disk encryption method used on the boot and data disks, defaults to GMEK. Possible values: ["DISK_ENCRYPTION_UNSPECIFIED", "GMEK", "CMEK"].
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_notebooks_instance#disk_encryption GoogleNotebooksInstance#disk_encryption}
DiskEncryption *string `field:"optional" json:"diskEncryption" yaml:"diskEncryption"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_notebooks_instance#id GoogleNotebooksInstance#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Whether the end user authorizes Google Cloud to install GPU driver on this instance.
//
// If this field is empty or set to false, the GPU driver
// won't be installed. Only applicable to instances with GPUs.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_notebooks_instance#install_gpu_driver GoogleNotebooksInstance#install_gpu_driver}
InstallGpuDriver interface{} `field:"optional" json:"installGpuDriver" yaml:"installGpuDriver"`
// The list of owners of this instance after creation.
//
// Format: alias@example.com.
// Currently supports one owner only.
// If not specified, all of the service account users of
// your VM instance's service account can use the instance.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_notebooks_instance#instance_owners GoogleNotebooksInstance#instance_owners}
InstanceOwners *[]*string `field:"optional" json:"instanceOwners" yaml:"instanceOwners"`
// The KMS key used to encrypt the disks, only applicable if diskEncryption is CMEK. Format: projects/{project_id}/locations/{location}/keyRings/{key_ring_id}/cryptoKeys/{key_id}.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_notebooks_instance#kms_key GoogleNotebooksInstance#kms_key}
KmsKey *string `field:"optional" json:"kmsKey" yaml:"kmsKey"`
// Labels to apply to this instance.
//
// These can be later modified by the setLabels method.
// An object containing a list of "key": value pairs. Example: { "name": "wrench", "mass": "1.3kg", "count": "3" }.
//
//
// **Note**: This field is non-authoritative, and will only manage the labels present in your configuration.
// Please refer to the field 'effective_labels' for all of the labels present on the resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_notebooks_instance#labels GoogleNotebooksInstance#labels}
Labels *map[string]*string `field:"optional" json:"labels" yaml:"labels"`
// Custom metadata to apply to this instance.
//
// An object containing a list of "key": value pairs. Example: { "name": "wrench", "mass": "1.3kg", "count": "3" }.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_notebooks_instance#metadata GoogleNotebooksInstance#metadata}
Metadata *map[string]*string `field:"optional" json:"metadata" yaml:"metadata"`
// The name of the VPC that this instance is in. Format: projects/{project_id}/global/networks/{network_id}.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_notebooks_instance#network GoogleNotebooksInstance#network}
Network *string `field:"optional" json:"network" yaml:"network"`
// The type of vNIC driver. Possible values: ["UNSPECIFIED_NIC_TYPE", "VIRTIO_NET", "GVNIC"].
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_notebooks_instance#nic_type GoogleNotebooksInstance#nic_type}
NicType *string `field:"optional" json:"nicType" yaml:"nicType"`
// The notebook instance will not register with the proxy..
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_notebooks_instance#no_proxy_access GoogleNotebooksInstance#no_proxy_access}
NoProxyAccess interface{} `field:"optional" json:"noProxyAccess" yaml:"noProxyAccess"`
// No public IP will be assigned to this instance.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_notebooks_instance#no_public_ip GoogleNotebooksInstance#no_public_ip}
NoPublicIp interface{} `field:"optional" json:"noPublicIp" yaml:"noPublicIp"`
// If true, the data disk will not be auto deleted when deleting the instance.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_notebooks_instance#no_remove_data_disk GoogleNotebooksInstance#no_remove_data_disk}
NoRemoveDataDisk interface{} `field:"optional" json:"noRemoveDataDisk" yaml:"noRemoveDataDisk"`
// Path to a Bash script that automatically runs after a notebook instance fully boots up.
//
// The path must be a URL
// or Cloud Storage path (gs://path-to-file/file-name).
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_notebooks_instance#post_startup_script GoogleNotebooksInstance#post_startup_script}
PostStartupScript *string `field:"optional" json:"postStartupScript" yaml:"postStartupScript"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_notebooks_instance#project GoogleNotebooksInstance#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// reservation_affinity block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_notebooks_instance#reservation_affinity GoogleNotebooksInstance#reservation_affinity}
ReservationAffinity *GoogleNotebooksInstanceReservationAffinity `field:"optional" json:"reservationAffinity" yaml:"reservationAffinity"`
// The service account on this instance, giving access to other Google Cloud services.
//
// You can use any service account within
// the same project, but you must have the service account user
// permission to use the instance. If not specified,
// the Compute Engine default service account is used.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_notebooks_instance#service_account GoogleNotebooksInstance#service_account}
ServiceAccount *string `field:"optional" json:"serviceAccount" yaml:"serviceAccount"`
// Optional.
//
// The URIs of service account scopes to be included in Compute Engine instances.
// If not specified, the following scopes are defined:
// - https://www.googleapis.com/auth/cloud-platform
// - https://www.googleapis.com/auth/userinfo.email
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_notebooks_instance#service_account_scopes GoogleNotebooksInstance#service_account_scopes}
ServiceAccountScopes *[]*string `field:"optional" json:"serviceAccountScopes" yaml:"serviceAccountScopes"`
// shielded_instance_config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_notebooks_instance#shielded_instance_config GoogleNotebooksInstance#shielded_instance_config}
ShieldedInstanceConfig *GoogleNotebooksInstanceShieldedInstanceConfig `field:"optional" json:"shieldedInstanceConfig" yaml:"shieldedInstanceConfig"`
// The name of the subnet that this instance is in. Format: projects/{project_id}/regions/{region}/subnetworks/{subnetwork_id}.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_notebooks_instance#subnet GoogleNotebooksInstance#subnet}
Subnet *string `field:"optional" json:"subnet" yaml:"subnet"`
// The Compute Engine tags to add to instance.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_notebooks_instance#tags GoogleNotebooksInstance#tags}
Tags *[]*string `field:"optional" json:"tags" yaml:"tags"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_notebooks_instance#timeouts GoogleNotebooksInstance#timeouts}
Timeouts *GoogleNotebooksInstanceTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
// Instance update time.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_notebooks_instance#update_time GoogleNotebooksInstance#update_time}
UpdateTime *string `field:"optional" json:"updateTime" yaml:"updateTime"`
// vm_image block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_notebooks_instance#vm_image GoogleNotebooksInstance#vm_image}
VmImage *GoogleNotebooksInstanceVmImage `field:"optional" json:"vmImage" yaml:"vmImage"`
}
type GoogleNotebooksInstanceContainerImage ¶
type GoogleNotebooksInstanceContainerImage struct {
// The path to the container image repository. For example: gcr.io/{project_id}/{imageName}.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_notebooks_instance#repository GoogleNotebooksInstance#repository}
Repository *string `field:"required" json:"repository" yaml:"repository"`
// The tag of the container image. If not specified, this defaults to the latest tag.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_notebooks_instance#tag GoogleNotebooksInstance#tag}
Tag *string `field:"optional" json:"tag" yaml:"tag"`
}
type GoogleNotebooksInstanceContainerImageOutputReference ¶
type GoogleNotebooksInstanceContainerImageOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleNotebooksInstanceContainerImage
SetInternalValue(val *GoogleNotebooksInstanceContainerImage)
Repository() *string
SetRepository(val *string)
RepositoryInput() *string
Tag() *string
SetTag(val *string)
TagInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetTag()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleNotebooksInstanceContainerImageOutputReference ¶
func NewGoogleNotebooksInstanceContainerImageOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleNotebooksInstanceContainerImageOutputReference
type GoogleNotebooksInstanceReservationAffinity ¶
type GoogleNotebooksInstanceReservationAffinity struct {
// The type of Compute Reservation. Possible values: ["NO_RESERVATION", "ANY_RESERVATION", "SPECIFIC_RESERVATION"].
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_notebooks_instance#consume_reservation_type GoogleNotebooksInstance#consume_reservation_type}
ConsumeReservationType *string `field:"required" json:"consumeReservationType" yaml:"consumeReservationType"`
// Corresponds to the label key of reservation resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_notebooks_instance#key GoogleNotebooksInstance#key}
Key *string `field:"optional" json:"key" yaml:"key"`
// Corresponds to the label values of reservation resource.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_notebooks_instance#values GoogleNotebooksInstance#values}
Values *[]*string `field:"optional" json:"values" yaml:"values"`
}
type GoogleNotebooksInstanceReservationAffinityOutputReference ¶
type GoogleNotebooksInstanceReservationAffinityOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
ConsumeReservationType() *string
SetConsumeReservationType(val *string)
ConsumeReservationTypeInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleNotebooksInstanceReservationAffinity
SetInternalValue(val *GoogleNotebooksInstanceReservationAffinity)
Key() *string
SetKey(val *string)
KeyInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Values() *[]*string
SetValues(val *[]*string)
ValuesInput() *[]*string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetKey()
ResetValues()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleNotebooksInstanceReservationAffinityOutputReference ¶
func NewGoogleNotebooksInstanceReservationAffinityOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleNotebooksInstanceReservationAffinityOutputReference
type GoogleNotebooksInstanceShieldedInstanceConfig ¶
type GoogleNotebooksInstanceShieldedInstanceConfig struct {
// Defines whether the instance has integrity monitoring enabled.
//
// Enables monitoring and attestation of the
// boot integrity of the instance. The attestation is performed against the integrity policy baseline.
// This baseline is initially derived from the implicitly trusted boot image when the instance is created.
// Enabled by default.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_notebooks_instance#enable_integrity_monitoring GoogleNotebooksInstance#enable_integrity_monitoring}
EnableIntegrityMonitoring interface{} `field:"optional" json:"enableIntegrityMonitoring" yaml:"enableIntegrityMonitoring"`
// Defines whether the instance has Secure Boot enabled.
//
// Secure Boot helps ensure that the system only runs
// authentic software by verifying the digital signature of all boot components, and halting the boot process
// if signature verification fails.
// Disabled by default.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_notebooks_instance#enable_secure_boot GoogleNotebooksInstance#enable_secure_boot}
EnableSecureBoot interface{} `field:"optional" json:"enableSecureBoot" yaml:"enableSecureBoot"`
// Defines whether the instance has the vTPM enabled. Enabled by default.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_notebooks_instance#enable_vtpm GoogleNotebooksInstance#enable_vtpm}
EnableVtpm interface{} `field:"optional" json:"enableVtpm" yaml:"enableVtpm"`
}
type GoogleNotebooksInstanceShieldedInstanceConfigOutputReference ¶
type GoogleNotebooksInstanceShieldedInstanceConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
EnableIntegrityMonitoring() interface{}
SetEnableIntegrityMonitoring(val interface{})
EnableIntegrityMonitoringInput() interface{}
EnableSecureBoot() interface{}
SetEnableSecureBoot(val interface{})
EnableSecureBootInput() interface{}
EnableVtpm() interface{}
SetEnableVtpm(val interface{})
EnableVtpmInput() interface{}
// Experimental.
Fqn() *string
InternalValue() *GoogleNotebooksInstanceShieldedInstanceConfig
SetInternalValue(val *GoogleNotebooksInstanceShieldedInstanceConfig)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetEnableIntegrityMonitoring()
ResetEnableSecureBoot()
ResetEnableVtpm()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleNotebooksInstanceShieldedInstanceConfigOutputReference ¶
func NewGoogleNotebooksInstanceShieldedInstanceConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleNotebooksInstanceShieldedInstanceConfigOutputReference
type GoogleNotebooksInstanceTimeouts ¶
type GoogleNotebooksInstanceTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_notebooks_instance#create GoogleNotebooksInstance#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_notebooks_instance#delete GoogleNotebooksInstance#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_notebooks_instance#update GoogleNotebooksInstance#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type GoogleNotebooksInstanceTimeoutsOutputReference ¶
type GoogleNotebooksInstanceTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleNotebooksInstanceTimeoutsOutputReference ¶
func NewGoogleNotebooksInstanceTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleNotebooksInstanceTimeoutsOutputReference
type GoogleNotebooksInstanceVmImage ¶
type GoogleNotebooksInstanceVmImage struct {
// The name of the Google Cloud project that this VM image belongs to. Format: projects/{project_id}.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_notebooks_instance#project GoogleNotebooksInstance#project}
Project *string `field:"required" json:"project" yaml:"project"`
// Use this VM image family to find the image; the newest image in this family will be used.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_notebooks_instance#image_family GoogleNotebooksInstance#image_family}
ImageFamily *string `field:"optional" json:"imageFamily" yaml:"imageFamily"`
// Use VM image name to find the image.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.1.0/docs/resources/google_notebooks_instance#image_name GoogleNotebooksInstance#image_name}
ImageName *string `field:"optional" json:"imageName" yaml:"imageName"`
}
type GoogleNotebooksInstanceVmImageOutputReference ¶
type GoogleNotebooksInstanceVmImageOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
ImageFamily() *string
SetImageFamily(val *string)
ImageFamilyInput() *string
ImageName() *string
SetImageName(val *string)
ImageNameInput() *string
InternalValue() *GoogleNotebooksInstanceVmImage
SetInternalValue(val *GoogleNotebooksInstanceVmImage)
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetImageFamily()
ResetImageName()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleNotebooksInstanceVmImageOutputReference ¶
func NewGoogleNotebooksInstanceVmImageOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleNotebooksInstanceVmImageOutputReference
Source Files
¶
- GoogleNotebooksInstance.go
- GoogleNotebooksInstanceAcceleratorConfig.go
- GoogleNotebooksInstanceAcceleratorConfigOutputReference.go
- GoogleNotebooksInstanceAcceleratorConfigOutputReference__checks.go
- GoogleNotebooksInstanceConfig.go
- GoogleNotebooksInstanceContainerImage.go
- GoogleNotebooksInstanceContainerImageOutputReference.go
- GoogleNotebooksInstanceContainerImageOutputReference__checks.go
- GoogleNotebooksInstanceReservationAffinity.go
- GoogleNotebooksInstanceReservationAffinityOutputReference.go
- GoogleNotebooksInstanceReservationAffinityOutputReference__checks.go
- GoogleNotebooksInstanceShieldedInstanceConfig.go
- GoogleNotebooksInstanceShieldedInstanceConfigOutputReference.go
- GoogleNotebooksInstanceShieldedInstanceConfigOutputReference__checks.go
- GoogleNotebooksInstanceTimeouts.go
- GoogleNotebooksInstanceTimeoutsOutputReference.go
- GoogleNotebooksInstanceTimeoutsOutputReference__checks.go
- GoogleNotebooksInstanceVmImage.go
- GoogleNotebooksInstanceVmImageOutputReference.go
- GoogleNotebooksInstanceVmImageOutputReference__checks.go
- GoogleNotebooksInstance__checks.go
- main.go