Documentation
¶
Index ¶
- func GoogleOrganizationIamCustomRole_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, ...) cdktf.ImportableResource
- func GoogleOrganizationIamCustomRole_IsConstruct(x interface{}) *bool
- func GoogleOrganizationIamCustomRole_IsTerraformElement(x interface{}) *bool
- func GoogleOrganizationIamCustomRole_IsTerraformResource(x interface{}) *bool
- func GoogleOrganizationIamCustomRole_TfResourceType() *string
- func NewGoogleOrganizationIamCustomRole_Override(g GoogleOrganizationIamCustomRole, scope constructs.Construct, id *string, ...)
- type GoogleOrganizationIamCustomRole
- type GoogleOrganizationIamCustomRoleConfig
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleOrganizationIamCustomRole_GenerateConfigForImport ¶
func GoogleOrganizationIamCustomRole_GenerateConfigForImport(scope constructs.Construct, importToId *string, importFromId *string, provider cdktf.TerraformProvider) cdktf.ImportableResource
Generates CDKTF code for importing a GoogleOrganizationIamCustomRole resource upon running "cdktf plan <stack-name>".
func GoogleOrganizationIamCustomRole_IsConstruct ¶
func GoogleOrganizationIamCustomRole_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleOrganizationIamCustomRole_IsTerraformElement ¶
func GoogleOrganizationIamCustomRole_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleOrganizationIamCustomRole_IsTerraformResource ¶
func GoogleOrganizationIamCustomRole_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleOrganizationIamCustomRole_TfResourceType ¶
func GoogleOrganizationIamCustomRole_TfResourceType() *string
func NewGoogleOrganizationIamCustomRole_Override ¶
func NewGoogleOrganizationIamCustomRole_Override(g GoogleOrganizationIamCustomRole, scope constructs.Construct, id *string, config *GoogleOrganizationIamCustomRoleConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_organization_iam_custom_role google_organization_iam_custom_role} Resource.
Types ¶
type GoogleOrganizationIamCustomRole ¶
type GoogleOrganizationIamCustomRole interface {
cdktf.TerraformResource
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
Deleted() cdktf.IResolvable
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
Description() *string
SetDescription(val *string)
DescriptionInput() *string
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
// The tree node.
Node() constructs.Node
OrgId() *string
SetOrgId(val *string)
OrgIdInput() *string
Permissions() *[]*string
SetPermissions(val *[]*string)
PermissionsInput() *[]*string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
// Experimental.
RawOverrides() interface{}
RoleId() *string
SetRoleId(val *string)
RoleIdInput() *string
Stage() *string
SetStage(val *string)
StageInput() *string
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Title() *string
SetTitle(val *string)
TitleInput() *string
// Adds a user defined moveTarget string to this resource to be later used in .moveTo(moveTarget) to resolve the location of the move.
// Experimental.
AddMoveTarget(moveTarget *string)
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
HasResourceMove() interface{}
// Experimental.
ImportFrom(id *string, provider cdktf.TerraformProvider)
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Move the resource corresponding to "id" to this resource.
//
// Note that the resource being moved from must be marked as moved using it's instance function.
// Experimental.
MoveFromId(id *string)
// Moves this resource to the target resource given by moveTarget.
// Experimental.
MoveTo(moveTarget *string, index interface{})
// Moves this resource to the resource corresponding to "id".
// Experimental.
MoveToId(id *string)
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
ResetDescription()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetStage()
SynthesizeAttributes() *map[string]interface{}
SynthesizeHclAttributes() *map[string]interface{}
// Experimental.
ToHclTerraform() interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_organization_iam_custom_role google_organization_iam_custom_role}.
func NewGoogleOrganizationIamCustomRole ¶
func NewGoogleOrganizationIamCustomRole(scope constructs.Construct, id *string, config *GoogleOrganizationIamCustomRoleConfig) GoogleOrganizationIamCustomRole
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_organization_iam_custom_role google_organization_iam_custom_role} Resource.
type GoogleOrganizationIamCustomRoleConfig ¶
type GoogleOrganizationIamCustomRoleConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// The numeric ID of the organization in which you want to create a custom role.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_organization_iam_custom_role#org_id GoogleOrganizationIamCustomRole#org_id}
OrgId *string `field:"required" json:"orgId" yaml:"orgId"`
// The names of the permissions this role grants when bound in an IAM policy.
//
// At least one permission must be specified.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_organization_iam_custom_role#permissions GoogleOrganizationIamCustomRole#permissions}
Permissions *[]*string `field:"required" json:"permissions" yaml:"permissions"`
// The role id to use for this role.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_organization_iam_custom_role#role_id GoogleOrganizationIamCustomRole#role_id}
RoleId *string `field:"required" json:"roleId" yaml:"roleId"`
// A human-readable title for the role.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_organization_iam_custom_role#title GoogleOrganizationIamCustomRole#title}
Title *string `field:"required" json:"title" yaml:"title"`
// A human-readable description for the role.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_organization_iam_custom_role#description GoogleOrganizationIamCustomRole#description}
Description *string `field:"optional" json:"description" yaml:"description"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_organization_iam_custom_role#id GoogleOrganizationIamCustomRole#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// The current launch stage of the role. Defaults to GA.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/6.37.0/docs/resources/google_organization_iam_custom_role#stage GoogleOrganizationIamCustomRole#stage}
Stage *string `field:"optional" json:"stage" yaml:"stage"`
}