Documentation
¶
Index ¶
- func GoogleIdentityPlatformConfig_IsConstruct(x interface{}) *bool
- func GoogleIdentityPlatformConfig_IsTerraformElement(x interface{}) *bool
- func GoogleIdentityPlatformConfig_IsTerraformResource(x interface{}) *bool
- func GoogleIdentityPlatformConfig_TfResourceType() *string
- func NewGoogleIdentityPlatformConfigBlockingFunctionsForwardInboundCredentialsOutputReference_Override(...)
- func NewGoogleIdentityPlatformConfigBlockingFunctionsOutputReference_Override(g GoogleIdentityPlatformConfigBlockingFunctionsOutputReference, ...)
- func NewGoogleIdentityPlatformConfigBlockingFunctionsTriggersList_Override(g GoogleIdentityPlatformConfigBlockingFunctionsTriggersList, ...)
- func NewGoogleIdentityPlatformConfigBlockingFunctionsTriggersOutputReference_Override(g GoogleIdentityPlatformConfigBlockingFunctionsTriggersOutputReference, ...)
- func NewGoogleIdentityPlatformConfigQuotaOutputReference_Override(g GoogleIdentityPlatformConfigQuotaOutputReference, ...)
- func NewGoogleIdentityPlatformConfigQuotaSignUpQuotaConfigOutputReference_Override(g GoogleIdentityPlatformConfigQuotaSignUpQuotaConfigOutputReference, ...)
- func NewGoogleIdentityPlatformConfigTimeoutsOutputReference_Override(g GoogleIdentityPlatformConfigTimeoutsOutputReference, ...)
- func NewGoogleIdentityPlatformConfig_Override(g GoogleIdentityPlatformConfig, scope constructs.Construct, id *string, ...)
- type GoogleIdentityPlatformConfig
- type GoogleIdentityPlatformConfigBlockingFunctions
- type GoogleIdentityPlatformConfigBlockingFunctionsForwardInboundCredentials
- type GoogleIdentityPlatformConfigBlockingFunctionsForwardInboundCredentialsOutputReference
- type GoogleIdentityPlatformConfigBlockingFunctionsOutputReference
- type GoogleIdentityPlatformConfigBlockingFunctionsTriggers
- type GoogleIdentityPlatformConfigBlockingFunctionsTriggersList
- type GoogleIdentityPlatformConfigBlockingFunctionsTriggersOutputReference
- type GoogleIdentityPlatformConfigConfig
- type GoogleIdentityPlatformConfigQuota
- type GoogleIdentityPlatformConfigQuotaOutputReference
- type GoogleIdentityPlatformConfigQuotaSignUpQuotaConfig
- type GoogleIdentityPlatformConfigQuotaSignUpQuotaConfigOutputReference
- type GoogleIdentityPlatformConfigTimeouts
- type GoogleIdentityPlatformConfigTimeoutsOutputReference
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GoogleIdentityPlatformConfig_IsConstruct ¶
func GoogleIdentityPlatformConfig_IsConstruct(x interface{}) *bool
Checks if `x` is a construct.
Use this method instead of `instanceof` to properly detect `Construct` instances, even when the construct library is symlinked.
Explanation: in JavaScript, multiple copies of the `constructs` library on disk are seen as independent, completely different libraries. As a consequence, the class `Construct` in each copy of the `constructs` library is seen as a different class, and an instance of one class will not test as `instanceof` the other class. `npm install` will not create installations like this, but users may manually symlink construct libraries together or use a monorepo tool: in those cases, multiple copies of the `constructs` library can be accidentally installed, and `instanceof` will behave unpredictably. It is safest to avoid using `instanceof`, and using this type-testing method instead.
Returns: true if `x` is an object created from a class which extends `Construct`.
func GoogleIdentityPlatformConfig_IsTerraformElement ¶
func GoogleIdentityPlatformConfig_IsTerraformElement(x interface{}) *bool
Experimental.
func GoogleIdentityPlatformConfig_IsTerraformResource ¶
func GoogleIdentityPlatformConfig_IsTerraformResource(x interface{}) *bool
Experimental.
func GoogleIdentityPlatformConfig_TfResourceType ¶
func GoogleIdentityPlatformConfig_TfResourceType() *string
func NewGoogleIdentityPlatformConfigBlockingFunctionsForwardInboundCredentialsOutputReference_Override ¶ added in v8.0.9
func NewGoogleIdentityPlatformConfigBlockingFunctionsForwardInboundCredentialsOutputReference_Override(g GoogleIdentityPlatformConfigBlockingFunctionsForwardInboundCredentialsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleIdentityPlatformConfigBlockingFunctionsOutputReference_Override ¶ added in v8.0.9
func NewGoogleIdentityPlatformConfigBlockingFunctionsOutputReference_Override(g GoogleIdentityPlatformConfigBlockingFunctionsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleIdentityPlatformConfigBlockingFunctionsTriggersList_Override ¶ added in v8.0.9
func NewGoogleIdentityPlatformConfigBlockingFunctionsTriggersList_Override(g GoogleIdentityPlatformConfigBlockingFunctionsTriggersList, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool)
func NewGoogleIdentityPlatformConfigBlockingFunctionsTriggersOutputReference_Override ¶ added in v8.0.9
func NewGoogleIdentityPlatformConfigBlockingFunctionsTriggersOutputReference_Override(g GoogleIdentityPlatformConfigBlockingFunctionsTriggersOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool)
func NewGoogleIdentityPlatformConfigQuotaOutputReference_Override ¶ added in v8.0.9
func NewGoogleIdentityPlatformConfigQuotaOutputReference_Override(g GoogleIdentityPlatformConfigQuotaOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleIdentityPlatformConfigQuotaSignUpQuotaConfigOutputReference_Override ¶ added in v8.0.9
func NewGoogleIdentityPlatformConfigQuotaSignUpQuotaConfigOutputReference_Override(g GoogleIdentityPlatformConfigQuotaSignUpQuotaConfigOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleIdentityPlatformConfigTimeoutsOutputReference_Override ¶
func NewGoogleIdentityPlatformConfigTimeoutsOutputReference_Override(g GoogleIdentityPlatformConfigTimeoutsOutputReference, terraformResource cdktf.IInterpolatingParent, terraformAttribute *string)
func NewGoogleIdentityPlatformConfig_Override ¶
func NewGoogleIdentityPlatformConfig_Override(g GoogleIdentityPlatformConfig, scope constructs.Construct, id *string, config *GoogleIdentityPlatformConfigConfig)
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.79.0/docs/resources/google_identity_platform_config google_identity_platform_config} Resource.
Types ¶
type GoogleIdentityPlatformConfig ¶
type GoogleIdentityPlatformConfig interface {
cdktf.TerraformResource
AuthorizedDomains() *[]*string
SetAuthorizedDomains(val *[]*string)
AuthorizedDomainsInput() *[]*string
AutodeleteAnonymousUsers() interface{}
SetAutodeleteAnonymousUsers(val interface{})
AutodeleteAnonymousUsersInput() interface{}
BlockingFunctions() GoogleIdentityPlatformConfigBlockingFunctionsOutputReference
BlockingFunctionsInput() *GoogleIdentityPlatformConfigBlockingFunctions
// Experimental.
CdktfStack() cdktf.TerraformStack
// Experimental.
Connection() interface{}
// Experimental.
SetConnection(val interface{})
// Experimental.
ConstructNodeMetadata() *map[string]interface{}
// Experimental.
Count() interface{}
// Experimental.
SetCount(val interface{})
// Experimental.
DependsOn() *[]*string
// Experimental.
SetDependsOn(val *[]*string)
// Experimental.
ForEach() cdktf.ITerraformIterator
// Experimental.
SetForEach(val cdktf.ITerraformIterator)
// Experimental.
Fqn() *string
// Experimental.
FriendlyUniqueId() *string
Id() *string
SetId(val *string)
IdInput() *string
// Experimental.
Lifecycle() *cdktf.TerraformResourceLifecycle
// Experimental.
SetLifecycle(val *cdktf.TerraformResourceLifecycle)
Name() *string
// The tree node.
Node() constructs.Node
Project() *string
SetProject(val *string)
ProjectInput() *string
// Experimental.
Provider() cdktf.TerraformProvider
// Experimental.
SetProvider(val cdktf.TerraformProvider)
// Experimental.
Provisioners() *[]interface{}
// Experimental.
SetProvisioners(val *[]interface{})
Quota() GoogleIdentityPlatformConfigQuotaOutputReference
QuotaInput() *GoogleIdentityPlatformConfigQuota
// Experimental.
RawOverrides() interface{}
// Experimental.
TerraformGeneratorMetadata() *cdktf.TerraformProviderGeneratorMetadata
// Experimental.
TerraformMetaArguments() *map[string]interface{}
// Experimental.
TerraformResourceType() *string
Timeouts() GoogleIdentityPlatformConfigTimeoutsOutputReference
TimeoutsInput() interface{}
// Experimental.
AddOverride(path *string, value interface{})
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationForAttribute(terraformAttribute *string) cdktf.IResolvable
// Overrides the auto-generated logical ID with a specific ID.
// Experimental.
OverrideLogicalId(newLogicalId *string)
PutBlockingFunctions(value *GoogleIdentityPlatformConfigBlockingFunctions)
PutQuota(value *GoogleIdentityPlatformConfigQuota)
PutTimeouts(value *GoogleIdentityPlatformConfigTimeouts)
ResetAuthorizedDomains()
ResetAutodeleteAnonymousUsers()
ResetBlockingFunctions()
ResetId()
// Resets a previously passed logical Id to use the auto-generated logical id again.
// Experimental.
ResetOverrideLogicalId()
ResetProject()
ResetQuota()
ResetTimeouts()
SynthesizeAttributes() *map[string]interface{}
// Experimental.
ToMetadata() interface{}
// Returns a string representation of this construct.
ToString() *string
// Adds this resource to the terraform JSON output.
// Experimental.
ToTerraform() interface{}
}
Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.79.0/docs/resources/google_identity_platform_config google_identity_platform_config}.
func NewGoogleIdentityPlatformConfig ¶
func NewGoogleIdentityPlatformConfig(scope constructs.Construct, id *string, config *GoogleIdentityPlatformConfigConfig) GoogleIdentityPlatformConfig
Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.79.0/docs/resources/google_identity_platform_config google_identity_platform_config} Resource.
type GoogleIdentityPlatformConfigBlockingFunctions ¶ added in v8.0.9
type GoogleIdentityPlatformConfigBlockingFunctions struct {
// triggers block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.79.0/docs/resources/google_identity_platform_config#triggers GoogleIdentityPlatformConfig#triggers}
Triggers interface{} `field:"required" json:"triggers" yaml:"triggers"`
// forward_inbound_credentials block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.79.0/docs/resources/google_identity_platform_config#forward_inbound_credentials GoogleIdentityPlatformConfig#forward_inbound_credentials}
ForwardInboundCredentials *GoogleIdentityPlatformConfigBlockingFunctionsForwardInboundCredentials `field:"optional" json:"forwardInboundCredentials" yaml:"forwardInboundCredentials"`
}
type GoogleIdentityPlatformConfigBlockingFunctionsForwardInboundCredentials ¶ added in v8.0.9
type GoogleIdentityPlatformConfigBlockingFunctionsForwardInboundCredentials struct {
// Whether to pass the user's OAuth identity provider's access token.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.79.0/docs/resources/google_identity_platform_config#access_token GoogleIdentityPlatformConfig#access_token}
AccessToken interface{} `field:"optional" json:"accessToken" yaml:"accessToken"`
// Whether to pass the user's OIDC identity provider's ID token.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.79.0/docs/resources/google_identity_platform_config#id_token GoogleIdentityPlatformConfig#id_token}
IdToken interface{} `field:"optional" json:"idToken" yaml:"idToken"`
// Whether to pass the user's OAuth identity provider's refresh token.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.79.0/docs/resources/google_identity_platform_config#refresh_token GoogleIdentityPlatformConfig#refresh_token}
RefreshToken interface{} `field:"optional" json:"refreshToken" yaml:"refreshToken"`
}
type GoogleIdentityPlatformConfigBlockingFunctionsForwardInboundCredentialsOutputReference ¶ added in v8.0.9
type GoogleIdentityPlatformConfigBlockingFunctionsForwardInboundCredentialsOutputReference interface {
cdktf.ComplexObject
AccessToken() interface{}
SetAccessToken(val interface{})
AccessTokenInput() interface{}
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
IdToken() interface{}
SetIdToken(val interface{})
IdTokenInput() interface{}
InternalValue() *GoogleIdentityPlatformConfigBlockingFunctionsForwardInboundCredentials
SetInternalValue(val *GoogleIdentityPlatformConfigBlockingFunctionsForwardInboundCredentials)
RefreshToken() interface{}
SetRefreshToken(val interface{})
RefreshTokenInput() interface{}
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetAccessToken()
ResetIdToken()
ResetRefreshToken()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleIdentityPlatformConfigBlockingFunctionsForwardInboundCredentialsOutputReference ¶ added in v8.0.9
func NewGoogleIdentityPlatformConfigBlockingFunctionsForwardInboundCredentialsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleIdentityPlatformConfigBlockingFunctionsForwardInboundCredentialsOutputReference
type GoogleIdentityPlatformConfigBlockingFunctionsOutputReference ¶ added in v8.0.9
type GoogleIdentityPlatformConfigBlockingFunctionsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
ForwardInboundCredentials() GoogleIdentityPlatformConfigBlockingFunctionsForwardInboundCredentialsOutputReference
ForwardInboundCredentialsInput() *GoogleIdentityPlatformConfigBlockingFunctionsForwardInboundCredentials
// Experimental.
Fqn() *string
InternalValue() *GoogleIdentityPlatformConfigBlockingFunctions
SetInternalValue(val *GoogleIdentityPlatformConfigBlockingFunctions)
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Triggers() GoogleIdentityPlatformConfigBlockingFunctionsTriggersList
TriggersInput() interface{}
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutForwardInboundCredentials(value *GoogleIdentityPlatformConfigBlockingFunctionsForwardInboundCredentials)
PutTriggers(value interface{})
ResetForwardInboundCredentials()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleIdentityPlatformConfigBlockingFunctionsOutputReference ¶ added in v8.0.9
func NewGoogleIdentityPlatformConfigBlockingFunctionsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleIdentityPlatformConfigBlockingFunctionsOutputReference
type GoogleIdentityPlatformConfigBlockingFunctionsTriggers ¶ added in v8.0.9
type GoogleIdentityPlatformConfigBlockingFunctionsTriggers struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.79.0/docs/resources/google_identity_platform_config#event_type GoogleIdentityPlatformConfig#event_type}.
EventType *string `field:"required" json:"eventType" yaml:"eventType"`
// HTTP URI trigger for the Cloud Function.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.79.0/docs/resources/google_identity_platform_config#function_uri GoogleIdentityPlatformConfig#function_uri}
FunctionUri *string `field:"required" json:"functionUri" yaml:"functionUri"`
}
type GoogleIdentityPlatformConfigBlockingFunctionsTriggersList ¶ added in v8.0.9
type GoogleIdentityPlatformConfigBlockingFunctionsTriggersList interface {
cdktf.ComplexList
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// The attribute on the parent resource this class is referencing.
TerraformAttribute() *string
SetTerraformAttribute(val *string)
// The parent resource.
TerraformResource() cdktf.IInterpolatingParent
SetTerraformResource(val cdktf.IInterpolatingParent)
// whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
WrapsSet() *bool
SetWrapsSet(val *bool)
// Experimental.
ComputeFqn() *string
Get(index *float64) GoogleIdentityPlatformConfigBlockingFunctionsTriggersOutputReference
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleIdentityPlatformConfigBlockingFunctionsTriggersList ¶ added in v8.0.9
func NewGoogleIdentityPlatformConfigBlockingFunctionsTriggersList(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, wrapsSet *bool) GoogleIdentityPlatformConfigBlockingFunctionsTriggersList
type GoogleIdentityPlatformConfigBlockingFunctionsTriggersOutputReference ¶ added in v8.0.9
type GoogleIdentityPlatformConfigBlockingFunctionsTriggersOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
EventType() *string
SetEventType(val *string)
EventTypeInput() *string
// Experimental.
Fqn() *string
FunctionUri() *string
SetFunctionUri(val *string)
FunctionUriInput() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
UpdateTime() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleIdentityPlatformConfigBlockingFunctionsTriggersOutputReference ¶ added in v8.0.9
func NewGoogleIdentityPlatformConfigBlockingFunctionsTriggersOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string, complexObjectIndex *float64, complexObjectIsFromSet *bool) GoogleIdentityPlatformConfigBlockingFunctionsTriggersOutputReference
type GoogleIdentityPlatformConfigConfig ¶
type GoogleIdentityPlatformConfigConfig struct {
// Experimental.
Connection interface{} `field:"optional" json:"connection" yaml:"connection"`
// Experimental.
Count interface{} `field:"optional" json:"count" yaml:"count"`
// Experimental.
DependsOn *[]cdktf.ITerraformDependable `field:"optional" json:"dependsOn" yaml:"dependsOn"`
// Experimental.
ForEach cdktf.ITerraformIterator `field:"optional" json:"forEach" yaml:"forEach"`
// Experimental.
Lifecycle *cdktf.TerraformResourceLifecycle `field:"optional" json:"lifecycle" yaml:"lifecycle"`
// Experimental.
Provider cdktf.TerraformProvider `field:"optional" json:"provider" yaml:"provider"`
// Experimental.
Provisioners *[]interface{} `field:"optional" json:"provisioners" yaml:"provisioners"`
// List of domains authorized for OAuth redirects.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.79.0/docs/resources/google_identity_platform_config#authorized_domains GoogleIdentityPlatformConfig#authorized_domains}
AuthorizedDomains *[]*string `field:"optional" json:"authorizedDomains" yaml:"authorizedDomains"`
// Whether anonymous users will be auto-deleted after a period of 30 days.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.79.0/docs/resources/google_identity_platform_config#autodelete_anonymous_users GoogleIdentityPlatformConfig#autodelete_anonymous_users}
AutodeleteAnonymousUsers interface{} `field:"optional" json:"autodeleteAnonymousUsers" yaml:"autodeleteAnonymousUsers"`
// blocking_functions block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.79.0/docs/resources/google_identity_platform_config#blocking_functions GoogleIdentityPlatformConfig#blocking_functions}
BlockingFunctions *GoogleIdentityPlatformConfigBlockingFunctions `field:"optional" json:"blockingFunctions" yaml:"blockingFunctions"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.79.0/docs/resources/google_identity_platform_config#id GoogleIdentityPlatformConfig#id}.
//
// Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
// If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
Id *string `field:"optional" json:"id" yaml:"id"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.79.0/docs/resources/google_identity_platform_config#project GoogleIdentityPlatformConfig#project}.
Project *string `field:"optional" json:"project" yaml:"project"`
// quota block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.79.0/docs/resources/google_identity_platform_config#quota GoogleIdentityPlatformConfig#quota}
Quota *GoogleIdentityPlatformConfigQuota `field:"optional" json:"quota" yaml:"quota"`
// timeouts block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.79.0/docs/resources/google_identity_platform_config#timeouts GoogleIdentityPlatformConfig#timeouts}
Timeouts *GoogleIdentityPlatformConfigTimeouts `field:"optional" json:"timeouts" yaml:"timeouts"`
}
type GoogleIdentityPlatformConfigQuota ¶ added in v8.0.9
type GoogleIdentityPlatformConfigQuota struct {
// sign_up_quota_config block.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.79.0/docs/resources/google_identity_platform_config#sign_up_quota_config GoogleIdentityPlatformConfig#sign_up_quota_config}
SignUpQuotaConfig *GoogleIdentityPlatformConfigQuotaSignUpQuotaConfig `field:"optional" json:"signUpQuotaConfig" yaml:"signUpQuotaConfig"`
}
type GoogleIdentityPlatformConfigQuotaOutputReference ¶ added in v8.0.9
type GoogleIdentityPlatformConfigQuotaOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleIdentityPlatformConfigQuota
SetInternalValue(val *GoogleIdentityPlatformConfigQuota)
SignUpQuotaConfig() GoogleIdentityPlatformConfigQuotaSignUpQuotaConfigOutputReference
SignUpQuotaConfigInput() *GoogleIdentityPlatformConfigQuotaSignUpQuotaConfig
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
PutSignUpQuotaConfig(value *GoogleIdentityPlatformConfigQuotaSignUpQuotaConfig)
ResetSignUpQuotaConfig()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleIdentityPlatformConfigQuotaOutputReference ¶ added in v8.0.9
func NewGoogleIdentityPlatformConfigQuotaOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleIdentityPlatformConfigQuotaOutputReference
type GoogleIdentityPlatformConfigQuotaSignUpQuotaConfig ¶ added in v8.0.9
type GoogleIdentityPlatformConfigQuotaSignUpQuotaConfig struct {
// A sign up APIs quota that customers can override temporarily.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.79.0/docs/resources/google_identity_platform_config#quota GoogleIdentityPlatformConfig#quota}
Quota *float64 `field:"optional" json:"quota" yaml:"quota"`
// How long this quota will be active for. It is measurred in seconds, e.g., Example: "9.615s".
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.79.0/docs/resources/google_identity_platform_config#quota_duration GoogleIdentityPlatformConfig#quota_duration}
QuotaDuration *string `field:"optional" json:"quotaDuration" yaml:"quotaDuration"`
// When this quota will take affect.
//
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.79.0/docs/resources/google_identity_platform_config#start_time GoogleIdentityPlatformConfig#start_time}
StartTime *string `field:"optional" json:"startTime" yaml:"startTime"`
}
type GoogleIdentityPlatformConfigQuotaSignUpQuotaConfigOutputReference ¶ added in v8.0.9
type GoogleIdentityPlatformConfigQuotaSignUpQuotaConfigOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
// Experimental.
Fqn() *string
InternalValue() *GoogleIdentityPlatformConfigQuotaSignUpQuotaConfig
SetInternalValue(val *GoogleIdentityPlatformConfigQuotaSignUpQuotaConfig)
Quota() *float64
SetQuota(val *float64)
QuotaDuration() *string
SetQuotaDuration(val *string)
QuotaDurationInput() *string
QuotaInput() *float64
StartTime() *string
SetStartTime(val *string)
StartTimeInput() *string
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetQuota()
ResetQuotaDuration()
ResetStartTime()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleIdentityPlatformConfigQuotaSignUpQuotaConfigOutputReference ¶ added in v8.0.9
func NewGoogleIdentityPlatformConfigQuotaSignUpQuotaConfigOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleIdentityPlatformConfigQuotaSignUpQuotaConfigOutputReference
type GoogleIdentityPlatformConfigTimeouts ¶
type GoogleIdentityPlatformConfigTimeouts struct {
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.79.0/docs/resources/google_identity_platform_config#create GoogleIdentityPlatformConfig#create}.
Create *string `field:"optional" json:"create" yaml:"create"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.79.0/docs/resources/google_identity_platform_config#delete GoogleIdentityPlatformConfig#delete}.
Delete *string `field:"optional" json:"delete" yaml:"delete"`
// Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.79.0/docs/resources/google_identity_platform_config#update GoogleIdentityPlatformConfig#update}.
Update *string `field:"optional" json:"update" yaml:"update"`
}
type GoogleIdentityPlatformConfigTimeoutsOutputReference ¶
type GoogleIdentityPlatformConfigTimeoutsOutputReference interface {
cdktf.ComplexObject
// the index of the complex object in a list.
// Experimental.
ComplexObjectIndex() interface{}
// Experimental.
SetComplexObjectIndex(val interface{})
// set to true if this item is from inside a set and needs tolist() for accessing it set to "0" for single list items.
// Experimental.
ComplexObjectIsFromSet() *bool
// Experimental.
SetComplexObjectIsFromSet(val *bool)
Create() *string
SetCreate(val *string)
CreateInput() *string
// The creation stack of this resolvable which will be appended to errors thrown during resolution.
//
// If this returns an empty array the stack will not be attached.
// Experimental.
CreationStack() *[]*string
Delete() *string
SetDelete(val *string)
DeleteInput() *string
// Experimental.
Fqn() *string
InternalValue() interface{}
SetInternalValue(val interface{})
// Experimental.
TerraformAttribute() *string
// Experimental.
SetTerraformAttribute(val *string)
// Experimental.
TerraformResource() cdktf.IInterpolatingParent
// Experimental.
SetTerraformResource(val cdktf.IInterpolatingParent)
Update() *string
SetUpdate(val *string)
UpdateInput() *string
// Experimental.
ComputeFqn() *string
// Experimental.
GetAnyMapAttribute(terraformAttribute *string) *map[string]interface{}
// Experimental.
GetBooleanAttribute(terraformAttribute *string) cdktf.IResolvable
// Experimental.
GetBooleanMapAttribute(terraformAttribute *string) *map[string]*bool
// Experimental.
GetListAttribute(terraformAttribute *string) *[]*string
// Experimental.
GetNumberAttribute(terraformAttribute *string) *float64
// Experimental.
GetNumberListAttribute(terraformAttribute *string) *[]*float64
// Experimental.
GetNumberMapAttribute(terraformAttribute *string) *map[string]*float64
// Experimental.
GetStringAttribute(terraformAttribute *string) *string
// Experimental.
GetStringMapAttribute(terraformAttribute *string) *map[string]*string
// Experimental.
InterpolationAsList() cdktf.IResolvable
// Experimental.
InterpolationForAttribute(property *string) cdktf.IResolvable
ResetCreate()
ResetDelete()
ResetUpdate()
// Produce the Token's value at resolution time.
// Experimental.
Resolve(_context cdktf.IResolveContext) interface{}
// Return a string representation of this resolvable object.
//
// Returns a reversible string representation.
// Experimental.
ToString() *string
}
func NewGoogleIdentityPlatformConfigTimeoutsOutputReference ¶
func NewGoogleIdentityPlatformConfigTimeoutsOutputReference(terraformResource cdktf.IInterpolatingParent, terraformAttribute *string) GoogleIdentityPlatformConfigTimeoutsOutputReference
Source Files
¶
- GoogleIdentityPlatformConfig.go
- GoogleIdentityPlatformConfigBlockingFunctions.go
- GoogleIdentityPlatformConfigBlockingFunctionsForwardInboundCredentials.go
- GoogleIdentityPlatformConfigBlockingFunctionsForwardInboundCredentialsOutputReference.go
- GoogleIdentityPlatformConfigBlockingFunctionsForwardInboundCredentialsOutputReference__checks.go
- GoogleIdentityPlatformConfigBlockingFunctionsOutputReference.go
- GoogleIdentityPlatformConfigBlockingFunctionsOutputReference__checks.go
- GoogleIdentityPlatformConfigBlockingFunctionsTriggers.go
- GoogleIdentityPlatformConfigBlockingFunctionsTriggersList.go
- GoogleIdentityPlatformConfigBlockingFunctionsTriggersList__checks.go
- GoogleIdentityPlatformConfigBlockingFunctionsTriggersOutputReference.go
- GoogleIdentityPlatformConfigBlockingFunctionsTriggersOutputReference__checks.go
- GoogleIdentityPlatformConfigConfig.go
- GoogleIdentityPlatformConfigQuota.go
- GoogleIdentityPlatformConfigQuotaOutputReference.go
- GoogleIdentityPlatformConfigQuotaOutputReference__checks.go
- GoogleIdentityPlatformConfigQuotaSignUpQuotaConfig.go
- GoogleIdentityPlatformConfigQuotaSignUpQuotaConfigOutputReference.go
- GoogleIdentityPlatformConfigQuotaSignUpQuotaConfigOutputReference__checks.go
- GoogleIdentityPlatformConfigTimeouts.go
- GoogleIdentityPlatformConfigTimeoutsOutputReference.go
- GoogleIdentityPlatformConfigTimeoutsOutputReference__checks.go
- GoogleIdentityPlatformConfig__checks.go
- main.go